#    pythonequations is a collection of equations expressed as Python classes
#    Copyright (C) 2008 James R. Phillips
#    2548 Vera Cruz Drive
#    Birmingham, AL 35235 USA
#    email: zunzun@zunzun.com
#
#    Version info: $Id: Miscellaneous.py 32 2008-11-01 11:16:48Z zunzun.com $
#
#    License: BSD-style (see LICENSE.txt in main source directory)

import pythonequations, pythonequations.EquationBaseClasses
import numpy
numpy.seterr(all = 'raise') # numpy raises warnings, convert to exceptions to trap them

class TobyBarrusCustomLogisticA2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Toby Barrus 5-Parameter Custom Logistic Equation"
        self.HTML = "y = d + (a - d) / (1 + (x / c)<sup>b</sup> )<sup>g</sup>"
        self.coefficientDesignatorTuple = ('a', 'b', 'c', 'd', 'g')

        self.function_cpp_code = 'temp = coeff[3] + ((coeff[0] - coeff[3]) / pow(1.0 + pow(indep_data[(int)cachedWeaveOffsets[0] + i] / coeff[2], coeff[1]), coeff[4]));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1] + "\n"


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = d + ((a - d) / pow(1.0 + pow(x_in / c), b), g));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = d + ((a - d) / Math.pow(1.0 + Math.pow(x_in / c), b), g));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = d + ((a - d) / Math.Pow(1.0 + Math.Pow(x_in / c), b), g));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\t\ttemp = d + ((a - d) / math.pow(1.0 + math.pow(x_in / c), b), g))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\t\ttemp = d + ((a - d) / pow(1.0 + pow(x_in / c), b), g))\n"
        return s


class TobyBarrusCustomLogisticA_LinearDecay_2D(TobyBarrusCustomLogisticA2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class TobyBarrusCustomLogisticA_ExponentialDecay_2D(TobyBarrusCustomLogisticA2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class TobyBarrusCustomLogisticA_LinearGrowth_2D(TobyBarrusCustomLogisticA2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class TobyBarrusCustomLogisticA_ExponentialGrowth_2D(TobyBarrusCustomLogisticA2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class TobyBarrusCustomLogisticA_LinearDecayAndOffset_2D(TobyBarrusCustomLogisticA2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class TobyBarrusCustomLogisticA_ExponentialDecayAndOffset_2D(TobyBarrusCustomLogisticA2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class TobyBarrusCustomLogisticA_LinearGrowthAndOffset_2D(TobyBarrusCustomLogisticA2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class TobyBarrusCustomLogisticA_ExponentialGrowthAndOffset_2D(TobyBarrusCustomLogisticA2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class TobyBarrusCustomLogisticB2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Toby Barrus 4-Parameter Custom Logistic Equation"
        self.HTML = "y = d + (a - d) / (1 + (x / c)<sup>b</sup>)"
        self.coefficientDesignatorTuple = ('a', 'b', 'c', 'd')

        self.function_cpp_code = 'temp = coeff[3] + ((coeff[0] - coeff[3]) / (1.0 + pow(indep_data[(int)cachedWeaveOffsets[0] + i] / coeff[2], coeff[1])));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1] + "\n"


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = d + ((a - d) / (1.0 + pow(x_in / c), b)));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = d + ((a - d) / (1.0 + Math.pow(x_in / c), b)));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = d + ((a - d) / (1.0 + Math.Pow(x_in / c), b)));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\t\ttemp = d + ((a - d) / (1.0 + math.pow(x_in / c), b)))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\t\ttemp = d + ((a - d) / (1.0 + pow(x_in / c), b)))\n"
        return s


class TobyBarrusCustomLogisticB_LinearDecay_2D(TobyBarrusCustomLogisticB2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class TobyBarrusCustomLogisticB_ExponentialDecay_2D(TobyBarrusCustomLogisticB2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class TobyBarrusCustomLogisticB_LinearGrowth_2D(TobyBarrusCustomLogisticB2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class TobyBarrusCustomLogisticB_ExponentialGrowth_2D(TobyBarrusCustomLogisticB2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class TobyBarrusCustomLogisticB_LinearDecayAndOffset_2D(TobyBarrusCustomLogisticB2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class TobyBarrusCustomLogisticB_ExponentialDecayAndOffset_2D(TobyBarrusCustomLogisticB2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class TobyBarrusCustomLogisticB_LinearGrowthAndOffset_2D(TobyBarrusCustomLogisticB2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class TobyBarrusCustomLogisticB_ExponentialGrowthAndOffset_2D(TobyBarrusCustomLogisticB2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class TobyBarrusCustomLogisticC2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Toby Barrus 3-Parameter Custom Logistic Equation"
        self.HTML = "y = d + (a - d) / (1 + (x / c))"
        self.coefficientDesignatorTuple = ('a', 'c', 'd')

        self.function_cpp_code = 'temp = coeff[2] + ((coeff[0] - coeff[2]) / (1.0 + (indep_data[(int)cachedWeaveOffsets[0] + i] / coeff[1])));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1] + "\n"


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = d + ((a - d) / (1.0 + (x_in / c)));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = d + ((a - d) / (1.0 + (x_in / c)));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = d + ((a - d) / (1.0 + (x_in / c)));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\t\ttemp = d + ((a - d) / (1.0 + (x_in / c)))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\t\ttemp = d + ((a - d) / (1.0 + (x_in / c)))\n"
        return s


class TobyBarrusCustomLogisticC_LinearDecay_2D(TobyBarrusCustomLogisticC2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class TobyBarrusCustomLogisticC_ExponentialDecay_2D(TobyBarrusCustomLogisticC2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class TobyBarrusCustomLogisticC_LinearGrowth_2D(TobyBarrusCustomLogisticC2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class TobyBarrusCustomLogisticC_ExponentialGrowth_2D(TobyBarrusCustomLogisticC2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class TobyBarrusCustomLogisticC_LinearDecayAndOffset_2D(TobyBarrusCustomLogisticC2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class TobyBarrusCustomLogisticC_ExponentialDecayAndOffset_2D(TobyBarrusCustomLogisticC2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class TobyBarrusCustomLogisticC_LinearGrowthAndOffset_2D(TobyBarrusCustomLogisticC2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class TobyBarrusCustomLogisticC_ExponentialGrowthAndOffset_2D(TobyBarrusCustomLogisticC2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class BertalanffyGrowth2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "von Bertalanffy Growth"
        self.HTML = "L(t) = L<sub>&#8734;</sub> * (1.0 - e<SUP>-K * (t-t<sub>0</sub>)</SUP>)"
        self.coefficientDesignatorTuple = ("Linf", "K",  "tzero")

        self.function_cpp_code = 'temp = coeff[0] * (1.0 - exp(-1.0 * coeff[1] * (indep_data[(int)cachedWeaveOffsets[0] + i] - coeff[2])));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1] + "\n"


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = Linf * (1.0 - exp(-1.0 * K * x_in));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = Linf * (1.0 - Math.exp(-1.0 * K * x_in));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = Linf * (1.0 - Math.Exp(-1.0 * K * x_in));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\t\ttemp = Linf * (1.0 - math.exp(-1.0 * K * x_in))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\t\ttemp = Linf * (1.0 - exp(-1.0 * K * x_in))\n"
        return s


class BertalanffyGrowth_LinearDecay_2D(BertalanffyGrowth2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class BertalanffyGrowth_ExponentialDecay_2D(BertalanffyGrowth2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class BertalanffyGrowth_LinearGrowth_2D(BertalanffyGrowth2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class BertalanffyGrowth_ExponentialGrowth_2D(BertalanffyGrowth2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class BertalanffyGrowth_LinearDecayAndOffset_2D(BertalanffyGrowth2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class BertalanffyGrowth_ExponentialDecayAndOffset_2D(BertalanffyGrowth2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class BertalanffyGrowth_LinearGrowthAndOffset_2D(BertalanffyGrowth2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class BertalanffyGrowth_ExponentialGrowthAndOffset_2D(BertalanffyGrowth2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class MichaelisMenten2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Michaelis-Menten"
        self.HTML = "y = ax / (b + x)"
        self.coefficientDesignatorTuple = ("a", "b")

        self.function_cpp_code = 'temp = (coeff[0] * indep_data[(int)cachedWeaveOffsets[0] + i]) / (coeff[1] + indep_data[(int)cachedWeaveOffsets[0] + i]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1] + "\n"


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = (a * x_in)) / (b + x_in);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = (a * x_in)) / (b + x_in);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = (a * x_in)) / (b + x_in);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\t\ttemp = (a * x_in)) / (b + x_in)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\t\ttemp = (a * x_in)) / (b + x_in)\n"
        return s


class MichaelisMenten_WO_2D(MichaelisMenten2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class MichaelisMenten_LinearDecay_2D(MichaelisMenten2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class MichaelisMenten_ExponentialDecay_2D(MichaelisMenten2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class MichaelisMenten_LinearGrowth_2D(MichaelisMenten2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class MichaelisMenten_ExponentialGrowth_2D(MichaelisMenten2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class MichaelisMenten_LinearDecayAndOffset_2D(MichaelisMenten2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class MichaelisMenten_ExponentialDecayAndOffset_2D(MichaelisMenten2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class MichaelisMenten_LinearGrowthAndOffset_2D(MichaelisMenten2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class MichaelisMenten_ExponentialGrowthAndOffset_2D(MichaelisMenten2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class HyperbolicLogistic2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Hyperbolic Logistic"
        self.HTML = "y = ax<sup>b</sup> / (c + x<sup>b</sup>)"
        self.coefficientDesignatorTuple = ("a", "b", "c")

        self.function_cpp_code = 'temp = (coeff[0] * pow(indep_data[(int)cachedWeaveOffsets[0] + i], coeff[1])) / (coeff[2] + pow(indep_data[(int)cachedWeaveOffsets[0] + i], coeff[1]));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1] + "\n"


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = (a * pow(x_in, b)) / (c + pow(x_in, b));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = (a * Math.pow(x_in, b)) / (c + Math.pow(x_in, b));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = (a * Math.Pow(x_in, b)) / (c + Math.Pow(x_in, b));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\t\ttemp = (a * math.pow(x_in, b)) / (c + math.pow(x_in, b))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\t\ttemp = (a * pow(x_in, b)) / (c + pow(x_in, b))\n"
        return s


class HyperbolicLogistic_WO_2D(HyperbolicLogistic2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class HyperbolicLogistic_LinearDecay_2D(HyperbolicLogistic2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class HyperbolicLogistic_ExponentialDecay_2D(HyperbolicLogistic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class HyperbolicLogistic_LinearGrowth_2D(HyperbolicLogistic2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class HyperbolicLogistic_ExponentialGrowth_2D(HyperbolicLogistic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class HyperbolicLogistic_LinearDecayAndOffset_2D(HyperbolicLogistic2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class HyperbolicLogistic_ExponentialDecayAndOffset_2D(HyperbolicLogistic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class HyperbolicLogistic_LinearGrowthAndOffset_2D(HyperbolicLogistic2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class HyperbolicLogistic_ExponentialGrowthAndOffset_2D(HyperbolicLogistic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class BioScienceA2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "BioScience A (Scaled Power)"
        self.HTML = "y = a * x<SUP>b</SUP>"
        self.coefficientDesignatorTuple = ("a", "b")

        self.function_cpp_code = 'temp = coeff[0] * pow(indep_data[(int)cachedWeaveOffsets[0] + i], coeff[1]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1] + "\n"


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a * pow(x_in, b);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a * Math.pow(x_in, b);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a * Math.Pow(x_in, b);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\t\ttemp = a * math.pow(x_in, b)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\t\ttemp = a * pow(x_in, b)\n"
        return s


class BioScienceA_WO_2D(BioScienceA2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class BioScienceA_LinearDecay_2D(BioScienceA2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class BioScienceA_ExponentialDecay_2D(BioScienceA2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class BioScienceA_LinearGrowth_2D(BioScienceA2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class BioScienceA_ExponentialGrowth_2D(BioScienceA2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class BioScienceA_LinearDecayAndOffset_2D(BioScienceA2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class BioScienceA_ExponentialDecayAndOffset_2D(BioScienceA2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class BioScienceA_LinearGrowthAndOffset_2D(BioScienceA2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class BioScienceA_ExponentialGrowthAndOffset_2D(BioScienceA2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class BioScienceA_Transform2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "BioScience A (Scaled Power) Transform"
        self.HTML = "y = a * (cx + d)<SUP>b</SUP>"
        self.coefficientDesignatorTuple = ("a", "b", 'c', 'd')

        self.function_cpp_code = 'temp = coeff[0] * pow(coeff[2] * indep_data[(int)cachedWeaveOffsets[0] + i] + coeff[3], coeff[1]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1] + "\n"


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a * pow(c * x_in + d, b);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a * Math.pow(c * x_in + d, b);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a * Math.Pow(c * x_in + d, b);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\t\ttemp = a * math.pow(c * x_in + d, b)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\t\ttemp = a * pow(c * x_in + d, b)\n"
        return s


class BioScienceA_Transform_WO_2D(BioScienceA_Transform2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class BioScienceA_Transform_LinearDecay_2D(BioScienceA_Transform2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class BioScienceA_Transform_ExponentialDecay_2D(BioScienceA_Transform2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class BioScienceA_Transform_LinearGrowth_2D(BioScienceA_Transform2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class BioScienceA_Transform_ExponentialGrowth_2D(BioScienceA_Transform2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class BioScienceA_Transform_LinearDecayAndOffset_2D(BioScienceA_Transform2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class BioScienceA_Transform_ExponentialDecayAndOffset_2D(BioScienceA_Transform2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class BioScienceA_Transform_LinearGrowthAndOffset_2D(BioScienceA_Transform2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class BioScienceA_Transform_ExponentialGrowthAndOffset_2D(BioScienceA_Transform2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class BioScienceB2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "BioScience B (Scaled Log)"
        self.HTML = "y = a * log(x)"
        self.coefficientDesignatorTuple = ("a")
        self.RequiresPositiveX = 1

        self.function_cpp_code = 'temp = coeff[0] * indep_data[(int)cachedWeaveOffsets[0] + i];// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1] + "\n"


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_LogX(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a * log(x_in);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\ttemp = a * Math.log(x_in);\n"
        return s

    def SpecificCodeCS(self):
        s = "\ttemp = a * Math.Log(x_in);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\t\ttemp = a * math.log(x_in)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\t\ttemp = a * log(x_in)\n"
        return s


class BioScienceB_WO_2D(BioScienceB2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class BioScienceB_LinearDecay_2D(BioScienceB2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class BioScienceB_ExponentialDecay_2D(BioScienceB2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class BioScienceB_LinearGrowth_2D(BioScienceB2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class BioScienceB_ExponentialGrowth_2D(BioScienceB2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class BioScienceB_LinearDecayAndOffset_2D(BioScienceB2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class BioScienceB_ExponentialDecayAndOffset_2D(BioScienceB2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class BioScienceB_LinearGrowthAndOffset_2D(BioScienceB2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class BioScienceB_ExponentialGrowthAndOffset_2D(BioScienceB2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class BioScienceB_Transform2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "BioScience B (Scaled Log) Transform"
        self.HTML = "y = a * log(bx + c)"
        self.coefficientDesignatorTuple = ("a", 'b', 'c')

        self.function_cpp_code = 'temp = coeff[0] * log(coeff[1] * indep_data[(int)cachedWeaveOffsets[0] + i] + coeff[2]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1] + "\n"


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a * log(b * x_in + c);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\ttemp = a * Math.log(b * x_in + c);\n"
        return s

    def SpecificCodeCS(self):
        s = "\ttemp = a * Math.Log(b * x_in + c);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\t\ttemp = a * math.log(b * x_in + c)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\t\ttemp = a * log(b * x_in + c)\n"
        return s


class BioScienceB_Transform_WO_2D(BioScienceB_Transform2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class BioScienceB_Transform_LinearDecay_2D(BioScienceB_Transform2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class BioScienceB_Transform_ExponentialDecay_2D(BioScienceB_Transform2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class BioScienceB_Transform_LinearGrowth_2D(BioScienceB_Transform2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class BioScienceB_Transform_ExponentialGrowth_2D(BioScienceB_Transform2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class BioScienceB_Transform_LinearDecayAndOffset_2D(BioScienceB_Transform2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class BioScienceB_Transform_ExponentialDecayAndOffset_2D(BioScienceB_Transform2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class BioScienceB_Transform_LinearGrowthAndOffset_2D(BioScienceB_Transform2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class BioScienceB_Transform_ExponentialGrowthAndOffset_2D(BioScienceB_Transform2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class BioScienceC2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "BioScience C (Negative Exponential)"
        self.HTML = "y = a * (1.0 - exp<SUP>-bx</SUP>)"
        self.coefficientDesignatorTuple = ("a", "b")

        self.function_cpp_code = 'temp = coeff[0] * (1.0 - exp(coeff[1] * indep_data[(int)cachedWeaveOffsets[0] + i]));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1] + "\n"


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_NegX(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a * (1.0 - exp(-1.0 * b * x_in));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a * (1.0 - Math.exp(-1.0 * b * x_in));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a * (1.0 - Math.Exp(-1.0 * b * x_in));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\t\ttemp = a * (1.0 - math.exp(-1.0 * b * x_in))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\t\ttemp = a * (1.0 - exp(-1.0 * b * x_in))\n"
        return s


class BioScienceC_WO_2D(BioScienceC2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class BioScienceC_LinearDecay_2D(BioScienceC2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class BioScienceC_ExponentialDecay_2D(BioScienceC2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class BioScienceC_LinearGrowth_2D(BioScienceC2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class BioScienceC_ExponentialGrowth_2D(BioScienceC2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class BioScienceC_LinearDecayAndOffset_2D(BioScienceC2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class BioScienceC_ExponentialDecayAndOffset_2D(BioScienceC2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class BioScienceC_LinearGrowthAndOffset_2D(BioScienceC2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class BioScienceC_ExponentialGrowthAndOffset_2D(BioScienceC2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class BioScienceD2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "BioScience D (Generalized Negative Exponential)"
        self.HTML = "y = a * (1.0 - exp<SUP>-bx</SUP>)<sup>c</sup>"
        self.coefficientDesignatorTuple = ("a", "b", "c")

        self.function_cpp_code = 'temp = coeff[0] * pow(1.0 - exp(coeff[1] * indep_data[(int)cachedWeaveOffsets[0] + i]), coeff[2]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1] + "\n"


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_NegX(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a * pow(1.0 - exp(-1.0 * b * x_in), c);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a * Math.pow(1.0 - Math.exp(-1.0 * b * x_in), c);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a * Math.Pow(1.0 - Math.Exp(-1.0 * b * x_in), c);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\t\ttemp = a * math.pow(1.0 - math.exp(-1.0 * b * x_in), c)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\t\ttemp = a * pow(1.0 - exp(-1.0 * b * x_in), c)\n"
        return s


class BioScienceD_WO_2D(BioScienceD2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class BioScienceD_LinearDecay_2D(BioScienceD2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class BioScienceD_ExponentialDecay_2D(BioScienceD2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class BioScienceD_LinearGrowth_2D(BioScienceD2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class BioScienceD_ExponentialGrowth_2D(BioScienceD2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class BioScienceD_LinearDecayAndOffset_2D(BioScienceD2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class BioScienceD_ExponentialDecayAndOffset_2D(BioScienceD2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class BioScienceD_LinearGrowthAndOffset_2D(BioScienceD2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class BioScienceD_ExponentialGrowthAndOffset_2D(BioScienceD2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class BioScienceE2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "BioScience E (Weibull)"
        self.HTML = "y = a * (1.0 - exp<SUP>-b * (x - c)^d</SUP>)"
        self.coefficientDesignatorTuple = ("a", "b", "c", "d")

        self.function_cpp_code = 'temp = coeff[0] * (1.0 - exp(-1.0 * coeff[1] * pow(indep_data[(int)cachedWeaveOffsets[0] + i] - coeff[2], coeff[3])));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1] + "\n"


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a * (1.0 - exp(-1.0 * b * pow(x_in - c, d)));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a * (1.0 - Math.exp(-1.0 * b * Math.pow(x_in - c, d)));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a * (1.0 - Math.Exp(-1.0 * b * Math.Pow(x_in - c, d)));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\t\ttemp = a * (1.0 - math.exp(-1.0 * b * mat.pow(x_in - c, d)))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\t\ttemp = a * (1.0 - exp(-1.0 * b * pow(x_in - c, d)))\n"
        return s


class BioScienceE_WO_2D(BioScienceE2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class BioScienceE_LinearDecay_2D(BioScienceE2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class BioScienceE_ExponentialDecay_2D(BioScienceE2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class BioScienceE_LinearGrowth_2D(BioScienceE2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class BioScienceE_ExponentialGrowth_2D(BioScienceE2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class BioScienceE_LinearDecayAndOffset_2D(BioScienceE2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class BioScienceE_ExponentialDecayAndOffset_2D(BioScienceE2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class BioScienceE_LinearGrowthAndOffset_2D(BioScienceE2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class BioScienceE_ExponentialGrowthAndOffset_2D(BioScienceE2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class BioScienceF2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "BioScience F (Generalized Hyperbolic 1)"
        self.HTML = "y = (a + x) / (b + x)"
        self.coefficientDesignatorTuple = ("a", "b")

        self.function_cpp_code = 'temp = (coeff[0] + indep_data[(int)cachedWeaveOffsets[0] + i]) / (coeff[1] + indep_data[(int)cachedWeaveOffsets[0] + i]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1] + "\n"


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = (a + x_in) / (b + x_in);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = (a + x_in) / (b + x_in);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = (a + x_in) / (b + x_in);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\t\ttemp = (a + x_in) / (b + x_in)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\t\ttemp = (a + x_in) / (b + x_in)\n"
        return s


class BioScienceF_WO_2D(BioScienceF2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class BioScienceF_LinearDecay_2D(BioScienceF2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class BioScienceF_ExponentialDecay_2D(BioScienceF2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class BioScienceF_LinearGrowth_2D(BioScienceF2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class BioScienceF_ExponentialGrowth_2D(BioScienceF2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class BioScienceF_LinearDecayAndOffset_2D(BioScienceF2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class BioScienceF_ExponentialDecayAndOffset_2D(BioScienceF2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class BioScienceF_LinearGrowthAndOffset_2D(BioScienceF2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class BioScienceF_ExponentialGrowthAndOffset_2D(BioScienceF2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class BioScienceG2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "BioScience G (Generalized Hyperbolic 2)"
        self.HTML = "y = (a + bx) / (c + x)"
        self.coefficientDesignatorTuple = ("a", "b", "c")

        self.function_cpp_code = 'temp = (coeff[0] + (coeff[1] * indep_data[(int)cachedWeaveOffsets[0] + i])) / (coeff[2] + indep_data[(int)cachedWeaveOffsets[0] + i]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1] + "\n"


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = (a + (b * x_in)) / (c + x_in);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = (a + (b * x_in)) / (c + x_in);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = (a + (b * x_in)) / (c + x_in);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\t\ttemp = (a + (b * x_in)) / (c + x_in)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\t\ttemp = (a + (b * x_in)) / (c + x_in)\n"
        return s


class BioScienceG_WO_2D(BioScienceG2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class BioScienceG_LinearDecay_2D(BioScienceG2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class BioScienceG_ExponentialDecay_2D(BioScienceG2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class BioScienceG_LinearGrowth_2D(BioScienceG2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class BioScienceG_ExponentialGrowth_2D(BioScienceG2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class BioScienceG_LinearDecayAndOffset_2D(BioScienceG2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class BioScienceG_ExponentialDecayAndOffset_2D(BioScienceG2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class BioScienceG_LinearGrowthAndOffset_2D(BioScienceG2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class BioScienceG_ExponentialGrowthAndOffset_2D(BioScienceG2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class BioScienceH2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "BioScience H (Generalized Hyperbolic 3)"
        self.HTML = "y = (a + x) / (b + cx)"
        self.coefficientDesignatorTuple = ("a", "b", "c")

        self.function_cpp_code = 'temp = (coeff[0] + indep_data[(int)cachedWeaveOffsets[0] + i]) / (coeff[1] + (coeff[2] * indep_data[(int)cachedWeaveOffsets[0] + i]));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1] + "\n"


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = (a + x_in) / (b + (c * x_in));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = (a + x_in) / (b + (c * x_in));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = (a + x_in) / (b + (c * x_in));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\t\ttemp = (a + x_in) / (b + (c * x_in))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\t\ttemp = (a + (b * x_in)) / (c + x_in)\n"
        return s


class BioScienceH_WO_2D(BioScienceH2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class BioScienceH_LinearDecay_2D(BioScienceH2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class BioScienceH_ExponentialDecay_2D(BioScienceH2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class BioScienceH_LinearGrowth_2D(BioScienceH2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class BioScienceH_ExponentialGrowth_2D(BioScienceH2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class BioScienceH_LinearDecayAndOffset_2D(BioScienceH2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class BioScienceH_ExponentialDecayAndOffset_2D(BioScienceH2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class BioScienceH_LinearGrowthAndOffset_2D(BioScienceH2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class BioScienceH_ExponentialGrowthAndOffset_2D(BioScienceH2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class BioScienceI2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "BioScience I (Generalized Hyperbolic 4)"
        self.HTML = "y = (a + bx) / (c + dx)"
        self.coefficientDesignatorTuple = ("a", "b", "c", "d")

        self.function_cpp_code = 'temp = (coeff[0] + (coeff[1] * indep_data[(int)cachedWeaveOffsets[0] + i])) / (coeff[2] + (coeff[3] * indep_data[(int)cachedWeaveOffsets[0] + i]));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1] + "\n"


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = (a + (b * x_in)) / (c + (d * x_in));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = (a + (b * x_in)) / (c + (d * x_in));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = (a + (b * x_in)) / (c + (d * x_in));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\t\ttemp = (a + (b * x_in)) / (c + (d * x_in))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\t\ttemp = (a + (b * x_in)) / (c + (d * x_in))\n"
        return s


class BioScienceI_WO_2D(BioScienceI2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class BioScienceI_LinearDecay_2D(BioScienceI2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class BioScienceI_ExponentialDecay_2D(BioScienceI2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class BioScienceI_LinearGrowth_2D(BioScienceI2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class BioScienceI_ExponentialGrowth_2D(BioScienceI2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class BioScienceI_LinearDecayAndOffset_2D(BioScienceI2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class BioScienceI_ExponentialDecayAndOffset_2D(BioScienceI2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class BioScienceI_LinearGrowthAndOffset_2D(BioScienceI2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class BioScienceI_ExponentialGrowthAndOffset_2D(BioScienceI2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class BioScienceJ2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "BioScience J (Other 1)"
        self.HTML = "y = a * (1.0 - (b * c<SUP>x</SUP>))"
        self.coefficientDesignatorTuple = ("a", "b", "c")

        self.function_cpp_code = 'temp = coeff[0] * (1.0 - (coeff[1] * pow(coeff[2], indep_data[(int)cachedWeaveOffsets[0] + i])));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1] + "\n"


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a * (1.0 - (b * pow(c, x_in)));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a * (1.0 - (b * Math.pow(c, x_in)));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a * (1.0 - (b * Math.Pow(c, x_in)));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\t\ttemp = a * (1.0 - (b * math.pow(c, x_in)))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\t\ttemp = a * (1.0 - (b * pow(c, x_in)))\n"
        return s


class BioScienceJ_WO_2D(BioScienceJ2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class BioScienceJ_LinearDecay_2D(BioScienceJ2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class BioScienceJ_ExponentialDecay_2D(BioScienceJ2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class BioScienceJ_LinearGrowth_2D(BioScienceJ2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class BioScienceJ_ExponentialGrowth_2D(BioScienceJ2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class BioScienceJ_LinearDecayAndOffset_2D(BioScienceJ2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class BioScienceJ_ExponentialDecayAndOffset_2D(BioScienceJ2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class BioScienceJ_LinearGrowthAndOffset_2D(BioScienceJ2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class BioScienceJ_ExponentialGrowthAndOffset_2D(BioScienceJ2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class BioScienceK2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "BioScience K (Other 2)"
        self.HTML = "y = a * (1.0 -(1.0 + (x/b)<sup>c</sup>)<sup>-1.0 * d</sup>)"
        self.coefficientDesignatorTuple = ("a", "b", "c", "d")

        self.function_cpp_code = 'temp = coeff[0] * (1.0 - pow(1.0 + pow(indep_data[(int)cachedWeaveOffsets[0] + i] / coeff[1], coeff[2]), -1.0 * coeff[3]));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1] + "\n"


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a * (1.0 - pow(1.0 + pow(x_in / b, c), -1.0 * d));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a * (1.0 - Math.pow(1.0 + Math.pow(x_in / b, c), -1.0 * d));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a * (1.0 - Math.Pow(1.0 + Math.Pow(x_in / b, c), -1.0 * d));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\t\ttemp = a * (1.0 - math.pow(1.0 + math.pow(x_in / b, c), -1.0 * d))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\t\ttemp = a * (1.0 - pow(1.0 + pow(x_in / b, c), -1.0 * d))\n"
        return s


class BioScienceK_WO_2D(BioScienceK2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class BioScienceK_LinearDecay_2D(BioScienceK2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class BioScienceK_ExponentialDecay_2D(BioScienceK2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class BioScienceK_LinearGrowth_2D(BioScienceK2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class BioScienceK_ExponentialGrowth_2D(BioScienceK2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class BioScienceK_LinearDecayAndOffset_2D(BioScienceK2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class BioScienceK_ExponentialDecayAndOffset_2D(BioScienceK2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class BioScienceK_LinearGrowthAndOffset_2D(BioScienceK2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class BioScienceK_ExponentialGrowthAndOffset_2D(BioScienceK2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()



class NewZealandEcologyLogistic1_2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "New Zealand Ecology Logistic 1"
        self.HTML = "n = B0 + ((B1 - B0) / (1.0 + e<sup>(B2 - D) * B3</sup>)))"
        self.coefficientDesignatorTuple = ("B0", "B1", "B2", "B3")

        self.function_cpp_code = 'temp = coeff[0] + ((coeff[1] - coeff[0]) / (1.0 + exp((coeff[2] - indep_data[(int)cachedWeaveOffsets[0] + i]) * coeff[3])));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1] + "\n"


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s = "\ttemp = " + j[0] + " + ((" + j[1] + " - " + j[0] + ") / (1.0 + exp((" + j[2] + " + x_in) * " + j[3] + ")));\n"
        return s

    def SpecificCodeJAVA(self):
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s = "\t\ttemp = " + j[0] + " + ((" + j[1] + " - " + j[0] + ") / (1.0 + Math.exp((" + j[2] + " + x_in) * " + j[3] + ")));\n"
        return s

    def SpecificCodeCS(self):
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s = "\t\ttemp = " + j[0] + " + ((" + j[1] + " - " + j[0] + ") / (1.0 + Math.Exp((" + j[2] + " + x_in) * " + j[3] + ")));\n"
        return s

    def SpecificCodePYTHON(self):
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s = "\t\ttemp = " + j[0] + " + ((" + j[1] + " - " + j[0] + ") / (1.0 + math.exp((" + j[2] + " + x_in) * " + j[3] + ")))\n"
        return s

    def SpecificCodeSCILAB(self):
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s = "\t\ttemp = " + j[0] + " + ((" + j[1] + " - " + j[0] + ") / (1.0 + exp((" + j[2] + " + x_in) * " + j[3] + ")))\n"
        return s


class NewZealandEcologyLogistic1__LinearDecay_2D(NewZealandEcologyLogistic1_2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class NewZealandEcologyLogistic1__ExponentialDecay_2D(NewZealandEcologyLogistic1_2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class NewZealandEcologyLogistic1__LinearGrowth_2D(NewZealandEcologyLogistic1_2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class NewZealandEcologyLogistic1__ExponentialGrowth_2D(NewZealandEcologyLogistic1_2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class NewZealandEcologyLogistic1__LinearDecayAndOffset_2D(NewZealandEcologyLogistic1_2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class NewZealandEcologyLogistic1__ExponentialDecayAndOffset_2D(NewZealandEcologyLogistic1_2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class NewZealandEcologyLogistic1__LinearGrowthAndOffset_2D(NewZealandEcologyLogistic1_2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class NewZealandEcologyLogistic1__ExponentialGrowthAndOffset_2D(NewZealandEcologyLogistic1_2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()



class NewZealandEcologyLogistic2_2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "New Zealand Ecology Logistic 2"
        self.HTML = "n = B0 + ((B1 - B0) / (1.0 + e<sup>(B2 - D + (B4*D<sup>2</sup>)) * B3</sup>)))"
        self.coefficientDesignatorTuple = ("B0", "B1", "B2", "B3", "B4")

        self.function_cpp_code = 'temp = coeff[0] + ((coeff[1] - coeff[0]) / (1.0 + exp((coeff[2] - indep_data[(int)cachedWeaveOffsets[0] + i] + (coeff[4] * indep_data[(int)cachedWeaveOffsets[1] + i])) * coeff[3])));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1] + "\n"


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_PowX(NameOrValueFlag=1, args=[2.0]), [2.0]])

    def SpecificCodeCPP(self):
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s = "\ttemp = " + j[0] + " + ((" + j[1] + " - " + j[0] + ") / (1.0 + exp((" + j[2] + " + x_in + (" + j[4] + " * x_in * x_in)) * " + j[3] + ")));\n"
        return s

    def SpecificCodeJAVA(self):
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s = "\t\ttemp = " + j[0] + " + ((" + j[1] + " - " + j[0] + ") / (1.0 + Math.exp((" + j[2] + " + x_in + (" + j[4] + " * x_in * x_in)) * " + j[3] + ")));\n"
        return s

    def SpecificCodeCS(self):
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s = "\t\ttemp = " + j[0] + " + ((" + j[1] + " - " + j[0] + ") / (1.0 + Math.Exp((" + j[2] + " + x_in + (" + j[4] + " * x_in * x_in)) * " + j[3] + ")));\n"
        return s

    def SpecificCodePYTHON(self):
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s = "\t\ttemp = " + j[0] + " + ((" + j[1] + " - " + j[0] + ") / (1.0 + math.exp((" + j[2] + " + x_in + (" + j[4] + " * x_in * x_in)) * " + j[3] + ")));\n"
        return s

    def SpecificCodeSCILAB(self):
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s = "\t\ttemp = " + j[0] + " + ((" + j[1] + " - " + j[0] + ") / (1.0 + exp((" + j[2] + " + x_in + (" + j[4] + " * x_in * x_in)) * " + j[3] + ")));\n"
        return s


class NewZealandEcologyLogistic2__LinearDecay_2D(NewZealandEcologyLogistic2_2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class NewZealandEcologyLogistic2__ExponentialDecay_2D(NewZealandEcologyLogistic2_2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class NewZealandEcologyLogistic2__LinearGrowth_2D(NewZealandEcologyLogistic2_2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class NewZealandEcologyLogistic2__ExponentialGrowth_2D(NewZealandEcologyLogistic2_2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class NewZealandEcologyLogistic2__LinearDecayAndOffset_2D(NewZealandEcologyLogistic2_2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class NewZealandEcologyLogistic2__ExponentialDecayAndOffset_2D(NewZealandEcologyLogistic2_2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class NewZealandEcologyLogistic2__LinearGrowthAndOffset_2D(NewZealandEcologyLogistic2_2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class NewZealandEcologyLogistic2__ExponentialGrowthAndOffset_2D(NewZealandEcologyLogistic2_2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
