#    pythonequations is a collection of equations expressed as Python classes
#    Copyright (C) 2008 James R. Phillips
#    2548 Vera Cruz Drive
#    Birmingham, AL 35235 USA
#    email: zunzun@zunzun.com
#
#    Version info: $Id$
#
#    License: BSD-style (see LICENSE.txt in main source directory)

import pythonequations, pythonequations.EquationBaseClasses
import numpy
numpy.seterr(all = 'raise') # numpy raises warnings, convert to exceptions to trap them


class VanDeemter2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "VanDeemter Chromatography"
        self.HTML = "y = a + b/x + cx"
        self.coefficientDesignatorTuple = ('a', 'b', 'c')
        self.RequiresNonzeroX = 1

        self.function_cpp_code = 'temp = coeff[0] + (coeff[1] * indep_data[(int)cachedWeaveOffsets[0] + i]) + (coeff[2] / indep_data[(int)cachedWeaveOffsets[0] + i]) + (coeff[2] / indep_data[(int)cachedWeaveOffsets[1] + i]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_InverseX(NameOrValueFlag=1, args=[2.0]), [2.0]])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1, args=[4.0]), [4.0]])

    def SpecificCodeCPP(self):
        s = "\ttemp = a + b / x_in + c * x_in;\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a + b / x_in + c * x_in;\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a + b / x_in + c * x_in;\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = a + b / x_in + c * x_in\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = a + b / x_in + c * x_in\n"
        return s


class VanDeemter_LinearDecay_2D(VanDeemter2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class VanDeemter_ExponentialDecay_2D(VanDeemter2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class VanDeemter_LinearGrowth_2D(VanDeemter2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class VanDeemter_ExponentialGrowth_2D(VanDeemter2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class VanDeemter_LinearDecayAndOffset_2D(VanDeemter2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class VanDeemter_ExponentialDecayAndOffset_2D(VanDeemter2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class VanDeemter_LinearGrowthAndOffset_2D(VanDeemter2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class VanDeemter_ExponentialGrowthAndOffset_2D(VanDeemter2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()




class Dispersion2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Dispersion Optical"
        self.HTML = "n<sup>2</sup>(x) = A1 + A2*x<sup>2</sup> + A3/x<sup>2</sup> + A4/x<sup>4</sup>"
        self.coefficientDesignatorTuple = ("A1", "A2", "A3", "A4")

        self.function_cpp_code = 'temp = coeff[0] + (coeff[1] * indep_data[(int)cachedWeaveOffsets[0] + i]) + (coeff[2] / indep_data[(int)cachedWeaveOffsets[0] + i]) + (coeff[2] / indep_data[(int)cachedWeaveOffsets[1] + i]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_PowX(NameOrValueFlag=1, args=[2.0]), [2.0]])
        self.CacheGenerationList.append([self.CG_PowX(NameOrValueFlag=1, args=[4.0]), [4.0]])

    def SpecificCodeCPP(self):
        s = "\ttemp = A1 + (A2 * x_in * x_in) + (A3 / (x_in * x_in)) + (A4 / (x_in * x_in * x_in * x_in));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = A1 + (A2 * x_in * x_in) + (A3 / (x_in * x_in)) + (A4 / (x_in * x_in * x_in * x_in));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = A1 + (A2 * x_in * x_in) + (A3 / (x_in * x_in)) + (A4 / (x_in * x_in * x_in * x_in));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = A1 + (A2 * x_in * x_in) + (A3 / (x_in * x_in)) + (A4 / (x_in * x_in * x_in * x_in))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = A1 + (A2 * x_in * x_in) + (A3 / (x_in * x_in)) + (A4 / (x_in * x_in * x_in * x_in))\n"
        return s


class Dispersion_LinearDecay_2D(Dispersion2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class Dispersion_ExponentialDecay_2D(Dispersion2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class Dispersion_LinearGrowth_2D(Dispersion2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class Dispersion_ExponentialGrowth_2D(Dispersion2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class Dispersion_LinearDecayAndOffset_2D(Dispersion2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class Dispersion_ExponentialDecayAndOffset_2D(Dispersion2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class Dispersion_LinearGrowthAndOffset_2D(Dispersion2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class Dispersion_ExponentialGrowthAndOffset_2D(Dispersion2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class DispersionSqrt2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Dispersion Optical Square Root"
        self.HTML = "n = (A1 + A2*x<sup>2</sup> + A3/x<sup>2</sup> + A4/x<sup>4</sup>)<sup>0.5</sup>"
        self.coefficientDesignatorTuple = ("A1", "A2", "A3", "A4")

        self.function_cpp_code = 'temp = pow(coeff[0] + (coeff[1] * indep_data[(int)cachedWeaveOffsets[0] + i]) + (coeff[2] / indep_data[(int)cachedWeaveOffsets[0] + i]) + (coeff[2] / indep_data[(int)cachedWeaveOffsets[1] + i]), 0.5);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_PowX(NameOrValueFlag=1, args=[2.0]), [2.0]])
        self.CacheGenerationList.append([self.CG_PowX(NameOrValueFlag=1, args=[4.0]), [4.0]])

    def SpecificCodeCPP(self):
        s = "\ttemp = pow(A1 + (A2 * x_in * x_in) + (A3 / (x_in * x_in)) + (A4 / (x_in * x_in * x_in * x_in)), 0.5);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = Math.pow(A1 + (A2 * x_in * x_in) + (A3 / (x_in * x_in)) + (A4 / (x_in * x_in * x_in * x_in)), 0.5);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = Math.Pow(A1 + (A2 * x_in * x_in) + (A3 / (x_in * x_in)) + (A4 / (x_in * x_in * x_in * x_in)), 0.5);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = math.pow(A1 + (A2 * x_in * x_in) + (A3 / (x_in * x_in)) + (A4 / (x_in * x_in * x_in * x_in)), 0.5)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = (A1 + (A2 * x_in * x_in) + (A3 / (x_in * x_in)) + (A4 / (x_in * x_in * x_in * x_in))) ^ 0.5\n"
        return s


class DispersionSqrt_LinearDecay_2D(DispersionSqrt2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class DispersionSqrt_ExponentialDecay_2D(DispersionSqrt2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class DispersionSqrt_LinearGrowth_2D(DispersionSqrt2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class DispersionSqrt_ExponentialGrowth_2D(DispersionSqrt2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class DispersionSqrt_LinearDecayAndOffset_2D(DispersionSqrt2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class DispersionSqrt_ExponentialDecayAndOffset_2D(DispersionSqrt2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class DispersionSqrt_LinearGrowthAndOffset_2D(DispersionSqrt2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class DispersionSqrt_ExponentialGrowthAndOffset_2D(DispersionSqrt2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class Sellmeier2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Sellmeier Optical"
        self.HTML = "n<sup>2</sup>(x) = 1 + (B1 x<sup>2</sup>)/(x<sup>2</sup>-C1) +  (B2 x<sup>2</sup>)/(x<sup>2</sup>-C2) +  (B3 x<sup>2</sup>)/(x<sup>2</sup>-C3)"
        self.coefficientDesignatorTuple = ("B1", "C1", "B2", "C2", "B3", "C3")

        self.function_cpp_code = 'temp = 1.0 + ((coeff[0] * indep_data[(int)cachedWeaveOffsets[0] + i]) / (indep_data[(int)cachedWeaveOffsets[0] + i] - coeff[1])) + ((coeff[2] * indep_data[(int)cachedWeaveOffsets[0] + i]) / (indep_data[(int)cachedWeaveOffsets[0] + i] - coeff[3])) + ((coeff[4] * indep_data[(int)cachedWeaveOffsets[0] + i]) / (indep_data[(int)cachedWeaveOffsets[0] + i] - coeff[5]));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_PowX(NameOrValueFlag=1, args=[2.0]), [2.0]])

    def SpecificCodeCPP(self):
        s = "\ttemp = 1.0 + ((B1 * x_in * x_in)/(x_in * x_in - C1)) + ((B2 * x_in * x_in)/(x_in * x_in - C2)) + ((B3 * x_in * x_in)/(x_in * x_in - C3));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = 1.0 + ((B1 * x_in * x_in)/(x_in * x_in - C1)) + ((B2 * x_in * x_in)/(x_in * x_in - C2)) + ((B3 * x_in * x_in)/(x_in * x_in - C3));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = 1.0 + ((B1 * x_in * x_in)/(x_in * x_in - C1)) + ((B2 * x_in * x_in)/(x_in * x_in - C2)) + ((B3 * x_in * x_in)/(x_in * x_in - C3)));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = 1.0 + ((B1 * x_in * x_in)/(x_in * x_in - C1)) + ((B2 * x_in * x_in)/(x_in * x_in - C2)) + ((B3 * x_in * x_in)/(x_in * x_in - C3))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = 1.0 + ((B1 * x_in * x_in)/(x_in * x_in - C1)) + ((B2 * x_in * x_in)/(x_in * x_in - C2)) + ((B3 * x_in * x_in)/(x_in * x_in - C3))\n"
        return s


class Sellmeier_LinearDecay_2D(Sellmeier2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class Sellmeier_ExponentialDecay_2D(Sellmeier2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class Sellmeier_LinearGrowth_2D(Sellmeier2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class Sellmeier_ExponentialGrowth_2D(Sellmeier2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class Sellmeier_LinearDecayAndOffset_2D(Sellmeier2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class Sellmeier_ExponentialDecayAndOffset_2D(Sellmeier2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class Sellmeier_LinearGrowthAndOffset_2D(Sellmeier2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class Sellmeier_ExponentialGrowthAndOffset_2D(Sellmeier2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class SellmeierSqrt2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Sellmeier Optical Square Root"
        self.HTML = "n = (1 + (B1 x<sup>2</sup>)/(x<sup>2</sup>-C1) +  (B2 x<sup>2</sup>)/(x<sup>2</sup>-C2) +  (B3 x<sup>2</sup>)/(x<sup>2</sup>-C3))<sup>0.5</sup>"
        self.coefficientDesignatorTuple = ("B1", "C1", "B2", "C2", "B3", "C3")

        self.function_cpp_code = 'temp = 1.0 + ((coeff[0] * indep_data[(int)cachedWeaveOffsets[0] + i]) / (indep_data[(int)cachedWeaveOffsets[0] + i] - coeff[1])) + ((coeff[2] * indep_data[(int)cachedWeaveOffsets[0] + i]) / (indep_data[(int)cachedWeaveOffsets[0] + i] - coeff[3])) + ((coeff[4] * indep_data[(int)cachedWeaveOffsets[0] + i]) / (indep_data[(int)cachedWeaveOffsets[0] + i] - coeff[5]));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_PowX(NameOrValueFlag=1, args=[2.0]), [2.0]])

    def SpecificCodeCPP(self):
        s = "\ttemp = pow(1.0 + ((B1 * x_in * x_in)/(x_in * x_in - C1)) + ((B2 * x_in * x_in)/(x_in * x_in - C2)) + ((B3 * x_in * x_in)/(x_in * x_in - C3)), 0.5);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = Math.pow(1.0 + ((B1 * x_in * x_in)/(x_in * x_in - C1)) + ((B2 * x_in * x_in)/(x_in * x_in - C2)) + ((B3 * x_in * x_in)/(x_in * x_in - C3)), 0.5);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = Math.Pow(1.0 + ((B1 * x_in * x_in)/(x_in * x_in - C1)) + ((B2 * x_in * x_in)/(x_in * x_in - C2)) + ((B3 * x_in * x_in)/(x_in * x_in - C3))), 0.5);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = math.pow(1.0 + ((B1 * x_in * x_in)/(x_in * x_in - C1)) + ((B2 * x_in * x_in)/(x_in * x_in - C2)) + ((B3 * x_in * x_in)/(x_in * x_in - C3)), 0.5)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = (1.0 + ((B1 * x_in * x_in)/(x_in * x_in - C1)) + ((B2 * x_in * x_in)/(x_in * x_in - C2)) + ((B3 * x_in * x_in)/(x_in * x_in - C3))) ^ 0.5\n"
        return s


class SellmeierSqrt_LinearDecay_2D(SellmeierSqrt2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class SellmeierSqrt_ExponentialDecay_2D(SellmeierSqrt2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class SellmeierSqrt_LinearGrowth_2D(SellmeierSqrt2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class SellmeierSqrt_ExponentialGrowth_2D(SellmeierSqrt2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class SellmeierSqrt_LinearDecayAndOffset_2D(SellmeierSqrt2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class SellmeierSqrt_ExponentialDecayAndOffset_2D(SellmeierSqrt2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class SellmeierSqrt_LinearGrowthAndOffset_2D(SellmeierSqrt2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class SellmeierSqrt_ExponentialGrowthAndOffset_2D(SellmeierSqrt2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class Ramberg_Osgood2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Ramberg-Osgood"
        self.HTML = "y = (Stress / Young's Modulus) + (Stress&nbsp;/&nbsp;K)<SUP>(1.0&nbsp;/&nbsp;n)</SUP>"
        self.coefficientDesignatorTuple = ("Youngs_Modulus", "K", "n")

        self.function_cpp_code = 'temp = (indep_data[(int)cachedWeaveOffsets[0] + i] / coeff[0]) + pow(indep_data[(int)cachedWeaveOffsets[1] + i] / coeff[1], 1.0 / coeff[2]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read

        s = "\ttemp = (x_in / " + j[0] + ") +  pow(x_in / " + j[1] + ", 1.0 / " + j[2] + ");\n"
        return s

    def SpecificCodeJAVA(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read

        s = "\t\ttemp = (x_in / " + j[0] + ") +  Math.pow(x_in / " + j[1] + ", 1.0 / " + j[2] + ");\n"
        return s

    def SpecificCodeCS(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read

        s = "\t\ttemp = (x_in / " + j[0] + ") +  Math.Pow(x_in / " + j[1] + ", 1.0 / " + j[2] + ");\n"
        return s

    def SpecificCodePYTHON(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read

        s = "\ttemp = (x_in / " + j[0] + ") +  math.pow(x_in / " + j[1] + ", 1.0 / " + j[2] + ")\n"
        return s

    def SpecificCodeSCILAB(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read

        s = "\ttemp = (x_in / " + j[0] + ") +  pow(x_in / " + j[1] + ", 1.0 / " + j[2] + ")\n"
        return s


class Ramberg_Osgood_WO_2D(Ramberg_Osgood2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class Ramberg_Osgood_LinearDecay_2D(Ramberg_Osgood2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class Ramberg_Osgood_ExponentialDecay_2D(Ramberg_Osgood2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class Ramberg_Osgood_LinearGrowth_2D(Ramberg_Osgood2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class Ramberg_Osgood_ExponentialGrowth_2D(Ramberg_Osgood2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class Ramberg_Osgood_LinearDecayAndOffset_2D(Ramberg_Osgood2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class Ramberg_Osgood_ExponentialDecayAndOffset_2D(Ramberg_Osgood2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class Ramberg_Osgood_LinearGrowthAndOffset_2D(Ramberg_Osgood2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class Ramberg_Osgood_ExponentialGrowthAndOffset_2D(Ramberg_Osgood2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()



class Steinhart_Hart2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Steinhart-Hart"
        self.HTML = "1/T = A + Bln(R) + C(ln(R))<SUP>3</SUP>"
        self.coefficientDesignatorTuple = ("A", "B", "C")

        self.function_cpp_code = 'temp = coeff[0] + (coeff[1] * indep_data[(int)cachedWeaveOffsets[0] + i]) + pow(coeff[2] * indep_data[(int)cachedWeaveOffsets[0] + i], 3.0);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]

        self.guessDivisor = 50.0
        self.maxparamvalue = 1.0
        self.minparamvalue = -1.0


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_LogX(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read

        s = "\ttemp = " + j[0] + " + " + j[1] + "*log(x_in) + " + j[2] + "*pow(log(x_in), 3.0);\n"
        return s

    def SpecificCodeJAVA(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read

        s = "\t\ttemp = " + j[0] + " + " + j[1] + "*Math.log(x_in) + " + j[2] + "*Math.pow(Math.log(x_in), 3.0);\n"
        return s

    def SpecificCodeCS(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read

        s = "\t\ttemp = " + j[0] + " + " + j[1] + "*Math.Log(x_in) + " + j[2] + "*Math.Pow(Math.log(x_in), 3.0);\n"
        return s

    def SpecificCodePYTHON(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read

        s = "\ttemp = " + j[0] + " + " + j[1] + "*math.log(x_in) + " + j[2] + "*math.pow(math.log(x_in), 3.0)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read

        s = "\ttemp = " + j[0] + " + " + j[1] + "*log(x_in) + " + j[2] + "*pow(log(x_in), 3.0)\n"
        return s


class Steinhart_Hart2D_LinearDecay_2D(Steinhart_Hart2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class Steinhart_Hart2D_ExponentialDecay_2D(Steinhart_Hart2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class Steinhart_Hart2D_LinearGrowth_2D(Steinhart_Hart2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class Steinhart_Hart2D_ExponentialGrowth_2D(Steinhart_Hart2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class Steinhart_Hart2D_LinearDecayAndOffset_2D(Steinhart_Hart2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class Steinhart_Hart2D_ExponentialDecayAndOffset_2D(Steinhart_Hart2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class Steinhart_Hart2D_LinearGrowthAndOffset_2D(Steinhart_Hart2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class Steinhart_Hart2D_ExponentialGrowthAndOffset_2D(Steinhart_Hart2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()



class Reciprocal_Steinhart_Hart2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Reciprocal Steinhart-Hart"
        self.HTML = "T = 1.0 / (A + Bln(R) + C(ln(R))<SUP>3</SUP>)"
        self.coefficientDesignatorTuple = ("A", "B", "C")

        self.function_cpp_code = 'temp = 1.0 / (coeff[0] + (coeff[1] * indep_data[(int)cachedWeaveOffsets[0] + i]) + pow(coeff[2] * indep_data[(int)cachedWeaveOffsets[0] + i], 3.0));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]
        
        self.guessDivisor = 50.0
        self.maxparamvalue = 1.0
        self.minparamvalue = -1.0


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_LogX(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read

        s = "\ttemp = 1.0 / (" + j[0] + " + " + j[1] + "*log(x_in) + " + j[2] + "*pow(log(x_in), 3.0));\n"
        return s

    def SpecificCodeJAVA(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read

        s = "\t\ttemp = 1.0 / (" + j[0] + " + " + j[1] + "*Math.Log(x_in) + " + j[2] + "*Math.pow(Math.log(x_in), 3.0));\n"
        return s

    def SpecificCodeCS(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read

        s = "\t\ttemp = 1.0 / (" + j[0] + " + " + j[1] + "*Math.Log(x_in) + " + j[2] + "*Math.Pow(Math.log(x_in), 3.0));\n"
        return s

    def SpecificCodePYTHON(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read

        s = "\ttemp = 1.0 / (" + j[0] + " + " + j[1] + "*math.log(x_in) + " + j[2] + "*math.pow(math.log(x_in), 3.0))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read

        s = "\ttemp = 1.0 / (" + j[0] + " + " + j[1] + "*log(x_in) + " + j[2] + "*pow(log(x_in), 3.0))\n"
        return s


class Reciprocal_Steinhart_Hart2D_LinearDecay_2D(Reciprocal_Steinhart_Hart2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class Reciprocal_Steinhart_Hart2D_ExponentialDecay_2D(Reciprocal_Steinhart_Hart2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class Reciprocal_Steinhart_Hart2D_LinearGrowth_2D(Reciprocal_Steinhart_Hart2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class Reciprocal_Steinhart_Hart2D_ExponentialGrowth_2D(Reciprocal_Steinhart_Hart2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class Reciprocal_Steinhart_Hart2D_LinearDecayAndOffset_2D(Reciprocal_Steinhart_Hart2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class Reciprocal_Steinhart_Hart2D_ExponentialDecayAndOffset_2D(Reciprocal_Steinhart_Hart2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class Reciprocal_Steinhart_Hart2D_LinearGrowthAndOffset_2D(Reciprocal_Steinhart_Hart2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class Reciprocal_Steinhart_Hart2D_ExponentialGrowthAndOffset_2D(Reciprocal_Steinhart_Hart2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()



class Extended_Steinhart_Hart2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Extended Steinhart-Hart"
        self.HTML = "1/T = A + Bln(R) + C(ln(R))<SUP>2</SUP> + D(ln(R))<SUP>3</SUP>"
        self.coefficientDesignatorTuple = ("A", "B", "C", "D")

        self.function_cpp_code = 'temp = coeff[0] + (coeff[1] * indep_data[(int)cachedWeaveOffsets[0] + i]) + pow(coeff[2] * indep_data[(int)cachedWeaveOffsets[0] + i], 2.0) + pow(coeff[3] * indep_data[(int)cachedWeaveOffsets[0] + i], 3.0);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]

        self.guessDivisor = 50.0
        self.maxparamvalue = 1.0
        self.minparamvalue = -1.0

    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_LogX(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read

        s = "\ttemp = " + j[0] + " + " + j[1] + "*log(x_in) + " + j[2] + "*pow(log(x_in), 2.0) + "+  j[3]  + "*pow(log(x_in), 3.0);\n"
        return s

    def SpecificCodeJAVA(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read

        s = "\t\ttemp = " + j[0] + " + " + j[1] + "*Math.log(x_in) + " + j[2] + "*Math.pow(Math.log(x_in), 2.0) + "+  j[3]  + "*Math.pow(Math.log(x_in), 3.0);\n"
        return s

    def SpecificCodeCS(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read

        s = "\t\ttemp = " + j[0] + " + " + j[1] + "*Math.Log(x_in) + " + j[2] + "*Math.Pow(Math.Log(x_in), 2.0) + "+  j[3]  + "*Math.Pow(Math.Log(x_in), 3.0);\n"
        return s

    def SpecificCodePYTHON(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read

        s = "\ttemp = " + j[0] + " + " + j[1] + "*math.log(x_in) + " + j[2] + "*math.pow(math.log(x_in), 2.0) + "+  j[3]  + "*math.pow(math.log(x_in), 3.0)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read

        s = "\ttemp = " + j[0] + " + " + j[1] + "*log(x_in) + " + j[2] + "*pow(log(x_in), 2.0) + "+  j[3]  + "*pow(log(x_in), 3.0)\n"
        return s


class Extended_Steinhart_Hart2D_LinearDecay_2D(Extended_Steinhart_Hart2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class Extended_Steinhart_Hart2D_ExponentialDecay_2D(Extended_Steinhart_Hart2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class Extended_Steinhart_Hart2D_LinearGrowth_2D(Extended_Steinhart_Hart2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class Extended_Steinhart_Hart2D_ExponentialGrowth_2D(Extended_Steinhart_Hart2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class Extended_Steinhart_Hart2D_LinearDecayAndOffset_2D(Extended_Steinhart_Hart2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class Extended_Steinhart_Hart2D_ExponentialDecayAndOffset_2D(Extended_Steinhart_Hart2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class Extended_Steinhart_Hart2D_LinearGrowthAndOffset_2D(Extended_Steinhart_Hart2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class Extended_Steinhart_Hart2D_ExponentialGrowthAndOffset_2D(Extended_Steinhart_Hart2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()



class Reciprocal_Extended_Steinhart_Hart2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Reciprocal Extended Steinhart-Hart"
        self.HTML = "T = 1.0 / (A + Bln(R) + C(ln(R))<SUP>2</SUP> + D(ln(R))<SUP>3</SUP>)"
        self.coefficientDesignatorTuple = ("A", "B", "C", "D")

        self.function_cpp_code = 'temp = 1.0 / (coeff[0] + (coeff[1] * indep_data[(int)cachedWeaveOffsets[0] + i]) + pow(coeff[2] * indep_data[(int)cachedWeaveOffsets[0] + i], 2.0) + pow(coeff[3] * indep_data[(int)cachedWeaveOffsets[0] + i], 3.0));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]

        self.guessDivisor = 50.0
        self.maxparamvalue = 1.0
        self.minparamvalue = -1.0


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_LogX(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read

        s = "\ttemp = 1.0 / (" + j[0] + " + " + j[1] + "*log(x_in) + " + j[2] + "*pow(log(x_in), 2.0) + "+  j[3]  + "*pow(log(x_in), 3.0));\n"
        return s

    def SpecificCodeJAVA(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read

        s = "\t\ttemp = 1.0 / (" + j[0] + " + " + j[1] + "*Math.log(x_in) + " + j[2] + "*Math.pow(Math.log(x_in), 2.0) + "+  j[3]  + "*Math.pow(Math.log(x_in), 3.0));\n"
        return s

    def SpecificCodeCS(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read

        s = "\t\ttemp = 1.0 / (" + j[0] + " + " + j[1] + "*Math.Log(x_in) + " + j[2] + "*Math.Pow(Math.Log(x_in), 2.0) + "+  j[3]  + "*Math.Pow(Math.Log(x_in), 3.0));\n"
        return s

    def SpecificCodePYTHON(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read

        s = "\ttemp = 1.0 / (" + j[0] + " + " + j[1] + "*math.log(x_in) + " + j[2] + "*math.pow(math.log(x_in), 2.0) + "+  j[3]  + "*math.pow(math.log(x_in), 3.0))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read

        s = "\ttemp = 1.0 / (" + j[0] + " + " + j[1] + "*log(x_in) + " + j[2] + "*pow(log(x_in), 2.0) + "+  j[3]  + "*pow(log(x_in), 3.0))\n"
        return s


class Reciprocal_Extended_Steinhart_Hart2D_LinearDecay_2D(Reciprocal_Extended_Steinhart_Hart2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class Reciprocal_Extended_Steinhart_Hart2D_ExponentialDecay_2D(Reciprocal_Extended_Steinhart_Hart2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class Reciprocal_Extended_Steinhart_Hart2D_LinearGrowth_2D(Reciprocal_Extended_Steinhart_Hart2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class Reciprocal_Extended_Steinhart_Hart2D_ExponentialGrowth_2D(Reciprocal_Extended_Steinhart_Hart2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class Reciprocal_Extended_Steinhart_Hart2D_LinearDecayAndOffset_2D(Reciprocal_Extended_Steinhart_Hart2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class Reciprocal_Extended_Steinhart_Hart2D_ExponentialDecayAndOffset_2D(Reciprocal_Extended_Steinhart_Hart2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class Reciprocal_Extended_Steinhart_Hart2D_LinearGrowthAndOffset_2D(Reciprocal_Extended_Steinhart_Hart2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class Reciprocal_Extended_Steinhart_Hart2D_ExponentialGrowthAndOffset_2D(Reciprocal_Extended_Steinhart_Hart2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
