#    pythonequations is a collection of equations expressed as Python classes
#    Copyright (C) 2008 James R. Phillips
#    2548 Vera Cruz Drive
#    Birmingham, AL 35235 USA
#    email: zunzun@zunzun.com
#
#    Version info: $Id$
#
#    License: BSD-style (see LICENSE.txt in main source directory)

import pythonequations, pythonequations.EquationBaseClasses
import numpy
numpy.seterr(all = 'raise') # numpy raises warnings, convert to exceptions to trap them

class SteveBattisonExponentialA2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Steve Battison Exponential A"
        self.HTML = "y = e<SUP>(a + bx) / (c + dx)</SUP>"
        self.coefficientDesignatorTuple = ("a", "b", "c", "d")

        self.function_cpp_code = 'temp = exp((coeff[0] + coeff[1] * indep_data[(int)cachedWeaveOffsets[0] + i]) / (coeff[2] + coeff[3] * indep_data[(int)cachedWeaveOffsets[0] + i]));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = exp((a + b * x_in) / (c + d * x_in));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = Math.exp((a + b * x_in) / (c + d * x_in));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = Math.Exp((a + b * x_in) / (c + d * x_in));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = math.exp((a + b * x_in) / (c + d * x_in))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = exp((a + b * x_in) / (c + d * x_in))\n"
        return s


class SteveBattisonExponentialA_WO_2D(SteveBattisonExponentialA2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class SteveBattisonExponentialA_LinearDecay_2D(SteveBattisonExponentialA2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class SteveBattisonExponentialA_ExponentialDecay_2D(SteveBattisonExponentialA2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class SteveBattisonExponentialA_LinearGrowth_2D(SteveBattisonExponentialA2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class SteveBattisonExponentialA_ExponentialGrowth_2D(SteveBattisonExponentialA2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class SteveBattisonExponentialA_LinearDecayAndOffset_2D(SteveBattisonExponentialA2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class SteveBattisonExponentialA_ExponentialDecayAndOffset_2D(SteveBattisonExponentialA2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class SteveBattisonExponentialA_LinearGrowthAndOffset_2D(SteveBattisonExponentialA2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class SteveBattisonExponentialA_ExponentialGrowthAndOffset_2D(SteveBattisonExponentialA2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class SteveBattisonExponentialB2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Steve Battison Exponential B"
        self.HTML = "y = a * e<SUP>(b + cx) / (d + ex)</SUP>"
        self.coefficientDesignatorTuple = ("a", "b", "c", "d", "e")

        self.function_cpp_code = 'temp = coeff[0] * exp((coeff[1] + coeff[2] * indep_data[(int)cachedWeaveOffsets[0] + i]) / (coeff[3] + coeff[4] * indep_data[(int)cachedWeaveOffsets[0] + i]));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a * exp((b + c * x_in) / (d + e * x_in));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a * Math.exp((b + c * x_in) / (d + e * x_in));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a * Math.Exp((b + c * x_in) / (d + e * x_in));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = a * math.exp((b + c * x_in) / (d + e * x_in))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = a * exp((b + c * x_in) / (d + e * x_in))\n"
        return s


class SteveBattisonExponentialB_WO_2D(SteveBattisonExponentialB2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class SteveBattisonExponentialB_LinearDecay_2D(SteveBattisonExponentialB2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class SteveBattisonExponentialB_ExponentialDecay_2D(SteveBattisonExponentialB2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class SteveBattisonExponentialB_LinearGrowth_2D(SteveBattisonExponentialB2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class SteveBattisonExponentialB_ExponentialGrowth_2D(SteveBattisonExponentialB2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class SteveBattisonExponentialB_LinearDecayAndOffset_2D(SteveBattisonExponentialB2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class SteveBattisonExponentialB_ExponentialDecayAndOffset_2D(SteveBattisonExponentialB2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class SteveBattisonExponentialB_LinearGrowthAndOffset_2D(SteveBattisonExponentialB2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class SteveBattisonExponentialB_ExponentialGrowthAndOffset_2D(SteveBattisonExponentialB2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class Hoerl2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Hoerl"
        self.HTML = "y = x<SUP>a</SUP> * e<SUP>x</SUP>"
        self.coefficientDesignatorTuple = ("a")
        self.RequiresPositiveX = 1

        self.function_cpp_code = 'temp = pow(indep_data[(int)cachedWeaveOffsets[0] + i], coeff[0]) * indep_data[(int)cachedWeaveOffsets[1] + i];// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_ExpX(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = pow(x_in, a) * exp(x_in);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = Math.pow(x_in, a) * Math.exp(x_in);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = Math.Pow(x_in, a) * Math.Exp(x_in);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = math.pow(x_in, a) * math.exp(x_in)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = pow(x_in, a) * exp(x_in)\n"
        return s


class Hoerl_WO_2D(Hoerl2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class Hoerl_LinearDecay_2D(Hoerl2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class Hoerl_ExponentialDecay_2D(Hoerl2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class Hoerl_LinearGrowth_2D(Hoerl2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class Hoerl_ExponentialGrowth_2D(Hoerl2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class Hoerl_LinearDecayAndOffset_2D(Hoerl2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class Hoerl_ExponentialDecayAndOffset_2D(Hoerl2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class Hoerl_LinearGrowthAndOffset_2D(Hoerl2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class Hoerl_ExponentialGrowthAndOffset_2D(Hoerl2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class Hoerl_Transform2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Hoerl Transform"
        self.HTML = "y = (bx + c)<SUP>a</SUP> * e<SUP>bx + c</SUP>"
        self.coefficientDesignatorTuple = ("a", 'b', 'c')

        self.function_cpp_code = 'temp = pow(coeff[1] * indep_data[(int)cachedWeaveOffsets[0] + i] + coeff[2], coeff[0]) * exp(coeff[1] * indep_data[(int)cachedWeaveOffsets[0] + i] + coeff[2]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = pow(b * x_in + c, a) * exp(b * x_in + c);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = Math.pow(b * x_in + c, a) * Math.exp(b * x_in + c);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = Math.Pow(b * x_in + c, a) * Math.Exp(b * x_in + c);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = math.pow(b * x_in + c, a) * math.exp(b * x_in + c)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = pow(b * x_in + c, a) * exp(b * x_in + c)\n"
        return s


class Hoerl_Transform_WO_2D(Hoerl_Transform2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class Hoerl_Transform_LinearDecay_2D(Hoerl_Transform2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class Hoerl_Transform_ExponentialDecay_2D(Hoerl_Transform2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class Hoerl_Transform_LinearGrowth_2D(Hoerl_Transform2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class Hoerl_Transform_ExponentialGrowth_2D(Hoerl_Transform2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class Hoerl_Transform_LinearDecayAndOffset_2D(Hoerl_Transform2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class Hoerl_Transform_ExponentialDecayAndOffset_2D(Hoerl_Transform2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class Hoerl_Transform_LinearGrowthAndOffset_2D(Hoerl_Transform2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class Hoerl_Transform_ExponentialGrowthAndOffset_2D(Hoerl_Transform2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class VaporPressure2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Standard Vapor Pressure"
        self.HTML = "y = e<SUP>(a + (b/x) + c*ln(x))</SUP>"
        self.coefficientDesignatorTuple = ("a", "b", "c")
        self.RequiresPositiveX = 1

        self.function_cpp_code = 'temp = exp(coeff[0] + coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[2] * indep_data[(int)cachedWeaveOffsets[2] + i]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_InverseX(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogX(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = exp(a + (b/x_in) + c*log(x_in));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = Math.exp(a + (b/x_in) + c*Math.log(x_in));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = Math.Exp(a + (b/x_in) + c*Math.Log(x_in));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = math.exp(a + (b/x_in) + c*math.log(x_in))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = exp(a + (b/x_in) + c*log(x_in))\n"
        return s


class VaporPressure_WO_2D(VaporPressure2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class VaporPressure_LinearDecay_2D(VaporPressure2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class VaporPressure_ExponentialDecay_2D(VaporPressure2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class VaporPressure_LinearGrowth_2D(VaporPressure2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class VaporPressure_ExponentialGrowth_2D(VaporPressure2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class VaporPressure_LinearDecayAndOffset_2D(VaporPressure2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class VaporPressure_ExponentialDecayAndOffset_2D(VaporPressure2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class VaporPressure_LinearGrowthAndOffset_2D(VaporPressure2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class VaporPressure_ExponentialGrowthAndOffset_2D(VaporPressure2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class SimpleExponential2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Simple Exponential"
        self.HTML = "y = a<SUP>x</SUP>"
        self.coefficientDesignatorTuple = ("a")

        self.function_cpp_code = 'temp = pow(coeff[0], indep_data[(int)cachedWeaveOffsets[0] + i]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = pow(a, x_in);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = Math.pow(a, x_in);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = Math.Pow(a, x_in);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = math.pow(a, x_in)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = pow(a, x_in)\n"
        return s


class SimpleExponential_WO_2D(SimpleExponential2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class SimpleExponential_LinearDecay_2D(SimpleExponential2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class SimpleExponential_LinearGrowth_2D(SimpleExponential2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class SimpleExponential_ExponentialGrowth_2D(SimpleExponential2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class SimpleExponential_LinearDecayAndOffset_2D(SimpleExponential2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class SimpleExponential_LinearGrowthAndOffset_2D(SimpleExponential2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class SimpleExponential_ExponentialGrowthAndOffset_2D(SimpleExponential2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class AsymptoticExponentialA2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Asymptotic Exponential A"
        self.HTML = "y = 1.0 - a<SUP>x</SUP>"
        self.coefficientDesignatorTuple = ("a")

        self.function_cpp_code = 'temp = 1.0 - pow(coeff[0], indep_data[(int)cachedWeaveOffsets[0] + i]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = 1.0 - pow(a, x_in);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = 1.0 - Math.pow(a, x_in);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = 1.0 - Math.Pow(a, x_in);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = 1.0 - math.pow(a, x_in)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = 1.0 - pow(a, x_in)\n"
        return s


class AsymptoticExponentialA_WO_2D(AsymptoticExponentialA2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class AsymptoticExponentialA_LinearDecay_2D(AsymptoticExponentialA2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class AsymptoticExponentialA_LinearGrowth_2D(AsymptoticExponentialA2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class AsymptoticExponentialA_ExponentialGrowth_2D(AsymptoticExponentialA2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class AsymptoticExponentialA_LinearDecayAndOffset_2D(AsymptoticExponentialA2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class AsymptoticExponentialA_LinearGrowthAndOffset_2D(AsymptoticExponentialA2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class AsymptoticExponentialA_ExponentialGrowthAndOffset_2D(AsymptoticExponentialA2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class AsymptoticExponentialA_Transform2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Asymptotic Exponential A Transform"
        self.HTML = "y = 1.0 - a<SUP>bx + c</SUP>"
        self.coefficientDesignatorTuple = ("a", 'b', 'c')

        self.function_cpp_code = 'temp = 1.0 - pow(coeff[0], coeff[1] * indep_data[(int)cachedWeaveOffsets[0] + i] + coeff[2]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = 1.0 - pow(a, b * x_in + c);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = 1.0 - Math.pow(a, b * x_in + c);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = 1.0 - Math.Pow(a, b * x_in + c);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = 1.0 - math.pow(a, b * x_in + c)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = 1.0 - pow(a, b * x_in + c)\n"
        return s


class AsymptoticExponentialA_Transform_WO_2D(AsymptoticExponentialA_Transform2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class AsymptoticExponentialA_Transform_LinearDecay_2D(AsymptoticExponentialA_Transform2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class AsymptoticExponentialA_Transform_LinearGrowth_2D(AsymptoticExponentialA_Transform2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class AsymptoticExponentialA_Transform_ExponentialGrowth_2D(AsymptoticExponentialA_Transform2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class AsymptoticExponentialA_Transform_LinearDecayAndOffset_2D(AsymptoticExponentialA_Transform2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class AsymptoticExponentialA_Transform_LinearGrowthAndOffset_2D(AsymptoticExponentialA_Transform2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class AsymptoticExponentialA_Transform_ExponentialGrowthAndOffset_2D(AsymptoticExponentialA_Transform2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class AsymptoticExponentialB2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Asymptotic Exponential B"
        self.HTML = "y = a * (1.0 - e<SUP>bx</SUP>)"
        self.coefficientDesignatorTuple = ("a", "b")

        self.function_cpp_code = 'temp = coeff[0] * (1.0 - exp(coeff[1] * indep_data[(int)cachedWeaveOffsets[0] + i]));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a * (1.0 - exp(b * x_in));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a * (1.0 - Math.exp(b * x_in));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a * (1.0 - Math.Exp(b * x_in));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = a * (1.0 - math.exp(b * x_in))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = a * (1.0 - exp(b * x_in))\n"
        return s


class AsymptoticExponentialB_WO_2D(AsymptoticExponentialB2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class AsymptoticExponentialB_LinearDecay_2D(AsymptoticExponentialB2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class AsymptoticExponentialB_LinearGrowth_2D(AsymptoticExponentialB2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class AsymptoticExponentialB_ExponentialGrowth_2D(AsymptoticExponentialB2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class AsymptoticExponentialB_LinearDecayAndOffset_2D(AsymptoticExponentialB2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class AsymptoticExponentialB_LinearGrowthAndOffset_2D(AsymptoticExponentialB2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class AsymptoticExponentialB_ExponentialGrowthAndOffset_2D(AsymptoticExponentialB2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class SimpleScaledExponential2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Simple Scaled Exponential"
        self.HTML = "y = a * e<SUP>x</SUP>"
        self.coefficientDesignatorTuple = ("a")

        self.function_cpp_code = 'temp = coeff[0] * indep_data[(int)cachedWeaveOffsets[0] + i];// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_ExpX(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a * exp(x_in);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a * Math.exp(x_in);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a * Math.Exp(x_in);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = a * math.exp(x_in)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = a * exp(x_in)\n"
        return s


class SimpleScaledExponential_WO_2D(SimpleScaledExponential2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class SimpleScaledExponential_LinearDecay_2D(SimpleScaledExponential2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class SimpleScaledExponential_LinearGrowth_2D(SimpleScaledExponential2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class SimpleScaledExponential_ExponentialGrowth_2D(SimpleScaledExponential2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class SimpleScaledExponential_LinearDecayAndOffset_2D(SimpleScaledExponential2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class SimpleScaledExponential_LinearGrowthAndOffset_2D(SimpleScaledExponential2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class SimpleScaledExponential_ExponentialGrowthAndOffset_2D(SimpleScaledExponential2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class Exponential2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Exponential"
        self.HTML = "y = a * e<SUP>bx</SUP>"
        self.coefficientDesignatorTuple = ("a", "b")

        self.function_cpp_code = 'temp = coeff[0] * exp(coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a * exp(b*x_in);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a * Math.exp(b*x_in);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a * Math.Exp(b*x_in);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = a * math.exp(b*x_in)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = a * exp(b*x_in)\n"
        return s


class Exponential_WO_2D(Exponential2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class Exponential_LinearDecay_2D(Exponential2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class Exponential_ExponentialDecay_2D(Exponential2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class Exponential_LinearGrowth_2D(Exponential2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class Exponential_ExponentialGrowth_2D(Exponential2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class Exponential_LinearDecayAndOffset_2D(Exponential2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class Exponential_ExponentialDecayAndOffset_2D(Exponential2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class Exponential_LinearGrowthAndOffset_2D(Exponential2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class Exponential_ExponentialGrowthAndOffset_2D(Exponential2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class OffsetExponential2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Offset Exponential"
        self.HTML = "y = a * e<SUP>bx + c</SUP>"
        self.coefficientDesignatorTuple = ("a", "b", "c")

        self.function_cpp_code = 'temp = coeff[0] * exp(coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[2]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a * exp(b*x_in + c);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a * Math.exp(b*x_in + c);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a * Math.Exp(b*x_in + c);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = a * math.exp(b*x_in + c)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = a * exp(b*x_in + c)\n"
        return s


class OffsetExponential_WO_2D(OffsetExponential2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class OffsetExponential_LinearDecay_2D(OffsetExponential2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class OffsetExponential_ExponentialDecay_2D(OffsetExponential2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class OffsetExponential_LinearGrowth_2D(OffsetExponential2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class OffsetExponential_ExponentialGrowth_2D(OffsetExponential2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class OffsetExponential_LinearDecayAndOffset_2D(OffsetExponential2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class OffsetExponential_ExponentialDecayAndOffset_2D(OffsetExponential2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class OffsetExponential_LinearGrowthAndOffset_2D(OffsetExponential2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class OffsetExponential_ExponentialGrowthAndOffset_2D(OffsetExponential2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class ShiftedExponential2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Shifted Exponential"
        self.HTML = "y = a * e<SUP>x + b</SUP>"
        self.coefficientDesignatorTuple = ("a", "b")

        self.function_cpp_code = 'temp = coeff[0] * exp(indep_data[(int)cachedWeaveOffsets[0] + i] + coeff[1]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a * exp(x_in + b);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a * Math.exp(x_in + b);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a * Math.Exp(x_in + b);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = a * math.exp(x_in + b)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = a * exp(x_in + b)\n"
        return s


class ShiftedExponential_WO_2D(ShiftedExponential2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class ShiftedExponential_LinearDecay_2D(ShiftedExponential2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class ShiftedExponential_ExponentialDecay_2D(ShiftedExponential2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class ShiftedExponential_LinearGrowth_2D(ShiftedExponential2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class ShiftedExponential_ExponentialGrowth_2D(ShiftedExponential2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class ShiftedExponential_LinearDecayAndShifted_2D(ShiftedExponential2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class ShiftedExponential_ExponentialDecayAndShifted_2D(ShiftedExponential2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class ShiftedExponential_LinearGrowthAndShifted_2D(ShiftedExponential2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class ShiftedExponential_ExponentialGrowthAndShifted_2D(ShiftedExponential2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class InvExponential2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Inverse Exponential"
        self.HTML = "y = a * e<SUP>b/x</SUP>"
        self.coefficientDesignatorTuple = ("a", "b")
        self.RequiresNonzeroX = 1

        self.function_cpp_code = 'temp = coeff[0] * exp(coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_InverseX(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a * exp(b/x_in);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a * Math.exp(b/x_in);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a * Math.Exp(b/x_in);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = a * math.exp(b/x_in)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = a * exp(b/x_in)\n"
        return s


class InvExponential_WO_2D(InvExponential2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class InvExponential_LinearDecay_2D(InvExponential2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class InvExponential_ExponentialDecay_2D(InvExponential2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class InvExponential_LinearGrowth_2D(InvExponential2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class InvExponential_ExponentialGrowth_2D(InvExponential2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class InvExponential_LinearDecayAndOffset_2D(InvExponential2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class InvExponential_ExponentialDecayAndOffset_2D(InvExponential2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class InvExponential_LinearGrowthAndOffset_2D(InvExponential2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class InvExponential_ExponentialGrowthAndOffset_2D(InvExponential2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class Hocket_Sherby2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Hocket-Sherby"
        self.HTML = "y = b - (b-a) * e<SUP>(-c * (x^d))</SUP>"
        self.coefficientDesignatorTuple = ("a", "b", "c", "d")

        self.function_cpp_code = 'temp = coeff[1] - (coeff[1] - coeff[0]) * exp(-1.0 * coeff[2] * pow(indep_data[(int)cachedWeaveOffsets[2] + i], coeff[3]));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = b - (b-a) * exp(-1.0 * c * pow(x_in, d));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = b - (b-a) * Math.exp(-1.0 * c * Math.pow(x_in, d));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = b - (b-a) * Math.Exp(-1.0 * c * Math.Pow(x_in, d));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = b - (b-a) * math.exp(-1.0 * c * math.pow(x_in, d))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = b - (b-a) * exp(-1.0 * c * (x_in ^ d))\n"
        return s


class Hocket_Sherby_LinearDecay_2D(Hocket_Sherby2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class Hocket_Sherby_ExponentialDecay_2D(Hocket_Sherby2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class Hocket_Sherby_LinearGrowth_2D(Hocket_Sherby2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class Hocket_Sherby_ExponentialGrowth_2D(Hocket_Sherby2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class Hocket_Sherby_LinearDecayAndOffset_2D(Hocket_Sherby2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class Hocket_Sherby_ExponentialDecayAndOffset_2D(Hocket_Sherby2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class Hocket_Sherby_LinearGrowthAndOffset_2D(Hocket_Sherby2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class Hocket_Sherby_ExponentialGrowthAndOffset_2D(Hocket_Sherby2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
