#    pythonequations is a collection of equations expressed as Python classes
#    Copyright (C) 2008 James R. Phillips
#    2548 Vera Cruz Drive
#    Birmingham, AL 35235 USA
#    email: zunzun@zunzun.com
#
#    Version info: $Id$
#
#    License: BSD-style (see LICENSE.txt in main source directory)

import pythonequations, pythonequations.EquationBaseClasses
import numpy
numpy.seterr(all = 'raise') # numpy raises warnings, convert to exceptions to trap them

class CrystalResonatorAgeing2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Crystal Resonator Ageing MIL-PRF-55310E"
        self.HTML = "y = A(ln(Bt + 1)) + f0"
        self.coefficientDesignatorTuple = ("A", "B", "f0")
        self.RequiresPositiveX = 1

        self.function_cpp_code = 'temp = coeff[0] * (log(coeff[1] * indep_data[(int)cachedWeaveOffsets[0] + i] + 1.0)) + coeff[2];// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_LogX(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = A * (log(B * x_in + 1.0)) + f0;\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = A * (Math.log(B * x_in + 1.0)) + f0;\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = A * (Math.Log(B * x_in + 1.0)) + f0;\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = A * (math.log(B * x_in + 1.0)) + f0\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = A * (log(B * x_in + 1.0)) + f0\n"
        return s


class CrystalResonatorAgeing_LinearDecay_2D(CrystalResonatorAgeing2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class CrystalResonatorAgeing_ExponentialDecay_2D(CrystalResonatorAgeing2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class CrystalResonatorAgeing_LinearGrowth_2D(CrystalResonatorAgeing2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class CrystalResonatorAgeing_ExponentialGrowth_2D(CrystalResonatorAgeing2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class CrystalResonatorAgeing_LinearDecayAndOffset_2D(CrystalResonatorAgeing2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class CrystalResonatorAgeing_ExponentialDecayAndOffset_2D(CrystalResonatorAgeing2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class CrystalResonatorAgeing_LinearGrowthAndOffset_2D(CrystalResonatorAgeing2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class CrystalResonatorAgeing_ExponentialGrowthAndOffset_2D(CrystalResonatorAgeing2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class LinearLogarithmic2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Linear Logarithmic"
        self.HTML = "y = a + b*ln(x)"
        self.coefficientDesignatorTuple = ("a", "b")
        self.LinearSSQSolverFlag = 1
        self.RequiresPositiveX = 1

        self.function_cpp_code = 'temp = coeff[0] + coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i];// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogX(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a + b*log(x_in);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a + b*Math.log(x_in);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a + b*Math.Log(x_in);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = a + b*math.log(x_in)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = a + b*log(x_in)\n"
        return s


class LinearLogarithmic_LinearDecay_2D(LinearLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class LinearLogarithmic_ExponentialDecay_2D(LinearLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class LinearLogarithmic_LinearGrowth_2D(LinearLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class LinearLogarithmic_ExponentialGrowth_2D(LinearLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class LinearLogarithmic_LinearDecayAndOffset_2D(LinearLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class LinearLogarithmic_ExponentialDecayAndOffset_2D(LinearLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class LinearLogarithmic_LinearGrowthAndOffset_2D(LinearLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class LinearLogarithmic_ExponentialGrowthAndOffset_2D(LinearLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class QuadraticLogarithmic2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Quadratic Logarithmic"
        self.HTML = "y = a + b*ln(x) + c*ln(x)<sup>2</sup>"
        self.coefficientDesignatorTuple = ("a", "b", 'c')
        self.LinearSSQSolverFlag = 1
        self.RequiresPositiveX = 1

        self.function_cpp_code = 'temp = coeff[0] + coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[2] * indep_data[(int)cachedWeaveOffsets[2] + i];// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogX(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_PowLogX(NameOrValueFlag=1, args=[2.0]), [2.0]])

    def SpecificCodeCPP(self):
        s = "\ttemp = a + b*log(x_in) + c*pow(log(x_in), 2.0);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a + b*Math.log(x_in) + c*Math.pow(Math.log(x_in), 2.0);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a + b*Math.Log(x_in) + c*Math.Pow(Math.Log(x_in), 2.0);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = a + b*math.log(x_in) + c*math.pow(math.log(x_in), 2.0)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = a + b*log(x_in) + c*log(x_in) ^ 2.0\n"
        return s


class QuadraticLogarithmic_LinearDecay_2D(QuadraticLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class QuadraticLogarithmic_ExponentialDecay_2D(QuadraticLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class QuadraticLogarithmic_LinearGrowth_2D(QuadraticLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class QuadraticLogarithmic_ExponentialGrowth_2D(QuadraticLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class QuadraticLogarithmic_LinearDecayAndOffset_2D(QuadraticLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class QuadraticLogarithmic_ExponentialDecayAndOffset_2D(QuadraticLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class QuadraticLogarithmic_LinearGrowthAndOffset_2D(QuadraticLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class QuadraticLogarithmic_ExponentialGrowthAndOffset_2D(QuadraticLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class CubicLogarithmic2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Cubic Logarithmic"
        self.HTML = "y = a + b*ln(x) + c*ln(x)<sup>2</sup> + d*ln(x)<sup>3</sup>"
        self.coefficientDesignatorTuple = ("a", "b", 'c', 'd')
        self.LinearSSQSolverFlag = 1
        self.RequiresPositiveX = 1

        self.function_cpp_code = 'temp = coeff[0] + coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[2] * indep_data[(int)cachedWeaveOffsets[2] + i] + coeff[3] * indep_data[(int)cachedWeaveOffsets[3] + i];// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogX(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_PowLogX(NameOrValueFlag=1, args=[2.0]), [2.0]])
        self.CacheGenerationList.append([self.CG_PowLogX(NameOrValueFlag=1, args=[3.0]), [3.0]])

    def SpecificCodeCPP(self):
        s = "\ttemp = a + b*log(x_in) + c*pow(log(x_in), 2.0) + d*pow(log(x_in), 3.0);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a + b*Math.log(x_in) + c*Math.pow(Math.log(x_in), 2.0) + d*Math.pow(Math.log(x_in), 3.0);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a + b*Math.Log(x_in) + c*Math.Pow(Math.Log(x_in), 2.0) + d*Math.Pow(Math.Log(x_in), 3.0);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = a + b*math.log(x_in) + c*math.pow(math.log(x_in), 2.0) + d*math.pow(math.log(x_in), 3.0)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = a + b*log(x_in) + c*log(x_in) ^ 2.0 + d*log(x_in) ^ 3.0\n"
        return s


class CubicLogarithmic_LinearDecay_2D(CubicLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class CubicLogarithmic_ExponentialDecay_2D(CubicLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class CubicLogarithmic_LinearGrowth_2D(CubicLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class CubicLogarithmic_ExponentialGrowth_2D(CubicLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class CubicLogarithmic_LinearDecayAndOffset_2D(CubicLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class CubicLogarithmic_ExponentialDecayAndOffset_2D(CubicLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class CubicLogarithmic_LinearGrowthAndOffset_2D(CubicLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class CubicLogarithmic_ExponentialGrowthAndOffset_2D(CubicLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()



class ReciprocalLinearLogarithmic2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Reciprocal Linear Logarithmic"
        self.HTML = "y = 1.0 / (a + b*ln(x))"
        self.coefficientDesignatorTuple = ("a", "b")
        self.LinearSSQSolverFlag = 1
        self.RequiresPositiveX = 1

        self.function_cpp_code = 'temp = 1.0 / (coeff[0] + coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogX(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = 1.0 / (a + b*log(x_in));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = 1.0 / (a + b*Math.log(x_in));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = 1.0 / (a + b*Math.Log(x_in));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = 1.0 / (a + b*math.log(x_in))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = 1.0 / (a + b*log(x_in))\n"
        return s


class ReciprocalLinearLogarithmic_LinearDecay_2D(ReciprocalLinearLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class ReciprocalLinearLogarithmic_ExponentialDecay_2D(ReciprocalLinearLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class ReciprocalLinearLogarithmic_LinearGrowth_2D(ReciprocalLinearLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class ReciprocalLinearLogarithmic_ExponentialGrowth_2D(ReciprocalLinearLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class ReciprocalLinearLogarithmic_LinearDecayAndOffset_2D(ReciprocalLinearLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class ReciprocalLinearLogarithmic_ExponentialDecayAndOffset_2D(ReciprocalLinearLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class ReciprocalLinearLogarithmic_LinearGrowthAndOffset_2D(ReciprocalLinearLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class ReciprocalLinearLogarithmic_ExponentialGrowthAndOffset_2D(ReciprocalLinearLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class InverseLinearLogarithmic2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Inverse Linear Logarithmic"
        self.HTML = "y = x/ (a + b*ln(x))"
        self.coefficientDesignatorTuple = ("a", "b")
        self.LinearSSQSolverFlag = 1
        self.RequiresPositiveX = 1

        self.function_cpp_code = 'temp = indep_data[(int)cachedWeaveOffsets[0] + i] / (coeff[0] + coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogX(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = x_in / (a + b*log(x_in));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = x_in / (a + b*Math.log(x_in));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = x_in / (a + b*Math.Log(x_in));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = x_in / (a + b*math.log(x_in))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = x_in / (a + b*log(x_in))\n"
        return s


class InverseLinearLogarithmic_LinearDecay_2D(InverseLinearLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class InverseLinearLogarithmic_ExponentialDecay_2D(InverseLinearLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class InverseLinearLogarithmic_LinearGrowth_2D(InverseLinearLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class InverseLinearLogarithmic_ExponentialGrowth_2D(InverseLinearLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class InverseLinearLogarithmic_LinearDecayAndOffset_2D(InverseLinearLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class InverseLinearLogarithmic_ExponentialDecayAndOffset_2D(InverseLinearLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class InverseLinearLogarithmic_LinearGrowthAndOffset_2D(InverseLinearLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class InverseLinearLogarithmic_ExponentialGrowthAndOffset_2D(InverseLinearLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class ReciprocalQuadraticLogarithmic2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Reciprocal Quadratic Logarithmic"
        self.HTML = "y = 1.0 / (a + b*ln(x) + c*ln(x)<sup>2</sup>)"
        self.coefficientDesignatorTuple = ("a", "b", 'c')
        self.LinearSSQSolverFlag = 1
        self.RequiresPositiveX = 1

        self.function_cpp_code = 'temp = 1.0 / (coeff[0] + coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[2] * indep_data[(int)cachedWeaveOffsets[2] + i]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogX(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_PowLogX(NameOrValueFlag=1, args=[2.0]), [2.0]])

    def SpecificCodeCPP(self):
        s = "\ttemp = 1.0 / (a + b*log(x_in) + c*pow(log(x_in), 2.0));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = 1.0 / (a + b*Math.log(x_in) + c*Math.pow(Math.log(x_in), 2.0));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = 1.0 / (a + b*Math.Log(x_in) + c*Math.Pow(Math.Log(x_in), 2.0));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = 1.0 / (a + b*math.log(x_in) + c*math.pow(math.log(x_in), 2.0))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = 1.0 / (a + b*log(x_in) + c*log(x_in) ^ 2.0)\n"
        return s


class ReciprocalQuadraticLogarithmic_LinearDecay_2D(ReciprocalQuadraticLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class ReciprocalQuadraticLogarithmic_ExponentialDecay_2D(ReciprocalQuadraticLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class ReciprocalQuadraticLogarithmic_LinearGrowth_2D(ReciprocalQuadraticLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class ReciprocalQuadraticLogarithmic_ExponentialGrowth_2D(ReciprocalQuadraticLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class ReciprocalQuadraticLogarithmic_LinearDecayAndOffset_2D(ReciprocalQuadraticLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class ReciprocalQuadraticLogarithmic_ExponentialDecayAndOffset_2D(ReciprocalQuadraticLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class ReciprocalQuadraticLogarithmic_LinearGrowthAndOffset_2D(ReciprocalQuadraticLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class ReciprocalQuadraticLogarithmic_ExponentialGrowthAndOffset_2D(ReciprocalQuadraticLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class InverseQuadraticLogarithmic2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Inverse Quadratic Logarithmic"
        self.HTML = "y = x / (a + b*ln(x) + c*ln(x)<sup>2</sup>)"
        self.coefficientDesignatorTuple = ("a", "b", 'c')
        self.LinearSSQSolverFlag = 1
        self.RequiresPositiveX = 1

        self.function_cpp_code = 'temp = indep_data[(int)cachedWeaveOffsets[0] + i] / (coeff[0] + coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[2] * indep_data[(int)cachedWeaveOffsets[2] + i]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogX(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_PowLogX(NameOrValueFlag=1, args=[2.0]), [2.0]])

    def SpecificCodeCPP(self):
        s = "\ttemp = x_in / (a + b*log(x_in) + c*pow(log(x_in), 2.0));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = x_in / (a + b*Math.log(x_in) + c*Math.pow(Math.log(x_in), 2.0));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = x_in / (a + b*Math.Log(x_in) + c*Math.Pow(Math.Log(x_in), 2.0));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = x_in / (a + b*math.log(x_in) + c*math.pow(math.log(x_in), 2.0))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = x_in / (a + b*log(x_in) + c*log(x_in) ^ 2.0)\n"
        return s


class InverseQuadraticLogarithmic_LinearDecay_2D(InverseQuadraticLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class InverseQuadraticLogarithmic_ExponentialDecay_2D(InverseQuadraticLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class InverseQuadraticLogarithmic_LinearGrowth_2D(InverseQuadraticLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class InverseQuadraticLogarithmic_ExponentialGrowth_2D(InverseQuadraticLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class InverseQuadraticLogarithmic_LinearDecayAndOffset_2D(InverseQuadraticLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class InverseQuadraticLogarithmic_ExponentialDecayAndOffset_2D(InverseQuadraticLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class InverseQuadraticLogarithmic_LinearGrowthAndOffset_2D(InverseQuadraticLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class InverseQuadraticLogarithmic_ExponentialGrowthAndOffset_2D(InverseQuadraticLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class ReciprocalCubicLogarithmic2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Reciprocal Cubic Logarithmic"
        self.HTML = "y = 1.0 / (a + b*ln(x) + c*ln(x)<sup>2</sup> + d*ln(x)<sup>3</sup>)"
        self.coefficientDesignatorTuple = ("a", "b", 'c', 'd')
        self.LinearSSQSolverFlag = 1
        self.RequiresPositiveX = 1

        self.function_cpp_code = 'temp = 1.0 / (coeff[0] + coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[2] * indep_data[(int)cachedWeaveOffsets[2] + i] + coeff[3] * indep_data[(int)cachedWeaveOffsets[3] + i]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogX(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_PowLogX(NameOrValueFlag=1, args=[2.0]), [2.0]])
        self.CacheGenerationList.append([self.CG_PowLogX(NameOrValueFlag=1, args=[3.0]), [3.0]])

    def SpecificCodeCPP(self):
        s = "\ttemp = 1.0 / (a + b*log(x_in) + c*pow(log(x_in), 2.0) + d*pow(log(x_in), 3.0));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = 1.0 / (a + b*Math.log(x_in) + c*Math.pow(Math.log(x_in), 2.0) + d*Math.pow(Math.log(x_in), 3.0));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = 1.0 / (a + b*Math.Log(x_in) + c*Math.Pow(Math.Log(x_in), 2.0) + d*Math.Pow(Math.Log(x_in), 3.0));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = 1.0 / (a + b*math.log(x_in) + c*math.pow(math.log(x_in), 2.0) + d*math.pow(math.log(x_in), 3.0))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = 1.0 / (a + b*log(x_in) + c*log(x_in) ^ 2.0 + d*log(x_in) ^ 3.0)\n"
        return s


class ReciprocalCubicLogarithmic_LinearDecay_2D(ReciprocalCubicLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class ReciprocalCubicLogarithmic_ExponentialDecay_2D(ReciprocalCubicLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class ReciprocalCubicLogarithmic_LinearGrowth_2D(ReciprocalCubicLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class ReciprocalCubicLogarithmic_ExponentialGrowth_2D(ReciprocalCubicLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class ReciprocalCubicLogarithmic_LinearDecayAndOffset_2D(ReciprocalCubicLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class ReciprocalCubicLogarithmic_ExponentialDecayAndOffset_2D(ReciprocalCubicLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class ReciprocalCubicLogarithmic_LinearGrowthAndOffset_2D(ReciprocalCubicLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class ReciprocalCubicLogarithmic_ExponentialGrowthAndOffset_2D(ReciprocalCubicLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()



class InverseCubicLogarithmic2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Inverse Cubic Logarithmic"
        self.HTML = "y = x / (a + b*ln(x) + c*ln(x)<sup>2</sup> + d*ln(x)<sup>3</sup>)"
        self.coefficientDesignatorTuple = ("a", "b", 'c', 'd')
        self.LinearSSQSolverFlag = 1
        self.RequiresPositiveX = 1

        self.function_cpp_code = 'temp = indep_data[(int)cachedWeaveOffsets[1] + i] / (coeff[0] + coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[2] * indep_data[(int)cachedWeaveOffsets[2] + i] + coeff[3] * indep_data[(int)cachedWeaveOffsets[3] + i]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogX(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_PowLogX(NameOrValueFlag=1, args=[2.0]), [2.0]])
        self.CacheGenerationList.append([self.CG_PowLogX(NameOrValueFlag=1, args=[3.0]), [3.0]])

    def SpecificCodeCPP(self):
        s = "\ttemp = x_in / (a + b*log(x_in) + c*pow(log(x_in), 2.0) + d*pow(log(x_in), 3.0));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = x_in / (a + b*Math.log(x_in) + c*Math.pow(Math.log(x_in), 2.0) + d*Math.pow(Math.log(x_in), 3.0));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = x_in / (a + b*Math.Log(x_in) + c*Math.Pow(Math.Log(x_in), 2.0) + d*Math.Pow(Math.Log(x_in), 3.0));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = x_in / (a + b*math.log(x_in) + c*math.pow(math.log(x_in), 2.0) + d*math.pow(math.log(x_in), 3.0))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = x_in / (a + b*log(x_in) + c*log(x_in) ^ 2.0 + d*log(x_in) ^ 3.0)\n"
        return s


class InverseCubicLogarithmic_LinearDecay_2D(InverseCubicLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class InverseCubicLogarithmic_ExponentialDecay_2D(InverseCubicLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class InverseCubicLogarithmic_LinearGrowth_2D(InverseCubicLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class InverseCubicLogarithmic_ExponentialGrowth_2D(InverseCubicLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class InverseCubicLogarithmic_LinearDecayAndOffset_2D(InverseCubicLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class InverseCubicLogarithmic_ExponentialDecayAndOffset_2D(InverseCubicLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class InverseCubicLogarithmic_LinearGrowthAndOffset_2D(InverseCubicLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class InverseCubicLogarithmic_ExponentialGrowthAndOffset_2D(InverseCubicLogarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()



class Base10Logarithmic2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Base 10 Logarithmic"
        self.HTML = "y = a + b*log<SUB>10</SUB>(x)"
        self.coefficientDesignatorTuple = ("a", "b")
        self.LinearSSQSolverFlag = 1
        self.RequiresPositiveX = 1

        self.function_cpp_code = 'temp = coeff[0] + coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i];// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Log10X(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a + b*log10(x_in);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a + b*Math.log(x_in)/Math.log(10.0);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a + b*Math.Log(x_in)/Math.Log(10.0);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = a + b*math.log10(x_in)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = a + b*log10(x_in)\n"
        return s


class Base10Logarithmic_LinearDecay_2D(Base10Logarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class Base10Logarithmic_ExponentialDecay_2D(Base10Logarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class Base10Logarithmic_LinearGrowth_2D(Base10Logarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class Base10Logarithmic_ExponentialGrowth_2D(Base10Logarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class Base10Logarithmic_LinearDecayAndOffset_2D(Base10Logarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class Base10Logarithmic_ExponentialDecayAndOffset_2D(Base10Logarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class Base10Logarithmic_LinearGrowthAndOffset_2D(Base10Logarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class Base10Logarithmic_ExponentialGrowthAndOffset_2D(Base10Logarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()



class ReciprocalBase10Logarithmic2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Reciprocal Base 10 Logarithmic"
        self.HTML = "y = 1.0 / (a + b*log<SUB>10</SUB>(x))"
        self.coefficientDesignatorTuple = ("a", "b")
        self.RequiresPositiveX = 1

        self.function_cpp_code = 'temp = 1.0 / (coeff[0] + coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Log10X(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = 1.0 / (a + b*log10(x_in));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = 1.0 / (a + b*Math.log(x_in)/Math.log(10.0));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = 1.0 / (a + b*Math.Log(x_in)/Math.Log(10.0));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = 1.0 / (a + b*math.log10(x_in))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = 1.0 / (a + b*log10(x_in))\n"
        return s


class ReciprocalBase10Logarithmic_LinearDecay_2D(ReciprocalBase10Logarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class ReciprocalBase10Logarithmic_ExponentialDecay_2D(ReciprocalBase10Logarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class ReciprocalBase10Logarithmic_LinearGrowth_2D(ReciprocalBase10Logarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class ReciprocalBase10Logarithmic_ExponentialGrowth_2D(ReciprocalBase10Logarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class ReciprocalBase10Logarithmic_LinearDecayAndOffset_2D(ReciprocalBase10Logarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class ReciprocalBase10Logarithmic_ExponentialDecayAndOffset_2D(ReciprocalBase10Logarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class ReciprocalBase10Logarithmic_LinearGrowthAndOffset_2D(ReciprocalBase10Logarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class ReciprocalBase10Logarithmic_ExponentialGrowthAndOffset_2D(ReciprocalBase10Logarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class InverseBase10Logarithmic2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Inverse Base 10 Logarithmic"
        self.HTML = "y = x / (a + b*log<SUB>10</SUB>(x))"
        self.coefficientDesignatorTuple = ("a", "b")
        self.RequiresPositiveX = 1

        self.function_cpp_code = 'temp = indep_data[(int)cachedWeaveOffsets[1] + i] / (coeff[0] + coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Log10X(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = x_in / (a + b*log10(x_in));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = x_in / (a + b*Math.log(x_in)/Math.log(10.0));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = x_in / (a + b*Math.Log(x_in)/Math.Log(10.0));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = x_in / (a + b*math.log10(x_in))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = x_in / (a + b*log10(x_in))\n"
        return s


class InverseBase10Logarithmic_LinearDecay_2D(InverseBase10Logarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class InverseBase10Logarithmic_ExponentialDecay_2D(InverseBase10Logarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class InverseBase10Logarithmic_LinearGrowth_2D(InverseBase10Logarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class InverseBase10Logarithmic_ExponentialGrowth_2D(InverseBase10Logarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class InverseBase10Logarithmic_LinearDecayAndOffset_2D(InverseBase10Logarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class InverseBase10Logarithmic_ExponentialDecayAndOffset_2D(InverseBase10Logarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class InverseBase10Logarithmic_LinearGrowthAndOffset_2D(InverseBase10Logarithmic2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class InverseBase10Logarithmic_ExponentialGrowthAndOffset_2D(InverseBase10Logarithmic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


