#    pythonequations is a collection of equations expressed as Python classes
#    Copyright (C) 2008 James R. Phillips
#    2548 Vera Cruz Drive
#    Birmingham, AL 35235 USA
#    email: zunzun@zunzun.com
#
#    Version info: $Id$
#
#    License: BSD-style (see LICENSE.txt in main source directory)

import pythonequations, pythonequations.EquationBaseClasses
import numpy
numpy.seterr(all = 'raise') # numpy raises warnings, convert to exceptions to trap them

class NIST_Thurber2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "NIST Thurber"
        self.HTML = "y = (a + bx + cx<SUP>2</SUP> + dx<SUP>3</SUP>) / (1.0 + ex + fx<SUP>2</SUP> + gx<SUP>3</SUP>)"
        self.coefficientDesignatorTuple = ("a", "b", "c", "d", "e", "f", "g")

        self.function_cpp_code = 'temp = (coeff[0] + coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[2] * indep_data[(int)cachedWeaveOffsets[2] + i] + coeff[3] * indep_data[(int)cachedWeaveOffsets[3] + i]) / (1.0 + coeff[4] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[5] * indep_data[(int)cachedWeaveOffsets[2] + i] + coeff[6] * indep_data[(int)cachedWeaveOffsets[3] + i]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_PowX(NameOrValueFlag=1, args=[2.0]), [2.0]])
        self.CacheGenerationList.append([self.CG_PowX(NameOrValueFlag=1, args=[3.0]), [3.0]])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s = "\ttemp = " + j[0] + " + " + j[1] + " * x_in + " + j[2] + " * pow(x_in, 2.0) + " + j[3] + " * pow(x_in, 3.0) / (1.0 + " + j[4] + " * x_in + " + j[5] + " * pow(x_in, 2.0) + " + j[6] + " * pow(x_in, 3.0));\n"
        return s

    def SpecificCodeJAVA(self):
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s = "\ttemp = " + j[0] + " + " + j[1] + " * x_in + " + j[2] + " * Math.pow(x_in, 2.0) + " + j[3] + " * Math.pow(x_in, 3.0) / (1.0 + " + j[4] + " * x_in + " + j[5] + " * Math.pow(x_in, 2.0) + " + j[6] + " * Math.pow(x_in, 3.0));\n"
        return s

    def SpecificCodeCS(self):
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s = "\ttemp = " + j[0] + " + " + j[1] + " * x_in + " + j[2] + " * Math.Pow(x_in, 2.0) + " + j[3] + " * Math.Pow(x_in, 3.0) / (1.0 + " + j[4] + " * x_in + " + j[5] + " * Math.Pow(x_in, 2.0) + " + j[6] + " * Math.Pow(x_in, 3.0));\n"
        return s

    def SpecificCodePYTHON(self):
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s = "\ttemp = " + j[0] + " + " + j[1] + " * x_in + " + j[2] + " * math.pow(x_in, 2.0) + " + j[3] + " * math.pow(x_in, 3.0) / (1.0 + " + j[4] + " * x_in + " + j[5] + " * math.pow(x_in, 2.0) + " + j[6] + " * math.pow(x_in, 3.0))\n"
        return s

    def SpecificCodeSCILAB(self):
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s = "\ttemp = " + j[0] + " + " + j[1] + " * x_in + " + j[2] + " * (x_in ^ 2.0) + " + j[3] + " * (x_in ^ 3.0) / (1.0 + " + j[4] + " * x_in + " + j[5] + " * (x_in ^ 2.0) + " + j[6] + " * (x_in ^ 3.0))\n"
        return s


class NIST_Thurber_WO_2D(NIST_Thurber2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class NIST_Thurber_LinearDecay_2D(NIST_Thurber2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class NIST_Thurber_ExponentialDecay_2D(NIST_Thurber2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class NIST_Thurber_LinearGrowth_2D(NIST_Thurber2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class NIST_Thurber_ExponentialGrowth_2D(NIST_Thurber2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class NIST_Thurber_LinearDecayAndOffset_2D(NIST_Thurber2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class NIST_Thurber_ExponentialDecayAndOffset_2D(NIST_Thurber2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class NIST_Thurber_LinearGrowthAndOffset_2D(NIST_Thurber2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class NIST_Thurber_ExponentialGrowthAndOffset_2D(NIST_Thurber2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class NIST_Roszman2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "NIST Roszman"
        self.HTML = "y = a - bx - (arctan[c/(x-d)] / pi)"
        self.coefficientDesignatorTuple = ("a", "b", "c", "d")

        self.function_cpp_code = 'temp = coeff[0] - coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i] - (atan(coeff[2] / (indep_data[(int)cachedWeaveOffsets[1] + i] - coeff[3])) / 3.14159265358979323846);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s = "\ttemp += " + j[0] + " - " + j[1] + " * x_in + atan(" + j[2] + "/" + "(x_in-" + j[3] + ")) / 3.14159265358979323846;\n"
        return s

    def SpecificCodeJAVA(self):
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s = "\ttemp += " + j[0] + " - " + j[1] + " * x_in + Math.atan(" + j[2] + "/" + "(x_in-" + j[3] + ")) / Math.PI;\n"
        return s

    def SpecificCodeCS(self):
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s = "\ttemp += " + j[0] + " - " + j[1] + " * x_in + Math.Atan(" + j[2] + "/" + "(x_in-" + j[3] + ")) / Math.PI;\n"
        return s

    def SpecificCodePYTHON(self):
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s = "\ttemp += " + j[0] + " - " + j[1] + " * x_in + math.atan(" + j[2] + "/" + "(x_in-" + j[3] + ")) / math.pi\n"
        return s

    def SpecificCodeSCILAB(self):
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s = "\ttemp = temp + " + j[0] + " - " + j[1] + " * x_in + atan(" + j[2] + "/" + "(x_in-" + j[3] + ")) / 3.14159265358979323846\n"
        return s


class NIST_Roszman_LinearDecay_2D(NIST_Roszman2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class NIST_Roszman_ExponentialDecay_2D(NIST_Roszman2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class NIST_Roszman_LinearGrowth_2D(NIST_Roszman2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class NIST_Roszman_ExponentialGrowth_2D(NIST_Roszman2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class NIST_Roszman_LinearDecayAndOffset_2D(NIST_Roszman2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class NIST_Roszman_ExponentialDecayAndOffset_2D(NIST_Roszman2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class NIST_Roszman_LinearGrowthAndOffset_2D(NIST_Roszman2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class NIST_Roszman_ExponentialGrowthAndOffset_2D(NIST_Roszman2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class NIST_Rat432D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "NIST Rat43"
        self.HTML = "y =  a / ((1.0 + exp[b - c*x])<SUP>(1.0/d)</SUP>)"
        self.coefficientDesignatorTuple = ("a", "b", "c", "d")

        self.function_cpp_code = 'temp = coeff[0] / pow(1.0 + exp(coeff[1] - indep_data[(int)cachedWeaveOffsets[1] + i] * coeff[2]), 1.0 / coeff[3]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " / pow(1.0 + exp(" + j[1] + " - " + j[2] + " * x_in), 1.0 / " + j[3] + ");\n"
        return s

    def SpecificCodeJAVA(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " / Math.pow(1.0 + Math.exp(" + j[1] + " - " + j[2] + " * x_in), 1.0 / " + j[3] + ");\n"
        return s

    def SpecificCodeCS(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " / Math.Pow(1.0 + Math.Exp(" + j[1] + " - " + j[2] + " * x_in), 1.0 / " + j[3] + ");\n"
        return s

    def SpecificCodePYTHON(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " / pow(1.0 + exp(" + j[1] + " - " + j[2] + " * x_in), 1.0 / " + j[3] + ")\n"
        return s

    def SpecificCodeSCILAB(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp = temp + " + j[0] + " / (1.0 + exp(" + j[1] + " - " + j[2] + " * x_in) ^ 1.0 / " + j[3] + ")\n"
        return s


class NIST_Rat43_WO_2D(NIST_Rat432D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class NIST_Rat43_LinearDecay_2D(NIST_Rat432D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class NIST_Rat43_ExponentialDecay_2D(NIST_Rat432D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class NIST_Rat43_LinearGrowth_2D(NIST_Rat432D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class NIST_Rat43_ExponentialGrowth_2D(NIST_Rat432D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class NIST_Rat43_LinearDecayAndOffset_2D(NIST_Rat432D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class NIST_Rat43_ExponentialDecayAndOffset_2D(NIST_Rat432D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class NIST_Rat43_LinearGrowthAndOffset_2D(NIST_Rat432D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class NIST_Rat43_ExponentialGrowthAndOffset_2D(NIST_Rat432D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class NIST_Rat422D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "NIST Rat42"
        self.HTML = "y =  a / (1.0 + exp[b - c*x])"
        self.coefficientDesignatorTuple = ("a", "b", "c")

        self.function_cpp_code = 'temp = coeff[0] / (1.0 + exp(coeff[1] - indep_data[(int)cachedWeaveOffsets[1] + i] * coeff[2]));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " / (1.0 + exp(" + j[1] + " - " + j[2] + " * x_in));\n"
        return s

    def SpecificCodeJAVA(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " / (1.0 + Math.exp(" + j[1] + " - " + j[2] + " * x_in));\n"
        return s

    def SpecificCodeCS(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " / (1.0 + Math.Exp(" + j[1] + " - " + j[2] + " * x_in));\n"
        return s

    def SpecificCodePYTHON(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " / (1.0 + exp(" + j[1] + " - " + j[2] + " * x_in))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp = temp + " + j[0] + " / (1.0 + exp(" + j[1] + " - " + j[2] + " * x_in))\n"
        return s


class NIST_Rat42_WO_2D(NIST_Rat422D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class NIST_Rat42_LinearDecay_2D(NIST_Rat422D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class NIST_Rat42_ExponentialDecay_2D(NIST_Rat422D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class NIST_Rat42_LinearGrowth_2D(NIST_Rat422D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class NIST_Rat42_ExponentialGrowth_2D(NIST_Rat422D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class NIST_Rat42_LinearDecayAndOffset_2D(NIST_Rat422D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class NIST_Rat42_ExponentialDecayAndOffset_2D(NIST_Rat422D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class NIST_Rat42_LinearGrowthAndOffset_2D(NIST_Rat422D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class NIST_Rat42_ExponentialGrowthAndOffset_2D(NIST_Rat422D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class NIST_Misra1a2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "NIST Misra1a"
        self.HTML = "y =  a * (1.0 - e<SUP>-b*x</SUP>)"
        self.coefficientDesignatorTuple = ("a", "b")

        self.function_cpp_code = 'temp = coeff[0] * (1.0 - exp(coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i]));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_NegX(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " * (1.0 - exp(-1.0 * " + j[1] + " * x_in));\n"
        return s

    def SpecificCodeJAVA(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " * (1.0 - Math.exp(-1.0 * " + j[1] + " * x_in));\n"
        return s

    def SpecificCodeCS(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " * (1.0 - Math.Exp(-1.0 * " + j[1] + " * x_in));\n"
        return s

    def SpecificCodePYTHON(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " * (1.0 - exp(-1.0 * " + j[1] + " * x_in))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp = temp + " + j[0] + " * (1.0 - exp(-1.0 * " + j[1] + " * x_in))\n"
        return s


class NIST_Misra1a_WO_2D(NIST_Misra1a2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class NIST_Misra1a_LinearDecay_2D(NIST_Misra1a2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class NIST_Misra1a_ExponentialDecay_2D(NIST_Misra1a2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class NIST_Misra1a_LinearGrowth_2D(NIST_Misra1a2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class NIST_Misra1a_ExponentialGrowth_2D(NIST_Misra1a2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class NIST_Misra1a_LinearDecayAndOffset_2D(NIST_Misra1a2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class NIST_Misra1a_ExponentialDecayAndOffset_2D(NIST_Misra1a2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class NIST_Misra1a_LinearGrowthAndOffset_2D(NIST_Misra1a2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class NIST_Misra1a_ExponentialGrowthAndOffset_2D(NIST_Misra1a2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class NIST_Misra1b2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "NIST Misra1b"
        self.HTML = "y =  a * (1.0 - (1.0+b*x/2.0)<SUP>-2.0</SUP>)"
        self.coefficientDesignatorTuple = ("a", "b")

        self.function_cpp_code = 'temp = coeff[0] * (1.0 - pow(1.0 + coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i] / 2.0, -2.0));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " * (1.0 - pow(1.0 + " + j[1] + " * x_in / 2.0, -2.0));\n"
        return s

    def SpecificCodeJAVA(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " * (1.0 - Math.pow(1.0 + " + j[1] + " * x_in / 2.0, -2.0));\n"
        return s

    def SpecificCodeCS(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " * (1.0 - Math.Pow(1.0 + " + j[1] + " * x_in / 2.0, -2.0));\n"
        return s

    def SpecificCodePYTHON(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " * (1.0 - pow(1.0 + " + j[1] + " * x_in / 2.0, -2.0))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp = temp + " + j[0] + " * (1.0 -(1.0 + " + j[1] + " * x_in / 2.0 ^ -2.0))\n"
        return s


class NIST_Misra1b_WO_2D(NIST_Misra1b2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class NIST_Misra1b_LinearDecay_2D(NIST_Misra1b2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class NIST_Misra1b_ExponentialDecay_2D(NIST_Misra1b2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class NIST_Misra1b_LinearGrowth_2D(NIST_Misra1b2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class NIST_Misra1b_ExponentialGrowth_2D(NIST_Misra1b2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class NIST_Misra1b_LinearDecayAndOffset_2D(NIST_Misra1b2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class NIST_Misra1b_ExponentialDecayAndOffset_2D(NIST_Misra1b2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class NIST_Misra1b_LinearGrowthAndOffset_2D(NIST_Misra1b2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class NIST_Misra1b_ExponentialGrowthAndOffset_2D(NIST_Misra1b2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class NIST_Misra1c2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "NIST Misra1c"
        self.HTML = "y =  a * (1.0 - 2.0*b*x)<SUP>-0.5</SUP>"
        self.coefficientDesignatorTuple = ("a", "b")

        self.function_cpp_code = 'temp = coeff[0] * pow(1.0 - 2.0 * coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i], -0.5);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " * pow(1.0 - 2.0 * " + j[1] + " * x_in, -0.5);\n"
        return s

    def SpecificCodeJAVA(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " * Math.pow(1.0 - 2.0 * " + j[1] + " * x_in, -0.5);\n"
        return s

    def SpecificCodeCS(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " * Math.Pow(1.0 - 2.0 * " + j[1] + " * x_in, -0.5);\n"
        return s

    def SpecificCodePYTHON(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " * pow(1.0 - 2.0 * " + j[1] + " * x_in, -0.5)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp = temp + " + j[0] + " * (1.0 - 2.0 * " + j[1] + " * x_in ^ -0.5)\n"
        return s


class NIST_Misra1c_WO_2D(NIST_Misra1c2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class NIST_Misra1c_LinearDecay_2D(NIST_Misra1c2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class NIST_Misra1c_ExponentialDecay_2D(NIST_Misra1c2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class NIST_Misra1c_LinearGrowth_2D(NIST_Misra1c2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class NIST_Misra1c_ExponentialGrowth_2D(NIST_Misra1c2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class NIST_Misra1c_LinearDecayAndOffset_2D(NIST_Misra1c2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class NIST_Misra1c_ExponentialDecayAndOffset_2D(NIST_Misra1c2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class NIST_Misra1c_LinearGrowthAndOffset_2D(NIST_Misra1c2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class NIST_Misra1c_ExponentialGrowthAndOffset_2D(NIST_Misra1c2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class NIST_Misra1d2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "NIST Misra1d"
        self.HTML = "y =  a * b * x * (1.0 + b*x)<SUP>-1.0</SUP>"
        self.coefficientDesignatorTuple = ("a", "b")

        self.function_cpp_code = 'temp = coeff[0] * coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i] * pow(1.0 + coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i], -1.0);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " * " + j[1] + " * x_in / (1.0 + " + j[1] + " * x_in);\n"
        return s

    def SpecificCodeJAVA(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " * " + j[1] + " * x_in / (1.0 + " + j[1] + " * x_in);\n"
        return s

    def SpecificCodeCS(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " * " + j[1] + " * x_in / (1.0 + " + j[1] + " * x_in);\n"
        return s

    def SpecificCodePYTHON(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " * " + j[1] + " * x_in / (1.0 + " + j[1] + " * x_in)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp = temp + " + j[0] + " * " + j[1] + " * x_in / (1.0 + " + j[1] + " * x_in)\n"
        return s


class NIST_Misra1d_WO_2D(NIST_Misra1d2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class NIST_Misra1d_LinearDecay_2D(NIST_Misra1d2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class NIST_Misra1d_ExponentialDecay_2D(NIST_Misra1d2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class NIST_Misra1d_LinearGrowth_2D(NIST_Misra1d2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class NIST_Misra1d_ExponentialGrowth_2D(NIST_Misra1d2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class NIST_Misra1d_LinearDecayAndOffset_2D(NIST_Misra1d2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class NIST_Misra1d_ExponentialDecayAndOffset_2D(NIST_Misra1d2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class NIST_Misra1d_LinearGrowthAndOffset_2D(NIST_Misra1d2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class NIST_Misra1d_ExponentialGrowthAndOffset_2D(NIST_Misra1d2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class NIST_Chwirut2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "NIST Chwirut"
        self.HTML = "y = e<SUP>(-a*x)</SUP> / (b + c*x)"
        self.coefficientDesignatorTuple = ("a", "b", "c")

        self.function_cpp_code = 'temp = exp(coeff[0]) * indep_data[(int)cachedWeaveOffsets[0] + i] / (coeff[1] + coeff[2] * indep_data[(int)cachedWeaveOffsets[2] + i]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_NegX(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += exp(-" + j[0] + " * x_in) / (" + j[1] + " + " + j[2] + " * x_in);\n"
        return s

    def SpecificCodeJAVA(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += Math.exp(-" + j[0] + " * x_in) / (" + j[1] + " + " + j[2] + " * x_in);\n"
        return s

    def SpecificCodeCS(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += Math.Exp(-" + j[0] + " * x_in) / (" + j[1] + " + " + j[2] + " * x_in);\n"
        return s

    def SpecificCodePYTHON(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += math.exp(-" + j[0] + " * x_in) / (" + j[1] + " + " + j[2] + " * x_in)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp = temp + exp(-" + j[0] + " * x_in) / (" + j[1] + " + " + j[2] + " * x_in)\n"
        return s


class NIST_Chwirut_WO_2D(NIST_Chwirut2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class NIST_Chwirut_LinearDecay_2D(NIST_Chwirut2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class NIST_Chwirut_ExponentialDecay_2D(NIST_Chwirut2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class NIST_Chwirut_LinearGrowth_2D(NIST_Chwirut2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class NIST_Chwirut_ExponentialGrowth_2D(NIST_Chwirut2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class NIST_Chwirut_LinearDecayAndOffset_2D(NIST_Chwirut2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class NIST_Chwirut_ExponentialDecayAndOffset_2D(NIST_Chwirut2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class NIST_Chwirut_LinearGrowthAndOffset_2D(NIST_Chwirut2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class NIST_Chwirut_ExponentialGrowthAndOffset_2D(NIST_Chwirut2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class NIST_Lanczos2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "NIST Lanczos"
        self.HTML = "y = a*exp(-b*x) + c*exp(-d*x) + e*exp(-f*x)"
        self.coefficientDesignatorTuple = ("a", "b", "c", "d", "e", "f")

        self.function_cpp_code = 'temp = coeff[0] * exp(coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i]) + coeff[2] * exp(coeff[3] * indep_data[(int)cachedWeaveOffsets[3] + i]) + coeff[4] * exp(coeff[5] * indep_data[(int)cachedWeaveOffsets[5] + i]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_NegX(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_NegX(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_NegX(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " * exp(-" + j[1] + " * x_in) + " + j[2] + " * exp(-" + j[3] + " * x_in) + " + j[4] + " * exp(-" + j[5] + " * x_in);\n"
        return s

    def SpecificCodeJAVA(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " * Math.exp(-" + j[1] + " * x_in) + " + j[2] + " * Math.exp(-" + j[3] + " * x_in) + " + j[4] + " * Math.exp(-" + j[5] + " * x_in);\n"
        return s

    def SpecificCodeCS(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " * Math.Exp(-" + j[1] + " * x_in) + " + j[2] + " * Math.Exp(-" + j[3] + " * x_in) + " + j[4] + " * Math.Exp(-" + j[5] + " * x_in);\n"
        return s

    def SpecificCodePYTHON(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " * math.exp(-" + j[1] + " * x_in) + " + j[2] + " * math.exp(-" + j[3] + " * x_in) + " + j[4] + " * math.exp(-" + j[5] + " * x_in)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp = temp + " + j[0] + " * exp(-" + j[1] + " * x_in) + " + j[2] + " * exp(-" + j[3] + " * x_in) + " + j[4] + " * exp(-" + j[5] + " * x_in)\n"
        return s


class NIST_Lanczos_WO_2D(NIST_Lanczos2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class NIST_Lanczos_LinearDecay_2D(NIST_Lanczos2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class NIST_Lanczos_ExponentialDecay_2D(NIST_Lanczos2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class NIST_Lanczos_LinearGrowth_2D(NIST_Lanczos2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class NIST_Lanczos_ExponentialGrowth_2D(NIST_Lanczos2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class NIST_Lanczos_LinearDecayAndOffset_2D(NIST_Lanczos2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class NIST_Lanczos_ExponentialDecayAndOffset_2D(NIST_Lanczos2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class NIST_Lanczos_LinearGrowthAndOffset_2D(NIST_Lanczos2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class NIST_Lanczos_ExponentialGrowthAndOffset_2D(NIST_Lanczos2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class NIST_Gauss2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "NIST Gauss"
        self.HTML = "y = a*e<SUP>(-b*x)</SUP> + c*e<SUP>(-(x-d)^2 / e^2)</SUP> + f*e<SUP>(-(x-g)^2 / h^2)</SUP>"
        self.coefficientDesignatorTuple = ("a", "b", "c", "d", "e", "f", "g", "h")

        self.function_cpp_code = 'temp = coeff[0] * exp(coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i]) + coeff[2] * exp(-pow(indep_data[(int)cachedWeaveOffsets[3] + i] - coeff[3], 2.0)) + coeff[4] * exp(-pow(indep_data[(int)cachedWeaveOffsets[3] + i] - coeff[5], 2.0));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_NegX(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " * exp(-" + j[1] + " * x_in) + " + j[2] + " * exp(-1.0 * (x_in-" + j[3] + ") * (x_in-" + j[3] + ") / (" + j[4] + " * " + j[4] + ")) + " + j[5] + " * exp(-1.0 * (x_in-" + j[6] + ") * (x_in-" + j[6] + ") / (" + j[7] + " * " + j[7] + "));\n"
        return s

    def SpecificCodeJAVA(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " * Math.exp(-" + j[1] + " * x_in) + " + j[2] + " * Math.exp(-1.0 * (x_in-" + j[3] + ") * (x_in-" + j[3] + ") / (" + j[4] + " * " + j[4] + ")) + " + j[5] + " * Math.exp(-1.0 * (x_in-" + j[6] + ") * (x_in-" + j[6] + ") / (" + j[7] + " * " + j[7] + "));\n"
        return s

    def SpecificCodeCS(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " * Math.Exp(-" + j[1] + " * x_in) + " + j[2] + " * Math.Exp(-1.0 * (x_in-" + j[3] + ") * (x_in-" + j[3] + ") / (" + j[4] + " * " + j[4] + ")) + " + j[5] + " * Math.Exp(-1.0 * (x_in-" + j[6] + ") * (x_in-" + j[6] + ") / (" + j[7] + " * " + j[7] + "));\n"
        return s

    def SpecificCodePYTHON(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " * math.exp(-" + j[1] + " * x_in) + " + j[2] + " * math.exp(-1.0 * (x_in-" + j[3] + ") * (x_in-" + j[3] + ") / (" + j[4] + " * " + j[4] + ")) + " + j[5] + " * math.exp(-1.0 * (x_in-" + j[6] + ") * (x_in-" + j[6] + ") / (" + j[7] + " * " + j[7] + "))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp = temp + " + j[0] + " * exp(-" + j[1] + " * x_in) + " + j[2] + " * exp(-1.0 * (x_in-" + j[3] + ") * (x_in-" + j[3] + ") / (" + j[4] + " * " + j[4] + ")) + " + j[5] + " * exp(-1.0 * (x_in-" + j[6] + ") * (x_in-" + j[6] + ") / (" + j[7] + " * " + j[7] + "))\n"
        return s


class NIST_Gauss_WO_2D(NIST_Gauss2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class NIST_Gauss_LinearDecay_2D(NIST_Gauss2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class NIST_Gauss_ExponentialDecay_2D(NIST_Gauss2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class NIST_Gauss_LinearGrowth_2D(NIST_Gauss2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class NIST_Gauss_ExponentialGrowth_2D(NIST_Gauss2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class NIST_Gauss_LinearDecayAndOffset_2D(NIST_Gauss2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class NIST_Gauss_ExponentialDecayAndOffset_2D(NIST_Gauss2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class NIST_Gauss_LinearGrowthAndOffset_2D(NIST_Gauss2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class NIST_Gauss_ExponentialGrowthAndOffset_2D(NIST_Gauss2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class NIST_DanWood2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "NIST DanWood"
        self.HTML = "y = a*x<SUP>b</SUP>"
        self.coefficientDesignatorTuple = ("a", "b")

        self.function_cpp_code = 'temp = coeff[0] * pow(indep_data[(int)cachedWeaveOffsets[1] + i], coeff[1]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " * pow(x_in, " + j[1] + ");\n"
        return s

    def SpecificCodeJAVA(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " * Math.pow(x_in, " + j[1] + ");\n"
        return s

    def SpecificCodeCS(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " * Math.Pow(x_in, " + j[1] + ");\n"
        return s

    def SpecificCodePYTHON(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " * math.pow(x_in, " + j[1] + ")\n"
        return s

    def SpecificCodeSCILAB(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp = temp + " + j[0] + " * (x_in ^ " + j[1] + ")\n"
        return s


class NIST_DanWood_WO_2D(NIST_DanWood2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class NIST_DanWood_LinearDecay_2D(NIST_DanWood2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class NIST_DanWood_ExponentialDecay_2D(NIST_DanWood2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class NIST_DanWood_LinearGrowth_2D(NIST_DanWood2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class NIST_DanWood_ExponentialGrowth_2D(NIST_DanWood2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class NIST_DanWood_LinearDecayAndOffset_2D(NIST_DanWood2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class NIST_DanWood_ExponentialDecayAndOffset_2D(NIST_DanWood2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class NIST_DanWood_LinearGrowthAndOffset_2D(NIST_DanWood2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class NIST_DanWood_ExponentialGrowthAndOffset_2D(NIST_DanWood2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class NIST_Kirby2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "NIST Kirby"
        self.HTML = "y = (a + b*x + c*x<SUP>2</SUP>) / (1.0 + d*x + e*x<SUP>2</SUP>)"
        self.coefficientDesignatorTuple = ("a", "b", "c", "d", "e")

        self.function_cpp_code = 'temp = (coeff[0] + coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[2] * indep_data[(int)cachedWeaveOffsets[2] + i]) / (1.0 + coeff[3] * indep_data[(int)cachedWeaveOffsets[3] + i] + coeff[4] * indep_data[(int)cachedWeaveOffsets[4] + i]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_PowX(NameOrValueFlag=1, args=[2.0]), [2.0]])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_PowX(NameOrValueFlag=1, args=[2.0]), [2.0]])

    def SpecificCodeCPP(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += (" + j[0] + " + " + j[1] + " * x_in + " + j[2] + " * x_in * x_in) / (1.0 + " + j[3] + " * x_in + " + j[4] + " * x_in * x_in);\n"
        return s

    def SpecificCodeJAVA(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += (" + j[0] + " + " + j[1] + " * x_in + " + j[2] + " * x_in * x_in) / (1.0 + " + j[3] + " * x_in + " + j[4] + " * x_in * x_in);\n"
        return s

    def SpecificCodeCS(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += (" + j[0] + " + " + j[1] + " * x_in + " + j[2] + " * x_in * x_in) / (1.0 + " + j[3] + " * x_in + " + j[4] + " * x_in * x_in);\n"
        return s

    def SpecificCodePYTHON(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += (" + j[0] + " + " + j[1] + " * x_in + " + j[2] + " * x_in * x_in) / (1.0 + " + j[3] + " * x_in + " + j[4] + " * x_in * x_in)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp = temp + (" + j[0] + " + " + j[1] + " * x_in + " + j[2] + " * x_in * x_in) / (1.0 + " + j[3] + " * x_in + " + j[4] + " * x_in * x_in)\n"
        return s


class NIST_Kirby_WO_2D(NIST_Kirby2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class NIST_Kirby_LinearDecay_2D(NIST_Kirby2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class NIST_Kirby_ExponentialDecay_2D(NIST_Kirby2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class NIST_Kirby_LinearGrowth_2D(NIST_Kirby2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class NIST_Kirby_ExponentialGrowth_2D(NIST_Kirby2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class NIST_Kirby_LinearDecayAndOffset_2D(NIST_Kirby2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class NIST_Kirby_ExponentialDecayAndOffset_2D(NIST_Kirby2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class NIST_Kirby_LinearGrowthAndOffset_2D(NIST_Kirby2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class NIST_Kirby_ExponentialGrowthAndOffset_2D(NIST_Kirby2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class NIST_Hahn2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "NIST Hahn"
        self.HTML = "y = (a + b*x + c*x<SUP>2</SUP> + d*x<SUP>3</SUP>) / (1.0 + e*x + f*x<SUP>2</SUP> + g*x<SUP>3</SUP>)"
        self.coefficientDesignatorTuple = ("a", "b", "c", "d", "e", "f", "g")

        self.function_cpp_code = 'temp = (coeff[0] + coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[2] * indep_data[(int)cachedWeaveOffsets[2] + i] + coeff[3] * indep_data[(int)cachedWeaveOffsets[3] + i]) / (1.0 + coeff[4] * indep_data[(int)cachedWeaveOffsets[4] + i] + coeff[5] * indep_data[(int)cachedWeaveOffsets[5] + i] + coeff[6] * indep_data[(int)cachedWeaveOffsets[6] + i]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_PowX(NameOrValueFlag=1, args=[2.0]), [2.0]])
        self.CacheGenerationList.append([self.CG_PowX(NameOrValueFlag=1, args=[3.0]), [3.0]])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_PowX(NameOrValueFlag=1, args=[2.0]), [2.0]])
        self.CacheGenerationList.append([self.CG_PowX(NameOrValueFlag=1, args=[3.0]), [3.0]])

    def SpecificCodeCPP(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += (" + j[0] + " + " + j[1] + " * x_in + " + j[2] + " * x_in * x_in + " + j[3] + " * x_in * x_in * x_in) / (1.0 + " + j[4] + " * x_in + " + j[5] + " * x_in * x_in + " + j[6] + " * x_in * x_in * x_in);\n"
        return s

    def SpecificCodeJAVA(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += (" + j[0] + " + " + j[1] + " * x_in + " + j[2] + " * x_in * x_in + " + j[3] + " * x_in * x_in * x_in) / (1.0 + " + j[4] + " * x_in + " + j[5] + " * x_in * x_in + " + j[6] + " * x_in * x_in * x_in);\n"
        return s

    def SpecificCodeCS(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += (" + j[0] + " + " + j[1] + " * x_in + " + j[2] + " * x_in * x_in + " + j[3] + " * x_in * x_in * x_in) / (1.0 + " + j[4] + " * x_in + " + j[5] + " * x_in * x_in + " + j[6] + " * x_in * x_in * x_in);\n"
        return s

    def SpecificCodePYTHON(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += (" + j[0] + " + " + j[1] + " * x_in + " + j[2] + " * x_in * x_in + " + j[3] + " * x_in * x_in * x_in) / (1.0 + " + j[4] + " * x_in + " + j[5] + " * x_in * x_in + " + j[6] + " * x_in * x_in * x_in)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp = temp + (" + j[0] + " + " + j[1] + " * x_in + " + j[2] + " * x_in * x_in + " + j[3] + " * x_in * x_in * x_in) / (1.0 + " + j[4] + " * x_in + " + j[5] + " * x_in * x_in + " + j[6] + " * x_in * x_in * x_in)\n"
        return s


class NIST_Hahn_WO_2D(NIST_Hahn2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class NIST_Hahn_LinearDecay_2D(NIST_Hahn2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class NIST_Hahn_ExponentialDecay_2D(NIST_Hahn2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class NIST_Hahn_LinearGrowth_2D(NIST_Hahn2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class NIST_Hahn_ExponentialGrowth_2D(NIST_Hahn2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class NIST_Hahn_LinearDecayAndOffset_2D(NIST_Hahn2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class NIST_Hahn_ExponentialDecayAndOffset_2D(NIST_Hahn2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class NIST_Hahn_LinearGrowthAndOffset_2D(NIST_Hahn2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class NIST_Hahn_ExponentialGrowthAndOffset_2D(NIST_Hahn2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class NIST_MGH172D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "NIST MGH17"
        self.HTML = "y = a + b*exp(-x*d) + c*exp(-x*e)"
        self.coefficientDesignatorTuple = ("a", "b", "c", "d", "e")

        self.function_cpp_code = 'temp = coeff[0] + coeff[1] * exp(indep_data[(int)cachedWeaveOffsets[3] + i] * coeff[3]) + coeff[2] * exp(indep_data[(int)cachedWeaveOffsets[4] + i] * coeff[4]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_NegX(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_NegX(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " + " + j[1] + " * exp(-1.0 * x_in * " + j[3] + ")" + " + " + j[2] + " * exp(-1.0 * x_in * " + j[4] + ");\n"
        return s

    def SpecificCodeJAVA(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " + " + j[1] + " * Math.exp(-1.0 * x_in * " + j[3] + ")" + " + " + j[2] + " * Math.exp(-1.0 * x_in * " + j[4] + ");\n"
        return s

    def SpecificCodeCS(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " + " + j[1] + " * Math.Exp(-1.0 * x_in * " + j[3] + ")" + " + " + j[2] + " * Math.Exp(-1.0 * x_in * " + j[4] + ");\n"
        return s

    def SpecificCodePYTHON(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " + " + j[1] + " * math.exp(-1.0 * x_in * " + j[3] + ")" + " + " + j[2] + " * math.exp(-1.0 * x_in * " + j[4] + ")\n"
        return s

    def SpecificCodeSCILAB(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp = temp + " + j[0] + " + " + j[1] + " * exp(-1.0 * x_in * " + j[3] + ")" + " + " + j[2] + " * exp(-1.0 * x_in * " + j[4] + ")\n"
        return s


class NIST_MGH17_LinearDecay_2D(NIST_MGH172D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class NIST_MGH17_ExponentialDecay_2D(NIST_MGH172D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class NIST_MGH17_LinearGrowth_2D(NIST_MGH172D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class NIST_MGH17_ExponentialGrowth_2D(NIST_MGH172D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class NIST_MGH17_LinearDecayAndOffset_2D(NIST_MGH172D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class NIST_MGH17_ExponentialDecayAndOffset_2D(NIST_MGH172D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class NIST_MGH17_LinearGrowthAndOffset_2D(NIST_MGH172D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class NIST_MGH17_ExponentialGrowthAndOffset_2D(NIST_MGH172D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class NIST_ENSO2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.HTMLIsSplitIntoTwoLinesOfHTML = 1
        self.name = "NIST ENSO"
        self.HTML = "y = a + b*cos(2*pi*x/12) + c*sin(2*pi*x/12) + e*cos(2*pi*x/d) +<br>f*sin(2*pi*x/d) + h*cos(2*pi*x/g) + i*sin(2*pi*x/g)"
        self.coefficientDesignatorTuple = ("a", "b", "c", "d", "e", "f", "g", "h", "i")

        self.function_cpp_code = 'temp = coeff[0] + coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[2] * indep_data[(int)cachedWeaveOffsets[2] + i] + coeff[4] * cos(indep_data[(int)cachedWeaveOffsets[3] + i]/coeff[3]) + coeff[5] * sin(indep_data[(int)cachedWeaveOffsets[3] + i]/coeff[3]) + coeff[7] * cos(indep_data[(int)cachedWeaveOffsets[3] + i]/coeff[6]) + coeff[8] * sin(indep_data[(int)cachedWeaveOffsets[3] + i]/coeff[6]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_NistEnsoCosX(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_NistEnsoSinX(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_TwoPiX(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\tdouble two_pi_x = 2.0 * 3.14159265358979323846 * x_in;\n"
        s += "\tdouble o12 = two_pi_x / 12.0;\n"
        s += "\tdouble od = two_pi_x / " + j[3] + ";\n"
        s += "\tdouble og = two_pi_x / " + j[6] + ";\n"
        s += "\ttemp += " + j[0] + " + " + j[1] + " * cos(o12) + " + j[2] + " * sin(o12);\n"
        s += "\ttemp += " + j[4] + " * cos(od) + " + j[5] + " * sin(od);\n"
        s += "\ttemp += " + j[7] + " * cos(og) + " + j[8] + " * sin(og);\n"
        return s

    def SpecificCodeJAVA(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\tdouble two_pi_x = 2.0 * 3.14159265358979323846 * x_in;\n"
        s += "\tdouble o12 = two_pi_x / 12.0;\n"
        s += "\tdouble od = two_pi_x / " + j[3] + ";\n"
        s += "\tdouble og = two_pi_x / " + j[6] + ";\n"
        s += "\ttemp += " + j[0] + " + " + j[1] + " * Math.cos(o12) + " + j[2] + " * Math.sin(o12);\n"
        s += "\ttemp += " + j[4] + " * Math.cos(od) + " + j[5] + " * Math.sin(od);\n"
        s += "\ttemp += " + j[7] + " * Math.cos(og) + " + j[8] + " * Math.sin(og);\n"
        return s

    def SpecificCodeCS(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\tdouble two_pi_x = 2.0 * 3.14159265358979323846 * x_in;\n"
        s += "\tdouble o12 = two_pi_x / 12.0;\n"
        s += "\tdouble od = two_pi_x / " + j[3] + ";\n"
        s += "\tdouble og = two_pi_x / " + j[6] + ";\n"
        s += "\ttemp += " + j[0] + " + " + j[1] + " * Math.Cos(o12) + " + j[2] + " * Math.Sin(o12);\n"
        s += "\ttemp += " + j[4] + " * Math.Cos(od) + " + j[5] + " * Math.Sin(od);\n"
        s += "\ttemp += " + j[7] + " * Math.Cos(og) + " + j[8] + " * Math.Sin(og);\n"
        return s

    def SpecificCodePYTHON(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttwo_pi_x = 2.0 * 3.14159265358979323846 * x_in\n"
        s += "\to12 = two_pi_x / 12.0\n"
        s += "\tod = two_pi_x / " + j[3] + "\n"
        s += "\tog = two_pi_x / " + j[6] + "\n"
        s += "\ttemp += " + j[0] + " + " + j[1] + " * math.cos(o12) + " + j[2] + " * math.sin(o12)\n"
        s += "\ttemp += " + j[4] + " * math.cos(od) + " + j[5] + " * math.sin(od)\n"
        s += "\ttemp += " + j[7] + " * math.cos(og) + " + j[8] + " * math.sin(og)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttwo_pi_x = 2.0 * 3.14159265358979323846 * x_in\n"
        s += "\to12 = two_pi_x / 12.0\n"
        s += "\tod = two_pi_x / " + j[3] + "\n"
        s += "\tog = two_pi_x / " + j[6] + "\n"
        s += "\ttemp += " + j[0] + " + " + j[1] + " * cos(o12) + " + j[2] + " * sin(o12)\n"
        s += "\ttemp += " + j[4] + " * cos(od) + " + j[5] + " * sin(od)\n"
        s += "\ttemp += " + j[7] + " * cos(og) + " + j[8] + " * sin(og)\n"
        return s


class NIST_ENSO_LinearDecay_2D(NIST_ENSO2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class NIST_ENSO_ExponentialDecay_2D(NIST_ENSO2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class NIST_ENSO_LinearGrowth_2D(NIST_ENSO2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class NIST_ENSO_ExponentialGrowth_2D(NIST_ENSO2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class NIST_ENSO_LinearDecayAndOffset_2D(NIST_ENSO2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class NIST_ENSO_ExponentialDecayAndOffset_2D(NIST_ENSO2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class NIST_ENSO_LinearGrowthAndOffset_2D(NIST_ENSO2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class NIST_ENSO_ExponentialGrowthAndOffset_2D(NIST_ENSO2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class NIST_MGH092D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "NIST MGH09"
        self.HTML = "y = a * (x<SUP>2</SUP> + b*x) / (x<SUP>2</SUP> + c*x + d)"
        self.coefficientDesignatorTuple = ("a", "b", "c", "d")

        self.function_cpp_code = 'temp = coeff[0] * (indep_data[(int)cachedWeaveOffsets[2] + i] + indep_data[(int)cachedWeaveOffsets[1] + i] * coeff[1]) / (indep_data[(int)cachedWeaveOffsets[2] + i] + indep_data[(int)cachedWeaveOffsets[1] + i] * coeff[2] + coeff[3]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_PowX(NameOrValueFlag=1, args=[2.0]), [2.0]])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " * (x_in*x_in + " + j[1] + " * x_in) / (x_in*x_in + " + j[2] + " * x_in + " + j[3] + ");\n"
        return s

    def SpecificCodeJAVA(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " * (x_in*x_in + " + j[1] + " * x_in) / (x_in*x_in + " + j[2] + " * x_in + " + j[3] + ");\n"
        return s

    def SpecificCodeCS(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " * (x_in*x_in + " + j[1] + " * x_in) / (x_in*x_in + " + j[2] + " * x_in + " + j[3] + ");\n"
        return s

    def SpecificCodePYTHON(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " * (x_in*x_in + " + j[1] + " * x_in) / (x_in*x_in + " + j[2] + " * x_in + " + j[3] + ")\n"
        return s

    def SpecificCodeSCILAB(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp = temp + " + j[0] + " * (x_in*x_in + " + j[1] + " * x_in) / (x_in*x_in + " + j[2] + " * x_in + " + j[3] + ")\n"
        return s


class NIST_MGH09_WO_2D(NIST_MGH092D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class NIST_MGH09_LinearDecay_2D(NIST_MGH092D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class NIST_MGH09_ExponentialDecay_2D(NIST_MGH092D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class NIST_MGH09_LinearGrowth_2D(NIST_MGH092D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class NIST_MGH09_ExponentialGrowth_2D(NIST_MGH092D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class NIST_MGH09_LinearDecayAndOffset_2D(NIST_MGH092D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class NIST_MGH09_ExponentialDecayAndOffset_2D(NIST_MGH092D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class NIST_MGH09_LinearGrowthAndOffset_2D(NIST_MGH092D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class NIST_MGH09_ExponentialGrowthAndOffset_2D(NIST_MGH092D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class NIST_BoxBOD2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "NIST BoxBOD"
        self.HTML = "y = a * (1.0-e<SUP>-b*x</SUP>)"
        self.coefficientDesignatorTuple = ("a", "b")

        self.function_cpp_code = 'temp = coeff[0] * (1.0 - exp(coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i]));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_NegX(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " * (1.0 - exp(-" + j[1] + "*x_in));\n"
        return s

    def SpecificCodeJAVA(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " * (1.0 - Math.exp(-" + j[1] + "*x_in));\n"
        return s

    def SpecificCodeCS(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " * (1.0 - Math.Exp(-" + j[1] + "*x_in));\n"
        return s

    def SpecificCodePYTHON(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " * (1.0 - math.exp(-" + j[1] + "*x_in))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp = temp + " + j[0] + " * (1.0 - exp(-" + j[1] + "*x_in))\n"
        return s


class NIST_BoxBOD_WO_2D(NIST_BoxBOD2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class NIST_BoxBOD_LinearDecay_2D(NIST_BoxBOD2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class NIST_BoxBOD_ExponentialDecay_2D(NIST_BoxBOD2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class NIST_BoxBOD_LinearGrowth_2D(NIST_BoxBOD2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class NIST_BoxBOD_ExponentialGrowth_2D(NIST_BoxBOD2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class NIST_BoxBOD_LinearDecayAndOffset_2D(NIST_BoxBOD2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class NIST_BoxBOD_ExponentialDecayAndOffset_2D(NIST_BoxBOD2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class NIST_BoxBOD_LinearGrowthAndOffset_2D(NIST_BoxBOD2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class NIST_BoxBOD_ExponentialGrowthAndOffset_2D(NIST_BoxBOD2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class NIST_MGH102D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "NIST MGH10"
        self.HTML = "y = a * e<SUP>b/(x+c)</SUP>"
        self.coefficientDesignatorTuple = ("a", "b", "c")

        self.function_cpp_code = 'temp = coeff[0] * exp(coeff[1] / (indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[2]));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " * exp(" + j[1] + " / (x_in + " + j[2] + "));\n"
        return s

    def SpecificCodeJAVA(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " * Math.exp(" + j[1] + " / (x_in + " + j[2] + "));\n"
        return s

    def SpecificCodeCS(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " * Math.Exp(" + j[1] + " / (x_in + " + j[2] + "));\n"
        return s

    def SpecificCodePYTHON(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " * math.exp(" + j[1] + " / (x_in + " + j[2] + "))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp = temp + " + j[0] + " * exp(" + j[1] + " / (x_in + " + j[2] + "))\n"
        return s


class NIST_MGH10_WO_2D(NIST_MGH102D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class NIST_MGH10_LinearDecay_2D(NIST_MGH102D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class NIST_MGH10_ExponentialDecay_2D(NIST_MGH102D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class NIST_MGH10_LinearGrowth_2D(NIST_MGH102D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class NIST_MGH10_ExponentialGrowth_2D(NIST_MGH102D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class NIST_MGH10_LinearDecayAndOffset_2D(NIST_MGH102D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class NIST_MGH10_ExponentialDecayAndOffset_2D(NIST_MGH102D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class NIST_MGH10_LinearGrowthAndOffset_2D(NIST_MGH102D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class NIST_MGH10_ExponentialGrowthAndOffset_2D(NIST_MGH102D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class NIST_Eckerle42D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "NIST Eckerle4"
        self.HTML = "y = (a/b) * e<SUP>-0.5*((x-c)/b)^2</SUP>"
        self.coefficientDesignatorTuple = ("a", "b", "c")

        self.function_cpp_code = 'temp = (coeff[0] / coeff[1]) * exp(-0.5 * ((indep_data[(int)cachedWeaveOffsets[1] + i] - coeff[2]) / coeff[1]) * ((indep_data[(int)cachedWeaveOffsets[1] + i] - coeff[2]) / coeff[1]));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += (" + j[0] + " / " + j[1] + ") * exp(-0.5 * ((x_in - " + j[2] + ") / " + j[1] + ") * ((x_in - " + j[2] + ") / " + j[1] + "));\n"
        return s

    def SpecificCodeJAVA(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += (" + j[0] + " / " + j[1] + ") * Math.exp(-0.5 * ((x_in - " + j[2] + ") / " + j[1] + ") * ((x_in - " + j[2] + ") / " + j[1] + "));\n"
        return s

    def SpecificCodeCS(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += (" + j[0] + " / " + j[1] + ") * Math.Exp(-0.5 * ((x_in - " + j[2] + ") / " + j[1] + ") * ((x_in - " + j[2] + ") / " + j[1] + "));\n"
        return s

    def SpecificCodePYTHON(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += (" + j[0] + " / " + j[1] + ") * math.exp(-0.5 * ((x_in - " + j[2] + ") / " + j[1] + ") * ((x_in - " + j[2] + ") / " + j[1] + "))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp = temp + (" + j[0] + " / " + j[1] + ") * exp(-0.5 * ((x_in - " + j[2] + ") / " + j[1] + ") * ((x_in - " + j[2] + ") / " + j[1] + "))\n"
        return s


class NIST_Eckerle4_WO_2D(NIST_Eckerle42D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class NIST_Eckerle4_LinearDecay_2D(NIST_Eckerle42D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class NIST_Eckerle4_ExponentialDecay_2D(NIST_Eckerle42D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class NIST_Eckerle4_LinearGrowth_2D(NIST_Eckerle42D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class NIST_Eckerle4_ExponentialGrowth_2D(NIST_Eckerle42D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class NIST_Eckerle4_LinearDecayAndOffset_2D(NIST_Eckerle42D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class NIST_Eckerle4_ExponentialDecayAndOffset_2D(NIST_Eckerle42D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class NIST_Eckerle4_LinearGrowthAndOffset_2D(NIST_Eckerle42D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class NIST_Eckerle4_ExponentialGrowthAndOffset_2D(NIST_Eckerle42D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class NIST_Bennett52D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "NIST Bennett5"
        self.HTML = "y = a * (b+x)^(-1/c)"
        self.coefficientDesignatorTuple = ("a", "b", "c")

        self.function_cpp_code = 'temp = coeff[0] * pow(coeff[1] + indep_data[(int)cachedWeaveOffsets[1] + i], -1.0 / coeff[2]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " * pow(" + j[1] + " * x_in, 1.0 / " + j[2] + ");\n"
        return s

    def SpecificCodeJAVA(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " * Math.pow(" + j[1] + " * x_in, 1.0 / " + j[2] + ");\n"
        return s

    def SpecificCodeCS(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " * Math.Pow(" + j[1] + " * x_in, 1.0 / " + j[2] + ");\n"
        return s

    def SpecificCodePYTHON(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp += " + j[0] + " * math.pow(" + j[1] + " * x_in, 1.0 / " + j[2] + ")\n"
        return s

    def SpecificCodeSCILAB(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += "\ttemp = temp + " + j[0] + " * (" + j[1] + " * x_in ^ 1.0 / " + j[2] + ")\n"
        return s


class NIST_Bennett5_WO_2D(NIST_Bennett52D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class NIST_Bennett5_LinearDecay_2D(NIST_Bennett52D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class NIST_Bennett5_ExponentialDecay_2D(NIST_Bennett52D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class NIST_Bennett5_LinearGrowth_2D(NIST_Bennett52D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class NIST_Bennett5_ExponentialGrowth_2D(NIST_Bennett52D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class NIST_Bennett5_LinearDecayAndOffset_2D(NIST_Bennett52D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class NIST_Bennett5_ExponentialDecayAndOffset_2D(NIST_Bennett52D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class NIST_Bennett5_LinearGrowthAndOffset_2D(NIST_Bennett52D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class NIST_Bennett5_ExponentialGrowthAndOffset_2D(NIST_Bennett52D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
