#    pythonequations is a collection of equations expressed as Python classes
#    Copyright (C) 2008 James R. Phillips
#    2548 Vera Cruz Drive
#    Birmingham, AL 35235 USA
#    email: zunzun@zunzun.com
#
#    Version info: $Id$
#
#    License: BSD-style (see LICENSE.txt in main source directory)

import pythonequations, pythonequations.EquationBaseClasses, pythonequations.EquationsForPolyfunctionals
import numpy
numpy.seterr(all = 'raise') # numpy raises warnings, convert to exceptions to trap them

class Polyfunctional2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "User-Selectable Polyfunctional"
        self.HTML = "y = user-selectable function"
        self.coefficientDesignatorTuple = ()
        self.polyfunctionalFlag = 1
        self.LinearSSQSolverFlag = 1
        self.EquationListForPolyfunctional = pythonequations.EquationsForPolyfunctionals.GenerateList('x', 'x_in')
        self.Polyfun2DEqList = pythonequations.EquationsForPolyfunctionals.GenerateList('unused', 'unused')

        self.function_cpp_code = 'temp = 0.0;\nfor (int k=0; k<numberOfCoefficients; k++)\n\ttemp += coeff[k] * indep_data[(int)cachedWeaveOffsets[k] + i];// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        for i in range(1, len(self.EquationListForPolyfunctional)):
            if i in self.Polyfun2DFlags:
                self.CacheGenerationList.append([self.CG_Polyfunctional2D(NameOrValueFlag=1, args=i), i])
        if 0 in self.Polyfun2DFlags:
            self.CacheGenerationList.append([self.CG_Polyfunctional2D(NameOrValueFlag=1, args=0), 0])

    def SpecificCodeCPP(self):
        s = ""
        count = 0
        for xindex in range(1, len(self.EquationListForPolyfunctional)):
            if xindex in self.Polyfun2DFlags:
                s += "\ttemp += " + self.coefficientDesignatorTuple[count] + " * " + self.EquationListForPolyfunctional[xindex].CPP + ";\n"
                count += 1
        if 0 in self.Polyfun2DFlags:
            s += "\ttemp += " + self.coefficientDesignatorTuple[count] + ";\n"
        return s

    def SpecificCodeJAVA(self):
        s = ""
        count = 0
        for xindex in range(1, len(self.EquationListForPolyfunctional)):
            if xindex in self.Polyfun2DFlags:
                s += "\t\ttemp += " + self.coefficientDesignatorTuple[count] + " * " + self.EquationListForPolyfunctional[xindex].JAVA + ";\n"
                count += 1
        if 0 in self.Polyfun2DFlags:
            s += "\t\ttemp += " + self.coefficientDesignatorTuple[count] + ";\n"
        return s

    def SpecificCodeCS(self):
        s = ""
        count = 0
        for xindex in range(1, len(self.EquationListForPolyfunctional)):
            if xindex in self.Polyfun2DFlags:
                s += "\t\ttemp += " + self.coefficientDesignatorTuple[count] + " * " + self.EquationListForPolyfunctional[xindex].CSHARP + ";\n"
                count += 1
        if 0 in self.Polyfun2DFlags:
            s += "\t\ttemp += " + self.coefficientDesignatorTuple[count] + ";\n"
        return s

    def SpecificCodePYTHON(self):
        s = ""
        count = 0
        for xindex in range(1, len(self.EquationListForPolyfunctional)):
            if xindex in self.Polyfun2DFlags:
                s += "\ttemp += " + self.coefficientDesignatorTuple[count] + " * " + self.EquationListForPolyfunctional[xindex].PYTHON + "\n"
                count += 1
        if 0 in self.Polyfun2DFlags:
            s += "\ttemp += " + self.coefficientDesignatorTuple[count] + "\n"
        return s

    def SpecificCodeSCILAB(self):
        s = ""
        count = 0
        for xindex in range(1, len(self.EquationListForPolyfunctional)):
            if xindex in self.Polyfun2DFlags:
                s += "\ttemp = temp + " + self.coefficientDesignatorTuple[count] + " * " + self.EquationListForPolyfunctional[xindex].SCILAB + "\n"
                count += 1
        if 0 in self.Polyfun2DFlags:
            s += "\ttemp = temp + " + self.coefficientDesignatorTuple[count] + "\n"
        return s

    def Initialize(self):
        indexmax = len(self.Polyfun2DFlags)
        self.coefficientDesignatorTuple = ()
        for i in range(indexmax):
            self.coefficientDesignatorTuple += (pythonequations.EquationBaseClasses.Equation.ascii[i]),

        pythonequations.EquationBaseClasses.Equation2D.Initialize(self)

        self.RequiresNonzeroX = 0
        self.RequiresPositiveX = 0
        for i in range(indexmax):
            self.RequiresNonzeroX |= self.EquationListForPolyfunctional[self.Polyfun2DFlags[i]].RequiresNonzero
            self.RequiresPositiveX |= self.EquationListForPolyfunctional[self.Polyfun2DFlags[i]].RequiresPositive


    def RegenerateForm(self):
        #print "2d regen, flags =", self.Polyfun2DFlags
        self.coefficientDesignatorTuple = ()
        if len(self.Polyfun2DFlags) == 0:
            self.HTML = "y = user-selectable function"
            return
        
        for i in range(len(self.Polyfun2DFlags)-1):
            self.coefficientDesignatorTuple += (pythonequations.EquationBaseClasses.Equation.ascii[i]),
        if 0 in self.Polyfun2DFlags:
            self.coefficientDesignatorTuple += ('offset'),
        else:
            self.coefficientDesignatorTuple += (pythonequations.EquationBaseClasses.Equation.ascii[len(self.Polyfun2DFlags)-1]),

        self.HTML = "</B><B>y = " # turn off any preceding bolding
        count = 0
        for xindex in range(1, len(self.EquationListForPolyfunctional)):
            if xindex in self.Polyfun2DFlags:
                self.HTML += pythonequations.EquationBaseClasses.Equation.ascii[count] + "(</B>&nbsp;" + self.EquationListForPolyfunctional[xindex].HTML + "&nbsp;<B>) "
                count += 1
                if len(self.Polyfun2DFlags) > count:
                    self.HTML += "+ "
        if 0 in self.Polyfun2DFlags:
                self.HTML += "offset"

        self.HTML += '</B>'



