#    pythonequations is a collection of equations expressed as Python classes
#    Copyright (C) 2008 James R. Phillips
#    2548 Vera Cruz Drive
#    Birmingham, AL 35235 USA
#    email: zunzun@zunzun.com
#
#    Version info: $Id$
#
#    License: BSD-style (see LICENSE.txt in main source directory)

import pythonequations, pythonequations.EquationBaseClasses
import numpy
numpy.seterr(all = 'raise') # numpy raises warnings, convert to exceptions to trap them

class DonLevinSigmoid2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Don Levin Sigmoid"
        self.HTML = "y = a1 / (1.0 + e<SUP>(-(x-b1)/c1)</SUP>) + a2 / (1.0 + e<SUP>(-(x-b2)/c2)</SUP>) + a3 / (1.0 + e<SUP>(-(x-b3)/c3)</SUP>)"
        self.coefficientDesignatorTuple = ("a1", "b1", "c1", "a2", "b2", "c2", "a3", "b3", "c3")

        self.function_cpp_code = 'temp = coeff[0] / (1.0 + exp(-1.0 * (indep_data[(int)cachedWeaveOffsets[0] + i] - coeff[1]) / coeff[2])) + coeff[3] / (1.0 + exp(-1.0 * (indep_data[(int)cachedWeaveOffsets[0] + i] - coeff[4]) / coeff[5])) + coeff[6] / (1.0 + exp(-1.0 * (indep_data[(int)cachedWeaveOffsets[0] + i] - coeff[7]) / coeff[8]));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a1 / (1.0 + exp(-1.0 * (x_in - b1) / c1)) + a2 / (1.0 + exp(-1.0 * (x_in - b2) / c2)) + a3 / (1.0 + exp(-1.0 * (x_in - b3) / c3));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a1 / (1.0 + Math.exp(-1.0 * (x_in - b1) / c1)) + a2 / (1.0 + Math.exp(-1.0 * (x_in - b2) / c2)) + a3 / (1.0 + Math.exp(-1.0 * (x_in - b3) / c3));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a1 / (1.0 + Math.Exp(-1.0 * (x_in - b1) / c1)) + a2 / (1.0 + Math.Exp(-1.0 * (x_in - b2) / c2)) + a3 / (1.0 + Math.Exp(-1.0 * (x_in - b3) / c3));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = a1 / (1.0 + math.exp(-1.0 * (x_in - b1) / c1)) + a2 / (1.0 + math.exp(-1.0 * (x_in - b2) / c2)) + a3 / (1.0 + math.exp(-1.0 * (x_in - b3) / c3))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = a1 / (1.0 + exp(-1.0 * (x_in - b1) / c1)) + a2 / (1.0 + exp(-1.0 * (x_in - b2) / c2)) + a3 / (1.0 + exp(-1.0 * (x_in - b3) / c3))\n"
        return s


class DonLevinSigmoid_WO_2D(DonLevinSigmoid2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class DonLevinSigmoid_LinearDecay_2D(DonLevinSigmoid2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class DonLevinSigmoid_ExponentialDecay_2D(DonLevinSigmoid2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class DonLevinSigmoid_LinearGrowth_2D(DonLevinSigmoid2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class DonLevinSigmoid_ExponentialGrowth_2D(DonLevinSigmoid2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class DonLevinSigmoid_LinearDecayAndOffset_2D(DonLevinSigmoid2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class DonLevinSigmoid_ExponentialDecayAndOffset_2D(DonLevinSigmoid2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class DonLevinSigmoid_LinearGrowthAndOffset_2D(DonLevinSigmoid2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class DonLevinSigmoid_ExponentialGrowthAndOffset_2D(DonLevinSigmoid2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class BET_Sigmoidal2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "BET Sigmoidal"
        self.HTML = "y = x / (a + bx - (a+b)x<sup>2</sup>)"
        self.coefficientDesignatorTuple = ("a", "b")

        self.function_cpp_code = 'temp = indep_data[(int)cachedWeaveOffsets[0] + i] / (coeff[0] + (coeff[1] * indep_data[(int)cachedWeaveOffsets[0] + i]) - ((coeff[0] + coeff[1]) * indep_data[(int)cachedWeaveOffsets[1] + i]));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_PowX(NameOrValueFlag=1, args=[2.0]), [2.0]])

    def SpecificCodeCPP(self):
        s = "\ttemp = x_in / (a + (b * x_in) - (( a+ b) * x_in * x_in));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = x_in / (a + (b * x_in) - (( a+ b) * x_in * x_in));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = x_in / (a + (b * x_in) - (( a+ b) * x_in * x_in));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = x_in / (a + (b * x_in) - (( a+ b) * x_in * x_in))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = x_in / (a + (b * x_in) - (( a+ b) * x_in * x_in))\n"
        return s


class BET_Sigmoidal_WO_2D(BET_Sigmoidal2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class BET_Sigmoidal_LinearDecay_2D(BET_Sigmoidal2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class BET_Sigmoidal_ExponentialDecay_2D(BET_Sigmoidal2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class BET_Sigmoidal_LinearGrowth_2D(BET_Sigmoidal2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class BET_Sigmoidal_ExponentialGrowth_2D(BET_Sigmoidal2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class BET_Sigmoidal_LinearDecayAndOffset_2D(BET_Sigmoidal2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class BET_Sigmoidal_ExponentialDecayAndOffset_2D(BET_Sigmoidal2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class BET_Sigmoidal_LinearGrowthAndOffset_2D(BET_Sigmoidal2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class BET_Sigmoidal_ExponentialGrowthAndOffset_2D(BET_Sigmoidal2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class SigmoidA2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Sigmoid A"
        self.HTML = "y = 1.0 / (1.0 + e<SUP>-a(x-b)</SUP>)"
        self.coefficientDesignatorTuple = ("a", "b")

        self.function_cpp_code = 'temp = 1.0 / (1.0 + exp(-1.0 * coeff[0] * (indep_data[(int)cachedWeaveOffsets[0] + i] - coeff[1])));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = 1.0 / (1.0 + exp(-1.0 * a * (x_in - b)));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = 1.0 / (1.0 + Math.exp(-1.0 * a * (x_in - b)));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = 1.0 / (1.0 + Math.Exp(-1.0 * a * (x_in - b)));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = 1.0 / (1.0 + math.exp(-1.0 * a * (x_in - b)))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = 1.0 / (1.0 + exp(-1.0 * a * (x_in - b)))\n"
        return s


class SigmoidA_WO_2D(SigmoidA2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class SigmoidA_LinearDecay_2D(SigmoidA2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class SigmoidA_ExponentialDecay_2D(SigmoidA2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class SigmoidA_LinearGrowth_2D(SigmoidA2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class SigmoidA_ExponentialGrowth_2D(SigmoidA2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class SigmoidA_LinearDecayAndOffset_2D(SigmoidA2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class SigmoidA_ExponentialDecayAndOffset_2D(SigmoidA2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class SigmoidA_LinearGrowthAndOffset_2D(SigmoidA2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class SigmoidA_ExponentialGrowthAndOffset_2D(SigmoidA2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class SigmoidB2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Sigmoid B"
        self.HTML = "y = a / (1.0 + e<SUP>(-(x-b)/c)</SUP>)"
        self.coefficientDesignatorTuple = ("a", "b", "c")

        self.function_cpp_code = 'temp = coeff[0] / (1.0 + exp(-1.0 * (indep_data[(int)cachedWeaveOffsets[1] + i] - coeff[1]) / coeff[2]));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a / (1.0 + exp(-1.0 * (x_in - b) / c));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a / (1.0 + Math.exp(-1.0 * (x_in - b) / c));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a / (1.0 + Math.Exp(-1.0 * (x_in - b) / c));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = a / (1.0 + math.exp(-1.0 * (x_in - b) / c))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = a / (1.0 + exp(-1.0 * (x_in - b) / c))\n"
        return s


class SigmoidB_WO_2D(SigmoidB2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class SigmoidB_LinearDecay_2D(SigmoidB2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class SigmoidB_ExponentialDecay_2D(SigmoidB2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class SigmoidB_LinearGrowth_2D(SigmoidB2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class SigmoidB_ExponentialGrowth_2D(SigmoidB2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class SigmoidB_LinearDecayAndOffset_2D(SigmoidB2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class SigmoidB_ExponentialDecayAndOffset_2D(SigmoidB2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class SigmoidB_LinearGrowthAndOffset_2D(SigmoidB2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class SigmoidB_ExponentialGrowthAndOffset_2D(SigmoidB2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class Gompertz2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Gompertz"
        self.HTML = "y = a * e^(-e<SUP>(b - cx)</SUP>)"
        self.coefficientDesignatorTuple = ("a", "b", "c")

        self.function_cpp_code = 'temp = coeff[0] * exp(-1.0 * exp(coeff[1] - indep_data[(int)cachedWeaveOffsets[1] + i] * coeff[2]));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a * exp(-1.0 * exp(b - c*x_in));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a * Math.exp(-1.0 * Math.exp(b - c*x_in));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a * Math.Exp(-1.0 * Math.Exp(b - c*x_in));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = a * math.exp(-1.0 * math.exp(b - c*x_in))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = a * exp(-1.0 * exp(b - c*x_in))\n"
        return s


class Gompertz_WO_2D(Gompertz2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class Gompertz_LinearDecay_2D(Gompertz2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class Gompertz_ExponentialDecay_2D(Gompertz2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class Gompertz_LinearGrowth_2D(Gompertz2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class Gompertz_ExponentialGrowth_2D(Gompertz2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class Gompertz_LinearDecayAndOffset_2D(Gompertz2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class Gompertz_ExponentialDecayAndOffset_2D(Gompertz2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class Gompertz_LinearGrowthAndOffset_2D(Gompertz2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class Gompertz_ExponentialGrowthAndOffset_2D(Gompertz2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class Logistic2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Logistic"
        self.HTML = "y = a / (1.0 + be<SUP>-cx</SUP>)"
        self.coefficientDesignatorTuple = ("a", "b", "c")

        self.function_cpp_code = 'temp = coeff[0] / (1.0 + coeff[1] * exp(coeff[2] * indep_data[(int)cachedWeaveOffsets[1] + i]));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_NegX(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a / (1.0 + b*exp(-1.0 * c * x_in));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a / (1.0 + b*Math.exp(-1.0 * c * x_in));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a / (1.0 + b*Math.Exp(-1.0 * c * x_in));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = a / (1.0 + b*math.exp(-1.0 * c * x_in))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = a / (1.0 + b*exp(-1.0 * c * x_in))\n"
        return s


class Logistic_WO_2D(Logistic2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class Logistic_LinearDecay_2D(Logistic2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class Logistic_ExponentialDecay_2D(Logistic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class Logistic_LinearGrowth_2D(Logistic2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class Logistic_ExponentialGrowth_2D(Logistic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class Logistic_LinearDecayAndOffset_2D(Logistic2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class Logistic_ExponentialDecayAndOffset_2D(Logistic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class Logistic_LinearGrowthAndOffset_2D(Logistic2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class Logistic_ExponentialGrowthAndOffset_2D(Logistic2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class Weibull2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Weibull"
        self.HTML = "y = a - b*e<SUP>-cx^d</SUP>"
        self.coefficientDesignatorTuple = ("a", "b", "c", "d")

        self.function_cpp_code = 'temp = coeff[0] - coeff[1] * exp(-1.0 * coeff[2] * pow(indep_data[(int)cachedWeaveOffsets[2] + i], coeff[3]));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a - b*exp(-1.0 * c * pow(x_in, d));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a - b*Math.exp(-1.0 * c * Math.pow(x_in, d));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a - b*Math.Exp(-1.0 * c * Math.Pow(x_in, d));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = a - b*math.exp(-1.0 * c * math.pow(x_in, d))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = a - b*exp(-1.0 * c * (x_in ^ d))\n"
        return s


class Weibull_LinearDecay_2D(Weibull2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class Weibull_ExponentialDecay_2D(Weibull2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class Weibull_LinearGrowth_2D(Weibull2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class Weibull_ExponentialGrowth_2D(Weibull2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class Weibull_LinearDecayAndOffset_2D(Weibull2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class Weibull_ExponentialDecayAndOffset_2D(Weibull2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class Weibull_LinearGrowthAndOffset_2D(Weibull2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class Weibull_ExponentialGrowthAndOffset_2D(Weibull2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class WeibullPDF2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Weibull PDF"
        self.HTML = "y = (a/b) * (x/b)<SUP>(a-1.0)</SUP> * e<SUP>-(x/b)^a</SUP>"
        self.coefficientDesignatorTuple = ("a", "b")

        self.function_cpp_code = 'temp = (coeff[0] / coeff[1]) * pow(indep_data[(int)cachedWeaveOffsets[0] + i] / coeff[1], coeff[0] - 1.0) *  exp(-1.0 * pow(indep_data[(int)cachedWeaveOffsets[0] + i] / coeff[1], coeff[0]));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = (a/b) * pow(x_in/b, a-1.0) * exp(-1.0 * pow(x_in/b, a));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = (a/b) * Math.pow(x_in/b, a-1.0) * Math.exp(-1.0 * Math.pow(x_in/b, a));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = (a/b) * Math.Pow(x_in/b, a-1.0) * Math.Exp(-1.0 * Math.Pow(x_in/b, a));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = (a/b) * math.pow(x_in/b, a-1.0) * math.exp(-1.0 * math.pow(x_in/b, a))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = (a/b) * (x_in/b ^ a-1.0) * exp(-1.0 * (x_in/b ^ a))\n"
        return s


class WeibullPDF_WO_2D(WeibullPDF2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class WeibullPDF_LinearDecay_2D(WeibullPDF2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class WeibullPDF_ExponentialDecay_2D(WeibullPDF2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class WeibullPDF_LinearGrowth_2D(WeibullPDF2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class WeibullPDF_ExponentialGrowth_2D(WeibullPDF2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class WeibullPDF_LinearDecayAndOffset_2D(WeibullPDF2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class WeibullPDF_ExponentialDecayAndOffset_2D(WeibullPDF2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class WeibullPDF_LinearGrowthAndOffset_2D(WeibullPDF2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class WeibullPDF_ExponentialGrowthAndOffset_2D(WeibullPDF2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class WeibullCDF2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Weibull CDF"
        self.HTML = "y = 1.0 - e<SUP>-(x/b)^a</SUP>"
        self.coefficientDesignatorTuple = ("a", "b")

        self.function_cpp_code = 'temp = 1.0 - exp(-1.0 * pow(indep_data[(int)cachedWeaveOffsets[0] + i] / coeff[1], coeff[0]));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = 1.0 - exp(-1.0 * pow(x_in/b, a));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = 1.0 - Math.exp(-1.0 * Math.pow(x_in/b, a));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = 1.0 - Math.Exp(-1.0 * Math.Pow(x_in/b, a));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = 1.0 - math.exp(-1.0 * math.pow(x_in/b, a))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = 1.0 - exp(-1.0 * (x_in/b) ^ a)\n"
        return s


class WeibullCDF_WO_2D(WeibullCDF2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class WeibullCDF_LinearDecay_2D(WeibullCDF2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class WeibullCDF_ExponentialDecay_2D(WeibullCDF2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class WeibullCDF_LinearGrowth_2D(WeibullCDF2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class WeibullCDF_ExponentialGrowth_2D(WeibullCDF2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class WeibullCDF_LinearDecayAndOffset_2D(WeibullCDF2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class WeibullCDF_ExponentialDecayAndOffset_2D(WeibullCDF2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class WeibullCDF_LinearGrowthAndOffset_2D(WeibullCDF2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class WeibullCDF_ExponentialGrowthAndOffset_2D(WeibullCDF2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class MagneticSaturation2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Magnetic Saturation"
        self.HTML = "y = ax * (1.0 + b*e<SUP>cx</SUP>)"
        self.coefficientDesignatorTuple = ("a", "b", "c")

        self.function_cpp_code = 'temp = coeff[0] * indep_data[(int)cachedWeaveOffsets[0] + i] *(1.0 + coeff[1] * exp(coeff[2] * indep_data[(int)cachedWeaveOffsets[0] + i]));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a*x_in * (1.0 + b*exp(c*x_in));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a*x_in * (1.0 + b*Math.exp(c*x_in));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a*x_in * (1.0 + b*Math.Exp(c*x_in));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = a*x_in * (1.0 + b*math.exp(c*x_in))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = a*x_in * (1.0 + b*exp(c*x_in))\n"
        return s


class MagneticSaturation_WO_2D(MagneticSaturation2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class MagneticSaturation_LinearDecay_2D(MagneticSaturation2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class MagneticSaturation_ExponentialDecay_2D(MagneticSaturation2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class MagneticSaturation_LinearGrowth_2D(MagneticSaturation2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class MagneticSaturation_ExponentialGrowth_2D(MagneticSaturation2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class MagneticSaturation_LinearDecayAndOffset_2D(MagneticSaturation2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class MagneticSaturation_ExponentialDecayAndOffset_2D(MagneticSaturation2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class MagneticSaturation_LinearGrowthAndOffset_2D(MagneticSaturation2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class MagneticSaturation_ExponentialGrowthAndOffset_2D(MagneticSaturation2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()



class ReciprocalGompertz2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Reciprocal Gompertz"
        self.HTML = "y = 1.0 / (a * e^(-e<SUP>(b - cx)</SUP>))"
        self.coefficientDesignatorTuple = ("a", "b", "c")

        self.function_cpp_code = 'temp = 1.0 / (coeff[0] * exp(-1.0 * exp(coeff[1] - indep_data[(int)cachedWeaveOffsets[1] + i] * coeff[2])));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = 1.0 / (a * exp(-1.0 * exp(b - c*x_in)));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = 1.0 / (a * Math.exp(-1.0 * Math.exp(b - c*x_in)));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = 1.0 / (a * Math.Exp(-1.0 * Math.Exp(b - c*x_in)));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = 1.0 / (a * math.exp(-1.0 * math.exp(b - c*x_in))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = 1.0 / (a * exp(-1.0 * exp(b - c*x_in)))\n"
        return s


class ReciprocalGompertz_WO_2D(ReciprocalGompertz2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class ReciprocalGompertz_LinearDecay_2D(ReciprocalGompertz2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class ReciprocalGompertz_ExponentialDecay_2D(ReciprocalGompertz2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class ReciprocalGompertz_LinearGrowth_2D(ReciprocalGompertz2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class ReciprocalGompertz_ExponentialGrowth_2D(ReciprocalGompertz2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class ReciprocalGompertz_LinearDecayAndOffset_2D(ReciprocalGompertz2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class ReciprocalGompertz_ExponentialDecayAndOffset_2D(ReciprocalGompertz2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class ReciprocalGompertz_LinearGrowthAndOffset_2D(ReciprocalGompertz2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class ReciprocalGompertz_ExponentialGrowthAndOffset_2D(ReciprocalGompertz2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()



class InverseGompertz2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Inverse Gompertz"
        self.HTML = "y = x / (a * e^(-e<SUP>(b - cx)</SUP>))"
        self.coefficientDesignatorTuple = ("a", "b", "c")

        self.function_cpp_code = 'temp = indep_data[(int)cachedWeaveOffsets[1] + i] / (coeff[0] * exp(-1.0 * exp(coeff[1] - indep_data[(int)cachedWeaveOffsets[1] + i] * coeff[2])));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = x_in / (a * exp(-1.0 * exp(b - c*x_in)));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = x_in / (a * Math.exp(-1.0 * Math.exp(b - c*x_in)));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = x_in / (a * Math.Exp(-1.0 * Math.Exp(b - c*x_in)));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = x_in / (a * math.exp(-1.0 * math.exp(b - c*x_in))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = x_in / (a * exp(-1.0 * exp(b - c*x_in)))\n"
        return s


class InverseGompertz_WO_2D(InverseGompertz2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class InverseGompertz_LinearDecay_2D(InverseGompertz2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class InverseGompertz_ExponentialDecay_2D(InverseGompertz2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class InverseGompertz_LinearGrowth_2D(InverseGompertz2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class InverseGompertz_ExponentialGrowth_2D(InverseGompertz2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class InverseGompertz_LinearDecayAndOffset_2D(InverseGompertz2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class InverseGompertz_ExponentialDecayAndOffset_2D(InverseGompertz2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class InverseGompertz_LinearGrowthAndOffset_2D(InverseGompertz2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class InverseGompertz_ExponentialGrowthAndOffset_2D(InverseGompertz2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()



class ReciprocalWeibull2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Reciprocal Weibull"
        self.HTML = "y = 1.0 / (a - b*e<SUP>-cx^d</SUP>)"
        self.coefficientDesignatorTuple = ("a", "b", "c", "d")

        self.function_cpp_code = 'temp = 1.0 / (coeff[0] - coeff[1] * exp(-1.0 * coeff[2] * pow(indep_data[(int)cachedWeaveOffsets[2] + i], coeff[3])));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = 1.0 / (a - b*exp(-1.0 * c * pow(x_in, d)));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = 1.0 / (a - b*Math.exp(-1.0 * c * Math.pow(x_in, d)));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = 1.0 / (a - b*Math.Exp(-1.0 * c * Math.Pow(x_in, d)));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = 1.0 / (a - b*math.exp(-1.0 * c * math.pow(x_in, d)))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = 1.0 / (a - b*exp(-1.0 * c * (x_in ^ d)))\n"
        return s


class ReciprocalWeibull_LinearDecay_2D(ReciprocalWeibull2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class ReciprocalWeibull_ExponentialDecay_2D(ReciprocalWeibull2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class ReciprocalWeibull_LinearGrowth_2D(ReciprocalWeibull2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class ReciprocalWeibull_ExponentialGrowth_2D(ReciprocalWeibull2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class ReciprocalWeibull_LinearDecayAndOffset_2D(ReciprocalWeibull2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class ReciprocalWeibull_ExponentialDecayAndOffset_2D(ReciprocalWeibull2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class ReciprocalWeibull_LinearGrowthAndOffset_2D(ReciprocalWeibull2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class ReciprocalWeibull_ExponentialGrowthAndOffset_2D(ReciprocalWeibull2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()



class InverseWeibull2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Inverse Weibull"
        self.HTML = "y = x / (a - b*e<SUP>-cx^d</SUP>)"
        self.coefficientDesignatorTuple = ("a", "b", "c", "d")

        self.function_cpp_code = 'temp = indep_data[(int)cachedWeaveOffsets[2] + i] / (coeff[0] - coeff[1] * exp(-1.0 * coeff[2] * pow(indep_data[(int)cachedWeaveOffsets[2] + i], coeff[3])));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = x_in / (a - b*exp(-1.0 * c * pow(x_in, d)));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = x_in / (a - b*Math.exp(-1.0 * c * Math.pow(x_in, d)));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = x_in / (a - b*Math.Exp(-1.0 * c * Math.Pow(x_in, d)));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = x_in / (a - b*math.exp(-1.0 * c * math.pow(x_in, d)))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = x_in / (a - b*exp(-1.0 * c * (x_in ^ d)))\n"
        return s


class InverseWeibull_LinearDecay_2D(InverseWeibull2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class InverseWeibull_ExponentialDecay_2D(InverseWeibull2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class InverseWeibull_LinearGrowth_2D(InverseWeibull2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class InverseWeibull_ExponentialGrowth_2D(InverseWeibull2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class InverseWeibull_LinearDecayAndOffset_2D(InverseWeibull2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class InverseWeibull_ExponentialDecayAndOffset_2D(InverseWeibull2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class InverseWeibull_LinearGrowthAndOffset_2D(InverseWeibull2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class InverseWeibull_ExponentialGrowthAndOffset_2D(InverseWeibull2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()



class ReciprocalWeibullPDF2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Reciprocal Weibull PDF"
        self.HTML = "y = 1.0 / ((a/b) * (x/b)<SUP>(a-1.0)</SUP> * e<SUP>-(x/b)^a</SUP>)"
        self.coefficientDesignatorTuple = ("a", "b")

        self.function_cpp_code = 'temp = 1.0 / ((coeff[0] / coeff[1]) * pow(indep_data[(int)cachedWeaveOffsets[0] + i] / coeff[1], coeff[0] - 1.0) *  exp(-1.0 * pow(indep_data[(int)cachedWeaveOffsets[0] + i] / coeff[1], coeff[0])));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = 1.0 / ((a/b) * pow(x_in/b, a-1.0) * exp(-1.0 * pow(x_in/b, a)));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = 1.0 / ((a/b) * Math.pow(x_in/b, a-1.0) * Math.exp(-1.0 * Math.pow(x_in/b, a)));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = 1.0 / ((a/b) * Math.Pow(x_in/b, a-1.0) * Math.Exp(-1.0 * Math.Pow(x_in/b, a)));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = 1.0 / ((a/b) * math.pow(x_in/b, a-1.0) * math.exp(-1.0 * math.pow(x_in/b, a)))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = 1.0 / ((a/b) * (x_in/b ^ a-1.0) * exp(-1.0 * (x_in/b ^ a)))\n"
        return s


class ReciprocalWeibullPDF_WO_2D(ReciprocalWeibullPDF2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class ReciprocalWeibullPDF_LinearDecay_2D(ReciprocalWeibullPDF2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class ReciprocalWeibullPDF_ExponentialDecay_2D(ReciprocalWeibullPDF2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class ReciprocalWeibullPDF_LinearGrowth_2D(ReciprocalWeibullPDF2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class ReciprocalWeibullPDF_ExponentialGrowth_2D(ReciprocalWeibullPDF2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class ReciprocalWeibullPDF_LinearDecayAndOffset_2D(ReciprocalWeibullPDF2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class ReciprocalWeibullPDF_ExponentialDecayAndOffset_2D(ReciprocalWeibullPDF2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class ReciprocalWeibullPDF_LinearGrowthAndOffset_2D(ReciprocalWeibullPDF2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class ReciprocalWeibullPDF_ExponentialGrowthAndOffset_2D(ReciprocalWeibullPDF2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class InverseWeibullPDF2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Inverse Weibull PDF"
        self.HTML = "y = x / ((a/b) * (x/b)<SUP>(a-1.0)</SUP> * e<SUP>-(x/b)^a</SUP>)"
        self.coefficientDesignatorTuple = ("a", "b")

        self.function_cpp_code = 'temp = indep_data[(int)cachedWeaveOffsets[0] + i] / ((coeff[0] / coeff[1]) * pow(indep_data[(int)cachedWeaveOffsets[0] + i] / coeff[1], coeff[0] - 1.0) *  exp(-1.0 * pow(indep_data[(int)cachedWeaveOffsets[0] + i] / coeff[1], coeff[0])));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = x_in / ((a/b) * pow(x_in/b, a-1.0) * exp(-1.0 * pow(x_in/b, a)));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = x_in / ((a/b) * Math.pow(x_in/b, a-1.0) * Math.exp(-1.0 * Math.pow(x_in/b, a)));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = x_in / ((a/b) * Math.Pow(x_in/b, a-1.0) * Math.Exp(-1.0 * Math.Pow(x_in/b, a)));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = x_in / ((a/b) * math.pow(x_in/b, a-1.0) * math.exp(-1.0 * math.pow(x_in/b, a)))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = x_in / ((a/b) * (x_in/b ^ a-1.0) * exp(-1.0 * (x_in/b ^ a)))\n"
        return s


class InverseWeibullPDF_WO_2D(InverseWeibullPDF2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class InverseWeibullPDF_LinearDecay_2D(InverseWeibullPDF2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class InverseWeibullPDF_ExponentialDecay_2D(InverseWeibullPDF2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class InverseWeibullPDF_LinearGrowth_2D(InverseWeibullPDF2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class InverseWeibullPDF_ExponentialGrowth_2D(InverseWeibullPDF2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class InverseWeibullPDF_LinearDecayAndOffset_2D(InverseWeibullPDF2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class InverseWeibullPDF_ExponentialDecayAndOffset_2D(InverseWeibullPDF2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class InverseWeibullPDF_LinearGrowthAndOffset_2D(InverseWeibullPDF2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class InverseWeibullPDF_ExponentialGrowthAndOffset_2D(InverseWeibullPDF2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class ReciprocalWeibullCDF2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Reciprocal Weibull CDF"
        self.HTML = "y = 1.0 / (1.0 - e<SUP>-(x/b)^a</SUP>)"
        self.coefficientDesignatorTuple = ("a", "b")

        self.function_cpp_code = 'temp = 1.0 / (1.0 - exp(-1.0 * pow(indep_data[(int)cachedWeaveOffsets[0] + i] / coeff[1], coeff[0])));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = 1.0 / (1.0 - exp(-1.0 * pow(x_in/b, a)));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = 1.0 / (1.0 - Math.exp(-1.0 * Math.pow(x_in/b, a)));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = 1.0 / (1.0 - Math.Exp(-1.0 * Math.Pow(x_in/b, a)));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = 1.0 / (1.0 - math.exp(-1.0 * math.pow(x_in/b, a)))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = 1.0 / (1.0 - exp(-1.0 * (x_in/b) ^ a))\n"
        return s


class ReciprocalWeibullCDF_WO_2D(ReciprocalWeibullCDF2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class ReciprocalWeibullCDF_LinearDecay_2D(ReciprocalWeibullCDF2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class ReciprocalWeibullCDF_ExponentialDecay_2D(ReciprocalWeibullCDF2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class ReciprocalWeibullCDF_LinearGrowth_2D(ReciprocalWeibullCDF2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class ReciprocalWeibullCDF_ExponentialGrowth_2D(ReciprocalWeibullCDF2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class ReciprocalWeibullCDF_LinearDecayAndOffset_2D(ReciprocalWeibullCDF2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class ReciprocalWeibullCDF_ExponentialDecayAndOffset_2D(ReciprocalWeibullCDF2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class ReciprocalWeibullCDF_LinearGrowthAndOffset_2D(ReciprocalWeibullCDF2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class ReciprocalWeibullCDF_ExponentialGrowthAndOffset_2D(ReciprocalWeibullCDF2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class InverseWeibullCDF2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Inverse Weibull CDF"
        self.HTML = "y = x / (1.0 - e<SUP>-(x/b)^a</SUP>)"
        self.coefficientDesignatorTuple = ("a", "b")

        self.function_cpp_code = 'temp = indep_data[(int)cachedWeaveOffsets[0] + i] / (1.0 - exp(-1.0 * pow(indep_data[(int)cachedWeaveOffsets[0] + i] / coeff[1], coeff[0])));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = x_in / (1.0 - exp(-1.0 * pow(x_in/b, a)));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = x_in / (1.0 - Math.exp(-1.0 * Math.pow(x_in/b, a)));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = x_in / (1.0 - Math.Exp(-1.0 * Math.Pow(x_in/b, a)));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = x_in / (1.0 - math.exp(-1.0 * math.pow(x_in/b, a)))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = x_in / (1.0 - exp(-1.0 * (x_in/b) ^ a))\n"
        return s


class InverseWeibullCDF_WO_2D(InverseWeibullCDF2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class InverseWeibullCDF_LinearDecay_2D(InverseWeibullCDF2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class InverseWeibullCDF_ExponentialDecay_2D(InverseWeibullCDF2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class InverseWeibullCDF_LinearGrowth_2D(InverseWeibullCDF2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class InverseWeibullCDF_ExponentialGrowth_2D(InverseWeibullCDF2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class InverseWeibullCDF_LinearDecayAndOffset_2D(InverseWeibullCDF2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class InverseWeibullCDF_ExponentialDecayAndOffset_2D(InverseWeibullCDF2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class InverseWeibullCDF_LinearGrowthAndOffset_2D(InverseWeibullCDF2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class InverseWeibullCDF_ExponentialGrowthAndOffset_2D(InverseWeibullCDF2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class ReciprocalMagneticSaturation2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Reciprocal Magnetic Saturation"
        self.HTML = "y = 1.0 / (ax * (1.0 + b*e<SUP>cx</SUP>))"
        self.coefficientDesignatorTuple = ("a", "b", "c")

        self.function_cpp_code = 'temp = 1.0 / (coeff[0] * indep_data[(int)cachedWeaveOffsets[0] + i] *(1.0 + coeff[1] * exp(coeff[2] * indep_data[(int)cachedWeaveOffsets[0] + i])));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = 1.0 / (a*x_in * (1.0 + b*exp(c*x_in)));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = 1.0 / (a*x_in * (1.0 + b*Math.exp(c*x_in)));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = 1.0 / (a*x_in * (1.0 + b*Math.Exp(c*x_in)));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = 1.0 / (a*x_in * (1.0 + b*math.exp(c*x_in)))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = 1.0 / (a*x_in * (1.0 + b*exp(c*x_in)))\n"
        return s


class ReciprocalMagneticSaturation_WO_2D(ReciprocalMagneticSaturation2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class ReciprocalMagneticSaturation_LinearDecay_2D(ReciprocalMagneticSaturation2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class ReciprocalMagneticSaturation_ExponentialDecay_2D(ReciprocalMagneticSaturation2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class ReciprocalMagneticSaturation_LinearGrowth_2D(ReciprocalMagneticSaturation2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class ReciprocalMagneticSaturation_ExponentialGrowth_2D(ReciprocalMagneticSaturation2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class ReciprocalMagneticSaturation_LinearDecayAndOffset_2D(ReciprocalMagneticSaturation2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class ReciprocalMagneticSaturation_ExponentialDecayAndOffset_2D(ReciprocalMagneticSaturation2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class ReciprocalMagneticSaturation_LinearGrowthAndOffset_2D(ReciprocalMagneticSaturation2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class ReciprocalMagneticSaturation_ExponentialGrowthAndOffset_2D(ReciprocalMagneticSaturation2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class InverseMagneticSaturation2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Inverse Magnetic Saturation"
        self.HTML = "y = x / (ax * (1.0 + b*e<SUP>cx</SUP>))"
        self.coefficientDesignatorTuple = ("a", "b", "c")

        self.function_cpp_code = 'temp = indep_data[(int)cachedWeaveOffsets[0] + i] / (coeff[0] * indep_data[(int)cachedWeaveOffsets[0] + i] *(1.0 + coeff[1] * exp(coeff[2] * indep_data[(int)cachedWeaveOffsets[0] + i])));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = x_in / (a*x_in * (1.0 + b*exp(c*x_in)));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = x_in / (a*x_in * (1.0 + b*Math.exp(c*x_in)));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = x_in / (a*x_in * (1.0 + b*Math.Exp(c*x_in)));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = x_in / (a*x_in * (1.0 + b*math.exp(c*x_in)))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = x_in / (a*x_in * (1.0 + b*exp(c*x_in)))\n"
        return s


class InverseMagneticSaturation_WO_2D(InverseMagneticSaturation2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class InverseMagneticSaturation_LinearDecay_2D(InverseMagneticSaturation2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class InverseMagneticSaturation_ExponentialDecay_2D(InverseMagneticSaturation2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class InverseMagneticSaturation_LinearGrowth_2D(InverseMagneticSaturation2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class InverseMagneticSaturation_ExponentialGrowth_2D(InverseMagneticSaturation2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class InverseMagneticSaturation_LinearDecayAndOffset_2D(InverseMagneticSaturation2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class InverseMagneticSaturation_ExponentialDecayAndOffset_2D(InverseMagneticSaturation2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class InverseMagneticSaturation_LinearGrowthAndOffset_2D(InverseMagneticSaturation2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class InverseMagneticSaturation_ExponentialGrowthAndOffset_2D(InverseMagneticSaturation2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
