#    pythonequations is a collection of equations expressed as Python classes
#    Copyright (C) 2008 James R. Phillips
#    2548 Vera Cruz Drive
#    Birmingham, AL 35235 USA
#    email: zunzun@zunzun.com
#
#    Version info: $Id$
#
#    License: BSD-style (see LICENSE.txt in main source directory)

import pythonequations, pythonequations.EquationBaseClasses
import numpy
numpy.seterr(all = 'raise') # numpy raises warnings, convert to exceptions to trap them

class SineA2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Sine A [radians]"
        self.HTML = "y = a * sin(x)"
        self.LinearSSQSolverFlag = 1
        self.coefficientDesignatorTuple = ("a")

        self.function_cpp_code = 'temp = coeff[0] * indep_data[(int)cachedWeaveOffsets[0] + i];// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_SinX(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a * sin(x_in);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a * Math.sin(x_in);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a * Math.Sin(x_in);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = a * math.sin(x_in)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = a * sin(x_in)\n"
        return s


class SineA_WO_2D(SineA2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class SineA_LinearDecay_2D(SineA2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class SineA_ExponentialDecay_2D(SineA2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class SineA_LinearGrowth_2D(SineA2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class SineA_ExponentialGrowth_2D(SineA2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class SineA_LinearDecayAndOffset_2D(SineA2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class SineA_ExponentialDecayAndOffset_2D(SineA2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class SineA_LinearGrowthAndOffset_2D(SineA2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class SineA_ExponentialGrowthAndOffset_2D(SineA2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class SineB2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Sine B [radians]"
        self.HTML = "y = a * sin(b*x)"
        self.coefficientDesignatorTuple = ("a", "b")

        self.function_cpp_code = 'temp = coeff[0] * sin(coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a * sin(b * x_in);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a * Math.sin(b * x_in);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a * Math.Sin(b * x_in);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = a * math.sin(b * x_in)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = a * sin(b * x_in)\n"
        return s


class SineB_WO_2D(SineB2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class SineB_LinearDecay_2D(SineB2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class SineB_ExponentialDecay_2D(SineB2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class SineB_LinearGrowth_2D(SineB2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class SineB_ExponentialGrowth_2D(SineB2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class SineB_LinearDecayAndOffset_2D(SineB2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class SineB_ExponentialDecayAndOffset_2D(SineB2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class SineB_LinearGrowthAndOffset_2D(SineB2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class SineB_ExponentialGrowthAndOffset_2D(SineB2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class SineC2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Sine C [radians]"
        self.HTML = "y = a * sin(bx + c)"
        self.coefficientDesignatorTuple = ("a", "b", "c")

        self.function_cpp_code = 'temp = coeff[0] * sin(coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[2]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a * sin(b * x_in + c);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a * Math.sin(b * x_in + c);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a * Math.Sin(b * x_in + c);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = a * math.sin(b * x_in + c)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = a * sin(b * x_in + c)\n"
        return s


class SineC_WO_2D(SineC2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class SineC_LinearDecay_2D(SineC2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class SineC_ExponentialDecay_2D(SineC2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class SineC_LinearGrowth_2D(SineC2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class SineC_ExponentialGrowth_2D(SineC2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class SineC_LinearDecayAndOffset_2D(SineC2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class SineC_ExponentialDecayAndOffset_2D(SineC2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class SineC_LinearGrowthAndOffset_2D(SineC2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class SineC_ExponentialGrowthAndOffset_2D(SineC2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class SineD2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Sine D [radians]"
        self.HTML = "y = a * sin(x + b)"
        self.coefficientDesignatorTuple = ("a", "b")
        self.requiresCoefficientBoundsCheckWhenFitting = 1

        self.function_cpp_code = 'temp = coeff[0] * sin(coeff[1] + indep_data[(int)cachedWeaveOffsets[1] + i]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])

    def Initialize(self):
        pythonequations.EquationBaseClasses.Equation2D.Initialize(self)

        temp = numpy.max(numpy.abs(self.IndependentDataArray[0]))
        self.upperCoefficientBoundsArray[1] = temp + 6.3
        self.lowerCoefficientBoundsArray[1] = (-1.0 * temp) - 6.3

    def VerifyCoefficientsAreWithinBounds(self, in_coeffArray):
        # see Equation base class definition of this method
        return self.lowerCoefficientBoundsArray[1] < in_coeffArray[1] < self.upperCoefficientBoundsArray[1]

    def SpecificCodeCPP(self):
        s = "\ttemp = a * sin(b + x_in);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a * Math.sin(b + x_in);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a * Math.Sin(b + x_in);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = a * math.sin(b + x_in)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = a * sin(b + x_in)\n"
        return s


class SineD_WO_2D(SineD2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class SineD_LinearDecay_2D(SineD2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class SineD_ExponentialDecay_2D(SineD2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class SineD_LinearGrowth_2D(SineD2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class SineD_ExponentialGrowth_2D(SineD2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class SineD_LinearDecayAndOffset_2D(SineD2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class SineD_ExponentialDecayAndOffset_2D(SineD2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class SineD_LinearGrowthAndOffset_2D(SineD2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class SineD_ExponentialGrowthAndOffset_2D(SineD2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class TanA2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Tangent A [radians]"
        self.HTML = "y = a * tan(x)"
        self.LinearSSQSolverFlag = 1
        self.coefficientDesignatorTuple = ("a")

        self.function_cpp_code = 'temp = coeff[0] * indep_data[(int)cachedWeaveOffsets[0] + i];// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_TanX(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a * tan(x_in);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a * Math.tan(x_in);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a * Math.Tan(x_in);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = a * math.tan(x_in)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = a * tan(x_in)\n"
        return s


class TanA_WO_2D(TanA2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class TanA_LinearDecay_2D(TanA2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class TanA_ExponentialDecay_2D(TanA2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class TanA_LinearGrowth_2D(TanA2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class TanA_ExponentialGrowth_2D(TanA2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class TanA_LinearDecayAndOffset_2D(TanA2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class TanA_ExponentialDecayAndOffset_2D(TanA2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class TanA_LinearGrowthAndOffset_2D(TanA2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class TanA_ExponentialGrowthAndOffset_2D(TanA2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class TanB2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Tangent B [radians]"
        self.HTML = "y = a * tan(b*x)"
        self.coefficientDesignatorTuple = ("a", "b")

        self.function_cpp_code = 'temp = coeff[0] * tan(coeff[1] * indep_data[(int)cachedWeaveOffsets[0] + i]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1] + "\n"


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a * tan(b * x_in);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a * Math.tan(b * x_in);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a * Math.Tan(b * x_in);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = a * math.tan(b * x_in)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = a * tan(b * x_in)\n"
        return s


class TanB_WO_2D(TanB2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class TanB_LinearDecay_2D(TanB2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class TanB_ExponentialDecay_2D(TanB2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class TanB_LinearGrowth_2D(TanB2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class TanB_ExponentialGrowth_2D(TanB2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class TanB_LinearDecayAndOffset_2D(TanB2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class TanB_ExponentialDecayAndOffset_2D(TanB2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class TanB_LinearGrowthAndOffset_2D(TanB2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class TanB_ExponentialGrowthAndOffset_2D(TanB2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class TanC2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Tangent C [radians]"
        self.HTML = "y = a * tan(bx + c)"
        self.coefficientDesignatorTuple = ("a", "b", "c")
        self.requiresCoefficientBoundsCheckWhenFitting = 1

        self.function_cpp_code = 'temp = coeff[0] * tan(coeff[1] * indep_data[(int)cachedWeaveOffsets[0] + i] + coeff[2]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1] + "\n"


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])

    def Initialize(self):
        pythonequations.EquationBaseClasses.Equation2D.Initialize(self)

        nobs = len(self.IndependentDataArray[0])
        self.upperCoefficientBoundsArray[1] = nobs / 2.0
        self.lowerCoefficientBoundsArray[1] = nobs / -2.0

        temp = numpy.max(numpy.abs(self.IndependentDataArray[0]))
        self.upperCoefficientBoundsArray[2] = temp
        self.lowerCoefficientBoundsArray[2] = -1.0 * temp

    def VerifyCoefficientsAreWithinBounds(self, in_coeffArray):
        # see Equation base class definition of this method
        return (self.lowerCoefficientBoundsArray[1] < in_coeffArray[1] < self.upperCoefficientBoundsArray[1]) and ((self.lowerCoefficientBoundsArray[2] < in_coeffArray[2] < self.upperCoefficientBoundsArray[2]))

    def SpecificCodeCPP(self):
        s = "\ttemp = a * tan(b * x_in + c);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a * Math.tan(b * x_in + c);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a * Math.Tan(b * x_in + c);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = a * math.tan(b * x_in + c)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = a * tan(b * x_in + c)\n"
        return s


class TanC_WO_2D(TanC2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class TanC_LinearDecay_2D(TanC2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class TanC_ExponentialDecay_2D(TanC2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class TanC_LinearGrowth_2D(TanC2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class TanC_ExponentialGrowth_2D(TanC2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class TanC_LinearDecayAndOffset_2D(TanC2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class TanC_ExponentialDecayAndOffset_2D(TanC2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class TanC_LinearGrowthAndOffset_2D(TanC2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class TanC_ExponentialGrowthAndOffset_2D(TanC2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class TanD2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Tangent D [radians]"
        self.HTML = "y = a * tan(x + b)"
        self.coefficientDesignatorTuple = ("a", "b")

        self.function_cpp_code = 'temp = coeff[0] * tan(coeff[1] + indep_data[(int)cachedWeaveOffsets[1] + i]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1] + "\n"


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a * tan(x_in + b);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a * Math.tan(x_in + b);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a * Math.Tan(x_in + b);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = a * math.tan(x_in + b)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = a * tan(x_in + b)\n"
        return s


class TanD_WO_2D(TanD2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class TanD_LinearDecay_2D(TanD2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class TanD_ExponentialDecay_2D(TanD2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class TanD_LinearGrowth_2D(TanD2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class TanD_ExponentialGrowth_2D(TanD2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class TanD_LinearDecayAndOffset_2D(TanD2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class TanD_ExponentialDecayAndOffset_2D(TanD2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class TanD_LinearGrowthAndOffset_2D(TanD2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class TanD_ExponentialGrowthAndOffset_2D(TanD2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class HyperbolicCosineA2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Hyperbolic Cosine A [radians]"
        self.HTML = "y = a * cosh(x)"
        self.LinearSSQSolverFlag = 1
        self.coefficientDesignatorTuple = ("a")

        self.function_cpp_code = 'temp = coeff[0] * indep_data[(int)cachedWeaveOffsets[0] + i];// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1] + "\n"


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_CoshX(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a * cosh(x_in);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a * Math.cosh(x_in);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a * Math.Cosh(x_in);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = a * math.cosh(x_in)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = a * cosh(x_in)\n"
        return s


class HyperbolicCosineA_WO_2D(HyperbolicCosineA2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class HyperbolicCosineA_LinearDecay_2D(HyperbolicCosineA2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class HyperbolicCosineA_ExponentialDecay_2D(HyperbolicCosineA2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class HyperbolicCosineA_LinearGrowth_2D(HyperbolicCosineA2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class HyperbolicCosineA_ExponentialGrowth_2D(HyperbolicCosineA2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class HyperbolicCosineA_LinearDecayAndOffset_2D(HyperbolicCosineA2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class HyperbolicCosineA_ExponentialDecayAndOffset_2D(HyperbolicCosineA2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class HyperbolicCosineA_LinearGrowthAndOffset_2D(HyperbolicCosineA2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class HyperbolicCosineA_ExponentialGrowthAndOffset_2D(HyperbolicCosineA2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class HyperbolicCosineB2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Hyperbolic Cosine B [radians]"
        self.HTML = "y = a * cosh(x + b)"
        self.coefficientDesignatorTuple = ("a", "b")

        self.function_cpp_code = 'temp = coeff[0] * cosh(indep_data[(int)cachedWeaveOffsets[0]] + coeff[1]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1] + "\n"


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a * cosh(x_in + b);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a * Math.cosh(x_in + b);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a * Math.Cosh(x_in + b);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = a * math.cosh(x_in + b)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = a * cosh(x_in + b)\n"
        return s


class HyperbolicCosineB_WO_2D(HyperbolicCosineB2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class HyperbolicCosineB_LinearDecay_2D(HyperbolicCosineB2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class HyperbolicCosineB_ExponentialDecay_2D(HyperbolicCosineB2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class HyperbolicCosineB_LinearGrowth_2D(HyperbolicCosineB2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class HyperbolicCosineB_ExponentialGrowth_2D(HyperbolicCosineB2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class HyperbolicCosineB_LinearDecayAndOffset_2D(HyperbolicCosineB2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class HyperbolicCosineB_ExponentialDecayAndOffset_2D(HyperbolicCosineB2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class HyperbolicCosineB_LinearGrowthAndOffset_2D(HyperbolicCosineB2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class HyperbolicCosineB_ExponentialGrowthAndOffset_2D(HyperbolicCosineB2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class HyperbolicCosineC2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Hyperbolic Cosine C [radians]"
        self.HTML = "y = a / cosh(x)"
        self.coefficientDesignatorTuple = ("a")

        self.function_cpp_code = 'temp = coeff[0] / indep_data[(int)cachedWeaveOffsets[0]];// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1] + "\n"


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_CoshX(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a / cosh(x_in);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a / Math.cosh(x_in);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a / Math.Cosh(x_in);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = a / math.cosh(x_in)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = a / cosh(x_in)\n"
        return s


class HyperbolicCosineC_WO_2D(HyperbolicCosineC2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class HyperbolicCosineC_LinearDecay_2D(HyperbolicCosineC2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class HyperbolicCosineC_ExponentialDecay_2D(HyperbolicCosineC2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class HyperbolicCosineC_LinearGrowth_2D(HyperbolicCosineC2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class HyperbolicCosineC_ExponentialGrowth_2D(HyperbolicCosineC2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class HyperbolicCosineC_LinearDecayAndOffset_2D(HyperbolicCosineC2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class HyperbolicCosineC_ExponentialDecayAndOffset_2D(HyperbolicCosineC2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class HyperbolicCosineC_LinearGrowthAndOffset_2D(HyperbolicCosineC2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class HyperbolicCosineC_ExponentialGrowthAndOffset_2D(HyperbolicCosineC2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class HyperbolicCosineD2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Hyperbolic Cosine D [radians]"
        self.HTML = "y = a / cosh(x + b)"
        self.coefficientDesignatorTuple = ("a", "b")

        self.function_cpp_code = 'temp = coeff[0] / cosh(indep_data[(int)cachedWeaveOffsets[0]] + coeff[1]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1] + "\n"


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a / cosh(x_in + b);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a / Math.cosh(x_in + b);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a / Math.Cosh(x_in + b);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = a / math.cosh(x_in + b)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = a / cosh(x_in + b)\n"
        return s


class HyperbolicCosineD_WO_2D(HyperbolicCosineD2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class HyperbolicCosineD_LinearDecay_2D(HyperbolicCosineD2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class HyperbolicCosineD_ExponentialDecay_2D(HyperbolicCosineD2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class HyperbolicCosineD_LinearGrowth_2D(HyperbolicCosineD2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class HyperbolicCosineD_ExponentialGrowth_2D(HyperbolicCosineD2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class HyperbolicCosineD_LinearDecayAndOffset_2D(HyperbolicCosineD2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class HyperbolicCosineD_ExponentialDecayAndOffset_2D(HyperbolicCosineD2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class HyperbolicCosineD_LinearGrowthAndOffset_2D(HyperbolicCosineD2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class HyperbolicCosineD_ExponentialGrowthAndOffset_2D(HyperbolicCosineD2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class HyperbolicCosineE2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Hyperbolic Cosine D [radians]"
        self.HTML = "y = a / cosh(x / a)"
        self.coefficientDesignatorTuple = ("a")

        self.function_cpp_code = 'temp = coeff[0] / cosh(indep_data[(int)cachedWeaveOffsets[0]] / coeff[0]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1] + "\n"


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a / cosh(x_in / a);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a / Math.cosh(x_in / a);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a / Math.Cosh(x_in / a);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = a / math.cosh(x_in / a)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = a / cosh(x_in / a)\n"
        return s


class HyperbolicCosineE_WO_2D(HyperbolicCosineE2D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class HyperbolicCosineE_LinearDecay_2D(HyperbolicCosineE2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class HyperbolicCosineE_ExponentialDecay_2D(HyperbolicCosineE2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class HyperbolicCosineE_LinearGrowth_2D(HyperbolicCosineE2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class HyperbolicCosineE_ExponentialGrowth_2D(HyperbolicCosineE2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class HyperbolicCosineE_LinearDecayAndOffset_2D(HyperbolicCosineE2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class HyperbolicCosineE_ExponentialDecayAndOffset_2D(HyperbolicCosineE2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class HyperbolicCosineE_LinearGrowthAndOffset_2D(HyperbolicCosineE2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class HyperbolicCosineE_ExponentialGrowthAndOffset_2D(HyperbolicCosineE2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
