#    pythonequations is a collection of equations expressed as Python classes
#    Copyright (C) 2008 James R. Phillips
#    2548 Vera Cruz Drive
#    Birmingham, AL 35235 USA
#    email: zunzun@zunzun.com
#
#    Version info: $Id$
#
#    License: BSD-style (see LICENSE.txt in main source directory)

import pythonequations, pythonequations.EquationBaseClasses
import numpy
numpy.seterr(all = 'raise') # numpy raises warnings, convert to exceptions to trap them

class Bleasdale2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Bleasdale"
        self.HTML = "y = 1.0 / (a + bx)<SUP>(-1.0/c)</SUP>"
        self.coefficientDesignatorTuple = ("a", "b", "c")

        self.function_cpp_code = 'temp = 1.0 / pow(coeff[0] + coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i], -1.0 / coeff[2]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = 1.0 / pow((a + b*x_in), (-1.0/c));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = 1.0 / Math.pow((a + b*x_in), (-1.0/c));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = 1.0 / Math.Pow((a + b*x_in), (-1.0/c));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = 1.0 / math.pow((a + b*x_in), (-1.0/c))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = 1.0 / ((a + b*x_in) ^ (-1.0/c))\n"
        return s


class Bleasdale_LinearDecay_2D(Bleasdale2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class Bleasdale_ExponentialDecay_2D(Bleasdale2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class Bleasdale_LinearGrowth_2D(Bleasdale2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class Bleasdale_ExponentialGrowth_2D(Bleasdale2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class Bleasdale_LinearDecayAndOffset_2D(Bleasdale2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class Bleasdale_ExponentialDecayAndOffset_2D(Bleasdale2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class Bleasdale_LinearGrowthAndOffset_2D(Bleasdale2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class Bleasdale_ExponentialGrowthAndOffset_2D(Bleasdale2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()


class InverseBleasdale2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Inverse Bleasdale"
        self.HTML = "y = x / (a + bx)<SUP>(-1.0/c)</SUP>"
        self.coefficientDesignatorTuple = ("a", "b", "c")

        self.function_cpp_code = 'temp = indep_data[(int)cachedWeaveOffsets[1] + i] / pow(coeff[0] + coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i], -1.0 / coeff[2]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = x_in / pow((a + b*x_in), (-1.0/c));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = x_in / Math.pow((a + b*x_in), (-1.0/c));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = x_in / Math.Pow((a + b*x_in), (-1.0/c));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = x_in / math.pow((a + b*x_in), (-1.0/c))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = x_in / ((a + b*x_in) ^ (-1.0/c))\n"
        return s


class InverseBleasdale_LinearDecay_2D(InverseBleasdale2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class InverseBleasdale_ExponentialDecay_2D(InverseBleasdale2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class InverseBleasdale_LinearGrowth_2D(InverseBleasdale2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class InverseBleasdale_ExponentialGrowth_2D(InverseBleasdale2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class InverseBleasdale_LinearDecayAndOffset_2D(InverseBleasdale2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class InverseBleasdale_ExponentialDecayAndOffset_2D(InverseBleasdale2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class InverseBleasdale_LinearGrowthAndOffset_2D(InverseBleasdale2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class InverseBleasdale_ExponentialGrowthAndOffset_2D(InverseBleasdale2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()



class Harris2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "Harris"
        self.HTML = "y = 1.0 / (a + bx<SUP>c</SUP>)"
        self.coefficientDesignatorTuple = ("a", "b", "c")
        self.RequiresPositiveX = 1

        self.function_cpp_code = 'temp = 1.0 / (coeff[0] + coeff[1] * pow(indep_data[(int)cachedWeaveOffsets[1] + i], coeff[2]));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = 1.0 / (a + b*pow(x_in, c));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = 1.0 / (a + b*Math.pow(x_in, c));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = 1.0 / (a + b*Math.Pow(x_in, c));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = 1.0 / (a + b*math.pow(x_in, c))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = 1.0 / (a + b*(x_in ^ c))\n"
        return s


class Harris_LinearDecay_2D(Harris2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class Harris_ExponentialDecay_2D(Harris2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class Harris_LinearGrowth_2D(Harris2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class Harris_ExponentialGrowth_2D(Harris2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class Harris_LinearDecayAndOffset_2D(Harris2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class Harris_ExponentialDecayAndOffset_2D(Harris2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class Harris_LinearGrowthAndOffset_2D(Harris2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class Harris_ExponentialGrowthAndOffset_2D(Harris2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()



class InverseHarris2D(pythonequations.EquationBaseClasses.Equation2D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation2D.__init__(self)
        self.name = "InverseHarris"
        self.HTML = "y = x / (a + bx<SUP>c</SUP>)"
        self.coefficientDesignatorTuple = ("a", "b", "c")
        self.RequiresPositiveX = 1

        self.function_cpp_code = 'temp = indep_data[(int)cachedWeaveOffsets[1] + i] / (coeff[0] + coeff[1] * pow(indep_data[(int)cachedWeaveOffsets[1] + i], coeff[2]));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = x_in / (a + b*pow(x_in, c));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = x_in / (a + b*Math.pow(x_in, c));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = x_in / (a + b*Math.Pow(x_in, c));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = x_in / (a + b*math.pow(x_in, c))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = x_in / (a + b*(x_in ^ c))\n"
        return s


class InverseHarris_LinearDecay_2D(InverseHarris2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class InverseHarris_ExponentialDecay_2D(InverseHarris2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class InverseHarris_LinearGrowth_2D(InverseHarris2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class InverseHarris_ExponentialGrowth_2D(InverseHarris2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class InverseHarris_LinearDecayAndOffset_2D(InverseHarris2D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class InverseHarris_ExponentialDecayAndOffset_2D(InverseHarris2D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class InverseHarris_LinearGrowthAndOffset_2D(InverseHarris2D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class InverseHarris_ExponentialGrowthAndOffset_2D(InverseHarris2D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
