#    pythonequations is a collection of equations expressed as Python classes
#    Copyright (C) 2008 James R. Phillips
#    2548 Vera Cruz Drive
#    Birmingham, AL 35235 USA
#    email: zunzun@zunzun.com
#
#    Version info: $Id: Polynomial.py 37 2008-11-24 15:50:28Z zunzun.com $
#
#    License: BSD-style (see LICENSE.txt in main source directory)

import pythonequations, pythonequations.EquationBaseClasses
import numpy
numpy.seterr(all = 'raise') # numpy raises warnings, convert to exceptions to trap them


class LinearLogarithmic3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Linear Logarithmic"
        self.HTML = "z = a + b*ln(x) + c*ln(y)"
        self.coefficientDesignatorTuple = ("a", "b", "c")
        self.LinearSSQSolverFlag = 1
        self.RequiresPositiveX = 1
        self.RequiresPositiveY = 1

        self.function_cpp_code = 'temp = coeff[0] + coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[2] * indep_data[(int)cachedWeaveOffsets[2] + i];// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogX(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogY(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp += " + self.coefficientDesignatorTuple[0] + ";\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[1] + " * log(x_in);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[2] + " * log(y_in);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp += " + self.coefficientDesignatorTuple[0] + ";\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[1] + " * Math.log(x_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[2] + " * Math.log(y_in);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp += " + self.coefficientDesignatorTuple[0] + ";\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[1] + " * Math.Log(x_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[2] + " * Math.Log(y_in);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp += " + self.coefficientDesignatorTuple[0] + "\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[1] + " * math.log(x_in)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[2] + " * math.log(y_in)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = temp + " + self.coefficientDesignatorTuple[0] + "\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[1] + " * log(x_in)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[2] + " * log(y_in)\n"
        return s


class LinearLogarithmic_X_LinearDecay_3D(LinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class LinearLogarithmic_Y_LinearDecay_3D(LinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class LinearLogarithmic_XY_LinearDecay_3D(LinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class LinearLogarithmic_X_ExponentialDecay_3D(LinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class LinearLogarithmic_Y_ExponentialDecay_3D(LinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class LinearLogarithmic_XY_ExponentialDecay_3D(LinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class LinearLogarithmic_X_LinearGrowth_3D(LinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class LinearLogarithmic_Y_LinearGrowth_3D(LinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class LinearLogarithmic_XY_LinearGrowth_3D(LinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class LinearLogarithmic_X_ExponentialGrowth_3D(LinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class LinearLogarithmic_Y_ExponentialGrowth_3D(LinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class LinearLogarithmic_XY_ExponentialGrowth_3D(LinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class LinearLogarithmic_X_LinearDecayAndOffset_3D(LinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class LinearLogarithmic_Y_LinearDecayAndOffset_3D(LinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class LinearLogarithmic_XY_LinearDecayAndOffset_3D(LinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class LinearLogarithmic_X_ExponentialDecayAndOffset_3D(LinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class LinearLogarithmic_Y_ExponentialDecayAndOffset_3D(LinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class LinearLogarithmic_XY_ExponentialDecayAndOffset_3D(LinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class LinearLogarithmic_X_LinearGrowthAndOffset_3D(LinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class LinearLogarithmic_Y_LinearGrowthAndOffset_3D(LinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class LinearLogarithmic_XY_LinearGrowthAndOffset_3D(LinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class LinearLogarithmic_X_ExponentialGrowthAndOffset_3D(LinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class LinearLogarithmic_Y_ExponentialGrowthAndOffset_3D(LinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class LinearLogarithmic_XY_ExponentialGrowthAndOffset_3D(LinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()


class ReciprocalLinearLogarithmic3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Reciprocal Linear Logarithmic"
        self.HTML = "z = 1.0 / (a + b*ln(x) + c*ln(y))"
        self.coefficientDesignatorTuple = ("a", "b", "c")
        self.RequiresPositiveX = 1
        self.RequiresPositiveY = 1

        self.function_cpp_code = 'temp = 1.0 / (coeff[0] + coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[2] * indep_data[(int)cachedWeaveOffsets[2] + i]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogX(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogY(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp += " + self.coefficientDesignatorTuple[0] + ";\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[1] + " * log(x_in);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[2] + " * log(y_in);\n"
        s += "\ttemp = 1.0 / temp;\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp += " + self.coefficientDesignatorTuple[0] + ";\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[1] + " * Math.log(x_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[2] + " * Math.log(y_in);\n"
        s += "\t\ttemp = 1.0 / temp;\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp += " + self.coefficientDesignatorTuple[0] + ";\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[1] + " * Math.Log(x_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[2] + " * Math.Log(y_in);\n"
        s += "\t\ttemp = 1.0 / temp;\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp += " + self.coefficientDesignatorTuple[0] + "\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[1] + " * math.log(x_in)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[2] + " * math.log(y_in)\n"
        s += "\ttemp = 1.0 / temp\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = temp + " + self.coefficientDesignatorTuple[0] + "\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[1] + " * log(x_in)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[2] + " * log(y_in)\n"
        s += "\ttemp = 1.0 / temp\n"
        return s


class ReciprocalLinearLogarithmic_X_LinearDecay_3D(ReciprocalLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class ReciprocalLinearLogarithmic_Y_LinearDecay_3D(ReciprocalLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class ReciprocalLinearLogarithmic_XY_LinearDecay_3D(ReciprocalLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class ReciprocalLinearLogarithmic_X_ExponentialDecay_3D(ReciprocalLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class ReciprocalLinearLogarithmic_Y_ExponentialDecay_3D(ReciprocalLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class ReciprocalLinearLogarithmic_XY_ExponentialDecay_3D(ReciprocalLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class ReciprocalLinearLogarithmic_X_LinearGrowth_3D(ReciprocalLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class ReciprocalLinearLogarithmic_Y_LinearGrowth_3D(ReciprocalLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class ReciprocalLinearLogarithmic_XY_LinearGrowth_3D(ReciprocalLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class ReciprocalLinearLogarithmic_X_ExponentialGrowth_3D(ReciprocalLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class ReciprocalLinearLogarithmic_Y_ExponentialGrowth_3D(ReciprocalLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class ReciprocalLinearLogarithmic_XY_ExponentialGrowth_3D(ReciprocalLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class ReciprocalLinearLogarithmic_X_LinearDecayAndOffset_3D(ReciprocalLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class ReciprocalLinearLogarithmic_Y_LinearDecayAndOffset_3D(ReciprocalLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class ReciprocalLinearLogarithmic_XY_LinearDecayAndOffset_3D(ReciprocalLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class ReciprocalLinearLogarithmic_X_ExponentialDecayAndOffset_3D(ReciprocalLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class ReciprocalLinearLogarithmic_Y_ExponentialDecayAndOffset_3D(ReciprocalLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class ReciprocalLinearLogarithmic_XY_ExponentialDecayAndOffset_3D(ReciprocalLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class ReciprocalLinearLogarithmic_X_LinearGrowthAndOffset_3D(ReciprocalLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class ReciprocalLinearLogarithmic_Y_LinearGrowthAndOffset_3D(ReciprocalLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class ReciprocalLinearLogarithmic_XY_LinearGrowthAndOffset_3D(ReciprocalLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class ReciprocalLinearLogarithmic_X_ExponentialGrowthAndOffset_3D(ReciprocalLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class ReciprocalLinearLogarithmic_Y_ExponentialGrowthAndOffset_3D(ReciprocalLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class ReciprocalLinearLogarithmic_XY_ExponentialGrowthAndOffset_3D(ReciprocalLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()



class InverseLinearLogarithmic3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Inverse Linear Logarithmic"
        self.HTML = "z = xy / (a + b*ln(x) + c*ln(y))"
        self.coefficientDesignatorTuple = ("a", "b", "c")
        self.RequiresPositiveX = 1
        self.RequiresPositiveY = 1

        self.function_cpp_code = 'temp = indep_data[(int)cachedWeaveOffsets[3] + i] / (coeff[0] + coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[2] * indep_data[(int)cachedWeaveOffsets[2] + i]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogX(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogY(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_XY(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp += " + self.coefficientDesignatorTuple[0] + ";\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[1] + " * log(x_in);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[2] + " * log(y_in);\n"
        s += "\ttemp = x_in * y_in / temp;\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp += " + self.coefficientDesignatorTuple[0] + ";\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[1] + " * Math.log(x_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[2] + " * Math.log(y_in);\n"
        s += "\t\ttemp = x_in * y_in / temp;\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp += " + self.coefficientDesignatorTuple[0] + ";\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[1] + " * Math.Log(x_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[2] + " * Math.Log(y_in);\n"
        s += "\t\ttemp = x_in * y_in / temp;\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp += " + self.coefficientDesignatorTuple[0] + "\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[1] + " * math.log(x_in)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[2] + " * math.log(y_in)\n"
        s += "\ttemp = x_in * y_in / temp\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = temp + " + self.coefficientDesignatorTuple[0] + "\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[1] + " * log(x_in)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[2] + " * log(y_in)\n"
        s += "\ttemp = x_in * y_in / temp\n"
        return s


class InverseLinearLogarithmic_X_LinearDecay_3D(InverseLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class InverseLinearLogarithmic_Y_LinearDecay_3D(InverseLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class InverseLinearLogarithmic_XY_LinearDecay_3D(InverseLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class InverseLinearLogarithmic_X_ExponentialDecay_3D(InverseLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class InverseLinearLogarithmic_Y_ExponentialDecay_3D(InverseLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class InverseLinearLogarithmic_XY_ExponentialDecay_3D(InverseLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class InverseLinearLogarithmic_X_LinearGrowth_3D(InverseLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class InverseLinearLogarithmic_Y_LinearGrowth_3D(InverseLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class InverseLinearLogarithmic_XY_LinearGrowth_3D(InverseLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class InverseLinearLogarithmic_X_ExponentialGrowth_3D(InverseLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class InverseLinearLogarithmic_Y_ExponentialGrowth_3D(InverseLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class InverseLinearLogarithmic_XY_ExponentialGrowth_3D(InverseLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class InverseLinearLogarithmic_X_LinearDecayAndOffset_3D(InverseLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class InverseLinearLogarithmic_Y_LinearDecayAndOffset_3D(InverseLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class InverseLinearLogarithmic_XY_LinearDecayAndOffset_3D(InverseLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class InverseLinearLogarithmic_X_ExponentialDecayAndOffset_3D(InverseLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class InverseLinearLogarithmic_Y_ExponentialDecayAndOffset_3D(InverseLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class InverseLinearLogarithmic_XY_ExponentialDecayAndOffset_3D(InverseLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class InverseLinearLogarithmic_X_LinearGrowthAndOffset_3D(InverseLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class InverseLinearLogarithmic_Y_LinearGrowthAndOffset_3D(InverseLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class InverseLinearLogarithmic_XY_LinearGrowthAndOffset_3D(InverseLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class InverseLinearLogarithmic_X_ExponentialGrowthAndOffset_3D(InverseLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class InverseLinearLogarithmic_Y_ExponentialGrowthAndOffset_3D(InverseLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class InverseLinearLogarithmic_XY_ExponentialGrowthAndOffset_3D(InverseLinearLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()



class SimplifiedQuadraticLogarithmic3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Simplified Quadratic Logarithmic"
        self.HTML = "z = a + b*ln(x) + c*ln(y) + d*ln(x)<SUP>2</SUP> + e*ln(y)<SUP>2</SUP>"
        self.coefficientDesignatorTuple = ("a", "b", "c", "d", "e")
        self.LinearSSQSolverFlag = 1
        self.RequiresPositiveX = 1
        self.RequiresPositiveY = 1

        self.function_cpp_code = 'temp = coeff[0] + coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[2] * indep_data[(int)cachedWeaveOffsets[2] + i] + coeff[3] * indep_data[(int)cachedWeaveOffsets[3] + i] + coeff[4] * indep_data[(int)cachedWeaveOffsets[4] + i];// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogX(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogY(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_PowLogX(NameOrValueFlag=1, args=[2.0]), [2.0]])
        self.CacheGenerationList.append([self.CG_PowLogY(NameOrValueFlag=1, args=[2.0]), [2.0]])

    def SpecificCodeCPP(self):
        s = "\ttemp += " + self.coefficientDesignatorTuple[0] + ";\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[1] + " * log(x_in);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[2] + " * log(y_in);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[3] + " * pow(log(x_in), 2.0);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[4] + " * pow(log(y_in), 2.0);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp += " + self.coefficientDesignatorTuple[0] + ";\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[1] + " * Math.log(x_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[2] + " * Math.log(y_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[3] + " * Math.pow(Math.log(x_in), 2.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[4] + " * Math.pow(Math.log(y_in), 2.0);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp += " + self.coefficientDesignatorTuple[0] + ";\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[1] + " * Math.Log(x_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[2] + " * Math.Log(y_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[3] + " * Math.Pow(Math.Log(x_in), 2.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[4] + " * Math.Pow(Math.Log(y_in), 2.0);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp += " + self.coefficientDesignatorTuple[0] + "\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[1] + " * math.log(x_in)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[2] + " * math.log(y_in)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[3] + " * math.pow(math.log(x_in), 2.0)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[4] + " * math.pow(math.log(y_in), 2.0)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = temp + " + self.coefficientDesignatorTuple[0] + "\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[1] + " * log(x_in)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[2] + " * log(y_in)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[3] + " * (log(x_in) ^ 2.0)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[4] + " * (log(y_in) ^ 2.0)\n"
        return s


class SimplifiedQuadraticLogarithmic_X_LinearDecay_3D(SimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class SimplifiedQuadraticLogarithmic_Y_LinearDecay_3D(SimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class SimplifiedQuadraticLogarithmic_XY_LinearDecay_3D(SimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class SimplifiedQuadraticLogarithmic_X_ExponentialDecay_3D(SimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class SimplifiedQuadraticLogarithmic_Y_ExponentialDecay_3D(SimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class SimplifiedQuadraticLogarithmic_XY_ExponentialDecay_3D(SimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class SimplifiedQuadraticLogarithmic_X_LinearGrowth_3D(SimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class SimplifiedQuadraticLogarithmic_Y_LinearGrowth_3D(SimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class SimplifiedQuadraticLogarithmic_XY_LinearGrowth_3D(SimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class SimplifiedQuadraticLogarithmic_X_ExponentialGrowth_3D(SimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class SimplifiedQuadraticLogarithmic_Y_ExponentialGrowth_3D(SimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class SimplifiedQuadraticLogarithmic_XY_ExponentialGrowth_3D(SimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class SimplifiedQuadraticLogarithmic_X_LinearDecayAndOffset_3D(SimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class SimplifiedQuadraticLogarithmic_Y_LinearDecayAndOffset_3D(SimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class SimplifiedQuadraticLogarithmic_XY_LinearDecayAndOffset_3D(SimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class SimplifiedQuadraticLogarithmic_X_ExponentialDecayAndOffset_3D(SimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class SimplifiedQuadraticLogarithmic_Y_ExponentialDecayAndOffset_3D(SimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class SimplifiedQuadraticLogarithmic_XY_ExponentialDecayAndOffset_3D(SimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class SimplifiedQuadraticLogarithmic_X_LinearGrowthAndOffset_3D(SimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class SimplifiedQuadraticLogarithmic_Y_LinearGrowthAndOffset_3D(SimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class SimplifiedQuadraticLogarithmic_XY_LinearGrowthAndOffset_3D(SimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class SimplifiedQuadraticLogarithmic_X_ExponentialGrowthAndOffset_3D(SimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class SimplifiedQuadraticLogarithmic_Y_ExponentialGrowthAndOffset_3D(SimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class SimplifiedQuadraticLogarithmic_XY_ExponentialGrowthAndOffset_3D(SimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()



class ReciprocalSimplifiedQuadraticLogarithmic3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Reciprocal Simplified Quadratic Logarithmic"
        self.HTML = "z = 1.0 / (a + b*ln(x) + c*ln(y) + d*ln(x)<SUP>2</SUP> + e*ln(y)<SUP>2</SUP>)"
        self.coefficientDesignatorTuple = ("a", "b", "c", "d", "e")
        self.RequiresPositiveX = 1
        self.RequiresPositiveY = 1

        self.function_cpp_code = 'temp = 1.0 / (coeff[0] + coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[2] * indep_data[(int)cachedWeaveOffsets[2] + i] + coeff[3] * indep_data[(int)cachedWeaveOffsets[3] + i] + coeff[4] * indep_data[(int)cachedWeaveOffsets[4] + i]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogX(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogY(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_PowLogX(NameOrValueFlag=1, args=[2.0]), [2.0]])
        self.CacheGenerationList.append([self.CG_PowLogY(NameOrValueFlag=1, args=[2.0]), [2.0]])

    def SpecificCodeCPP(self):
        s = "\ttemp += " + self.coefficientDesignatorTuple[0] + ";\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[1] + " * pow(log(x_in);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[2] + " * pow(log(y_in);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[3] + " * pow(pow(log(x_in), 2.0);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[4] + " * pow(pow(log(y_in), 2.0);\n"
        s += "\ttemp = 1.0 / temp;\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp += " + self.coefficientDesignatorTuple[0] + ";\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[1] + " * Math.log(x_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[2] + " * Math.log(y_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[3] + " * Math.pow(Math.log(x_in), 2.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[4] + " * Math.pow(Math.log(y_in), 2.0);\n"
        s += "\t\ttemp = 1.0 / temp;\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp += " + self.coefficientDesignatorTuple[0] + ";\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[1] + " * Math.Log(x_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[2] + " * Math.Log(y_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[3] + " * Math.Pow(Math.Log(x_in), 2.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[4] + " * Math.Pow(Math.Log(y_in), 2.0);\n"
        s += "\t\ttemp = 1.0 / temp;\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp += " + self.coefficientDesignatorTuple[0] + "\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[1] + " * math.log(x_in)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[2] + " * math.log(y_in)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[3] + " * math.pow(math.log(x_in), 2.0)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[4] + " * math.pow(math.log(y_in), 2.0)\n"
        s += "\ttemp = 1.0 / temp\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = temp + " + self.coefficientDesignatorTuple[0] + "\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[1] + " * log(x_in)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[2] + " * log(y_in)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[3] + " * (log(x_in) ^ 2.0)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[4] + " * (log(y_in) ^ 2.0)\n"
        s += "\ttemp = 1.0 / temp\n"
        return s


class ReciprocalSimplifiedQuadraticLogarithmic_X_LinearDecay_3D(ReciprocalSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class ReciprocalSimplifiedQuadraticLogarithmic_Y_LinearDecay_3D(ReciprocalSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class ReciprocalSimplifiedQuadraticLogarithmic_XY_LinearDecay_3D(ReciprocalSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class ReciprocalSimplifiedQuadraticLogarithmic_X_ExponentialDecay_3D(ReciprocalSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class ReciprocalSimplifiedQuadraticLogarithmic_Y_ExponentialDecay_3D(ReciprocalSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class ReciprocalSimplifiedQuadraticLogarithmic_XY_ExponentialDecay_3D(ReciprocalSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class ReciprocalSimplifiedQuadraticLogarithmic_X_LinearGrowth_3D(ReciprocalSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class ReciprocalSimplifiedQuadraticLogarithmic_Y_LinearGrowth_3D(ReciprocalSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class ReciprocalSimplifiedQuadraticLogarithmic_XY_LinearGrowth_3D(ReciprocalSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class ReciprocalSimplifiedQuadraticLogarithmic_X_ExponentialGrowth_3D(ReciprocalSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class ReciprocalSimplifiedQuadraticLogarithmic_Y_ExponentialGrowth_3D(ReciprocalSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class ReciprocalSimplifiedQuadraticLogarithmic_XY_ExponentialGrowth_3D(ReciprocalSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class ReciprocalSimplifiedQuadraticLogarithmic_X_LinearDecayAndOffset_3D(ReciprocalSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class ReciprocalSimplifiedQuadraticLogarithmic_Y_LinearDecayAndOffset_3D(ReciprocalSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class ReciprocalSimplifiedQuadraticLogarithmic_XY_LinearDecayAndOffset_3D(ReciprocalSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class ReciprocalSimplifiedQuadraticLogarithmic_X_ExponentialDecayAndOffset_3D(ReciprocalSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class ReciprocalSimplifiedQuadraticLogarithmic_Y_ExponentialDecayAndOffset_3D(ReciprocalSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class ReciprocalSimplifiedQuadraticLogarithmic_XY_ExponentialDecayAndOffset_3D(ReciprocalSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class ReciprocalSimplifiedQuadraticLogarithmic_X_LinearGrowthAndOffset_3D(ReciprocalSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class ReciprocalSimplifiedQuadraticLogarithmic_Y_LinearGrowthAndOffset_3D(ReciprocalSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class ReciprocalSimplifiedQuadraticLogarithmic_XY_LinearGrowthAndOffset_3D(ReciprocalSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class ReciprocalSimplifiedQuadraticLogarithmic_X_ExponentialGrowthAndOffset_3D(ReciprocalSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class ReciprocalSimplifiedQuadraticLogarithmic_Y_ExponentialGrowthAndOffset_3D(ReciprocalSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class ReciprocalSimplifiedQuadraticLogarithmic_XY_ExponentialGrowthAndOffset_3D(ReciprocalSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()



class InverseSimplifiedQuadraticLogarithmic3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Inverse Simplified Quadratic Logarithmic"
        self.HTML = "z = xy / (a + b*ln(x) + c*ln(y) + d*ln(x)<SUP>2</SUP> + e*ln(y)<SUP>2</SUP>)"
        self.coefficientDesignatorTuple = ("a", "b", "c", "d", "e")
        self.RequiresPositiveX = 1
        self.RequiresPositiveY = 1

        self.function_cpp_code = 'temp = indep_data[(int)cachedWeaveOffsets[5] + i] / (coeff[0] + coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[2] * indep_data[(int)cachedWeaveOffsets[2] + i] + coeff[3] * indep_data[(int)cachedWeaveOffsets[3] + i] + coeff[4] * indep_data[(int)cachedWeaveOffsets[4] + i]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogX(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogY(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_PowLogX(NameOrValueFlag=1, args=[2.0]), [2.0]])
        self.CacheGenerationList.append([self.CG_PowLogY(NameOrValueFlag=1, args=[2.0]), [2.0]])
        self.CacheGenerationList.append([self.CG_XY(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp += " + self.coefficientDesignatorTuple[0] + ";\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[1] + " * pow(log(x_in);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[2] + " * pow(log(y_in);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[3] + " * pow(pow(log(x_in), 2.0);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[4] + " * pow(pow(log(y_in), 2.0);\n"
        s += "\ttemp = x_in * y_in / temp;\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp += " + self.coefficientDesignatorTuple[0] + ";\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[1] + " * Math.log(x_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[2] + " * Math.log(y_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[3] + " * Math.pow(Math.log(x_in), 2.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[4] + " * Math.pow(Math.log(y_in), 2.0);\n"
        s += "\t\ttemp = x_in * y_in / temp;\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp += " + self.coefficientDesignatorTuple[0] + ";\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[1] + " * Math.Log(x_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[2] + " * Math.Log(y_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[3] + " * Math.Pow(Math.Log(x_in), 2.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[4] + " * Math.Pow(Math.Log(y_in), 2.0);\n"
        s += "\t\ttemp = x_in * y_in / temp;\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp += " + self.coefficientDesignatorTuple[0] + "\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[1] + " * math.log(x_in)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[2] + " * math.log(y_in)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[3] + " * math.pow(math.log(x_in), 2.0)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[4] + " * math.pow(math.log(y_in), 2.0)\n"
        s += "\ttemp = x_in * y_in / temp\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = temp + " + self.coefficientDesignatorTuple[0] + "\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[1] + " * log(x_in)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[2] + " * log(y_in)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[3] + " * (log(x_in) ^ 2.0)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[4] + " * (log(y_in) ^ 2.0)\n"
        s += "\ttemp = x_in * y_in / temp\n"
        return s


class InverseSimplifiedQuadraticLogarithmic_X_LinearDecay_3D(InverseSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class InverseSimplifiedQuadraticLogarithmic_Y_LinearDecay_3D(InverseSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class InverseSimplifiedQuadraticLogarithmic_XY_LinearDecay_3D(InverseSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class InverseSimplifiedQuadraticLogarithmic_X_ExponentialDecay_3D(InverseSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class InverseSimplifiedQuadraticLogarithmic_Y_ExponentialDecay_3D(InverseSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class InverseSimplifiedQuadraticLogarithmic_XY_ExponentialDecay_3D(InverseSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class InverseSimplifiedQuadraticLogarithmic_X_LinearGrowth_3D(InverseSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class InverseSimplifiedQuadraticLogarithmic_Y_LinearGrowth_3D(InverseSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class InverseSimplifiedQuadraticLogarithmic_XY_LinearGrowth_3D(InverseSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class InverseSimplifiedQuadraticLogarithmic_X_ExponentialGrowth_3D(InverseSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class InverseSimplifiedQuadraticLogarithmic_Y_ExponentialGrowth_3D(InverseSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class InverseSimplifiedQuadraticLogarithmic_XY_ExponentialGrowth_3D(InverseSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class InverseSimplifiedQuadraticLogarithmic_X_LinearDecayAndOffset_3D(InverseSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class InverseSimplifiedQuadraticLogarithmic_Y_LinearDecayAndOffset_3D(InverseSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class InverseSimplifiedQuadraticLogarithmic_XY_LinearDecayAndOffset_3D(InverseSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class InverseSimplifiedQuadraticLogarithmic_X_ExponentialDecayAndOffset_3D(InverseSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class InverseSimplifiedQuadraticLogarithmic_Y_ExponentialDecayAndOffset_3D(InverseSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class InverseSimplifiedQuadraticLogarithmic_XY_ExponentialDecayAndOffset_3D(InverseSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class InverseSimplifiedQuadraticLogarithmic_X_LinearGrowthAndOffset_3D(InverseSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class InverseSimplifiedQuadraticLogarithmic_Y_LinearGrowthAndOffset_3D(InverseSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class InverseSimplifiedQuadraticLogarithmic_XY_LinearGrowthAndOffset_3D(InverseSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class InverseSimplifiedQuadraticLogarithmic_X_ExponentialGrowthAndOffset_3D(InverseSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class InverseSimplifiedQuadraticLogarithmic_Y_ExponentialGrowthAndOffset_3D(InverseSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class InverseSimplifiedQuadraticLogarithmic_XY_ExponentialGrowthAndOffset_3D(InverseSimplifiedQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()



class FullQuadraticLogarithmic3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Full Quadratic Logarithmic"
        self.HTML = "z = a + b*ln(x) + c*ln(y) + d*ln(x)<SUP>2</SUP> + e*ln(y)<SUP>2</SUP> + f*ln(x)*ln(y)"
        self.coefficientDesignatorTuple = ("a", "b", "c", "d", "e", "f")
        self.LinearSSQSolverFlag = 1
        self.RequiresPositiveX = 1
        self.RequiresPositiveY = 1

        self.function_cpp_code = 'temp = coeff[0] + coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[2] * indep_data[(int)cachedWeaveOffsets[2] + i] + coeff[3] * indep_data[(int)cachedWeaveOffsets[3] + i] + coeff[4] * indep_data[(int)cachedWeaveOffsets[4] + i] + coeff[5] * indep_data[(int)cachedWeaveOffsets[5] + i];// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogX(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogY(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_PowLogX(NameOrValueFlag=1, args=[2.0]), [2.0]])
        self.CacheGenerationList.append([self.CG_PowLogY(NameOrValueFlag=1, args=[2.0]), [2.0]])
        self.CacheGenerationList.append([self.CG_LogXLogY(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp += " + self.coefficientDesignatorTuple[0] + ";\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[1] + " * log(x_in);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[2] + " * log(y_in);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[3] + " * pow(log(x_in), 2.0);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[4] + " * pow(log(y_in), 2.0);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[5] + " * log(x_in) * log(y_in);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp += " + self.coefficientDesignatorTuple[0] + ";\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[1] + " * Math.log(x_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[2] + " * Math.log(y_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[3] + " * Math.pow(Math.log(x_in), 2.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[4] + " * Math.pow(Math.log(y_in), 2.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[5] + " * Math.log(x_in) * Math.log(y_in);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp += " + self.coefficientDesignatorTuple[0] + ";\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[1] + " * Math.Log(x_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[2] + " * Math.Log(y_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[3] + " * Math.Pow(Math.Log(x_in), 2.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[4] + " * Math.Pow(Math.Log(xy_in), 2.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[5] + " * Math.Log(x_in) * Math.Log(y_in);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp += " + self.coefficientDesignatorTuple[0] + "\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[1] + " * math.log(x_in)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[2] + " * math.log(y_in)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[3] + " * math.pow(math.log(x_in), 2.0)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[4] + " * math.pow(math.log(y_in), 2.0)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[5] + " * math.log(x_in) * math.log(y_in)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = temp + " + self.coefficientDesignatorTuple[0] + "\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[1] + " * log(x_in)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[2] + " * log(y_in)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[3] + " * (log(x_in) ^ 2.0)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[4] + " * (log(y_in) ^ 2.0)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[5] + " * log(x_in) * log(y_in)\n"
        return s


class FullQuadraticLogarithmic_X_LinearDecay_3D(FullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class FullQuadraticLogarithmic_Y_LinearDecay_3D(FullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class FullQuadraticLogarithmic_XY_LinearDecay_3D(FullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class FullQuadraticLogarithmic_X_ExponentialDecay_3D(FullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class FullQuadraticLogarithmic_Y_ExponentialDecay_3D(FullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class FullQuadraticLogarithmic_XY_ExponentialDecay_3D(FullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class FullQuadraticLogarithmic_X_LinearGrowth_3D(FullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class FullQuadraticLogarithmic_Y_LinearGrowth_3D(FullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class FullQuadraticLogarithmic_XY_LinearGrowth_3D(FullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class FullQuadraticLogarithmic_X_ExponentialGrowth_3D(FullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class FullQuadraticLogarithmic_Y_ExponentialGrowth_3D(FullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class FullQuadraticLogarithmic_XY_ExponentialGrowth_3D(FullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class FullQuadraticLogarithmic_X_LinearDecayAndOffset_3D(FullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class FullQuadraticLogarithmic_Y_LinearDecayAndOffset_3D(FullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class FullQuadraticLogarithmic_XY_LinearDecayAndOffset_3D(FullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class FullQuadraticLogarithmic_X_ExponentialDecayAndOffset_3D(FullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class FullQuadraticLogarithmic_Y_ExponentialDecayAndOffset_3D(FullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class FullQuadraticLogarithmic_XY_ExponentialDecayAndOffset_3D(FullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class FullQuadraticLogarithmic_X_LinearGrowthAndOffset_3D(FullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class FullQuadraticLogarithmic_Y_LinearGrowthAndOffset_3D(FullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class FullQuadraticLogarithmic_XY_LinearGrowthAndOffset_3D(FullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class FullQuadraticLogarithmic_X_ExponentialGrowthAndOffset_3D(FullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class FullQuadraticLogarithmic_Y_ExponentialGrowthAndOffset_3D(FullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class FullQuadraticLogarithmic_XY_ExponentialGrowthAndOffset_3D(FullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()


class ReciprocalFullQuadraticLogarithmic3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Reciprocal Full Quadratic Logarithmic"
        self.HTML = "z = 1.0 / (a + b*ln(x) + c*ln(y) + d*ln(x)<SUP>2</SUP> + e*ln(y)<SUP>2</SUP> + f*ln(x)*ln(y))"
        self.coefficientDesignatorTuple = ("a", "b", "c", "d", "e", "f")
        self.RequiresPositiveX = 1
        self.RequiresPositiveY = 1

        self.function_cpp_code = 'temp = 1.0 / (coeff[0] + coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[2] * indep_data[(int)cachedWeaveOffsets[2] + i] + coeff[3] * indep_data[(int)cachedWeaveOffsets[3] + i] + coeff[4] * indep_data[(int)cachedWeaveOffsets[4] + i] + coeff[5] * indep_data[(int)cachedWeaveOffsets[5] + i]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogX(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogY(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_PowLogX(NameOrValueFlag=1, args=[2.0]), [2.0]])
        self.CacheGenerationList.append([self.CG_PowLogY(NameOrValueFlag=1, args=[2.0]), [2.0]])
        self.CacheGenerationList.append([self.CG_LogXLogY(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp += " + self.coefficientDesignatorTuple[0] + ";\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[1] + " * log(x_in);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[2] + " * log(y_in);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[3] + " * pow(log(x_in), 2.0);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[4] + " * pow(log(y_in), 2.0);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[5] + " * log(x_in) * log(y_in);\n"
        s += "\ttemp = 1.0 / temp;\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp += " + self.coefficientDesignatorTuple[0] + ";\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[1] + " * Math.log(x_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[2] + " * Math.log(y_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[3] + " * Math.pow(Math.log(x_in), 2.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[4] + " * Math.pow(Math.log(y_in), 2.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[5] + " * Math.log(x_in) * Math.log(y_in);\n"
        s += "\t\ttemp = 1.0 / temp;\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp += " + self.coefficientDesignatorTuple[0] + ";\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[1] + " * Math.Log(x_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[2] + " * Math.Log(y_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[3] + " * Math.Pow(Math.Log(x_in), 2.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[4] + " * Math.Pow(Math.Log(xy_in), 2.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[5] + " * Math.Log(x_in) * Math.Log(y_in);\n"
        s += "\t\ttemp = 1.0 / temp;\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp += " + self.coefficientDesignatorTuple[0] + "\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[1] + " * math.log(x_in)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[2] + " * math.log(y_in)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[3] + " * math.pow(math.log(x_in), 2.0)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[4] + " * math.pow(math.log(y_in), 2.0)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[5] + " * math.log(x_in) * math.log(y_in)\n"
        s += "\ttemp = 1.0 / temp\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = temp + " + self.coefficientDesignatorTuple[0] + "\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[1] + " * log(x_in)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[2] + " * log(y_in)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[3] + " * (log(x_in) ^ 2.0)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[4] + " * (log(y_in) ^ 2.0)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[5] + " * log(x_in) * log(y_in)\n"
        s += "\ttemp = 1.0 / temp\n"
        return s


class ReciprocalFullQuadraticLogarithmic_X_LinearDecay_3D(ReciprocalFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class ReciprocalFullQuadraticLogarithmic_Y_LinearDecay_3D(ReciprocalFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class ReciprocalFullQuadraticLogarithmic_XY_LinearDecay_3D(ReciprocalFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class ReciprocalFullQuadraticLogarithmic_X_ExponentialDecay_3D(ReciprocalFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class ReciprocalFullQuadraticLogarithmic_Y_ExponentialDecay_3D(ReciprocalFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class ReciprocalFullQuadraticLogarithmic_XY_ExponentialDecay_3D(ReciprocalFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class ReciprocalFullQuadraticLogarithmic_X_LinearGrowth_3D(ReciprocalFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class ReciprocalFullQuadraticLogarithmic_Y_LinearGrowth_3D(ReciprocalFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class ReciprocalFullQuadraticLogarithmic_XY_LinearGrowth_3D(ReciprocalFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class ReciprocalFullQuadraticLogarithmic_X_ExponentialGrowth_3D(ReciprocalFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class ReciprocalFullQuadraticLogarithmic_Y_ExponentialGrowth_3D(ReciprocalFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class ReciprocalFullQuadraticLogarithmic_XY_ExponentialGrowth_3D(ReciprocalFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class ReciprocalFullQuadraticLogarithmic_X_LinearDecayAndOffset_3D(ReciprocalFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class ReciprocalFullQuadraticLogarithmic_Y_LinearDecayAndOffset_3D(ReciprocalFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class ReciprocalFullQuadraticLogarithmic_XY_LinearDecayAndOffset_3D(ReciprocalFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class ReciprocalFullQuadraticLogarithmic_X_ExponentialDecayAndOffset_3D(ReciprocalFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class ReciprocalFullQuadraticLogarithmic_Y_ExponentialDecayAndOffset_3D(ReciprocalFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class ReciprocalFullQuadraticLogarithmic_XY_ExponentialDecayAndOffset_3D(ReciprocalFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class ReciprocalFullQuadraticLogarithmic_X_LinearGrowthAndOffset_3D(ReciprocalFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class ReciprocalFullQuadraticLogarithmic_Y_LinearGrowthAndOffset_3D(ReciprocalFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class ReciprocalFullQuadraticLogarithmic_XY_LinearGrowthAndOffset_3D(ReciprocalFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class ReciprocalFullQuadraticLogarithmic_X_ExponentialGrowthAndOffset_3D(ReciprocalFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class ReciprocalFullQuadraticLogarithmic_Y_ExponentialGrowthAndOffset_3D(ReciprocalFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class ReciprocalFullQuadraticLogarithmic_XY_ExponentialGrowthAndOffset_3D(ReciprocalFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()



class InverseFullQuadraticLogarithmic3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Inverse Full Quadratic Logarithmic"
        self.HTML = "z = xy / (a + b*ln(x) + c*ln(y) + d*ln(x)<SUP>2</SUP> + e*ln(y)<SUP>2</SUP> + f*ln(x)*ln(y))"
        self.coefficientDesignatorTuple = ("a", "b", "c", "d", "e", "f")
        self.RequiresPositiveX = 1
        self.RequiresPositiveY = 1

        self.function_cpp_code = 'temp = indep_data[(int)cachedWeaveOffsets[6] + i] / (coeff[0] + coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[2] * indep_data[(int)cachedWeaveOffsets[2] + i] + coeff[3] * indep_data[(int)cachedWeaveOffsets[3] + i] + coeff[4] * indep_data[(int)cachedWeaveOffsets[4] + i] + coeff[5] * indep_data[(int)cachedWeaveOffsets[5] + i]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogX(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogY(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_PowLogX(NameOrValueFlag=1, args=[2.0]), [2.0]])
        self.CacheGenerationList.append([self.CG_PowLogY(NameOrValueFlag=1, args=[2.0]), [2.0]])
        self.CacheGenerationList.append([self.CG_LogXLogY(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_XY(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp += " + self.coefficientDesignatorTuple[0] + ";\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[1] + " * log(x_in);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[2] + " * log(y_in);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[3] + " * pow(log(x_in), 2.0);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[4] + " * pow(log(y_in), 2.0);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[5] + " * log(x_in) * log(y_in);\n"
        s += "\ttemp = x_in * y_in / temp;\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp += " + self.coefficientDesignatorTuple[0] + ";\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[1] + " * Math.log(x_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[2] + " * Math.log(y_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[3] + " * Math.pow(Math.log(x_in), 2.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[4] + " * Math.pow(Math.log(y_in), 2.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[5] + " * Math.log(x_in) * Math.log(y_in);\n"
        s += "\t\ttemp = x_in * y_in / temp;\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp += " + self.coefficientDesignatorTuple[0] + ";\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[1] + " * Math.Log(x_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[2] + " * Math.Log(y_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[3] + " * Math.Pow(Math.Log(x_in), 2.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[4] + " * Math.Pow(Math.Log(xy_in), 2.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[5] + " * Math.Log(x_in) * Math.Log(y_in);\n"
        s += "\t\ttemp = x_in * y_in / temp;\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp += " + self.coefficientDesignatorTuple[0] + "\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[1] + " * math.log(x_in)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[2] + " * math.log(y_in)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[3] + " * math.pow(math.log(x_in), 2.0)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[4] + " * math.pow(math.log(y_in), 2.0)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[5] + " * math.log(x_in) * math.log(y_in)\n"
        s += "\ttemp = x_in * y_in / temp\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = temp + " + self.coefficientDesignatorTuple[0] + "\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[1] + " * log(x_in)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[2] + " * log(y_in)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[3] + " * (log(x_in) ^ 2.0)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[4] + " * (log(y_in) ^ 2.0)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[5] + " * log(x_in) * log(y_in)\n"
        s += "\ttemp = x_in * y_in / temp\n"
        return s


class InverseFullQuadraticLogarithmic_X_LinearDecay_3D(InverseFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class InverseFullQuadraticLogarithmic_Y_LinearDecay_3D(InverseFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class InverseFullQuadraticLogarithmic_XY_LinearDecay_3D(InverseFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class InverseFullQuadraticLogarithmic_X_ExponentialDecay_3D(InverseFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class InverseFullQuadraticLogarithmic_Y_ExponentialDecay_3D(InverseFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class InverseFullQuadraticLogarithmic_XY_ExponentialDecay_3D(InverseFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class InverseFullQuadraticLogarithmic_X_LinearGrowth_3D(InverseFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class InverseFullQuadraticLogarithmic_Y_LinearGrowth_3D(InverseFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class InverseFullQuadraticLogarithmic_XY_LinearGrowth_3D(InverseFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class InverseFullQuadraticLogarithmic_X_ExponentialGrowth_3D(InverseFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class InverseFullQuadraticLogarithmic_Y_ExponentialGrowth_3D(InverseFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class InverseFullQuadraticLogarithmic_XY_ExponentialGrowth_3D(InverseFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class InverseFullQuadraticLogarithmic_X_LinearDecayAndOffset_3D(InverseFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class InverseFullQuadraticLogarithmic_Y_LinearDecayAndOffset_3D(InverseFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class InverseFullQuadraticLogarithmic_XY_LinearDecayAndOffset_3D(InverseFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class InverseFullQuadraticLogarithmic_X_ExponentialDecayAndOffset_3D(InverseFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class InverseFullQuadraticLogarithmic_Y_ExponentialDecayAndOffset_3D(InverseFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class InverseFullQuadraticLogarithmic_XY_ExponentialDecayAndOffset_3D(InverseFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class InverseFullQuadraticLogarithmic_X_LinearGrowthAndOffset_3D(InverseFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class InverseFullQuadraticLogarithmic_Y_LinearGrowthAndOffset_3D(InverseFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class InverseFullQuadraticLogarithmic_XY_LinearGrowthAndOffset_3D(InverseFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class InverseFullQuadraticLogarithmic_X_ExponentialGrowthAndOffset_3D(InverseFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class InverseFullQuadraticLogarithmic_Y_ExponentialGrowthAndOffset_3D(InverseFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class InverseFullQuadraticLogarithmic_XY_ExponentialGrowthAndOffset_3D(InverseFullQuadraticLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()



class SimplifiedCubicLogarithmic3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Simplified Cubic Logarithmic"
        self.HTML = "z = a + b*ln(x) + c*ln(y) + d*ln(x)<SUP>2</SUP> + e*ln(y)<SUP>2</SUP> + f*ln(x)<SUP>3</SUP> + g*ln(y)<SUP>3</SUP>"
        self.coefficientDesignatorTuple = ("a", "b", "c", "d", "e", "f", "g")
        self.LinearSSQSolverFlag = 1
        self.RequiresPositiveX = 1
        self.RequiresPositiveY = 1

        self.function_cpp_code = 'temp = coeff[0] + coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[2] * indep_data[(int)cachedWeaveOffsets[2] + i] + coeff[3] * indep_data[(int)cachedWeaveOffsets[3] + i] + coeff[4] * indep_data[(int)cachedWeaveOffsets[4] + i] + coeff[5] * indep_data[(int)cachedWeaveOffsets[5] + i] + coeff[6] * indep_data[(int)cachedWeaveOffsets[6] + i];// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogX(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogY(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_PowLogX(NameOrValueFlag=1, args=[2.0]), [2.0]])
        self.CacheGenerationList.append([self.CG_PowLogY(NameOrValueFlag=1, args=[2.0]), [2.0]])
        self.CacheGenerationList.append([self.CG_PowLogX(NameOrValueFlag=1, args=[3.0]), [3.0]])
        self.CacheGenerationList.append([self.CG_PowLogY(NameOrValueFlag=1, args=[3.0]), [3.0]])

    def SpecificCodeCPP(self):
        s = "\ttemp += " + self.coefficientDesignatorTuple[0] + ";\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[1] + " * log(x_in);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[2] + " * log(y_in);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[3] + " * pow(log(x_in), 2.0);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[4] + " * pow(log(y_in), 2.0);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[3] + " * pow(log(x_in), 3.0);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[4] + " * pow(log(y_in), 3.0);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp += " + self.coefficientDesignatorTuple[0] + ";\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[1] + " * Math.log(x_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[2] + " * Math.log(y_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[3] + " * Math.pow(Math.log(x_in), 2.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[4] + " * Math.pow(Math.log(y_in), 2.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[3] + " * Math.pow(Math.log(x_in), 3.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[4] + " * Math.pow(Math.log(y_in), 3.0);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp += " + self.coefficientDesignatorTuple[0] + ";\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[1] + " * Math.Log(x_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[2] + " * Math.Log(y_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[3] + " * Math.Pow(Math.Log(x_in), 2.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[4] + " * Math.Pow(Math.Log(y_in), 2.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[3] + " * Math.Pow(Math.Log(x_in), 3.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[4] + " * Math.Pow(Math.Log(y_in), 3.0);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp += " + self.coefficientDesignatorTuple[0] + "\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[1] + " * math.log(x_in)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[2] + " * math.log(y_in)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[3] + " * math.pow(math.log(x_in), 2.0)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[4] + " * math.pow(math.log(y_in), 2.0)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[3] + " * math.pow(math.log(x_in), 3.0)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[4] + " * math.pow(math.log(y_in), 3.0)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = temp + " + self.coefficientDesignatorTuple[0] + "\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[1] + " * log(x_in)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[2] + " * log(y_in)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[3] + " * (log(x_in) ^ 2.0)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[4] + " * (log(y_in) ^ 2.0)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[3] + " * (log(x_in) ^ 3.0)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[4] + " * (log(y_in) ^ 3.0)\n"
        return s


class SimplifiedCubicLogarithmic_X_LinearDecay_3D(SimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class SimplifiedCubicLogarithmic_Y_LinearDecay_3D(SimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class SimplifiedCubicLogarithmic_XY_LinearDecay_3D(SimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class SimplifiedCubicLogarithmic_X_ExponentialDecay_3D(SimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class SimplifiedCubicLogarithmic_Y_ExponentialDecay_3D(SimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class SimplifiedCubicLogarithmic_XY_ExponentialDecay_3D(SimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class SimplifiedCubicLogarithmic_X_LinearGrowth_3D(SimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class SimplifiedCubicLogarithmic_Y_LinearGrowth_3D(SimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class SimplifiedCubicLogarithmic_XY_LinearGrowth_3D(SimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class SimplifiedCubicLogarithmic_X_ExponentialGrowth_3D(SimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class SimplifiedCubicLogarithmic_Y_ExponentialGrowth_3D(SimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class SimplifiedCubicLogarithmic_XY_ExponentialGrowth_3D(SimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class SimplifiedCubicLogarithmic_X_LinearDecayAndOffset_3D(SimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class SimplifiedCubicLogarithmic_Y_LinearDecayAndOffset_3D(SimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class SimplifiedCubicLogarithmic_XY_LinearDecayAndOffset_3D(SimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class SimplifiedCubicLogarithmic_X_ExponentialDecayAndOffset_3D(SimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class SimplifiedCubicLogarithmic_Y_ExponentialDecayAndOffset_3D(SimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class SimplifiedCubicLogarithmic_XY_ExponentialDecayAndOffset_3D(SimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class SimplifiedCubicLogarithmic_X_LinearGrowthAndOffset_3D(SimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class SimplifiedCubicLogarithmic_Y_LinearGrowthAndOffset_3D(SimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class SimplifiedCubicLogarithmic_XY_LinearGrowthAndOffset_3D(SimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class SimplifiedCubicLogarithmic_X_ExponentialGrowthAndOffset_3D(SimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class SimplifiedCubicLogarithmic_Y_ExponentialGrowthAndOffset_3D(SimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class SimplifiedCubicLogarithmic_XY_ExponentialGrowthAndOffset_3D(SimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()



class ReciprocalSimplifiedCubicLogarithmic3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Reciprocal Simplified Cubic Logarithmic"
        self.HTML = "z = 1.0 / (a + b*ln(x) + c*ln(y) + d*ln(x)<SUP>2</SUP> + e*ln(y)<SUP>2</SUP> + f*ln(x)<SUP>3</SUP> + g*ln(y)<SUP>3</SUP>)"
        self.coefficientDesignatorTuple = ("a", "b", "c", "d", "e", "f", "g")
        self.RequiresPositiveX = 1
        self.RequiresPositiveY = 1

        self.function_cpp_code = 'temp = 1.0 / (coeff[0] + coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[2] * indep_data[(int)cachedWeaveOffsets[2] + i] + coeff[3] * indep_data[(int)cachedWeaveOffsets[3] + i] + coeff[4] * indep_data[(int)cachedWeaveOffsets[4] + i] + coeff[5] * indep_data[(int)cachedWeaveOffsets[5] + i] + coeff[6] * indep_data[(int)cachedWeaveOffsets[6] + i]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogX(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogY(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_PowLogX(NameOrValueFlag=1, args=[2.0]), [2.0]])
        self.CacheGenerationList.append([self.CG_PowLogY(NameOrValueFlag=1, args=[2.0]), [2.0]])
        self.CacheGenerationList.append([self.CG_PowLogX(NameOrValueFlag=1, args=[3.0]), [3.0]])
        self.CacheGenerationList.append([self.CG_PowLogY(NameOrValueFlag=1, args=[3.0]), [3.0]])

    def SpecificCodeCPP(self):
        s = "\ttemp += " + self.coefficientDesignatorTuple[0] + ";\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[1] + " * log(x_in);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[2] + " * log(y_in);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[3] + " * pow(log(x_in), 2.0);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[4] + " * pow(log(y_in), 2.0);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[3] + " * pow(log(x_in), 3.0);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[4] + " * pow(log(y_in), 3.0);\n"
        s += "\ttemp = 1.0 / temp;\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp += " + self.coefficientDesignatorTuple[0] + ";\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[1] + " * Math.log(x_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[2] + " * Math.log(y_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[3] + " * Math.pow(Math.log(x_in), 2.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[4] + " * Math.pow(Math.log(y_in), 2.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[3] + " * Math.pow(Math.log(x_in), 3.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[4] + " * Math.pow(Math.log(y_in), 3.0);\n"
        s += "\t\ttemp = 1.0 / temp;\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp += " + self.coefficientDesignatorTuple[0] + ";\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[1] + " * Math.Log(x_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[2] + " * Math.Log(y_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[3] + " * Math.Pow(Math.Log(x_in), 2.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[4] + " * Math.Pow(Math.Log(y_in), 2.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[3] + " * Math.Pow(Math.Log(x_in), 3.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[4] + " * Math.Pow(Math.Log(y_in), 3.0);\n"
        s += "\t\ttemp = 1.0 / temp;\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp += " + self.coefficientDesignatorTuple[0] + "\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[1] + " * math.log(x_in)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[2] + " * math.log(y_in)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[3] + " * math.pow(math.log(x_in), 2.0)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[4] + " * math.pow(math.log(y_in), 2.0)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[3] + " * math.pow(math.log(x_in), 3.0)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[4] + " * math.pow(math.log(y_in), 3.0)\n"
        s += "\ttemp = 1.0 / temp\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = temp + " + self.coefficientDesignatorTuple[0] + "\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[1] + " * log(x_in)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[2] + " * log(y_in)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[3] + " * (log(x_in) ^ 2.0)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[4] + " * (log(y_in) ^ 2.0)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[3] + " * (log(x_in) ^ 3.0)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[4] + " * (log(y_in) ^ 3.0)\n"
        s += "\ttemp = 1.0 / temp\n"
        return s


class ReciprocalSimplifiedCubicLogarithmic_X_LinearDecay_3D(ReciprocalSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class ReciprocalSimplifiedCubicLogarithmic_Y_LinearDecay_3D(ReciprocalSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class ReciprocalSimplifiedCubicLogarithmic_XY_LinearDecay_3D(ReciprocalSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class ReciprocalSimplifiedCubicLogarithmic_X_ExponentialDecay_3D(ReciprocalSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class ReciprocalSimplifiedCubicLogarithmic_Y_ExponentialDecay_3D(ReciprocalSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class ReciprocalSimplifiedCubicLogarithmic_XY_ExponentialDecay_3D(ReciprocalSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class ReciprocalSimplifiedCubicLogarithmic_X_LinearGrowth_3D(ReciprocalSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class ReciprocalSimplifiedCubicLogarithmic_Y_LinearGrowth_3D(ReciprocalSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class ReciprocalSimplifiedCubicLogarithmic_XY_LinearGrowth_3D(ReciprocalSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class ReciprocalSimplifiedCubicLogarithmic_X_ExponentialGrowth_3D(ReciprocalSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class ReciprocalSimplifiedCubicLogarithmic_Y_ExponentialGrowth_3D(ReciprocalSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class ReciprocalSimplifiedCubicLogarithmic_XY_ExponentialGrowth_3D(ReciprocalSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class ReciprocalSimplifiedCubicLogarithmic_X_LinearDecayAndOffset_3D(ReciprocalSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class ReciprocalSimplifiedCubicLogarithmic_Y_LinearDecayAndOffset_3D(ReciprocalSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class ReciprocalSimplifiedCubicLogarithmic_XY_LinearDecayAndOffset_3D(ReciprocalSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class ReciprocalSimplifiedCubicLogarithmic_X_ExponentialDecayAndOffset_3D(ReciprocalSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class ReciprocalSimplifiedCubicLogarithmic_Y_ExponentialDecayAndOffset_3D(ReciprocalSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class ReciprocalSimplifiedCubicLogarithmic_XY_ExponentialDecayAndOffset_3D(ReciprocalSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class ReciprocalSimplifiedCubicLogarithmic_X_LinearGrowthAndOffset_3D(ReciprocalSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class ReciprocalSimplifiedCubicLogarithmic_Y_LinearGrowthAndOffset_3D(ReciprocalSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class ReciprocalSimplifiedCubicLogarithmic_XY_LinearGrowthAndOffset_3D(ReciprocalSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class ReciprocalSimplifiedCubicLogarithmic_X_ExponentialGrowthAndOffset_3D(ReciprocalSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class ReciprocalSimplifiedCubicLogarithmic_Y_ExponentialGrowthAndOffset_3D(ReciprocalSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class ReciprocalSimplifiedCubicLogarithmic_XY_ExponentialGrowthAndOffset_3D(ReciprocalSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()


class InverseSimplifiedCubicLogarithmic3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Inverse Simplified Cubic Logarithmic"
        self.HTML = "z = xy / (a + b*ln(x) + c*ln(y) + d*ln(x)<SUP>2</SUP> + e*ln(y)<SUP>2</SUP> + f*ln(x)<SUP>3</SUP> + g*ln(y)<SUP>3</SUP>)"
        self.coefficientDesignatorTuple = ("a", "b", "c", "d", "e", "f", "g")
        self.RequiresPositiveX = 1
        self.RequiresPositiveY = 1

        self.function_cpp_code = 'temp = indep_data[(int)cachedWeaveOffsets[7] + i] / (coeff[0] + coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[2] * indep_data[(int)cachedWeaveOffsets[2] + i] + coeff[3] * indep_data[(int)cachedWeaveOffsets[3] + i] + coeff[4] * indep_data[(int)cachedWeaveOffsets[4] + i] + coeff[5] * indep_data[(int)cachedWeaveOffsets[5] + i] + coeff[6] * indep_data[(int)cachedWeaveOffsets[6] + i]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogX(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogY(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_PowLogX(NameOrValueFlag=1, args=[2.0]), [2.0]])
        self.CacheGenerationList.append([self.CG_PowLogY(NameOrValueFlag=1, args=[2.0]), [2.0]])
        self.CacheGenerationList.append([self.CG_PowLogX(NameOrValueFlag=1, args=[3.0]), [3.0]])
        self.CacheGenerationList.append([self.CG_PowLogY(NameOrValueFlag=1, args=[3.0]), [3.0]])
        self.CacheGenerationList.append([self.CG_XY(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp += " + self.coefficientDesignatorTuple[0] + ";\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[1] + " * log(x_in);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[2] + " * log(y_in);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[3] + " * pow(log(x_in), 2.0);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[4] + " * pow(log(y_in), 2.0);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[3] + " * pow(log(x_in), 3.0);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[4] + " * pow(log(y_in), 3.0);\n"
        s += "\ttemp = x_in * y_in / temp;\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp += " + self.coefficientDesignatorTuple[0] + ";\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[1] + " * Math.log(x_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[2] + " * Math.log(y_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[3] + " * Math.pow(Math.log(x_in), 2.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[4] + " * Math.pow(Math.log(y_in), 2.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[3] + " * Math.pow(Math.log(x_in), 3.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[4] + " * Math.pow(Math.log(y_in), 3.0);\n"
        s += "\t\ttemp = x_in * y_in / temp;\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp += " + self.coefficientDesignatorTuple[0] + ";\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[1] + " * Math.Log(x_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[2] + " * Math.Log(y_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[3] + " * Math.Pow(Math.Log(x_in), 2.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[4] + " * Math.Pow(Math.Log(y_in), 2.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[3] + " * Math.Pow(Math.Log(x_in), 3.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[4] + " * Math.Pow(Math.Log(y_in), 3.0);\n"
        s += "\t\ttemp = x_in * y_in / temp;\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp += " + self.coefficientDesignatorTuple[0] + "\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[1] + " * math.log(x_in)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[2] + " * math.log(y_in)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[3] + " * math.pow(math.log(x_in), 2.0)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[4] + " * math.pow(math.log(y_in), 2.0)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[3] + " * math.pow(math.log(x_in), 3.0)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[4] + " * math.pow(math.log(y_in), 3.0)\n"
        s += "\ttemp = x_in * y_in / temp\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = temp + " + self.coefficientDesignatorTuple[0] + "\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[1] + " * log(x_in)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[2] + " * log(y_in)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[3] + " * (log(x_in) ^ 2.0)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[4] + " * (log(y_in) ^ 2.0)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[3] + " * (log(x_in) ^ 3.0)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[4] + " * (log(y_in) ^ 3.0)\n"
        s += "\ttemp = x_in * y_in / temp\n"
        return s


class InverseSimplifiedCubicLogarithmic_X_LinearDecay_3D(InverseSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class InverseSimplifiedCubicLogarithmic_Y_LinearDecay_3D(InverseSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class InverseSimplifiedCubicLogarithmic_XY_LinearDecay_3D(InverseSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class InverseSimplifiedCubicLogarithmic_X_ExponentialDecay_3D(InverseSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class InverseSimplifiedCubicLogarithmic_Y_ExponentialDecay_3D(InverseSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class InverseSimplifiedCubicLogarithmic_XY_ExponentialDecay_3D(InverseSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class InverseSimplifiedCubicLogarithmic_X_LinearGrowth_3D(InverseSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class InverseSimplifiedCubicLogarithmic_Y_LinearGrowth_3D(InverseSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class InverseSimplifiedCubicLogarithmic_XY_LinearGrowth_3D(InverseSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class InverseSimplifiedCubicLogarithmic_X_ExponentialGrowth_3D(InverseSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class InverseSimplifiedCubicLogarithmic_Y_ExponentialGrowth_3D(InverseSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class InverseSimplifiedCubicLogarithmic_XY_ExponentialGrowth_3D(InverseSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class InverseSimplifiedCubicLogarithmic_X_LinearDecayAndOffset_3D(InverseSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class InverseSimplifiedCubicLogarithmic_Y_LinearDecayAndOffset_3D(InverseSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class InverseSimplifiedCubicLogarithmic_XY_LinearDecayAndOffset_3D(InverseSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class InverseSimplifiedCubicLogarithmic_X_ExponentialDecayAndOffset_3D(InverseSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class InverseSimplifiedCubicLogarithmic_Y_ExponentialDecayAndOffset_3D(InverseSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class InverseSimplifiedCubicLogarithmic_XY_ExponentialDecayAndOffset_3D(InverseSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class InverseSimplifiedCubicLogarithmic_X_LinearGrowthAndOffset_3D(InverseSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class InverseSimplifiedCubicLogarithmic_Y_LinearGrowthAndOffset_3D(InverseSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class InverseSimplifiedCubicLogarithmic_XY_LinearGrowthAndOffset_3D(InverseSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class InverseSimplifiedCubicLogarithmic_X_ExponentialGrowthAndOffset_3D(InverseSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class InverseSimplifiedCubicLogarithmic_Y_ExponentialGrowthAndOffset_3D(InverseSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class InverseSimplifiedCubicLogarithmic_XY_ExponentialGrowthAndOffset_3D(InverseSimplifiedCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()



class FullCubicLogarithmic3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Full Cubic Logarithmic"
        self.HTML = "z = a + b*ln(x) + c*ln(y) + d*ln(x)<SUP>2</SUP> + e*ln(y)<SUP>2</SUP> + f*ln(x)<SUP>3</SUP> + g*ln(y)<SUP>3</SUP> + h*ln(x)*ln(y) + i*ln(x)<SUP>2</SUP>*ln(y) + j*ln(x)*ln(y)<SUP>2</SUP>"
        self.coefficientDesignatorTuple = ("a", "b", "c", "d", "e", "f", "g", "h", "i", "j")
        self.LinearSSQSolverFlag = 1
        self.RequiresPositiveX = 1
        self.RequiresPositiveY = 1

        self.function_cpp_code = 'temp = coeff[0] + coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[2] * indep_data[(int)cachedWeaveOffsets[2] + i] + coeff[3] * indep_data[(int)cachedWeaveOffsets[3] + i] + coeff[4] * indep_data[(int)cachedWeaveOffsets[4] + i] + coeff[5] * indep_data[(int)cachedWeaveOffsets[5] + i] + coeff[6] * indep_data[(int)cachedWeaveOffsets[6] + i] + coeff[7] * indep_data[(int)cachedWeaveOffsets[7] + i] + coeff[8] * indep_data[(int)cachedWeaveOffsets[8] + i] + coeff[9] * indep_data[(int)cachedWeaveOffsets[9] + i];// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogX(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogY(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_PowLogX(NameOrValueFlag=1, args=[2.0]), [2.0]])
        self.CacheGenerationList.append([self.CG_PowLogY(NameOrValueFlag=1, args=[2.0]), [2.0]])
        self.CacheGenerationList.append([self.CG_PowLogX(NameOrValueFlag=1, args=[3.0]), [3.0]])
        self.CacheGenerationList.append([self.CG_PowLogY(NameOrValueFlag=1, args=[3.0]), [3.0]])
        self.CacheGenerationList.append([self.CG_LogXLogY(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_PowLogXLogY(NameOrValueFlag=1, args=[2.0, 1.0]), [2.0, 1.0]])
        self.CacheGenerationList.append([self.CG_PowLogXLogY(NameOrValueFlag=1, args=[1.0, 2.0]), [1.0, 2.0]])

    def SpecificCodeCPP(self):
        s = "\ttemp += " + self.coefficientDesignatorTuple[0] + ";\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[1] + " * log(x_in);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[2] + " * log(y_in);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[3] + " * pow(log(x_in), 2.0);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[4] + " * pow(log(y_in), 2.0);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[5] + " * pow(log(x_in), 3.0);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[6] + " * pow(log(y_in), 3.0);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[7] + " * log(x_in) * log(y_in);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[8] + " * pow(log(x_in), 2.0) * log(y_in);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[9] + " * log(x_in) * pow(log(y_in), 2.0);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp += " + self.coefficientDesignatorTuple[0] + ";\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[1] + " * Math.log(x_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[2] + " * Math.log(y_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[3] + " * Math.pow(Math.log(x_in), 2.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[4] + " * Math.pow(Math.log(y_in), 2.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[5] + " * Math.pow(Math.log(x_in), 3.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[6] + " * Math.pow(Math.log(y_in), 3.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[7] + " * Math.log(x_in) * Math.log(y_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[8] + " * Math.pow(Math.log(x_in), 2.0) * Math.log(y_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[9] + " * Math.log(x_in) * Math.pow(Math.log(y_in), 2.0);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp += " + self.coefficientDesignatorTuple[0] + ";\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[1] + " * Math.Log(x_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[2] + " * Math.Log(y_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[3] + " * Math.Pow(Math.Log(x_in), 2.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[4] + " * Math.Pow(Math.Log(y_in), 2.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[5] + " * Math.Pow(Math.Log(x_in), 3.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[6] + " * Math.Pow(Math.Log(y_in), 3.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[7] + " * Math.Log(x_in) * Math.Log(y_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[8] + " * Math.Pow(Math.Log(x_in), 2.0) * Math.Log(y_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[9] + " * Math.Log(x_in) * Math.Pow(Math.Log(y_in), 2.0);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp += " + self.coefficientDesignatorTuple[0] + "\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[1] + " * math.log(x_in)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[2] + " * math.log(y_in)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[3] + " * math.pow(math.log(x_in), 2.0)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[4] + " * math.pow(math.log(y_in), 2.0)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[5] + " * math.pow(math.log(x_in), 3.0)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[6] + " * math.pow(math.log(y_in), 3.0)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[7] + " * math.log(x_in) * math.log(y_in)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[8] + " * math.pow(math.log(x_in), 2.0) * math.log(y_in)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[9] + " * math.log(x_in) * math.pow(math.log(y_in), 2.0)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = temp + " + self.coefficientDesignatorTuple[0] + "\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[1] + " * log(x_in)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[2] + " * log(y_in)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[3] + " * (log(x_in) ^ 2.0)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[4] + " * (log(y_in) ^ 2.0)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[5] + " * (log(x_in) ^ 3.0)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[6] + " * (log(y_in) ^ 3.0)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[7] + " * log(x_in) * log(y_in)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[8] + " * (log(x_in) ^ 2.0) * log(y_in)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[9] + " * log(x_in) * (log(y_in) ^ 2.0)\n"
        return s


class FullCubicLogarithmic_X_LinearDecay_3D(FullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class FullCubicLogarithmic_Y_LinearDecay_3D(FullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class FullCubicLogarithmic_XY_LinearDecay_3D(FullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class FullCubicLogarithmic_X_ExponentialDecay_3D(FullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class FullCubicLogarithmic_Y_ExponentialDecay_3D(FullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class FullCubicLogarithmic_XY_ExponentialDecay_3D(FullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class FullCubicLogarithmic_X_LinearGrowth_3D(FullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class FullCubicLogarithmic_Y_LinearGrowth_3D(FullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class FullCubicLogarithmic_XY_LinearGrowth_3D(FullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class FullCubicLogarithmic_X_ExponentialGrowth_3D(FullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class FullCubicLogarithmic_Y_ExponentialGrowth_3D(FullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class FullCubicLogarithmic_XY_ExponentialGrowth_3D(FullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class FullCubicLogarithmic_X_LinearDecayAndOffset_3D(FullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class FullCubicLogarithmic_Y_LinearDecayAndOffset_3D(FullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class FullCubicLogarithmic_XY_LinearDecayAndOffset_3D(FullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class FullCubicLogarithmic_X_ExponentialDecayAndOffset_3D(FullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class FullCubicLogarithmic_Y_ExponentialDecayAndOffset_3D(FullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class FullCubicLogarithmic_XY_ExponentialDecayAndOffset_3D(FullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class FullCubicLogarithmic_X_LinearGrowthAndOffset_3D(FullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class FullCubicLogarithmic_Y_LinearGrowthAndOffset_3D(FullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class FullCubicLogarithmic_XY_LinearGrowthAndOffset_3D(FullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class FullCubicLogarithmic_X_ExponentialGrowthAndOffset_3D(FullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class FullCubicLogarithmic_Y_ExponentialGrowthAndOffset_3D(FullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class FullCubicLogarithmic_XY_ExponentialGrowthAndOffset_3D(FullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()


class ReciprocalFullCubicLogarithmic3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Reciprocal Full Cubic Logarithmic"
        self.HTML = "z = 1.0 / (a + b*ln(x) + c*ln(y) + d*ln(x)<SUP>2</SUP> + e*ln(y)<SUP>2</SUP> + f*ln(x)<SUP>3</SUP> + g*ln(y)<SUP>3</SUP> + h*ln(x)*ln(y) + i*ln(x)<SUP>2</SUP>*ln(y) + j*ln(x)*ln(y)<SUP>2</SUP>)"
        self.coefficientDesignatorTuple = ("a", "b", "c", "d", "e", "f", "g", "h", "i", "j")
        self.RequiresPositiveX = 1
        self.RequiresPositiveY = 1

        self.function_cpp_code = 'temp = 1.0 / (coeff[0] + coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[2] * indep_data[(int)cachedWeaveOffsets[2] + i] + coeff[3] * indep_data[(int)cachedWeaveOffsets[3] + i] + coeff[4] * indep_data[(int)cachedWeaveOffsets[4] + i] + coeff[5] * indep_data[(int)cachedWeaveOffsets[5] + i] + coeff[6] * indep_data[(int)cachedWeaveOffsets[6] + i] + coeff[7] * indep_data[(int)cachedWeaveOffsets[7] + i] + coeff[8] * indep_data[(int)cachedWeaveOffsets[8] + i] + coeff[9] * indep_data[(int)cachedWeaveOffsets[9] + i]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogX(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogY(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_PowLogX(NameOrValueFlag=1, args=[2.0]), [2.0]])
        self.CacheGenerationList.append([self.CG_PowLogY(NameOrValueFlag=1, args=[2.0]), [2.0]])
        self.CacheGenerationList.append([self.CG_PowLogX(NameOrValueFlag=1, args=[3.0]), [3.0]])
        self.CacheGenerationList.append([self.CG_PowLogY(NameOrValueFlag=1, args=[3.0]), [3.0]])
        self.CacheGenerationList.append([self.CG_LogXLogY(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_PowLogXLogY(NameOrValueFlag=1, args=[2.0, 1.0]), [2.0, 1.0]])
        self.CacheGenerationList.append([self.CG_PowLogXLogY(NameOrValueFlag=1, args=[1.0, 2.0]), [1.0, 2.0]])

    def SpecificCodeCPP(self):
        s = "\ttemp += " + self.coefficientDesignatorTuple[0] + ";\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[1] + " * log(x_in);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[2] + " * log(y_in);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[3] + " * pow(log(x_in), 2.0);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[4] + " * pow(log(y_in), 2.0);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[5] + " * pow(log(x_in), 3.0);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[6] + " * pow(log(y_in), 3.0);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[7] + " * log(x_in) * log(y_in);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[8] + " * pow(log(x_in), 2.0) * log(y_in);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[9] + " * log(x_in) * pow(log(y_in), 2.0);\n"
        s += "\ttemp = 1.0 / temp;\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp += " + self.coefficientDesignatorTuple[0] + ";\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[1] + " * Math.log(x_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[2] + " * Math.log(y_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[3] + " * Math.pow(Math.log(x_in), 2.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[4] + " * Math.pow(Math.log(y_in), 2.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[5] + " * Math.pow(Math.log(x_in), 3.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[6] + " * Math.pow(Math.log(y_in), 3.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[7] + " * Math.log(x_in) * Math.log(y_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[8] + " * Math.pow(Math.log(x_in), 2.0) * Math.log(y_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[9] + " * Math.log(x_in) * Math.pow(Math.log(y_in), 2.0);\n"
        s += "\t\ttemp = 1.0 / temp;\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp += " + self.coefficientDesignatorTuple[0] + ";\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[1] + " * Math.Log(x_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[2] + " * Math.Log(y_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[3] + " * Math.Pow(Math.Log(x_in), 2.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[4] + " * Math.Pow(Math.Log(y_in), 2.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[5] + " * Math.Pow(Math.Log(x_in), 3.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[6] + " * Math.Pow(Math.Log(y_in), 3.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[7] + " * Math.Log(x_in) * Math.Log(y_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[8] + " * Math.Pow(Math.Log(x_in), 2.0) * Math.Log(y_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[9] + " * Math.Log(x_in) * Math.Pow(Math.Log(y_in), 2.0);\n"
        s += "\t\ttemp = 1.0 / temp;\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp += " + self.coefficientDesignatorTuple[0] + "\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[1] + " * math.log(x_in)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[2] + " * math.log(y_in)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[3] + " * math.pow(math.log(x_in), 2.0)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[4] + " * math.pow(math.log(y_in), 2.0)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[5] + " * math.pow(math.log(x_in), 3.0)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[6] + " * math.pow(math.log(y_in), 3.0)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[7] + " * math.log(x_in) * math.log(y_in)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[8] + " * math.pow(math.log(x_in), 2.0) * math.log(y_in)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[9] + " * math.log(x_in) * math.pow(math.log(y_in), 2.0)\n"
        s += "\ttemp = 1.0 / temp\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = temp + " + self.coefficientDesignatorTuple[0] + "\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[1] + " * log(x_in)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[2] + " * log(y_in)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[3] + " * (log(x_in) ^ 2.0)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[4] + " * (log(y_in) ^ 2.0)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[5] + " * (log(x_in) ^ 3.0)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[6] + " * (log(y_in) ^ 3.0)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[7] + " * log(x_in) * log(y_in)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[8] + " * (log(x_in) ^ 2.0) * log(y_in)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[9] + " * log(x_in) * (log(y_in) ^ 2.0)\n"
        s += "\ttemp = 1.0 / temp\n"
        return s


class ReciprocalFullCubicLogarithmic_X_LinearDecay_3D(ReciprocalFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class ReciprocalFullCubicLogarithmic_Y_LinearDecay_3D(ReciprocalFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class ReciprocalFullCubicLogarithmic_XY_LinearDecay_3D(ReciprocalFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class ReciprocalFullCubicLogarithmic_X_ExponentialDecay_3D(ReciprocalFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class ReciprocalFullCubicLogarithmic_Y_ExponentialDecay_3D(ReciprocalFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class ReciprocalFullCubicLogarithmic_XY_ExponentialDecay_3D(ReciprocalFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class ReciprocalFullCubicLogarithmic_X_LinearGrowth_3D(ReciprocalFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class ReciprocalFullCubicLogarithmic_Y_LinearGrowth_3D(ReciprocalFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class ReciprocalFullCubicLogarithmic_XY_LinearGrowth_3D(ReciprocalFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class ReciprocalFullCubicLogarithmic_X_ExponentialGrowth_3D(ReciprocalFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class ReciprocalFullCubicLogarithmic_Y_ExponentialGrowth_3D(ReciprocalFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class ReciprocalFullCubicLogarithmic_XY_ExponentialGrowth_3D(ReciprocalFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class ReciprocalFullCubicLogarithmic_X_LinearDecayAndOffset_3D(ReciprocalFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class ReciprocalFullCubicLogarithmic_Y_LinearDecayAndOffset_3D(ReciprocalFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class ReciprocalFullCubicLogarithmic_XY_LinearDecayAndOffset_3D(ReciprocalFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class ReciprocalFullCubicLogarithmic_X_ExponentialDecayAndOffset_3D(ReciprocalFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class ReciprocalFullCubicLogarithmic_Y_ExponentialDecayAndOffset_3D(ReciprocalFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class ReciprocalFullCubicLogarithmic_XY_ExponentialDecayAndOffset_3D(ReciprocalFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class ReciprocalFullCubicLogarithmic_X_LinearGrowthAndOffset_3D(ReciprocalFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class ReciprocalFullCubicLogarithmic_Y_LinearGrowthAndOffset_3D(ReciprocalFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class ReciprocalFullCubicLogarithmic_XY_LinearGrowthAndOffset_3D(ReciprocalFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class ReciprocalFullCubicLogarithmic_X_ExponentialGrowthAndOffset_3D(ReciprocalFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class ReciprocalFullCubicLogarithmic_Y_ExponentialGrowthAndOffset_3D(ReciprocalFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class ReciprocalFullCubicLogarithmic_XY_ExponentialGrowthAndOffset_3D(ReciprocalFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()


class InverseFullCubicLogarithmic3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Inverse Full Cubic Logarithmic"
        self.HTML = "z = xy / (a + b*ln(x) + c*ln(y) + d*ln(x)<SUP>2</SUP> + e*ln(y)<SUP>2</SUP> + f*ln(x)<SUP>3</SUP> + g*ln(y)<SUP>3</SUP> + h*ln(x)*ln(y) + i*ln(x)<SUP>2</SUP>*ln(y) + j*ln(x)*ln(y)<SUP>2</SUP>)"
        self.coefficientDesignatorTuple = ("a", "b", "c", "d", "e", "f", "g", "h", "i", "j")
        self.RequiresPositiveX = 1
        self.RequiresPositiveY = 1

        self.function_cpp_code = 'temp = indep_data[(int)cachedWeaveOffsets[10] + i] / (coeff[0] + coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[2] * indep_data[(int)cachedWeaveOffsets[2] + i] + coeff[3] * indep_data[(int)cachedWeaveOffsets[3] + i] + coeff[4] * indep_data[(int)cachedWeaveOffsets[4] + i] + coeff[5] * indep_data[(int)cachedWeaveOffsets[5] + i] + coeff[6] * indep_data[(int)cachedWeaveOffsets[6] + i] + coeff[7] * indep_data[(int)cachedWeaveOffsets[7] + i] + coeff[8] * indep_data[(int)cachedWeaveOffsets[8] + i] + coeff[9] * indep_data[(int)cachedWeaveOffsets[9] + i]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogX(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogY(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_PowLogX(NameOrValueFlag=1, args=[2.0]), [2.0]])
        self.CacheGenerationList.append([self.CG_PowLogY(NameOrValueFlag=1, args=[2.0]), [2.0]])
        self.CacheGenerationList.append([self.CG_PowLogX(NameOrValueFlag=1, args=[3.0]), [3.0]])
        self.CacheGenerationList.append([self.CG_PowLogY(NameOrValueFlag=1, args=[3.0]), [3.0]])
        self.CacheGenerationList.append([self.CG_LogXLogY(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_PowLogXLogY(NameOrValueFlag=1, args=[2.0, 1.0]), [2.0, 1.0]])
        self.CacheGenerationList.append([self.CG_PowLogXLogY(NameOrValueFlag=1, args=[1.0, 2.0]), [1.0, 2.0]])
        self.CacheGenerationList.append([self.CG_XY(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp += " + self.coefficientDesignatorTuple[0] + ";\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[1] + " * log(x_in);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[2] + " * log(y_in);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[3] + " * pow(log(x_in), 2.0);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[4] + " * pow(log(y_in), 2.0);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[5] + " * pow(log(x_in), 3.0);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[6] + " * pow(log(y_in), 3.0);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[7] + " * log(x_in) * log(y_in);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[8] + " * pow(log(x_in), 2.0) * log(y_in);\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[9] + " * log(x_in) * pow(log(y_in), 2.0);\n"
        s += "\ttemp = x_in * y_in / temp;\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp += " + self.coefficientDesignatorTuple[0] + ";\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[1] + " * Math.log(x_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[2] + " * Math.log(y_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[3] + " * Math.pow(Math.log(x_in), 2.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[4] + " * Math.pow(Math.log(y_in), 2.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[5] + " * Math.pow(Math.log(x_in), 3.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[6] + " * Math.pow(Math.log(y_in), 3.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[7] + " * Math.log(x_in) * Math.log(y_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[8] + " * Math.pow(Math.log(x_in), 2.0) * Math.log(y_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[9] + " * Math.log(x_in) * Math.pow(Math.log(y_in), 2.0);\n"
        s += "\t\ttemp = x_in * y_in / temp;\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp += " + self.coefficientDesignatorTuple[0] + ";\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[1] + " * Math.Log(x_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[2] + " * Math.Log(y_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[3] + " * Math.Pow(Math.Log(x_in), 2.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[4] + " * Math.Pow(Math.Log(y_in), 2.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[5] + " * Math.Pow(Math.Log(x_in), 3.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[6] + " * Math.Pow(Math.Log(y_in), 3.0);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[7] + " * Math.Log(x_in) * Math.Log(y_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[8] + " * Math.Pow(Math.Log(x_in), 2.0) * Math.Log(y_in);\n"
        s += "\t\ttemp += " + self.coefficientDesignatorTuple[9] + " * Math.Log(x_in) * Math.Pow(Math.Log(y_in), 2.0);\n"
        s += "\t\ttemp = x_in * y_in / temp;\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp += " + self.coefficientDesignatorTuple[0] + "\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[1] + " * math.log(x_in)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[2] + " * math.log(y_in)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[3] + " * math.pow(math.log(x_in), 2.0)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[4] + " * math.pow(math.log(y_in), 2.0)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[5] + " * math.pow(math.log(x_in), 3.0)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[6] + " * math.pow(math.log(y_in), 3.0)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[7] + " * math.log(x_in) * math.log(y_in)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[8] + " * math.pow(math.log(x_in), 2.0) * math.log(y_in)\n"
        s += "\ttemp += " + self.coefficientDesignatorTuple[9] + " * math.log(x_in) * math.pow(math.log(y_in), 2.0)\n"
        s += "\ttemp = x_in * y_in / temp\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = temp + " + self.coefficientDesignatorTuple[0] + "\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[1] + " * log(x_in)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[2] + " * log(y_in)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[3] + " * (log(x_in) ^ 2.0)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[4] + " * (log(y_in) ^ 2.0)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[5] + " * (log(x_in) ^ 3.0)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[6] + " * (log(y_in) ^ 3.0)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[7] + " * log(x_in) * log(y_in)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[8] + " * (log(x_in) ^ 2.0) * log(y_in)\n"
        s += "\ttemp = temp + " + self.coefficientDesignatorTuple[9] + " * log(x_in) * (log(y_in) ^ 2.0)\n"
        s += "\ttemp = x_in * y_in / temp\n"
        return s


class InverseFullCubicLogarithmic_X_LinearDecay_3D(InverseFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class InverseFullCubicLogarithmic_Y_LinearDecay_3D(InverseFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class InverseFullCubicLogarithmic_XY_LinearDecay_3D(InverseFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class InverseFullCubicLogarithmic_X_ExponentialDecay_3D(InverseFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class InverseFullCubicLogarithmic_Y_ExponentialDecay_3D(InverseFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class InverseFullCubicLogarithmic_XY_ExponentialDecay_3D(InverseFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class InverseFullCubicLogarithmic_X_LinearGrowth_3D(InverseFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class InverseFullCubicLogarithmic_Y_LinearGrowth_3D(InverseFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class InverseFullCubicLogarithmic_XY_LinearGrowth_3D(InverseFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class InverseFullCubicLogarithmic_X_ExponentialGrowth_3D(InverseFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class InverseFullCubicLogarithmic_Y_ExponentialGrowth_3D(InverseFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class InverseFullCubicLogarithmic_XY_ExponentialGrowth_3D(InverseFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class InverseFullCubicLogarithmic_X_LinearDecayAndOffset_3D(InverseFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class InverseFullCubicLogarithmic_Y_LinearDecayAndOffset_3D(InverseFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class InverseFullCubicLogarithmic_XY_LinearDecayAndOffset_3D(InverseFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class InverseFullCubicLogarithmic_X_ExponentialDecayAndOffset_3D(InverseFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class InverseFullCubicLogarithmic_Y_ExponentialDecayAndOffset_3D(InverseFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class InverseFullCubicLogarithmic_XY_ExponentialDecayAndOffset_3D(InverseFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class InverseFullCubicLogarithmic_X_LinearGrowthAndOffset_3D(InverseFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class InverseFullCubicLogarithmic_Y_LinearGrowthAndOffset_3D(InverseFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class InverseFullCubicLogarithmic_XY_LinearGrowthAndOffset_3D(InverseFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class InverseFullCubicLogarithmic_X_ExponentialGrowthAndOffset_3D(InverseFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class InverseFullCubicLogarithmic_Y_ExponentialGrowthAndOffset_3D(InverseFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class InverseFullCubicLogarithmic_XY_ExponentialGrowthAndOffset_3D(InverseFullCubicLogarithmic3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()
