#    pythonequations is a collection of equations expressed as Python classes
#    Copyright (C) 2008 James R. Phillips
#    2548 Vera Cruz Drive
#    Birmingham, AL 35235 USA
#    email: zunzun@zunzun.com
#
#    Version info: $Id$
#
#    License: BSD-style (see LICENSE.txt in main source directory)

import pythonequations, pythonequations.EquationBaseClasses
import numpy
numpy.seterr(all = 'raise') # numpy raises warnings, convert to exceptions to trap them



class MennSurface3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Menn's Surface"
        self.HTML = "z = ax<sup>4</sup> + x<sup>2</sup>y - y<sup>2</sup>"
        self.coefficientDesignatorTuple = ("a")

        self.function_cpp_code = 'temp = coeff[0] * indep_data[(int)cachedWeaveOffsets[0] + i] + indep_data[(int)cachedWeaveOffsets[1] + i] * indep_data[(int)cachedWeaveOffsets[2] + i] - indep_data[(int)cachedWeaveOffsets[3] + i];// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_PowX(NameOrValueFlag=1, args=[4.0]), [4.0]])
        self.CacheGenerationList.append([self.CG_PowY(NameOrValueFlag=1, args=[2.0]), [2.0]])
        self.CacheGenerationList.append([self.CG_Y(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_PowY(NameOrValueFlag=1, args=[2.0]), [2.0]])

    def SpecificCodeCPP(self):
        s = "\ttemp = a * x_in * x_in * x_in * x_in + x_in * x_in * y_in - y_in * y_in;\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a * x_in * x_in * x_in * x_in + x_in * x_in * y_in - y_in * y_in;\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a * x_in * x_in * x_in * x_in + x_in * x_in * y_in - y_in * y_in;\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\t\ttemp = a * x_in * x_in * x_in * x_in + x_in * x_in * y_in - y_in * y_in\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\t\ttemp = a * x_in * x_in * x_in * x_in + x_in * x_in * y_in - y_in * y_in\n"
        return s


class MennSurface_WO_3D(MennSurface3D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class MennSurface_X_LinearDecay_3D(MennSurface3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class MennSurface_Y_LinearDecay_3D(MennSurface3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class MennSurface_XY_LinearDecay_3D(MennSurface3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class MennSurface_X_ExponentialDecay_3D(MennSurface3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class MennSurface_Y_ExponentialDecay_3D(MennSurface3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class MennSurface_XY_ExponentialDecay_3D(MennSurface3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class MennSurface_X_LinearGrowth_3D(MennSurface3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class MennSurface_Y_LinearGrowth_3D(MennSurface3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class MennSurface_XY_LinearGrowth_3D(MennSurface3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class MennSurface_X_ExponentialGrowth_3D(MennSurface3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class MennSurface_Y_ExponentialGrowth_3D(MennSurface3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class MennSurface_XY_ExponentialGrowth_3D(MennSurface3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class MennSurface_X_LinearDecayAndOffset_3D(MennSurface3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class MennSurface_Y_LinearDecayAndOffset_3D(MennSurface3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class MennSurface_XY_LinearDecayAndOffset_3D(MennSurface3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class MennSurface_X_ExponentialDecayAndOffset_3D(MennSurface3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class MennSurface_Y_ExponentialDecayAndOffset_3D(MennSurface3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class MennSurface_XY_ExponentialDecayAndOffset_3D(MennSurface3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class MennSurface_X_LinearGrowthAndOffset_3D(MennSurface3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class MennSurface_Y_LinearGrowthAndOffset_3D(MennSurface3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class MennSurface_XY_LinearGrowthAndOffset_3D(MennSurface3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class MennSurface_X_ExponentialGrowthAndOffset_3D(MennSurface3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class MennSurface_Y_ExponentialGrowthAndOffset_3D(MennSurface3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class MennSurface_XY_ExponentialGrowthAndOffset_3D(MennSurface3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()



class MonkeySaddle3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "The Monkey Saddle"
        self.HTML = "z = ax<sup>3</sup> - bxy<sup>2</sup>"
        self.coefficientDesignatorTuple = ("a", 'b')

        self.function_cpp_code = 'temp = coeff[0] * indep_data[(int)cachedWeaveOffsets[0] + i] - coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i] * indep_data[(int)cachedWeaveOffsets[2] + i];// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_PowX(NameOrValueFlag=1, args=[3.0]), [3.0]])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_PowY(NameOrValueFlag=1, args=[2.0]), [2.0]])

    def SpecificCodeCPP(self):
        s = "\ttemp = a * x_in * x_in * x_in - b * x_in * y_in * y_in;\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a * x_in * x_in * x_in - b * x_in * y_in * y_in;\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a * x_in * x_in * x_in - b * x_in * y_in * y_in;\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\t\ttemp = a * x_in * x_in * x_in - b * x_in * y_in * y_in\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\t\ttemp = a * x_in * x_in * x_in - b * x_in * y_in * y_in\n"
        return s


class MonkeySaddle_WO_3D(MonkeySaddle3D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class MonkeySaddle_X_LinearDecay_3D(MonkeySaddle3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class MonkeySaddle_Y_LinearDecay_3D(MonkeySaddle3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class MonkeySaddle_XY_LinearDecay_3D(MonkeySaddle3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class MonkeySaddle_X_ExponentialDecay_3D(MonkeySaddle3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class MonkeySaddle_Y_ExponentialDecay_3D(MonkeySaddle3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class MonkeySaddle_XY_ExponentialDecay_3D(MonkeySaddle3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class MonkeySaddle_X_LinearGrowth_3D(MonkeySaddle3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class MonkeySaddle_Y_LinearGrowth_3D(MonkeySaddle3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class MonkeySaddle_XY_LinearGrowth_3D(MonkeySaddle3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class MonkeySaddle_X_ExponentialGrowth_3D(MonkeySaddle3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class MonkeySaddle_Y_ExponentialGrowth_3D(MonkeySaddle3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class MonkeySaddle_XY_ExponentialGrowth_3D(MonkeySaddle3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class MonkeySaddle_X_LinearDecayAndOffset_3D(MonkeySaddle3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class MonkeySaddle_Y_LinearDecayAndOffset_3D(MonkeySaddle3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class MonkeySaddle_XY_LinearDecayAndOffset_3D(MonkeySaddle3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class MonkeySaddle_X_ExponentialDecayAndOffset_3D(MonkeySaddle3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class MonkeySaddle_Y_ExponentialDecayAndOffset_3D(MonkeySaddle3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class MonkeySaddle_XY_ExponentialDecayAndOffset_3D(MonkeySaddle3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class MonkeySaddle_X_LinearGrowthAndOffset_3D(MonkeySaddle3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class MonkeySaddle_Y_LinearGrowthAndOffset_3D(MonkeySaddle3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class MonkeySaddle_XY_LinearGrowthAndOffset_3D(MonkeySaddle3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class MonkeySaddle_X_ExponentialGrowthAndOffset_3D(MonkeySaddle3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class MonkeySaddle_Y_ExponentialGrowthAndOffset_3D(MonkeySaddle3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class MonkeySaddle_XY_ExponentialGrowthAndOffset_3D(MonkeySaddle3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()



class MonkeySaddle_Transform3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "The Monkey Saddle Transform"
        self.HTML = "z = a(cx + d)<sup>3</sup> - b(cx + d)(ey + f)<sup>2</sup>"
        self.coefficientDesignatorTuple = ("a", 'b', 'c', 'd', 'e', 'f')

        self.function_cpp_code = 'temp = coeff[0] * pow(coeff[2] * indep_data[(int)cachedWeaveOffsets[0] + i] + coeff[3], 3.0) - coeff[1] * (coeff[2] * indep_data[(int)cachedWeaveOffsets[0] + i] + coeff[3]) * pow(coeff[4] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[5], 2.0);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Y(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a * pow(c * x_in + d, 3.0) - b * (c * x_in + d) * pow(e * y_in + f, 2.0);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a * Math.pow(c * x_in + d, 3.0) - b * (c * x_in + d) * Math.pow(e * y_in + f, 2.0);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a * Math.Pow(c * x_in + d, 3.0) - b * (c * x_in + d) * Math.Pow(e * y_in + f, 2.0);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\t\ttemp = a * math.pow(c * x_in + d, 3.0) - b * (c * x_in + d) * math.pow(e * y_in + f, 2.0)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\t\ttemp = a * pow(c * x_in + d, 3.0) - b * (c * x_in + d) * pow(e * y_in + f, 2.0)\n"
        return s


class MonkeySaddle_Transform_WO_3D(MonkeySaddle_Transform3D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class MonkeySaddle_Transform_X_LinearDecay_3D(MonkeySaddle_Transform3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class MonkeySaddle_Transform_Y_LinearDecay_3D(MonkeySaddle_Transform3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class MonkeySaddle_Transform_XY_LinearDecay_3D(MonkeySaddle_Transform3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class MonkeySaddle_Transform_X_ExponentialDecay_3D(MonkeySaddle_Transform3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class MonkeySaddle_Transform_Y_ExponentialDecay_3D(MonkeySaddle_Transform3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class MonkeySaddle_Transform_XY_ExponentialDecay_3D(MonkeySaddle_Transform3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class MonkeySaddle_Transform_X_LinearGrowth_3D(MonkeySaddle_Transform3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class MonkeySaddle_Transform_Y_LinearGrowth_3D(MonkeySaddle_Transform3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class MonkeySaddle_Transform_XY_LinearGrowth_3D(MonkeySaddle_Transform3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class MonkeySaddle_Transform_X_ExponentialGrowth_3D(MonkeySaddle_Transform3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class MonkeySaddle_Transform_Y_ExponentialGrowth_3D(MonkeySaddle_Transform3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class MonkeySaddle_Transform_XY_ExponentialGrowth_3D(MonkeySaddle_Transform3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class MonkeySaddle_Transform_X_LinearDecayAndOffset_3D(MonkeySaddle_Transform3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class MonkeySaddle_Transform_Y_LinearDecayAndOffset_3D(MonkeySaddle_Transform3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class MonkeySaddle_Transform_XY_LinearDecayAndOffset_3D(MonkeySaddle_Transform3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class MonkeySaddle_Transform_X_ExponentialDecayAndOffset_3D(MonkeySaddle_Transform3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class MonkeySaddle_Transform_Y_ExponentialDecayAndOffset_3D(MonkeySaddle_Transform3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class MonkeySaddle_Transform_XY_ExponentialDecayAndOffset_3D(MonkeySaddle_Transform3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class MonkeySaddle_Transform_X_LinearGrowthAndOffset_3D(MonkeySaddle_Transform3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class MonkeySaddle_Transform_Y_LinearGrowthAndOffset_3D(MonkeySaddle_Transform3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class MonkeySaddle_Transform_XY_LinearGrowthAndOffset_3D(MonkeySaddle_Transform3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class MonkeySaddle_Transform_X_ExponentialGrowthAndOffset_3D(MonkeySaddle_Transform3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class MonkeySaddle_Transform_Y_ExponentialGrowthAndOffset_3D(MonkeySaddle_Transform3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class MonkeySaddle_Transform_XY_ExponentialGrowthAndOffset_3D(MonkeySaddle_Transform3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()



class MeanCurvatureOfParaboloid3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Mean Curvature Of Paraboloid"
        self.HTML = "z = 2 * (a + 2a<sup>3</sup> * (x<sup>2</sup> + y<sup>2</sup>)) / (1 + 4a<sup>2</sup> * (x<sup>2</sup> + y<sup>2</sup>))<sup>1.5</sup>"
        self.coefficientDesignatorTuple = ("a")

        self.function_cpp_code = 'temp = 2.0 * (coeff[0] + 2.0 * pow(coeff[0], 3.0) * indep_data[(int)cachedWeaveOffsets[0] + i]) / pow(1.0 + 4.0 * pow(coeff[0], 2.0) * indep_data[(int)cachedWeaveOffsets[0] + i], 1.5);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_XSQPLUSYSQ(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = 2.0 * (a + 2.0 * pow(a, 3.0) * (x_in * x_in + y_in * y_in)) / pow(1.0 + 4.0 * a * a * (x_in * x_in + y_in * y_in)), 1.5);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = 2.0 * (a + 2.0 * Math.pow(a, 3.0) * (x_in * x_in + y_in * y_in)) / Math.pow(1.0 + 4.0 * a * a * (x_in * x_in + y_in * y_in)), 1.5);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = 2.0 * (a + 2.0 * Math.Pow(a, 3.0) * (x_in * x_in + y_in * y_in)) / Math.Pow(1.0 + 4.0 * a * a * (x_in * x_in + y_in * y_in)), 1.5);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\t\ttemp = 2.0 * (a + 2.0 * math.pow(a, 3.0) * (x_in * x_in + y_in * y_in)) / math.pow(1.0 + 4.0 * a * a * (x_in * x_in + y_in * y_in)), 1.5)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\t\ttemp = 2.0 * (a + 2.0 * pow(a, 3.0) * (x_in * x_in + y_in * y_in)) / pow(1.0 + 4.0 * a * a * (x_in * x_in + y_in * y_in)), 1.5)\n"
        return s


class MeanCurvatureOfParaboloid_WO_3D(MeanCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class MeanCurvatureOfParaboloid_X_LinearDecay_3D(MeanCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class MeanCurvatureOfParaboloid_Y_LinearDecay_3D(MeanCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class MeanCurvatureOfParaboloid_XY_LinearDecay_3D(MeanCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class MeanCurvatureOfParaboloid_X_ExponentialDecay_3D(MeanCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class MeanCurvatureOfParaboloid_Y_ExponentialDecay_3D(MeanCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class MeanCurvatureOfParaboloid_XY_ExponentialDecay_3D(MeanCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class MeanCurvatureOfParaboloid_X_LinearGrowth_3D(MeanCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class MeanCurvatureOfParaboloid_Y_LinearGrowth_3D(MeanCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class MeanCurvatureOfParaboloid_XY_LinearGrowth_3D(MeanCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class MeanCurvatureOfParaboloid_X_ExponentialGrowth_3D(MeanCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class MeanCurvatureOfParaboloid_Y_ExponentialGrowth_3D(MeanCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class MeanCurvatureOfParaboloid_XY_ExponentialGrowth_3D(MeanCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class MeanCurvatureOfParaboloid_X_LinearDecayAndOffset_3D(MeanCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class MeanCurvatureOfParaboloid_Y_LinearDecayAndOffset_3D(MeanCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class MeanCurvatureOfParaboloid_XY_LinearDecayAndOffset_3D(MeanCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class MeanCurvatureOfParaboloid_X_ExponentialDecayAndOffset_3D(MeanCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class MeanCurvatureOfParaboloid_Y_ExponentialDecayAndOffset_3D(MeanCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class MeanCurvatureOfParaboloid_XY_ExponentialDecayAndOffset_3D(MeanCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class MeanCurvatureOfParaboloid_X_LinearGrowthAndOffset_3D(MeanCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class MeanCurvatureOfParaboloid_Y_LinearGrowthAndOffset_3D(MeanCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class MeanCurvatureOfParaboloid_XY_LinearGrowthAndOffset_3D(MeanCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class MeanCurvatureOfParaboloid_X_ExponentialGrowthAndOffset_3D(MeanCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class MeanCurvatureOfParaboloid_Y_ExponentialGrowthAndOffset_3D(MeanCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class MeanCurvatureOfParaboloid_XY_ExponentialGrowthAndOffset_3D(MeanCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()



class GaussianCurvatureOfParaboloid3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Gaussian Curvature Of Paraboloid"
        self.HTML = "z = 4a<sup>2</sup> / (1 + 4a<sup>2</sup> * (x<sup>2</sup> + y<sup>2</sup>))<sup>2</sup>"
        self.coefficientDesignatorTuple = ("a")

        self.function_cpp_code = 'temp = 4.0 * pow(coeff[0], 2.0) / pow(1.0 + 4.0 * pow(coeff[0], 2.0) * indep_data[(int)cachedWeaveOffsets[0] + i], 2.0);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_XSQPLUSYSQ(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = 4.0 * a * a / pow(1.0 + 4.0 * a * a * (x_in * x_in + y_in * y_in)), 2.0);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = 4.0 * a * a / Math.pow(1.0 + 4.0 * a * a * (x_in * x_in + y_in * y_in)), 2.0);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = 4.0 * a * a / Math.Pow(1.0 + 4.0 * a * a * (x_in * x_in + y_in * y_in)), 2.0);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\t\ttemp = 4.0 * a * a / math.pow(1.0 + 4.0 * a * a * (x_in * x_in + y_in * y_in)), 2.0)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\t\ttemp = 4.0 * a * a / pow(1.0 + 4.0 * a * a * (x_in * x_in + y_in * y_in)), 2.0)\n"
        return s


class GaussianCurvatureOfParaboloid_WO_3D(GaussianCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class GaussianCurvatureOfParaboloid_X_LinearDecay_3D(GaussianCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class GaussianCurvatureOfParaboloid_Y_LinearDecay_3D(GaussianCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class GaussianCurvatureOfParaboloid_XY_LinearDecay_3D(GaussianCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class GaussianCurvatureOfParaboloid_X_ExponentialDecay_3D(GaussianCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class GaussianCurvatureOfParaboloid_Y_ExponentialDecay_3D(GaussianCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class GaussianCurvatureOfParaboloid_XY_ExponentialDecay_3D(GaussianCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class GaussianCurvatureOfParaboloid_X_LinearGrowth_3D(GaussianCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class GaussianCurvatureOfParaboloid_Y_LinearGrowth_3D(GaussianCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class GaussianCurvatureOfParaboloid_XY_LinearGrowth_3D(GaussianCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class GaussianCurvatureOfParaboloid_X_ExponentialGrowth_3D(GaussianCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class GaussianCurvatureOfParaboloid_Y_ExponentialGrowth_3D(GaussianCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class GaussianCurvatureOfParaboloid_XY_ExponentialGrowth_3D(GaussianCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class GaussianCurvatureOfParaboloid_X_LinearDecayAndOffset_3D(GaussianCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class GaussianCurvatureOfParaboloid_Y_LinearDecayAndOffset_3D(GaussianCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class GaussianCurvatureOfParaboloid_XY_LinearDecayAndOffset_3D(GaussianCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class GaussianCurvatureOfParaboloid_X_ExponentialDecayAndOffset_3D(GaussianCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class GaussianCurvatureOfParaboloid_Y_ExponentialDecayAndOffset_3D(GaussianCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class GaussianCurvatureOfParaboloid_XY_ExponentialDecayAndOffset_3D(GaussianCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class GaussianCurvatureOfParaboloid_X_LinearGrowthAndOffset_3D(GaussianCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class GaussianCurvatureOfParaboloid_Y_LinearGrowthAndOffset_3D(GaussianCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class GaussianCurvatureOfParaboloid_XY_LinearGrowthAndOffset_3D(GaussianCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class GaussianCurvatureOfParaboloid_X_ExponentialGrowthAndOffset_3D(GaussianCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class GaussianCurvatureOfParaboloid_Y_ExponentialGrowthAndOffset_3D(GaussianCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class GaussianCurvatureOfParaboloid_XY_ExponentialGrowthAndOffset_3D(GaussianCurvatureOfParaboloid3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()



class Paraboloid3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Paraboloid"
        self.HTML = "z = a * (x<sup>2</sup> + y<sup>2</sup>)"
        self.coefficientDesignatorTuple = ("a")

        self.function_cpp_code = 'temp = coeff[0] * indep_data[(int)cachedWeaveOffsets[0] + i];// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_XSQPLUSYSQ(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a * (x_in * x_in + y_in * y_in);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a * (x_in * x_in + y_in * y_in);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a * (x_in * x_in + y_in * y_in);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\t\ttemp = a * (x_in * x_in + y_in * y_in)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\t\ttemp = a * (x_in * x_in + y_in * y_in)\n"
        return s


class Paraboloid_WO_3D(Paraboloid3D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class Paraboloid_X_LinearDecay_3D(Paraboloid3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class Paraboloid_Y_LinearDecay_3D(Paraboloid3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class Paraboloid_XY_LinearDecay_3D(Paraboloid3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class Paraboloid_X_ExponentialDecay_3D(Paraboloid3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class Paraboloid_Y_ExponentialDecay_3D(Paraboloid3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class Paraboloid_XY_ExponentialDecay_3D(Paraboloid3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class Paraboloid_X_LinearGrowth_3D(Paraboloid3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class Paraboloid_Y_LinearGrowth_3D(Paraboloid3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class Paraboloid_XY_LinearGrowth_3D(Paraboloid3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class Paraboloid_X_ExponentialGrowth_3D(Paraboloid3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class Paraboloid_Y_ExponentialGrowth_3D(Paraboloid3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class Paraboloid_XY_ExponentialGrowth_3D(Paraboloid3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class Paraboloid_X_LinearDecayAndOffset_3D(Paraboloid3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class Paraboloid_Y_LinearDecayAndOffset_3D(Paraboloid3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class Paraboloid_XY_LinearDecayAndOffset_3D(Paraboloid3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class Paraboloid_X_ExponentialDecayAndOffset_3D(Paraboloid3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class Paraboloid_Y_ExponentialDecayAndOffset_3D(Paraboloid3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class Paraboloid_XY_ExponentialDecayAndOffset_3D(Paraboloid3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class Paraboloid_X_LinearGrowthAndOffset_3D(Paraboloid3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class Paraboloid_Y_LinearGrowthAndOffset_3D(Paraboloid3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class Paraboloid_XY_LinearGrowthAndOffset_3D(Paraboloid3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class Paraboloid_X_ExponentialGrowthAndOffset_3D(Paraboloid3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class Paraboloid_Y_ExponentialGrowthAndOffset_3D(Paraboloid3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class Paraboloid_XY_ExponentialGrowthAndOffset_3D(Paraboloid3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()



class Paraboloid_Transform3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Paraboloid Transform"
        self.HTML = "z = a * ((bx + c)<sup>2</sup> + (dy + e)<sup>2</sup>)"
        self.coefficientDesignatorTuple = ("a", 'b', 'c', 'd', 'e')

        self.function_cpp_code = 'temp = coeff[0] * (pow(coeff[1] * indep_data[(int)cachedWeaveOffsets[0] + i] + coeff[2], 2.0) + pow(coeff[3] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[4], 2.0));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Y(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a * (pow(b * x_in + c, 2.0) + pow(d * y_in + e, 2.0));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a * (Math.pow(b * x_in + c, 2.0) + Math.pow(d * y_in + e, 2.0));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a * (Math.Pow(b * x_in + c, 2.0) + Math.Pow(d * y_in + e, 2.0));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\t\ttemp = a * (math.pow(b * x_in + c, 2.0) + math.pow(d * y_in + e, 2.0))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\t\ttemp = a * (pow(b * x_in + c, 2.0) + pow(d * y_in + e, 2.0))\n"
        return s


class Paraboloid_WO_3D(Paraboloid_Transform3D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class Paraboloid_X_LinearDecay_3D(Paraboloid_Transform3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class Paraboloid_Y_LinearDecay_3D(Paraboloid_Transform3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class Paraboloid_XY_LinearDecay_3D(Paraboloid_Transform3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class Paraboloid_X_ExponentialDecay_3D(Paraboloid_Transform3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class Paraboloid_Y_ExponentialDecay_3D(Paraboloid_Transform3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class Paraboloid_XY_ExponentialDecay_3D(Paraboloid_Transform3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class Paraboloid_X_LinearGrowth_3D(Paraboloid_Transform3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class Paraboloid_Y_LinearGrowth_3D(Paraboloid_Transform3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class Paraboloid_XY_LinearGrowth_3D(Paraboloid_Transform3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class Paraboloid_X_ExponentialGrowth_3D(Paraboloid_Transform3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class Paraboloid_Y_ExponentialGrowth_3D(Paraboloid_Transform3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class Paraboloid_XY_ExponentialGrowth_3D(Paraboloid_Transform3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class Paraboloid_X_LinearDecayAndOffset_3D(Paraboloid_Transform3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class Paraboloid_Y_LinearDecayAndOffset_3D(Paraboloid_Transform3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class Paraboloid_XY_LinearDecayAndOffset_3D(Paraboloid_Transform3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class Paraboloid_X_ExponentialDecayAndOffset_3D(Paraboloid_Transform3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class Paraboloid_Y_ExponentialDecayAndOffset_3D(Paraboloid_Transform3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class Paraboloid_XY_ExponentialDecayAndOffset_3D(Paraboloid_Transform3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class Paraboloid_X_LinearGrowthAndOffset_3D(Paraboloid_Transform3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class Paraboloid_Y_LinearGrowthAndOffset_3D(Paraboloid_Transform3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class Paraboloid_XY_LinearGrowthAndOffset_3D(Paraboloid_Transform3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class Paraboloid_X_ExponentialGrowthAndOffset_3D(Paraboloid_Transform3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class Paraboloid_Y_ExponentialGrowthAndOffset_3D(Paraboloid_Transform3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class Paraboloid_XY_ExponentialGrowthAndOffset_3D(Paraboloid_Transform3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()



class GaussianCurvatureOfRichmondsMinimalSurface3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Gaussian Curvature Of Richmond's Minimal Surface"
        self.HTML = "z = -1.0 * a * (x<sup>2</sup> + y<sup>2</sup>)<sup>3</sup> / (b + (x<sup>2</sup> + y<sup>2</sup>)<sup>2</sup>)<sup>4</sup>"
        self.coefficientDesignatorTuple = ("a", "b")

        self.function_cpp_code = 'temp = -1.0 * coeff[0] * pow(indep_data[(int)cachedWeaveOffsets[0] + i], 3.0) / pow(coeff[1] + pow(indep_data[(int)cachedWeaveOffsets[0] + i], 2.0), 4.0);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_XSQPLUSYSQ(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = -1.0 * a * pow(x_in * x_in + y_in * y_in, 3.0) / pow(b + pow(x_in * x_in + y_in * y_in, 2.0), 4.0);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = -1.0 * a * Math.pow(x_in * x_in + y_in * y_in, 3.0) / Math.pow(b + Math.pow(x_in * x_in + y_in * y_in, 2.0), 4.0);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = -1.0 * a * Math.Pow(x_in * x_in + y_in * y_in, 3.0) / Math.Pow(b + Math.Pow(x_in * x_in + y_in * y_in, 2.0), 4.0);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\t\ttemp = -1.0 * a * math.pow(x_in * x_in + y_in * y_in, 3.0) / math.pow(b + math.pow(x_in * x_in + y_in * y_in, 2.0), 4.0)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\t\ttemp = -1.0 * a * pow(x_in * x_in + y_in * y_in, 3.0) / pow(b + pow(x_in * x_in + y_in * y_in, 2.0), 4.0)\n"
        return s


class GaussianCurvatureOfRichmondsMinimalSurface_WO_3D(GaussianCurvatureOfRichmondsMinimalSurface3D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class GaussianCurvatureOfRichmondsMinimalSurface_X_LinearDecay_3D(GaussianCurvatureOfRichmondsMinimalSurface3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class GaussianCurvatureOfRichmondsMinimalSurface_Y_LinearDecay_3D(GaussianCurvatureOfRichmondsMinimalSurface3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class GaussianCurvatureOfRichmondsMinimalSurface_XY_LinearDecay_3D(GaussianCurvatureOfRichmondsMinimalSurface3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class GaussianCurvatureOfRichmondsMinimalSurface_X_ExponentialDecay_3D(GaussianCurvatureOfRichmondsMinimalSurface3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class GaussianCurvatureOfRichmondsMinimalSurface_Y_ExponentialDecay_3D(GaussianCurvatureOfRichmondsMinimalSurface3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class GaussianCurvatureOfRichmondsMinimalSurface_XY_ExponentialDecay_3D(GaussianCurvatureOfRichmondsMinimalSurface3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class GaussianCurvatureOfRichmondsMinimalSurface_X_LinearGrowth_3D(GaussianCurvatureOfRichmondsMinimalSurface3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class GaussianCurvatureOfRichmondsMinimalSurface_Y_LinearGrowth_3D(GaussianCurvatureOfRichmondsMinimalSurface3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class GaussianCurvatureOfRichmondsMinimalSurface_XY_LinearGrowth_3D(GaussianCurvatureOfRichmondsMinimalSurface3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class GaussianCurvatureOfRichmondsMinimalSurface_X_ExponentialGrowth_3D(GaussianCurvatureOfRichmondsMinimalSurface3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class GaussianCurvatureOfRichmondsMinimalSurface_Y_ExponentialGrowth_3D(GaussianCurvatureOfRichmondsMinimalSurface3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class GaussianCurvatureOfRichmondsMinimalSurface_XY_ExponentialGrowth_3D(GaussianCurvatureOfRichmondsMinimalSurface3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class GaussianCurvatureOfRichmondsMinimalSurface_X_LinearDecayAndOffset_3D(GaussianCurvatureOfRichmondsMinimalSurface3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class GaussianCurvatureOfRichmondsMinimalSurface_Y_LinearDecayAndOffset_3D(GaussianCurvatureOfRichmondsMinimalSurface3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class GaussianCurvatureOfRichmondsMinimalSurface_XY_LinearDecayAndOffset_3D(GaussianCurvatureOfRichmondsMinimalSurface3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class GaussianCurvatureOfRichmondsMinimalSurface_X_ExponentialDecayAndOffset_3D(GaussianCurvatureOfRichmondsMinimalSurface3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class GaussianCurvatureOfRichmondsMinimalSurface_Y_ExponentialDecayAndOffset_3D(GaussianCurvatureOfRichmondsMinimalSurface3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class GaussianCurvatureOfRichmondsMinimalSurface_XY_ExponentialDecayAndOffset_3D(GaussianCurvatureOfRichmondsMinimalSurface3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class GaussianCurvatureOfRichmondsMinimalSurface_X_LinearGrowthAndOffset_3D(GaussianCurvatureOfRichmondsMinimalSurface3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class GaussianCurvatureOfRichmondsMinimalSurface_Y_LinearGrowthAndOffset_3D(GaussianCurvatureOfRichmondsMinimalSurface3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class GaussianCurvatureOfRichmondsMinimalSurface_XY_LinearGrowthAndOffset_3D(GaussianCurvatureOfRichmondsMinimalSurface3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class GaussianCurvatureOfRichmondsMinimalSurface_X_ExponentialGrowthAndOffset_3D(GaussianCurvatureOfRichmondsMinimalSurface3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class GaussianCurvatureOfRichmondsMinimalSurface_Y_ExponentialGrowthAndOffset_3D(GaussianCurvatureOfRichmondsMinimalSurface3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class GaussianCurvatureOfRichmondsMinimalSurface_XY_ExponentialGrowthAndOffset_3D(GaussianCurvatureOfRichmondsMinimalSurface3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()



class MeanCurvatureOfWhitneysUmbrella3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Mean Curvature Of Whitney's Umbrella"
        self.HTML = "z = -1.0 * x * (a + b * y<sup>2</sup>) / (x<sup>2</sup> + a * (y<sup>2</sup> + y<sup>4</sup>))<sup>1.5</sup>"
        self.coefficientDesignatorTuple = ('a', 'b')

        self.function_cpp_code = 'temp = -1.0 * indep_data[(int)cachedWeaveOffsets[3] + i] * (coeff[0] + coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i]) / pow(indep_data[(int)cachedWeaveOffsets[0] + i] + coeff[0] * (indep_data[(int)cachedWeaveOffsets[1] + i] + indep_data[(int)cachedWeaveOffsets[2] + i]), 1.5);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_PowX(NameOrValueFlag=1, args=[2.0]), [2.0]])
        self.CacheGenerationList.append([self.CG_PowY(NameOrValueFlag=1, args=[2.0]), [2.0]])
        self.CacheGenerationList.append([self.CG_PowY(NameOrValueFlag=1, args=[4.0]), [4.0]])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = -1.0 * x_in * (a + b * y_in * y_in) / pow(x_in * x_in + a * (y_in * y_in + pow(y_in, 4.0)), 1.5);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = -1.0 * x_in * (a + b * y_in * y_in) / Math.pow(x_in * x_in + a * (y_in * y_in + Math.pow(y_in, 4.0)), 1.5);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = -1.0 * x_in * (a + b * y_in * y_in) / Math.Pow(x_in * x_in + a * (y_in * y_in + Math.Pow(y_in, 4.0)), 1.5);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\t\ttemp = -1.0 * x_in * (a + b * y_in * y_in) / math.pow(x_in * x_in + a * (y_in * y_in + math.pow(y_in, 4.0)), 1.5)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\t\ttemp = -1.0 * x_in * (a + b * y_in * y_in) / pow(x_in * x_in + a * (y_in * y_in + pow(y_in, 4.0)), 1.5)\n"
        return s


class MeanCurvatureOfWhitneysUmbrella_WO_3D(MeanCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class MeanCurvatureOfWhitneysUmbrella_X_LinearDecay_3D(MeanCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class MeanCurvatureOfWhitneysUmbrella_Y_LinearDecay_3D(MeanCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class MeanCurvatureOfWhitneysUmbrella_XY_LinearDecay_3D(MeanCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class MeanCurvatureOfWhitneysUmbrella_X_ExponentialDecay_3D(MeanCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class MeanCurvatureOfWhitneysUmbrella_Y_ExponentialDecay_3D(MeanCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class MeanCurvatureOfWhitneysUmbrella_XY_ExponentialDecay_3D(MeanCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class MeanCurvatureOfWhitneysUmbrella_X_LinearGrowth_3D(MeanCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class MeanCurvatureOfWhitneysUmbrella_Y_LinearGrowth_3D(MeanCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class MeanCurvatureOfWhitneysUmbrella_XY_LinearGrowth_3D(MeanCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class MeanCurvatureOfWhitneysUmbrella_X_ExponentialGrowth_3D(MeanCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class MeanCurvatureOfWhitneysUmbrella_Y_ExponentialGrowth_3D(MeanCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class MeanCurvatureOfWhitneysUmbrella_XY_ExponentialGrowth_3D(MeanCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class MeanCurvatureOfWhitneysUmbrella_X_LinearDecayAndOffset_3D(MeanCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class MeanCurvatureOfWhitneysUmbrella_Y_LinearDecayAndOffset_3D(MeanCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class MeanCurvatureOfWhitneysUmbrella_XY_LinearDecayAndOffset_3D(MeanCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class MeanCurvatureOfWhitneysUmbrella_X_ExponentialDecayAndOffset_3D(MeanCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class MeanCurvatureOfWhitneysUmbrella_Y_ExponentialDecayAndOffset_3D(MeanCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class MeanCurvatureOfWhitneysUmbrella_XY_ExponentialDecayAndOffset_3D(MeanCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class MeanCurvatureOfWhitneysUmbrella_X_LinearGrowthAndOffset_3D(MeanCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class MeanCurvatureOfWhitneysUmbrella_Y_LinearGrowthAndOffset_3D(MeanCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class MeanCurvatureOfWhitneysUmbrella_XY_LinearGrowthAndOffset_3D(MeanCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class MeanCurvatureOfWhitneysUmbrella_X_ExponentialGrowthAndOffset_3D(MeanCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class MeanCurvatureOfWhitneysUmbrella_Y_ExponentialGrowthAndOffset_3D(MeanCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class MeanCurvatureOfWhitneysUmbrella_XY_ExponentialGrowthAndOffset_3D(MeanCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()



class GaussianCurvatureOfWhitneysUmbrella3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Gaussian Curvature Of Whitney's Umbrella"
        self.HTML = "z = -1.0 * a * y<sup>2</sup> / (x<sup>2</sup> + a * (y<sup>2</sup> + y<sup>4</sup>))<sup>2</sup>"
        self.coefficientDesignatorTuple = ("a")

        self.function_cpp_code = 'temp = -1.0 * coeff[0] * indep_data[(int)cachedWeaveOffsets[1] + i] / pow(indep_data[(int)cachedWeaveOffsets[0] + i] + coeff[0] * (indep_data[(int)cachedWeaveOffsets[1] + i] + indep_data[(int)cachedWeaveOffsets[2] + i]), 2.0);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_PowX(NameOrValueFlag=1, args=[2.0]), [2.0]])
        self.CacheGenerationList.append([self.CG_PowY(NameOrValueFlag=1, args=[2.0]), [2.0]])
        self.CacheGenerationList.append([self.CG_PowY(NameOrValueFlag=1, args=[4.0]), [4.0]])

    def SpecificCodeCPP(self):
        s = "\ttemp = -1.0 * a * y_in * y_in / pow(x_in * x_in + a * (y_in * y_in + pow(y_in, 4.0)), 2.0);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = -1.0 * a * y_in * y_in / Math.pow(x_in * x_in + a * (y_in * y_in + Math.pow(y_in, 4.0)), 2.0);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = -1.0 * a * y_in * y_in / Math.Pow(x_in * x_in + a * (y_in * y_in + Math.Pow(y_in, 4.0)), 2.0);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\t\ttemp = -1.0 * a * y_in * y_in / math.pow(x_in * x_in + a * (y_in * y_in + math.pow(y_in, 4.0)), 2.0)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\t\ttemp = -1.0 * a * y_in * y_in / pow(x_in * x_in + a * (y_in * y_in + pow(y_in, 4.0)), 2.0)\n"
        return s


class GaussianCurvatureOfWhitneysUmbrella_WO_3D(GaussianCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class GaussianCurvatureOfWhitneysUmbrella_X_LinearDecay_3D(GaussianCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class GaussianCurvatureOfWhitneysUmbrella_Y_LinearDecay_3D(GaussianCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class GaussianCurvatureOfWhitneysUmbrella_XY_LinearDecay_3D(GaussianCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class GaussianCurvatureOfWhitneysUmbrella_X_ExponentialDecay_3D(GaussianCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class GaussianCurvatureOfWhitneysUmbrella_Y_ExponentialDecay_3D(GaussianCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class GaussianCurvatureOfWhitneysUmbrella_XY_ExponentialDecay_3D(GaussianCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class GaussianCurvatureOfWhitneysUmbrella_X_LinearGrowth_3D(GaussianCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class GaussianCurvatureOfWhitneysUmbrella_Y_LinearGrowth_3D(GaussianCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class GaussianCurvatureOfWhitneysUmbrella_XY_LinearGrowth_3D(GaussianCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class GaussianCurvatureOfWhitneysUmbrella_X_ExponentialGrowth_3D(GaussianCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class GaussianCurvatureOfWhitneysUmbrella_Y_ExponentialGrowth_3D(GaussianCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class GaussianCurvatureOfWhitneysUmbrella_XY_ExponentialGrowth_3D(GaussianCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class GaussianCurvatureOfWhitneysUmbrella_X_LinearDecayAndOffset_3D(GaussianCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class GaussianCurvatureOfWhitneysUmbrella_Y_LinearDecayAndOffset_3D(GaussianCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class GaussianCurvatureOfWhitneysUmbrella_XY_LinearDecayAndOffset_3D(GaussianCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class GaussianCurvatureOfWhitneysUmbrella_X_ExponentialDecayAndOffset_3D(GaussianCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class GaussianCurvatureOfWhitneysUmbrella_Y_ExponentialDecayAndOffset_3D(GaussianCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class GaussianCurvatureOfWhitneysUmbrella_XY_ExponentialDecayAndOffset_3D(GaussianCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class GaussianCurvatureOfWhitneysUmbrella_X_LinearGrowthAndOffset_3D(GaussianCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class GaussianCurvatureOfWhitneysUmbrella_Y_LinearGrowthAndOffset_3D(GaussianCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class GaussianCurvatureOfWhitneysUmbrella_XY_LinearGrowthAndOffset_3D(GaussianCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class GaussianCurvatureOfWhitneysUmbrella_X_ExponentialGrowthAndOffset_3D(GaussianCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class GaussianCurvatureOfWhitneysUmbrella_Y_ExponentialGrowthAndOffset_3D(GaussianCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class GaussianCurvatureOfWhitneysUmbrella_XY_ExponentialGrowthAndOffset_3D(GaussianCurvatureOfWhitneysUmbrella3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()



class PaschensBreakdownFieldStrengthLaw3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Paschen's Law for Breakdown Field Strength"
        self.HTML = "Ebreakdown = pressure * (a / (ln(pressure * distance) + b))"
        self.coefficientDesignatorTuple = ("a", "b")
        self.RequiresPositiveX = 1
        self.RequiresPositiveY = 1

        self.function_cpp_code = 'temp = indep_data[(int)cachedWeaveOffsets[0] + i] * (coeff[0] / (indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[1]));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogXY(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = x_in * (a / (log(x_in * y_in) + b));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = x_in * (a / (Math.log(x_in * y_in) + b));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = x_in * (a / (Math.Log(x_in * y_in) + b));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\t\ttemp = x_in * (a / (math.log(x_in * y_in) + b))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\t\ttemp = x_in * (a / (log(x_in * y_in) + b))\n"
        return s


class PaschensBreakdownFieldStrengthLaw_WO_3D(PaschensBreakdownFieldStrengthLaw3D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class PaschensBreakdownFieldStrengthLaw_X_LinearDecay_3D(PaschensBreakdownFieldStrengthLaw3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class PaschensBreakdownFieldStrengthLaw_Y_LinearDecay_3D(PaschensBreakdownFieldStrengthLaw3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class PaschensBreakdownFieldStrengthLaw_XY_LinearDecay_3D(PaschensBreakdownFieldStrengthLaw3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class PaschensBreakdownFieldStrengthLaw_X_ExponentialDecay_3D(PaschensBreakdownFieldStrengthLaw3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class PaschensBreakdownFieldStrengthLaw_Y_ExponentialDecay_3D(PaschensBreakdownFieldStrengthLaw3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class PaschensBreakdownFieldStrengthLaw_XY_ExponentialDecay_3D(PaschensBreakdownFieldStrengthLaw3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class PaschensBreakdownFieldStrengthLaw_X_LinearGrowth_3D(PaschensBreakdownFieldStrengthLaw3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class PaschensBreakdownFieldStrengthLaw_Y_LinearGrowth_3D(PaschensBreakdownFieldStrengthLaw3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class PaschensBreakdownFieldStrengthLaw_XY_LinearGrowth_3D(PaschensBreakdownFieldStrengthLaw3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class PaschensBreakdownFieldStrengthLaw_X_ExponentialGrowth_3D(PaschensBreakdownFieldStrengthLaw3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class PaschensBreakdownFieldStrengthLaw_Y_ExponentialGrowth_3D(PaschensBreakdownFieldStrengthLaw3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class PaschensBreakdownFieldStrengthLaw_XY_ExponentialGrowth_3D(PaschensBreakdownFieldStrengthLaw3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class PaschensBreakdownFieldStrengthLaw_X_LinearDecayAndOffset_3D(PaschensBreakdownFieldStrengthLaw3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class PaschensBreakdownFieldStrengthLaw_Y_LinearDecayAndOffset_3D(PaschensBreakdownFieldStrengthLaw3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class PaschensBreakdownFieldStrengthLaw_XY_LinearDecayAndOffset_3D(PaschensBreakdownFieldStrengthLaw3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class PaschensBreakdownFieldStrengthLaw_X_ExponentialDecayAndOffset_3D(PaschensBreakdownFieldStrengthLaw3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class PaschensBreakdownFieldStrengthLaw_Y_ExponentialDecayAndOffset_3D(PaschensBreakdownFieldStrengthLaw3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class PaschensBreakdownFieldStrengthLaw_XY_ExponentialDecayAndOffset_3D(PaschensBreakdownFieldStrengthLaw3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class PaschensBreakdownFieldStrengthLaw_X_LinearGrowthAndOffset_3D(PaschensBreakdownFieldStrengthLaw3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class PaschensBreakdownFieldStrengthLaw_Y_LinearGrowthAndOffset_3D(PaschensBreakdownFieldStrengthLaw3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class PaschensBreakdownFieldStrengthLaw_XY_LinearGrowthAndOffset_3D(PaschensBreakdownFieldStrengthLaw3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class PaschensBreakdownFieldStrengthLaw_X_ExponentialGrowthAndOffset_3D(PaschensBreakdownFieldStrengthLaw3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class PaschensBreakdownFieldStrengthLaw_Y_ExponentialGrowthAndOffset_3D(PaschensBreakdownFieldStrengthLaw3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class PaschensBreakdownFieldStrengthLaw_XY_ExponentialGrowthAndOffset_3D(PaschensBreakdownFieldStrengthLaw3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()


class PaschensBreakdownVoltageLaw3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Paschen's Law for Breakdown Voltage"
        self.HTML = "Vbreakdown = a(pressure * distance) / (ln(pressure * distance) + b)"
        self.coefficientDesignatorTuple = ("a", "b")
        self.RequiresPositiveX = 1
        self.RequiresPositiveY = 1

        self.function_cpp_code = 'temp = (coeff[0] * indep_data[(int)cachedWeaveOffsets[0] + i]) / (indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[1]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_XY(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogXY(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = (a * x_in * y_in) / (log(x_in * y_in) + b);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = (a * x_in * y_in) / (Math.log(x_in * y_in) + b);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = (a * x_in * y_in) / (Math.Log(x_in * y_in) + b);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\t\ttemp = (a * x_in * y_in) / (math.log(x_in * y_in) + b)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\t\ttemp = (a * x_in * y_in) / (log(x_in * y_in) + b)\n"
        return s


class PaschensBreakdownVoltageLaw_WO_3D(PaschensBreakdownVoltageLaw3D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class PaschensBreakdownVoltageLaw_X_LinearDecay_3D(PaschensBreakdownVoltageLaw3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class PaschensBreakdownVoltageLaw_Y_LinearDecay_3D(PaschensBreakdownVoltageLaw3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class PaschensBreakdownVoltageLaw_XY_LinearDecay_3D(PaschensBreakdownVoltageLaw3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class PaschensBreakdownVoltageLaw_X_ExponentialDecay_3D(PaschensBreakdownVoltageLaw3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class PaschensBreakdownVoltageLaw_Y_ExponentialDecay_3D(PaschensBreakdownVoltageLaw3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class PaschensBreakdownVoltageLaw_XY_ExponentialDecay_3D(PaschensBreakdownVoltageLaw3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class PaschensBreakdownVoltageLaw_X_LinearGrowth_3D(PaschensBreakdownVoltageLaw3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class PaschensBreakdownVoltageLaw_Y_LinearGrowth_3D(PaschensBreakdownVoltageLaw3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class PaschensBreakdownVoltageLaw_XY_LinearGrowth_3D(PaschensBreakdownVoltageLaw3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class PaschensBreakdownVoltageLaw_X_ExponentialGrowth_3D(PaschensBreakdownVoltageLaw3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class PaschensBreakdownVoltageLaw_Y_ExponentialGrowth_3D(PaschensBreakdownVoltageLaw3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class PaschensBreakdownVoltageLaw_XY_ExponentialGrowth_3D(PaschensBreakdownVoltageLaw3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class PaschensBreakdownVoltageLaw_X_LinearDecayAndOffset_3D(PaschensBreakdownVoltageLaw3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class PaschensBreakdownVoltageLaw_Y_LinearDecayAndOffset_3D(PaschensBreakdownVoltageLaw3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class PaschensBreakdownVoltageLaw_XY_LinearDecayAndOffset_3D(PaschensBreakdownVoltageLaw3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class PaschensBreakdownVoltageLaw_X_ExponentialDecayAndOffset_3D(PaschensBreakdownVoltageLaw3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class PaschensBreakdownVoltageLaw_Y_ExponentialDecayAndOffset_3D(PaschensBreakdownVoltageLaw3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class PaschensBreakdownVoltageLaw_XY_ExponentialDecayAndOffset_3D(PaschensBreakdownVoltageLaw3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class PaschensBreakdownVoltageLaw_X_LinearGrowthAndOffset_3D(PaschensBreakdownVoltageLaw3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class PaschensBreakdownVoltageLaw_Y_LinearGrowthAndOffset_3D(PaschensBreakdownVoltageLaw3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class PaschensBreakdownVoltageLaw_XY_LinearGrowthAndOffset_3D(PaschensBreakdownVoltageLaw3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class PaschensBreakdownVoltageLaw_X_ExponentialGrowthAndOffset_3D(PaschensBreakdownVoltageLaw3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class PaschensBreakdownVoltageLaw_Y_ExponentialGrowthAndOffset_3D(PaschensBreakdownVoltageLaw3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class PaschensBreakdownVoltageLaw_XY_ExponentialGrowthAndOffset_3D(PaschensBreakdownVoltageLaw3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()


class LipingZheng3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Liping Zheng's core loss coefficients"
        self.HTML = "z = ax<SUP>2</SUP>y + bx<SUP>2</SUP>y<SUP>2</SUP> + cx<SUP>1.5</SUP>y<SUP>1.5</SUP>"
        self.coefficientDesignatorTuple = ("a", "b", "c")
        self.RequiresPositiveX = 1
        self.RequiresPositiveY = 1

        self.function_cpp_code = 'temp = coeff[0] * indep_data[(int)cachedWeaveOffsets[0] + i] + coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[2] * indep_data[(int)cachedWeaveOffsets[2] + i];// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_PowXY(NameOrValueFlag=1, args=[2.0, 1.0]), [2.0, 1.0]])
        self.CacheGenerationList.append([self.CG_PowXY(NameOrValueFlag=1, args=[2.0, 2.0]), [2.0, 2.0]])
        self.CacheGenerationList.append([self.CG_PowXY(NameOrValueFlag=1, args=[1.5, 1.5]), [1.5, 1.5]])

    def SpecificCodeCPP(self):
        s = "\ttemp = a * x_in * x_in * y_in + b * x_in * x_in * y_in * y_in + c * pow(x_in, 1.5) * pow(y_in, 1.5);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a * x_in * x_in * y_in + b * x_in * x_in * y_in * y_in + c * Math.pow(x_in, 1.5) * Math.pow(y_in, 1.5);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a * x_in * x_in * y_in + b * x_in * x_in * y_in * y_in + c * Math.Pow(x_in, 1.5) * Math.Pow(y_in, 1.5);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\t\ttemp = a * x_in * x_in * y_in + b * x_in * x_in * y_in * y_in + c * math.pow(x_in, 1.5) * math.pow(y_in, 1.5)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\t\ttemp = a * x_in * x_in * y_in + b * x_in * x_in * y_in * y_in + c * pow(x_in, 1.5) * pow(y_in, 1.5)\n"
        return s


class LipingZheng_WO_3D(LipingZheng3D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class LipingZheng_X_LinearDecay_3D(LipingZheng3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class LipingZheng_Y_LinearDecay_3D(LipingZheng3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class LipingZheng_XY_LinearDecay_3D(LipingZheng3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class LipingZheng_X_ExponentialDecay_3D(LipingZheng3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class LipingZheng_Y_ExponentialDecay_3D(LipingZheng3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class LipingZheng_XY_ExponentialDecay_3D(LipingZheng3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class LipingZheng_X_LinearGrowth_3D(LipingZheng3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class LipingZheng_Y_LinearGrowth_3D(LipingZheng3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class LipingZheng_XY_LinearGrowth_3D(LipingZheng3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class LipingZheng_X_ExponentialGrowth_3D(LipingZheng3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class LipingZheng_Y_ExponentialGrowth_3D(LipingZheng3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class LipingZheng_XY_ExponentialGrowth_3D(LipingZheng3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class LipingZheng_X_LinearDecayAndOffset_3D(LipingZheng3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class LipingZheng_Y_LinearDecayAndOffset_3D(LipingZheng3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class LipingZheng_XY_LinearDecayAndOffset_3D(LipingZheng3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class LipingZheng_X_ExponentialDecayAndOffset_3D(LipingZheng3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class LipingZheng_Y_ExponentialDecayAndOffset_3D(LipingZheng3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class LipingZheng_XY_ExponentialDecayAndOffset_3D(LipingZheng3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class LipingZheng_X_LinearGrowthAndOffset_3D(LipingZheng3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class LipingZheng_Y_LinearGrowthAndOffset_3D(LipingZheng3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class LipingZheng_XY_LinearGrowthAndOffset_3D(LipingZheng3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class LipingZheng_X_ExponentialGrowthAndOffset_3D(LipingZheng3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class LipingZheng_Y_ExponentialGrowthAndOffset_3D(LipingZheng3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class LipingZheng_XY_ExponentialGrowthAndOffset_3D(LipingZheng3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()


class GaryCler3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Gary Cler's Custom Equation"
        self.HTML = "z = a * x<SUP>b</SUP> * y<SUP>c</SUP>"
        self.coefficientDesignatorTuple = ("a", "b", "c")

        self.function_cpp_code = 'temp = coeff[0] * pow(indep_data[(int)cachedWeaveOffsets[0] + i], coeff[1]) * pow(indep_data[(int)cachedWeaveOffsets[1] + i], coeff[2]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1] + "\n"

    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Y(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a * pow(x_in, b) * pow(y_in, c);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a * Math.pow(x_in, b) * Math.pow(y_in, c);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a * Math.Pow(x_in, b) * Math.Pow(y_in, c);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\t\ttemp = a * math.pow(x_in, b) * math.pow(y_in, c)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\t\ttemp = a * pow(x_in, b) * pow(y_in, c)\n"
        return s


class GaryCler_WO_3D(GaryCler3D):
    def __init__(self,): self.InitCodeForOffsetFormsOfEquations()
class GaryCler_X_LinearDecay_3D(GaryCler3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class GaryCler_Y_LinearDecay_3D(GaryCler3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class GaryCler_XY_LinearDecay_3D(GaryCler3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class GaryCler_X_ExponentialDecay_3D(GaryCler3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class GaryCler_Y_ExponentialDecay_3D(GaryCler3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class GaryCler_XY_ExponentialDecay_3D(GaryCler3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class GaryCler_X_LinearGrowth_3D(GaryCler3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class GaryCler_Y_LinearGrowth_3D(GaryCler3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class GaryCler_XY_LinearGrowth_3D(GaryCler3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class GaryCler_X_ExponentialGrowth_3D(GaryCler3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class GaryCler_Y_ExponentialGrowth_3D(GaryCler3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class GaryCler_XY_ExponentialGrowth_3D(GaryCler3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class GaryCler_X_LinearDecayAndOffset_3D(GaryCler3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class GaryCler_Y_LinearDecayAndOffset_3D(GaryCler3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class GaryCler_XY_LinearDecayAndOffset_3D(GaryCler3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class GaryCler_X_ExponentialDecayAndOffset_3D(GaryCler3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class GaryCler_Y_ExponentialDecayAndOffset_3D(GaryCler3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class GaryCler_XY_ExponentialDecayAndOffset_3D(GaryCler3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class GaryCler_X_LinearGrowthAndOffset_3D(GaryCler3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class GaryCler_Y_LinearGrowthAndOffset_3D(GaryCler3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class GaryCler_XY_LinearGrowthAndOffset_3D(GaryCler3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class GaryCler_X_ExponentialGrowthAndOffset_3D(GaryCler3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class GaryCler_Y_ExponentialGrowthAndOffset_3D(GaryCler3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class GaryCler_XY_ExponentialGrowthAndOffset_3D(GaryCler3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()


class GaryCler_Transform3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Gary Cler's Custom Equation Transform"
        self.HTML = "z = a * (dx + e)<SUP>b</SUP> * (fy + g)<SUP>c</SUP>"
        self.coefficientDesignatorTuple = ("a", "b", "c", 'd', 'e', 'f', 'g')

        self.function_cpp_code = 'temp = coeff[0] * pow(coeff[3] * indep_data[(int)cachedWeaveOffsets[0] + i] + coeff[4], coeff[1]) * pow(coeff[5] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[6], coeff[2]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1] + "\n"

    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Y(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a * pow(d * x_in + e, b) * pow(f * y_in + g, c);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a * Math.pow(d * x_in + e, b) * Math.pow(f * y_in + g, c);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a * Math.Pow(d * x_in + e, b) * Math.Pow(f * y_in + g, c);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\t\ttemp = a * math.pow(d * x_in + e, b) * math.pow(f * y_in + g, c)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\t\ttemp = a * pow(d * x_in + e, b) * pow(f * y_in + g, c)\n"
        return s


class GaryCler_Transform_WO_3D(GaryCler_Transform3D):
    def __init__(self,): self.InitCodeForOffsetFormsOfEquations()
class GaryCler_Transform_X_LinearDecay_3D(GaryCler_Transform3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class GaryCler_Transform_Y_LinearDecay_3D(GaryCler_Transform3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class GaryCler_Transform_XY_LinearDecay_3D(GaryCler_Transform3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class GaryCler_Transform_X_ExponentialDecay_3D(GaryCler_Transform3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class GaryCler_Transform_Y_ExponentialDecay_3D(GaryCler_Transform3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class GaryCler_Transform_XY_ExponentialDecay_3D(GaryCler_Transform3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class GaryCler_Transform_X_LinearGrowth_3D(GaryCler_Transform3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class GaryCler_Transform_Y_LinearGrowth_3D(GaryCler_Transform3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class GaryCler_Transform_XY_LinearGrowth_3D(GaryCler_Transform3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class GaryCler_Transform_X_ExponentialGrowth_3D(GaryCler_Transform3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class GaryCler_Transform_Y_ExponentialGrowth_3D(GaryCler_Transform3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class GaryCler_Transform_XY_ExponentialGrowth_3D(GaryCler_Transform3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class GaryCler_Transform_X_LinearDecayAndOffset_3D(GaryCler_Transform3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class GaryCler_Transform_Y_LinearDecayAndOffset_3D(GaryCler_Transform3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class GaryCler_Transform_XY_LinearDecayAndOffset_3D(GaryCler_Transform3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class GaryCler_Transform_X_ExponentialDecayAndOffset_3D(GaryCler_Transform3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class GaryCler_Transform_Y_ExponentialDecayAndOffset_3D(GaryCler_Transform3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class GaryCler_Transform_XY_ExponentialDecayAndOffset_3D(GaryCler_Transform3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class GaryCler_Transform_X_LinearGrowthAndOffset_3D(GaryCler_Transform3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class GaryCler_Transform_Y_LinearGrowthAndOffset_3D(GaryCler_Transform3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class GaryCler_Transform_XY_LinearGrowthAndOffset_3D(GaryCler_Transform3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class GaryCler_Transform_X_ExponentialGrowthAndOffset_3D(GaryCler_Transform3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class GaryCler_Transform_Y_ExponentialGrowthAndOffset_3D(GaryCler_Transform3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class GaryCler_Transform_XY_ExponentialGrowthAndOffset_3D(GaryCler_Transform3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()
