#    pythonequations is a collection of equations expressed as Python classes
#    Copyright (C) 2008 James R. Phillips
#    2548 Vera Cruz Drive
#    Birmingham, AL 35235 USA
#    email: zunzun@zunzun.com
#
#    Version info: $Id$
#
#    License: BSD-style (see LICENSE.txt in main source directory)

import pythonequations, pythonequations.EquationBaseClasses
import numpy
numpy.seterr(all = 'raise') # numpy raises warnings, convert to exceptions to trap them

class SagForAsphere03D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.HTMLIsSplitIntoTwoLinesOfHTML = 1
        self.name = "Sag For Asphere 0"
        self.HTML = "s<SUP>2</SUP> = x<SUP>2</SUP> + y<SUP>2</SUP><BR>z = (s<SUP>2</SUP>/r) / (1+(1-(k+1)(s/r)<SUP>2</SUP>)<SUP>1/2</SUP>) + offset"
        self.coefficientDesignatorTuple = ("k", "r", "offset")

        self.function_cpp_code = 's_sq = indep_data[(int)cachedWeaveOffsets[0] + i] * indep_data[(int)cachedWeaveOffsets[0] + i] + indep_data[(int)cachedWeaveOffsets[1] + i] * indep_data[(int)cachedWeaveOffsets[1] + i];\n'
        self.function_cpp_code += 's_over_r = pow(s_sq, 0.5) / coeff[1];\n'
        self.function_cpp_code += 'temp = (s_sq / coeff[1]) / (1.0 + pow(1.0 - (coeff[0] + 1.0) * s_over_r * s_over_r, 0.5)) + coeff[2];// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1] + '\n'


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Y(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += '\tdouble s_sq = x_in * x_in + y_in * y_in;\n'
        s += '\tdouble s_over_r = pow(s_sq, 0.5) / ' + j[1] + ';\n'
        s += '\ttemp = (s_sq / ' + j[1] + ') / (1.0 + pow(1.0 - (' + j[0] + ' + 1.0) * s_over_r * s_over_r, 0.5)) + ' + j[2] + ';\n'
        return s

    def SpecificCodeJAVA(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += '\tdouble s_sq = x_in * x_in + y_in * y_in;\n'
        s += '\tdouble s_over_r = Math.pow(s_sq, 0.5) / ' + j[1] + ';\n'
        s += '\ttemp = (s_sq / ' + j[1] + ') / (1.0 + Math.pow(1.0 - (' + j[0] + ' + 1.0) * s_over_r * s_over_r, 0.5)) + ' + j[2] + ';\n'
        return s

    def SpecificCodeCS(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += '\tdouble s_sq = x_in * x_in + y_in * y_in;\n'
        s += '\tdouble s_over_r = Math.Pow(s_sq, 0.5) / ' + j[1] + ';\n'
        s += '\ttemp = (s_sq / ' + j[1] + ') / (1.0 + Math.Pow(1.0 - (' + j[0] + ' + 1.0) * s_over_r * s_over_r, 0.5)) + ' + j[2] + ';\n'
        return s

    def SpecificCodePYTHON(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += '\ts_sq = x_in * x_in + y_in * y_in\n'
        s += '\ts_over_r = math.pow(s_sq, 0.5) / ' + j[1] + '\n'
        s += '\ttemp = (s_sq / ' + j[1] + ') / (1.0 + math.pow(1.0 - (' + j[0] + ' + 1.0) * s_over_r * s_over_r, 0.5)) + ' + j[2] + '\n'
        return s

    def SpecificCodeSCILAB(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += '\ts_sq = x_in * x_in + y_in * y_in\n'
        s += '\ts_over_r = pow(s_sq, 0.5) / ' + j[1] + '\n'
        s += '\ttemp = (s_sq / ' + j[1] + ') / (1.0 + pow(1.0 - (' + j[0] + ' + 1.0) * s_over_r * s_over_r, 0.5)) + ' + j[2] + '\n'
        return s


class SagForAsphere0_X_LinearDecay_3D(SagForAsphere03D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class SagForAsphere0_Y_LinearDecay_3D(SagForAsphere03D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class SagForAsphere0_XY_LinearDecay_3D(SagForAsphere03D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class SagForAsphere0_X_ExponentialDecay_3D(SagForAsphere03D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class SagForAsphere0_Y_ExponentialDecay_3D(SagForAsphere03D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class SagForAsphere0_XY_ExponentialDecay_3D(SagForAsphere03D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class SagForAsphere0_X_LinearGrowth_3D(SagForAsphere03D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class SagForAsphere0_Y_LinearGrowth_3D(SagForAsphere03D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class SagForAsphere0_XY_LinearGrowth_3D(SagForAsphere03D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class SagForAsphere0_X_ExponentialGrowth_3D(SagForAsphere03D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class SagForAsphere0_Y_ExponentialGrowth_3D(SagForAsphere03D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class SagForAsphere0_XY_ExponentialGrowth_3D(SagForAsphere03D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class SagForAsphere0_X_LinearDecayAndOffset_3D(SagForAsphere03D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class SagForAsphere0_Y_LinearDecayAndOffset_3D(SagForAsphere03D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class SagForAsphere0_XY_LinearDecayAndOffset_3D(SagForAsphere03D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class SagForAsphere0_X_ExponentialDecayAndOffset_3D(SagForAsphere03D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class SagForAsphere0_Y_ExponentialDecayAndOffset_3D(SagForAsphere03D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class SagForAsphere0_XY_ExponentialDecayAndOffset_3D(SagForAsphere03D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class SagForAsphere0_X_LinearGrowthAndOffset_3D(SagForAsphere03D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class SagForAsphere0_Y_LinearGrowthAndOffset_3D(SagForAsphere03D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class SagForAsphere0_XY_LinearGrowthAndOffset_3D(SagForAsphere03D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class SagForAsphere0_X_ExponentialGrowthAndOffset_3D(SagForAsphere03D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class SagForAsphere0_Y_ExponentialGrowthAndOffset_3D(SagForAsphere03D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class SagForAsphere0_XY_ExponentialGrowthAndOffset_3D(SagForAsphere03D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()


class SagForAsphere0_Borisovsky_3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.HTMLIsSplitIntoTwoLinesOfHTML = 1
        self.name = "Sag For Asphere 0 Borisovsky"
        self.HTML = "s<SUP>2</SUP> = (x - a)<SUP>2</SUP> + (y - b)<SUP>2</SUP><BR>z = (s<SUP>2</SUP>/r) / "
        self.HTML += "(1+(1-(k+1)(s/r)<SUP>2</SUP>)<SUP>1/2</SUP>) + offset"
        self.coefficientDesignatorTuple = ("a", "b", "k", "r", "offset")

        self.function_cpp_code = 's_sq_b = ((indep_data[(int)cachedWeaveOffsets[0] + i] - coeff[0]) * (indep_data[(int)cachedWeaveOffsets[0] + i] - coeff[0])) + '
        self.function_cpp_code += '((indep_data[(int)cachedWeaveOffsets[1] + i] - coeff[1]) * (indep_data[(int)cachedWeaveOffsets[1] + i] - coeff[1]));\n'
        self.function_cpp_code += 's_over_r_b = pow(s_sq_b, 0.5) / coeff[3];\n'
        self.function_cpp_code += 'temp = (s_sq_b/ coeff[3]) / (1.0 + pow(1.0 - (coeff[2] + 1.0) * s_over_r_b * s_over_r_b, 0.5))'
        self.function_cpp_code += ' + coeff[4];// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1] + '\n'


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Y(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read

        s += '\tdouble s_sq = (x_in - ' + j[0] + ') * (x_in - ' + j[0] + ') + (y_in - ' + j[1] + ') * (y_in - ' + j[1] + ');\n'
        s += '\tdouble s_over_r = pow(s_sq, 0.5) / ' + j[1] + ';\n'
        s += '\ttemp = (s_sq / ' + j[3] + ') / (1.0 + pow(1.0 - (' + j[2] + ' + 1.0) * s_over_r * s_over_r, 0.5)) + ' + j[4] + ';\n'
        return s

    def SpecificCodeJAVA(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read

        s += '\tdouble s_sq = (x_in - ' + j[0] + ') * (x_in - ' + j[0] + ') + (y_in - ' + j[1] + ') * (y_in - ' + j[1] + ');\n'
        s += '\tdouble s_over_r = Math.pow(s_sq, 0.5) / ' + j[3] + ';\n'
        s += '\ttemp = (s_sq / ' + j[3] + ') / (1.0 + Math.pow(1.0 - (' + j[2] + ' + 1.0) * s_over_r * s_over_r, 0.5)) + ' + j[4] + ';\n'
        return s

    def SpecificCodeCS(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read

        s += '\tdouble s_sq = (x_in - ' + j[0] + ') * (x_in - ' + j[0] + ') + (y_in - ' + j[1] + ') * (y_in - ' + j[1] + ');\n'
        s += '\tdouble s_over_r = Math.Pow(s_sq, 0.5) / ' + j[3] + ';\n'
        s += '\ttemp = (s_sq / ' + j[3] + ') / (1.0 + Math.Pow(1.0 - (' + j[2] + ' + 1.0) * s_over_r * s_over_r, 0.5)) + ' + j[4] + ';\n'
        return s

    def SpecificCodePYTHON(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read

        s += '\ts_sq = (x_in - ' + j[0] + ') * (x_in - ' + j[0] + ') + (y_in - ' + j[1] + ') * (y_in - ' + j[1] + ')\n'
        s += '\ts_over_r = math.pow(s_sq, 0.5) / ' + j[3] + '\n'
        s += '\ttemp = (s_sq / ' + j[3] + ') / (1.0 + math.pow(1.0 - (' + j[2] + ' + 1.0) * s_over_r * s_over_r, 0.5)) + ' + j[4] + '\n'
        return s

    def SpecificCodeSCILAB(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read

        s += '\ts_sq = (x_in - ' + j[0] + ') * (x_in - ' + j[0] + ') + (y_in - ' + j[1] + ') * (y_in - ' + j[1] + ')\n'
        s += '\ts_over_r = pow(s_sq, 0.5) / ' + j[3] + '\n'
        s += '\ttemp = (s_sq / ' + j[3] + ') / (1.0 + pow(1.0 - (' + j[2] + ' + 1.0) * s_over_r * s_over_r, 0.5)) + ' + j[4] + '\n'
        return s

class SagForAsphere0_Borisovsky_X_LinearDecay_3D(SagForAsphere0_Borisovsky_3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class SagForAsphere0_Borisovsky_Y_LinearDecay_3D(SagForAsphere0_Borisovsky_3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class SagForAsphere0_Borisovsky_XY_LinearDecay_3D(SagForAsphere0_Borisovsky_3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class SagForAsphere0_Borisovsky_X_ExponentialDecay_3D(SagForAsphere0_Borisovsky_3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class SagForAsphere0_Borisovsky_Y_ExponentialDecay_3D(SagForAsphere0_Borisovsky_3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class SagForAsphere0_Borisovsky_XY_ExponentialDecay_3D(SagForAsphere0_Borisovsky_3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class SagForAsphere0_Borisovsky_X_LinearGrowth_3D(SagForAsphere0_Borisovsky_3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class SagForAsphere0_Borisovsky_Y_LinearGrowth_3D(SagForAsphere0_Borisovsky_3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class SagForAsphere0_Borisovsky_XY_LinearGrowth_3D(SagForAsphere0_Borisovsky_3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class SagForAsphere0_Borisovsky_X_ExponentialGrowth_3D(SagForAsphere0_Borisovsky_3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class SagForAsphere0_Borisovsky_Y_ExponentialGrowth_3D(SagForAsphere0_Borisovsky_3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class SagForAsphere0_Borisovsky_XY_ExponentialGrowth_3D(SagForAsphere0_Borisovsky_3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class SagForAsphere0_Borisovsky_X_LinearDecayAndOffset_3D(SagForAsphere0_Borisovsky_3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class SagForAsphere0_Borisovsky_Y_LinearDecayAndOffset_3D(SagForAsphere0_Borisovsky_3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class SagForAsphere0_Borisovsky_XY_LinearDecayAndOffset_3D(SagForAsphere0_Borisovsky_3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class SagForAsphere0_Borisovsky_X_ExponentialDecayAndOffset_3D(SagForAsphere0_Borisovsky_3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class SagForAsphere0_Borisovsky_Y_ExponentialDecayAndOffset_3D(SagForAsphere0_Borisovsky_3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class SagForAsphere0_Borisovsky_XY_ExponentialDecayAndOffset_3D(SagForAsphere0_Borisovsky_3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class SagForAsphere0_Borisovsky_X_LinearGrowthAndOffset_3D(SagForAsphere0_Borisovsky_3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class SagForAsphere0_Borisovsky_Y_LinearGrowthAndOffset_3D(SagForAsphere0_Borisovsky_3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class SagForAsphere0_Borisovsky_XY_LinearGrowthAndOffset_3D(SagForAsphere0_Borisovsky_3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class SagForAsphere0_Borisovsky_X_ExponentialGrowthAndOffset_3D(SagForAsphere0_Borisovsky_3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class SagForAsphere0_Borisovsky_Y_ExponentialGrowthAndOffset_3D(SagForAsphere0_Borisovsky_3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class SagForAsphere0_Borisovsky_XY_ExponentialGrowthAndOffset_3D(SagForAsphere0_Borisovsky_3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()
