#    pythonequations is a collection of equations expressed as Python classes
#    Copyright (C) 2008 James R. Phillips
#    2548 Vera Cruz Drive
#    Birmingham, AL 35235 USA
#    email: zunzun@zunzun.com
#
#    Version info: $Id$
#
#    License: BSD-style (see LICENSE.txt in main source directory)

import pythonequations, pythonequations.EquationBaseClasses, pythonequations.EquationsForPolyfunctionals
import numpy
numpy.seterr(all = 'raise') # numpy raises warnings, convert to exceptions to trap them

class Polyfunctional3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "User-Selectable Polyfunctional"
        self.HTML = "z = user-selectable function"
        self.coefficientDesignatorTuple = ()
        self.polyfunctionalFlag = 1
        self.LinearSSQSolverFlag = 1
        self.EquationListForPolyfunctional = []
        self.EquationListForPolyfunctional.append(pythonequations.EquationsForPolyfunctionals.GenerateList('x', 'x_in'))
        self.EquationListForPolyfunctional.append(pythonequations.EquationsForPolyfunctionals.GenerateList('y', 'y_in'))
        self.Polyfun3DEqList = pythonequations.EquationsForPolyfunctionals.GenerateList('unused', 'unused')

        self.function_cpp_code = 'temp = 0.0;\nfor (int k=0; k<numberOfCoefficients; k++)\n\ttemp += coeff[k] * indep_data[(int)cachedWeaveOffsets[k] + i];// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        for i in range(len(self.Polyfun3DFlags)):
            if self.Polyfun3DFlags[i][0] > 0 or self.Polyfun3DFlags[i][1] > 0:
                self.CacheGenerationList.append([self.CG_Polyfunctional3D(NameOrValueFlag=1, args=[self.Polyfun3DFlags[i][0], self.Polyfun3DFlags[i][1]]), [self.Polyfun3DFlags[i][0], self.Polyfun3DFlags[i][1]]])
        if [0,0] in self.Polyfun3DFlags:
            self.CacheGenerationList.append([self.CG_Polyfunctional3D(NameOrValueFlag=1, args=[0,0]), [0,0]])

    def GetSpecificJavascript(self):
        if self.SpecificJavascript == None:
            self.SpecificJavascript = self.ReadTextFile('FunctionMatrix3D.js')
        return self.SpecificJavascript

    def SpecificCodeCPP(self):
        s = ""
        count = 0
        for i in range(len(self.coefficientArray)):
            if self.Polyfun3DFlags[i][0] == 0 and self.Polyfun3DFlags[i][1] == 0:
                continue;
            if self.Polyfun3DFlags[i][0] > 0 and self.Polyfun3DFlags[i][1] == 0:
                s += "\ttemp += " + self.coefficientDesignatorTuple[count] + " * " + self.EquationListForPolyfunctional[0][self.Polyfun3DFlags[i][0]].CPP + ";\n"
            elif self.Polyfun3DFlags[i][0] == 0 and self.Polyfun3DFlags[i][1] > 0:
                s += "\ttemp += " + self.coefficientDesignatorTuple[count] + " * " + self.EquationListForPolyfunctional[1][self.Polyfun3DFlags[i][1]].CPP + ";\n"
            elif self.Polyfun3DFlags[i][0] > 0 and self.Polyfun3DFlags[i][1] > 0:
                s += "\ttemp += " + self.coefficientDesignatorTuple[count] + " * " + self.EquationListForPolyfunctional[0][self.Polyfun3DFlags[i][0]].CPP + " * " + self.EquationListForPolyfunctional[1][self.Polyfun3DFlags[i][1]].CPP + ";\n"
            count += 1
        if [0,0] in self.Polyfun3DFlags:
            s += "\ttemp += " + self.coefficientDesignatorTuple[count] + ";\n"
        return s

    def SpecificCodeJAVA(self):
        s = ""
        count = 0
        for i in range(len(self.coefficientArray)):
            if self.Polyfun3DFlags[i][0] == 0 and self.Polyfun3DFlags[i][1] == 0:
                continue;
            if self.Polyfun3DFlags[i][0] > 0 and self.Polyfun3DFlags[i][1] == 0:
                s += "\t\ttemp += " + self.coefficientDesignatorTuple[count] + " * " + self.EquationListForPolyfunctional[0][self.Polyfun3DFlags[i][0]].JAVA + ";\n"
            elif self.Polyfun3DFlags[i][0] == 0 and self.Polyfun3DFlags[i][1] > 0:
                s += "\t\ttemp += " + self.coefficientDesignatorTuple[count] + " * " + self.EquationListForPolyfunctional[1][self.Polyfun3DFlags[i][1]].JAVA + ";\n"
            elif self.Polyfun3DFlags[i][0] > 0 and self.Polyfun3DFlags[i][1] > 0:
                s += "\t\ttemp += " + self.coefficientDesignatorTuple[count] + " * " + self.EquationListForPolyfunctional[0][self.Polyfun3DFlags[i][0]].JAVA + " * " + self.EquationListForPolyfunctional[1][self.Polyfun3DFlags[i][1]].JAVA + ";\n"
            count += 1
        if [0,0] in self.Polyfun3DFlags:
            s += "\t\ttemp += " + self.coefficientDesignatorTuple[count] + ";\n"
        return s

    def SpecificCodeCS(self):
        s = ""
        count = 0
        for i in range(len(self.coefficientArray)):
            if self.Polyfun3DFlags[i][0] == 0 and self.Polyfun3DFlags[i][1] == 0:
                continue;
            if self.Polyfun3DFlags[i][0] > 0 and self.Polyfun3DFlags[i][1] == 0:
                s += "\t\ttemp += " + self.coefficientDesignatorTuple[count] + " * " + self.EquationListForPolyfunctional[0][self.Polyfun3DFlags[i][0]].CSHARP + ";\n"
            elif self.Polyfun3DFlags[i][0] == 0 and self.Polyfun3DFlags[i][1] > 0:
                s += "\t\ttemp += " + self.coefficientDesignatorTuple[count] + " * " + self.EquationListForPolyfunctional[1][self.Polyfun3DFlags[i][1]].CSHARP + ";\n"
            elif self.Polyfun3DFlags[i][0] > 0 and self.Polyfun3DFlags[i][1] > 0:
                s += "\t\ttemp += " + self.coefficientDesignatorTuple[count] + " * " + self.EquationListForPolyfunctional[0][self.Polyfun3DFlags[i][0]].CSHARP + " * " + self.EquationListForPolyfunctional[1][self.Polyfun3DFlags[i][1]].CSHARP + ";\n"
            count += 1
        if [0,0] in self.Polyfun3DFlags:
            s += "\t\ttemp += " + self.coefficientDesignatorTuple[count] + ";\n"
        return s

    def SpecificCodePYTHON(self):
        s = ""
        count = 0
        for i in range(len(self.coefficientArray)):
            if self.Polyfun3DFlags[i][0] == 0 and self.Polyfun3DFlags[i][1] == 0:
                continue;
            if self.Polyfun3DFlags[i][0] > 0 and self.Polyfun3DFlags[i][1] == 0:
                s += "\ttemp += " + self.coefficientDesignatorTuple[count] + " * " + self.EquationListForPolyfunctional[0][self.Polyfun3DFlags[i][0]].PYTHON + "\n"
            elif self.Polyfun3DFlags[i][0] == 0 and self.Polyfun3DFlags[i][1] > 0:
                s += "\ttemp += " + self.coefficientDesignatorTuple[count] + " * " + self.EquationListForPolyfunctional[1][self.Polyfun3DFlags[i][1]].PYTHON + "\n"
            elif self.Polyfun3DFlags[i][0] > 0 and self.Polyfun3DFlags[i][1] > 0:
                s += "\ttemp += " + self.coefficientDesignatorTuple[count] + " * " + self.EquationListForPolyfunctional[0][self.Polyfun3DFlags[i][0]].PYTHON + " * " + self.EquationListForPolyfunctional[1][self.Polyfun3DFlags[i][1]].PYTHON + "\n"
            count += 1
        if [0,0] in self.Polyfun3DFlags:
            s += "\ttemp += " + self.coefficientDesignatorTuple[count] + "\n"
        return s

    def SpecificCodeSCILAB(self):
        s = ""
        count = 0
        for i in range(len(self.coefficientArray)):
            if self.Polyfun3DFlags[i][0] == 0 and self.Polyfun3DFlags[i][1] == 0:
                continue;
            if self.Polyfun3DFlags[i][0] > 0 and self.Polyfun3DFlags[i][1] == 0:
                s += "\ttemp = temp + " + self.coefficientDesignatorTuple[count] + " * " + self.EquationListForPolyfunctional[0][self.Polyfun3DFlags[i][0]].SCILAB + "\n"
            elif self.Polyfun3DFlags[i][0] == 0 and self.Polyfun3DFlags[i][1] > 0:
                s += "\ttemp = temp + " + self.coefficientDesignatorTuple[count] + " * " + self.EquationListForPolyfunctional[1][self.Polyfun3DFlags[i][1]].SCILAB + "\n"
            elif self.Polyfun3DFlags[i][0] > 0 and self.Polyfun3DFlags[i][1] > 0:
                s += "\ttemp = temp + " + self.coefficientDesignatorTuple[count] + " * " + self.EquationListForPolyfunctional[0][self.Polyfun3DFlags[i][0]].SCILAB + " * " + self.EquationListForPolyfunctional[1][self.Polyfun3DFlags[i][1]].SCILAB + "\n"
            count += 1
        if [0,0] in self.Polyfun3DFlags:
            s += "\ttemp = temp + " + self.coefficientDesignatorTuple[count] + "\n"
        return s


    def Initialize(self):
        indexmax = len(self.Polyfun3DFlags)
        self.coefficientDesignatorTuple = ()
        for i in range(indexmax):
            self.coefficientDesignatorTuple += (pythonequations.EquationBaseClasses.Equation.ascii[i]),

        pythonequations.EquationBaseClasses.Equation3D.Initialize(self)

        self.RequiresNonzeroX = 0
        self.RequiresPositiveX = 0
        self.RequiresNonzeroY = 0
        self.RequiresPositiveY = 0
        for i in range(indexmax):
            self.RequiresNonzeroX |= self.EquationListForPolyfunctional[0][self.Polyfun3DFlags[i][0]].RequiresNonzero
            self.RequiresPositiveX |= self.EquationListForPolyfunctional[0][self.Polyfun3DFlags[i][0]].RequiresPositive
            self.RequiresNonzeroY |= self.EquationListForPolyfunctional[1][self.Polyfun3DFlags[i][1]].RequiresNonzero
            self.RequiresPositiveY |= self.EquationListForPolyfunctional[1][self.Polyfun3DFlags[i][1]].RequiresPositive


    def RegenerateForm(self):
        #print "3d regen, flags =", self.Polyfun3DFlags
        self.coefficientDesignatorTuple = ()
        if len(self.Polyfun3DFlags) == 0:
            self.HTML = "z = user-selectable function"
            return
        
        for i in range(len(self.Polyfun3DFlags)-1):
            self.coefficientDesignatorTuple += (pythonequations.EquationBaseClasses.Equation.ascii[i]),
        if [0,0] in self.Polyfun3DFlags:
            self.coefficientDesignatorTuple += ('offset'),
        else:
            self.coefficientDesignatorTuple += (pythonequations.EquationBaseClasses.Equation.ascii[len(self.Polyfun3DFlags)-1]),

        self.HTML = "</B><B>z = " # turn off any preceding bolding
        count = 0
        for i in range(len(self.Polyfun3DFlags)):
            if self.Polyfun3DFlags[i][0] == 0 and self.Polyfun3DFlags[i][1] == 0:
                continue
            elif self.Polyfun3DFlags[i][0] > 0 and self.Polyfun3DFlags[i][1] == 0:
                self.HTML += pythonequations.EquationBaseClasses.Equation.ascii[count] + '(</B>&nbsp;' + self.EquationListForPolyfunctional[0][self.Polyfun3DFlags[i][0]].HTML + '&nbsp;<B>)'
            elif self.Polyfun3DFlags[i][0] == 0 and self.Polyfun3DFlags[i][1] > 0:
                self.HTML += pythonequations.EquationBaseClasses.Equation.ascii[count] + '(</B>&nbsp;' + self.EquationListForPolyfunctional[1][self.Polyfun3DFlags[i][1]].HTML + '&nbsp;<B>)'
            else:
                self.HTML += pythonequations.EquationBaseClasses.Equation.ascii[count] + '(</B>&nbsp;' + self.EquationListForPolyfunctional[0][self.Polyfun3DFlags[i][0]].HTML + self.EquationListForPolyfunctional[1][self.Polyfun3DFlags[i][1]].HTML + '&nbsp;<B>)'
            if i < len(self.Polyfun3DFlags)-1 or [0,0] in self.Polyfun3DFlags:
                self.HTML += ' + '
            count += 1

        if [0,0] in self.Polyfun3DFlags:
            self.HTML += "offset"

        self.HTML += '</B>'
