#    pythonequations is a collection of equations expressed as Python classes
#    Copyright (C) 2008 James R. Phillips
#    2548 Vera Cruz Drive
#    Birmingham, AL 35235 USA
#    email: zunzun@zunzun.com
#
#    Version info: $Id$
#
#    License: BSD-style (see LICENSE.txt in main source directory)

import pythonequations, pythonequations.EquationBaseClasses
import numpy
numpy.seterr(all = 'raise') # numpy raises warnings, convert to exceptions to trap them

class PowerA3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Power A"
        self.HTML = "z = a * (x<SUP>b</SUP> + y<SUP>c</SUP>)"
        self.coefficientDesignatorTuple = ("a", "b", "c")
        self.RequiresPositiveX = 1
        self.RequiresPositiveY = 1

        self.function_cpp_code = 'temp = coeff[0] * (pow(indep_data[(int)cachedWeaveOffsets[1] + i], coeff[1]) + pow(indep_data[(int)cachedWeaveOffsets[2] + i], coeff[2]));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Y(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a * (pow(x_in, b) + pow(y_in, c));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a * (Math.pow(x_in, b) + Math.pow(y_in, c));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a * (Math.Pow(x_in, b) + Math.Pow(y_in, c));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = a * (math.pow(x_in, b) + math.pow(y_in, c))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = a * ((x_in ^ b) + (y_in ^ c))\n"
        return s


class PowerA_WO_3D(PowerA3D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class PowerA_X_LinearDecay_3D(PowerA3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class PowerA_Y_LinearDecay_3D(PowerA3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class PowerA_XY_LinearDecay_3D(PowerA3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class PowerA_X_ExponentialDecay_3D(PowerA3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class PowerA_Y_ExponentialDecay_3D(PowerA3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class PowerA_XY_ExponentialDecay_3D(PowerA3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class PowerA_X_LinearGrowth_3D(PowerA3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class PowerA_Y_LinearGrowth_3D(PowerA3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class PowerA_XY_LinearGrowth_3D(PowerA3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class PowerA_X_ExponentialGrowth_3D(PowerA3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class PowerA_Y_ExponentialGrowth_3D(PowerA3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class PowerA_XY_ExponentialGrowth_3D(PowerA3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class PowerA_X_LinearDecayAndOffset_3D(PowerA3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class PowerA_Y_LinearDecayAndOffset_3D(PowerA3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class PowerA_XY_LinearDecayAndOffset_3D(PowerA3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class PowerA_X_ExponentialDecayAndOffset_3D(PowerA3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class PowerA_Y_ExponentialDecayAndOffset_3D(PowerA3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class PowerA_XY_ExponentialDecayAndOffset_3D(PowerA3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class PowerA_X_LinearGrowthAndOffset_3D(PowerA3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class PowerA_Y_LinearGrowthAndOffset_3D(PowerA3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class PowerA_XY_LinearGrowthAndOffset_3D(PowerA3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class PowerA_X_ExponentialGrowthAndOffset_3D(PowerA3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class PowerA_Y_ExponentialGrowthAndOffset_3D(PowerA3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class PowerA_XY_ExponentialGrowthAndOffset_3D(PowerA3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()


class PowerA_Transform3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Power A Transform"
        self.HTML = "z = a * ((dx + e)<SUP>b</SUP> + (fy + g)<SUP>c</SUP>)"
        self.coefficientDesignatorTuple = ("a", "b", "c", 'd', 'e', 'f', 'g')

        self.function_cpp_code = 'temp = coeff[0] * (pow(coeff[3] * indep_data[(int)cachedWeaveOffsets[0] + i] + coeff[4], coeff[1]) + pow(coeff[5] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[6], coeff[2]));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Y(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a * (pow(d * x_in + e, b) + pow(f * y_in + g, c));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a * (Math.pow(d * x_in + e, b) + Math.pow(f * y_in + g, c));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a * (Math.Pow(d * x_in + e, b) + Math.Pow(f * y_in + g, c));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = a * (math.pow(d * x_in + e, b) + math.pow(f * y_in + g, c))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = a * (((d * x_in + e) ^ b) + ((f * y_in + g) ^ c))\n"
        return s


class PowerA_Transform_WO_3D(PowerA_Transform3D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class PowerA_Transform_X_LinearDecay_3D(PowerA_Transform3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class PowerA_Transform_Y_LinearDecay_3D(PowerA_Transform3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class PowerA_Transform_XY_LinearDecay_3D(PowerA_Transform3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class PowerA_Transform_X_ExponentialDecay_3D(PowerA_Transform3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class PowerA_Transform_Y_ExponentialDecay_3D(PowerA_Transform3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class PowerA_Transform_XY_ExponentialDecay_3D(PowerA_Transform3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class PowerA_Transform_X_LinearGrowth_3D(PowerA_Transform3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class PowerA_Transform_Y_LinearGrowth_3D(PowerA_Transform3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class PowerA_Transform_XY_LinearGrowth_3D(PowerA_Transform3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class PowerA_Transform_X_ExponentialGrowth_3D(PowerA_Transform3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class PowerA_Transform_Y_ExponentialGrowth_3D(PowerA_Transform3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class PowerA_Transform_XY_ExponentialGrowth_3D(PowerA_Transform3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class PowerA_Transform_X_LinearDecayAndOffset_3D(PowerA_Transform3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class PowerA_Transform_Y_LinearDecayAndOffset_3D(PowerA_Transform3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class PowerA_Transform_XY_LinearDecayAndOffset_3D(PowerA_Transform3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class PowerA_Transform_X_ExponentialDecayAndOffset_3D(PowerA_Transform3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class PowerA_Transform_Y_ExponentialDecayAndOffset_3D(PowerA_Transform3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class PowerA_Transform_XY_ExponentialDecayAndOffset_3D(PowerA_Transform3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class PowerA_Transform_X_LinearGrowthAndOffset_3D(PowerA_Transform3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class PowerA_Transform_Y_LinearGrowthAndOffset_3D(PowerA_Transform3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class PowerA_Transform_XY_LinearGrowthAndOffset_3D(PowerA_Transform3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class PowerA_Transform_X_ExponentialGrowthAndOffset_3D(PowerA_Transform3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class PowerA_Transform_Y_ExponentialGrowthAndOffset_3D(PowerA_Transform3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class PowerA_Transform_XY_ExponentialGrowthAndOffset_3D(PowerA_Transform3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()


class PowerB3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Power B"
        self.HTML = "z = a + x<SUP>b</SUP> + y<SUP>c</SUP>"
        self.coefficientDesignatorTuple = ("a", "b", "c")
        self.RequiresPositiveX = 1
        self.RequiresPositiveY = 1

        self.function_cpp_code = 'temp = coeff[0] + pow(indep_data[(int)cachedWeaveOffsets[1] + i], coeff[1]) + pow(indep_data[(int)cachedWeaveOffsets[2] + i], coeff[2]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Y(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a + pow(x_in, b) + pow(y_in, c);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a + Math.pow(x_in, b) + Math.pow(y_in, c);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a + Math.Pow(x_in, b) + Math.Pow(y_in, c);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = a + math.pow(x_in, b) + math.pow(y_in, c)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = a + (x_in ^ b) + (y_in ^ c)\n"
        return s


class PowerB_X_LinearDecay_3D(PowerB3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class PowerB_Y_LinearDecay_3D(PowerB3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class PowerB_XY_LinearDecay_3D(PowerB3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class PowerB_X_ExponentialDecay_3D(PowerB3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class PowerB_Y_ExponentialDecay_3D(PowerB3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class PowerB_XY_ExponentialDecay_3D(PowerB3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class PowerB_X_LinearGrowth_3D(PowerB3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class PowerB_Y_LinearGrowth_3D(PowerB3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class PowerB_XY_LinearGrowth_3D(PowerB3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class PowerB_X_ExponentialGrowth_3D(PowerB3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class PowerB_Y_ExponentialGrowth_3D(PowerB3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class PowerB_XY_ExponentialGrowth_3D(PowerB3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class PowerB_X_LinearDecayAndOffset_3D(PowerB3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class PowerB_Y_LinearDecayAndOffset_3D(PowerB3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class PowerB_XY_LinearDecayAndOffset_3D(PowerB3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class PowerB_X_ExponentialDecayAndOffset_3D(PowerB3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class PowerB_Y_ExponentialDecayAndOffset_3D(PowerB3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class PowerB_XY_ExponentialDecayAndOffset_3D(PowerB3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class PowerB_X_LinearGrowthAndOffset_3D(PowerB3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class PowerB_Y_LinearGrowthAndOffset_3D(PowerB3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class PowerB_XY_LinearGrowthAndOffset_3D(PowerB3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class PowerB_X_ExponentialGrowthAndOffset_3D(PowerB3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class PowerB_Y_ExponentialGrowthAndOffset_3D(PowerB3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class PowerB_XY_ExponentialGrowthAndOffset_3D(PowerB3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()


class PowerB_Transform3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Power B Transform"
        self.HTML = "z = a + (dx + e)<SUP>b</SUP> + (fy + g)<SUP>c</SUP>"
        self.coefficientDesignatorTuple = ("a", "b", "c", 'd', 'e', 'f', 'g')

        self.function_cpp_code = 'temp = coeff[0] + pow(coeff[3] * indep_data[(int)cachedWeaveOffsets[0] + i] + coeff[4], coeff[1]) + pow(coeff[5] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[6], coeff[2]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Y(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a + pow(d * x_in + e, b) + pow(f * y_in + g, c);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a + Math.pow(d * x_in + e, b) + Math.pow(f * y_in + g, c);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a + Math.Pow(d * x_in + e, b) + Math.Pow(f * y_in + g, c);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = a + math.pow(d * x_in + e, b) + math.pow(f * y_in + g, c)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = a + ((d * x_in + e) ^ b) + ((f * y_in + g) ^ c)\n"
        return s


class PowerB_Transform_X_LinearDecay_3D(PowerB_Transform3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class PowerB_Transform_Y_LinearDecay_3D(PowerB_Transform3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class PowerB_Transform_XY_LinearDecay_3D(PowerB_Transform3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class PowerB_Transform_X_ExponentialDecay_3D(PowerB_Transform3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class PowerB_Transform_Y_ExponentialDecay_3D(PowerB_Transform3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class PowerB_Transform_XY_ExponentialDecay_3D(PowerB_Transform3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class PowerB_Transform_X_LinearGrowth_3D(PowerB_Transform3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class PowerB_Transform_Y_LinearGrowth_3D(PowerB_Transform3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class PowerB_Transform_XY_LinearGrowth_3D(PowerB_Transform3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class PowerB_Transform_X_ExponentialGrowth_3D(PowerB_Transform3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class PowerB_Transform_Y_ExponentialGrowth_3D(PowerB_Transform3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class PowerB_Transform_XY_ExponentialGrowth_3D(PowerB_Transform3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class PowerB_Transform_X_LinearDecayAndOffset_3D(PowerB_Transform3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class PowerB_Transform_Y_LinearDecayAndOffset_3D(PowerB_Transform3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class PowerB_Transform_XY_LinearDecayAndOffset_3D(PowerB_Transform3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class PowerB_Transform_X_ExponentialDecayAndOffset_3D(PowerB_Transform3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class PowerB_Transform_Y_ExponentialDecayAndOffset_3D(PowerB_Transform3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class PowerB_Transform_XY_ExponentialDecayAndOffset_3D(PowerB_Transform3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class PowerB_Transform_X_LinearGrowthAndOffset_3D(PowerB_Transform3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class PowerB_Transform_Y_LinearGrowthAndOffset_3D(PowerB_Transform3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class PowerB_Transform_XY_LinearGrowthAndOffset_3D(PowerB_Transform3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class PowerB_Transform_X_ExponentialGrowthAndOffset_3D(PowerB_Transform3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class PowerB_Transform_Y_ExponentialGrowthAndOffset_3D(PowerB_Transform3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class PowerB_Transform_XY_ExponentialGrowthAndOffset_3D(PowerB_Transform3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()


class PowerC3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Power C"
        self.HTML = "z = a + x<SUP>b</SUP> * y<SUP>c</SUP>"
        self.coefficientDesignatorTuple = ("a", "b", "c")
        self.RequiresPositiveX = 1
        self.RequiresPositiveY = 1

        self.function_cpp_code = 'temp = coeff[0] + pow(indep_data[(int)cachedWeaveOffsets[1] + i], coeff[1]) * pow(indep_data[(int)cachedWeaveOffsets[2] + i], coeff[2]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Y(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a + pow(x_in, b) * pow(y_in, c);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a + Math.pow(x_in, b) * Math.pow(y_in, c);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a + Math.Pow(x_in, b) * Math.Pow(y_in, c);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = a + math.pow(x_in, b) * math.pow(y_in, c)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = a + (x_in ^ b) * (y_in ^ c)\n"
        return s


class PowerC_X_LinearDecay_3D(PowerC3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class PowerC_Y_LinearDecay_3D(PowerC3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class PowerC_XY_LinearDecay_3D(PowerC3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class PowerC_X_ExponentialDecay_3D(PowerC3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class PowerC_Y_ExponentialDecay_3D(PowerC3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class PowerC_XY_ExponentialDecay_3D(PowerC3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class PowerC_X_LinearGrowth_3D(PowerC3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class PowerC_Y_LinearGrowth_3D(PowerC3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class PowerC_XY_LinearGrowth_3D(PowerC3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class PowerC_X_ExponentialGrowth_3D(PowerC3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class PowerC_Y_ExponentialGrowth_3D(PowerC3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class PowerC_XY_ExponentialGrowth_3D(PowerC3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class PowerC_X_LinearDecayAndOffset_3D(PowerC3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class PowerC_Y_LinearDecayAndOffset_3D(PowerC3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class PowerC_XY_LinearDecayAndOffset_3D(PowerC3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class PowerC_X_ExponentialDecayAndOffset_3D(PowerC3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class PowerC_Y_ExponentialDecayAndOffset_3D(PowerC3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class PowerC_XY_ExponentialDecayAndOffset_3D(PowerC3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class PowerC_X_LinearGrowthAndOffset_3D(PowerC3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class PowerC_Y_LinearGrowthAndOffset_3D(PowerC3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class PowerC_XY_LinearGrowthAndOffset_3D(PowerC3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class PowerC_X_ExponentialGrowthAndOffset_3D(PowerC3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class PowerC_Y_ExponentialGrowthAndOffset_3D(PowerC3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class PowerC_XY_ExponentialGrowthAndOffset_3D(PowerC3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()


class PowerC_Transform3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Power C Transform"
        self.HTML = "z = a + (dx + e)<SUP>b</SUP> * (fy + g)<SUP>c</SUP>"
        self.coefficientDesignatorTuple = ("a", "b", "c", 'd', 'e', 'f', 'g')

        self.function_cpp_code = 'temp = coeff[0] + pow(coeff[3] * indep_data[(int)cachedWeaveOffsets[0] + i] + coeff[4], coeff[1]) * pow(coeff[5] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[6], coeff[2]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Y(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a + pow(d * x_in + e, b) * pow(f * y_in + g, c);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a + Math.pow(d * x_in + e, b) * Math.powf * y_in + g, c);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a + Math.Pow(d * x_in + e, b) * Math.Pow(f * y_in + g, c);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = a + math.pow(d * x_in + e, b) * math.pow(f * y_in + g, c)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = a + ((d * x_in + e) ^ b) * ((f * y_in + g) ^ c)\n"
        return s


class PowerC_Transform_X_LinearDecay_3D(PowerC_Transform3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class PowerC_Transform_Y_LinearDecay_3D(PowerC_Transform3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class PowerC_Transform_XY_LinearDecay_3D(PowerC_Transform3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class PowerC_Transform_X_ExponentialDecay_3D(PowerC_Transform3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class PowerC_Transform_Y_ExponentialDecay_3D(PowerC_Transform3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class PowerC_Transform_XY_ExponentialDecay_3D(PowerC_Transform3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class PowerC_Transform_X_LinearGrowth_3D(PowerC_Transform3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class PowerC_Transform_Y_LinearGrowth_3D(PowerC_Transform3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class PowerC_Transform_XY_LinearGrowth_3D(PowerC_Transform3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class PowerC_Transform_X_ExponentialGrowth_3D(PowerC_Transform3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class PowerC_Transform_Y_ExponentialGrowth_3D(PowerC_Transform3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class PowerC_Transform_XY_ExponentialGrowth_3D(PowerC_Transform3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class PowerC_Transform_X_LinearDecayAndOffset_3D(PowerC_Transform3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class PowerC_Transform_Y_LinearDecayAndOffset_3D(PowerC_Transform3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class PowerC_Transform_XY_LinearDecayAndOffset_3D(PowerC_Transform3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class PowerC_Transform_X_ExponentialDecayAndOffset_3D(PowerC_Transform3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class PowerC_Transform_Y_ExponentialDecayAndOffset_3D(PowerC_Transform3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class PowerC_Transform_XY_ExponentialDecayAndOffset_3D(PowerC_Transform3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class PowerC_Transform_X_LinearGrowthAndOffset_3D(PowerC_Transform3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class PowerC_Transform_Y_LinearGrowthAndOffset_3D(PowerC_Transform3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class PowerC_Transform_XY_LinearGrowthAndOffset_3D(PowerC_Transform3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class PowerC_Transform_X_ExponentialGrowthAndOffset_3D(PowerC_Transform3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class PowerC_Transform_Y_ExponentialGrowthAndOffset_3D(PowerC_Transform3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class PowerC_Transform_XY_ExponentialGrowthAndOffset_3D(PowerC_Transform3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()


class PowerD3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Power D"
        self.HTML = "z = ax<SUP>b</SUP> + cy<SUP>d</SUP>"
        self.coefficientDesignatorTuple = ("a", "b", "c", "d")
        self.RequiresPositiveX = 1
        self.RequiresPositiveY = 1

        self.function_cpp_code = 'temp = coeff[0] * pow(indep_data[(int)cachedWeaveOffsets[1] + i], coeff[1]) + coeff[2] * pow(indep_data[(int)cachedWeaveOffsets[2] + i], coeff[3]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Y(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a * pow(x_in, b) + c * pow(y_in, d);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a * Math.pow(x_in, b) + c * Math.pow(y_in, d);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a * Math.Pow(x_in, b) + c * Math.Pow(y_in, d);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = a * math.pow(x_in, b) + c * math.pow(y_in, d)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = a * (x_in ^ b) + c * (y_in ^ d)\n"
        return s


class PowerD_WO_3D(PowerD3D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class PowerD_X_LinearDecay_3D(PowerD3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class PowerD_Y_LinearDecay_3D(PowerD3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class PowerD_XY_LinearDecay_3D(PowerD3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class PowerD_X_ExponentialDecay_3D(PowerD3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class PowerD_Y_ExponentialDecay_3D(PowerD3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class PowerD_XY_ExponentialDecay_3D(PowerD3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class PowerD_X_LinearGrowth_3D(PowerD3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class PowerD_Y_LinearGrowth_3D(PowerD3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class PowerD_XY_LinearGrowth_3D(PowerD3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class PowerD_X_ExponentialGrowth_3D(PowerD3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class PowerD_Y_ExponentialGrowth_3D(PowerD3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class PowerD_XY_ExponentialGrowth_3D(PowerD3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class PowerD_X_LinearDecayAndOffset_3D(PowerD3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class PowerD_Y_LinearDecayAndOffset_3D(PowerD3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class PowerD_XY_LinearDecayAndOffset_3D(PowerD3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class PowerD_X_ExponentialDecayAndOffset_3D(PowerD3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class PowerD_Y_ExponentialDecayAndOffset_3D(PowerD3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class PowerD_XY_ExponentialDecayAndOffset_3D(PowerD3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class PowerD_X_LinearGrowthAndOffset_3D(PowerD3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class PowerD_Y_LinearGrowthAndOffset_3D(PowerD3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class PowerD_XY_LinearGrowthAndOffset_3D(PowerD3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class PowerD_X_ExponentialGrowthAndOffset_3D(PowerD3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class PowerD_Y_ExponentialGrowthAndOffset_3D(PowerD3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class PowerD_XY_ExponentialGrowthAndOffset_3D(PowerD3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()


class PowerD_Transform3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Power D Transform"
        self.HTML = "z = a(ex + f)<SUP>b</SUP> + c(gy + h)<SUP>d</SUP>"
        self.coefficientDesignatorTuple = ("a", "b", "c", "d", 'e', 'f', 'g', 'h')

        self.function_cpp_code = 'temp = coeff[0] * pow(coeff[4] * indep_data[(int)cachedWeaveOffsets[0] + i] + coeff[5], coeff[1]) + coeff[2] * pow(coeff[6] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[7], coeff[3]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Y(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a * pow(e * x_in + f, b) + c * pow(g * y_in + h, d);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = a * Math.pow(e * x_in + f, b) + c * Math.pow(g * y_in + h, d);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a * Math.Pow(e * x_in + f, b) + c * Math.Pow(g * y_in + h, d);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = a * math.pow(e * x_in + f, b) + c * math.pow(g * y_in + h, d)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = a * ((e * x_in + f) ^ b) + c * ((g * y_in + h) ^ d)\n"
        return s


class PowerD_Transform_WO_3D(PowerD_Transform3D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class PowerD_Transform_X_LinearDecay_3D(PowerD_Transform3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class PowerD_Transform_Y_LinearDecay_3D(PowerD_Transform3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class PowerD_Transform_XY_LinearDecay_3D(PowerD_Transform3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class PowerD_Transform_X_ExponentialDecay_3D(PowerD_Transform3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class PowerD_Transform_Y_ExponentialDecay_3D(PowerD_Transform3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class PowerD_Transform_XY_ExponentialDecay_3D(PowerD_Transform3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class PowerD_Transform_X_LinearGrowth_3D(PowerD_Transform3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class PowerD_Transform_Y_LinearGrowth_3D(PowerD_Transform3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class PowerD_Transform_XY_LinearGrowth_3D(PowerD_Transform3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class PowerD_Transform_X_ExponentialGrowth_3D(PowerD_Transform3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class PowerD_Transform_Y_ExponentialGrowth_3D(PowerD_Transform3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class PowerD_Transform_XY_ExponentialGrowth_3D(PowerD_Transform3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class PowerD_Transform_X_LinearDecayAndOffset_3D(PowerD_Transform3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class PowerD_Transform_Y_LinearDecayAndOffset_3D(PowerD_Transform3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class PowerD_Transform_XY_LinearDecayAndOffset_3D(PowerD_Transform3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class PowerD_Transform_X_ExponentialDecayAndOffset_3D(PowerD_Transform3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class PowerD_Transform_Y_ExponentialDecayAndOffset_3D(PowerD_Transform3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class PowerD_Transform_XY_ExponentialDecayAndOffset_3D(PowerD_Transform3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class PowerD_Transform_X_LinearGrowthAndOffset_3D(PowerD_Transform3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class PowerD_Transform_Y_LinearGrowthAndOffset_3D(PowerD_Transform3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class PowerD_Transform_XY_LinearGrowthAndOffset_3D(PowerD_Transform3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class PowerD_Transform_X_ExponentialGrowthAndOffset_3D(PowerD_Transform3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class PowerD_Transform_Y_ExponentialGrowthAndOffset_3D(PowerD_Transform3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class PowerD_Transform_XY_ExponentialGrowthAndOffset_3D(PowerD_Transform3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()
