#    pythonequations is a collection of equations expressed as Python classes
#    Copyright (C) 2008 James R. Phillips
#    2548 Vera Cruz Drive
#    Birmingham, AL 35235 USA
#    email: zunzun@zunzun.com
#
#    Version info: $Id$
#
#    License: BSD-style (see LICENSE.txt in main source directory)

import pythonequations, pythonequations.EquationBaseClasses
import numpy
numpy.seterr(all = 'raise') # numpy raises warnings, convert to exceptions to trap them

class RationalA3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Rational A"
        self.HTML = "z = (a + bx + cy)/(1 + dx + ey)"
        self.coefficientDesignatorTuple = ("a", "b", "c", "d", "e")

        self.function_cpp_code = 'temp = (coeff[0] + coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[2] * indep_data[(int)cachedWeaveOffsets[2] + i]) / (1.0 + coeff[3] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[4] * indep_data[(int)cachedWeaveOffsets[2] + i]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Y(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp  = (a + b*x_in + c*y_in) / (1.0 + d*x_in + e*y_in);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp  = (a + b*x_in + c*y_in) / (1.0 + d*x_in + e*y_in);\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp  = (a + b*x_in + c*y_in) / (1.0 + d*x_in + e*y_in);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = (a + b*x_in + c*y_in) / (1.0 + d*x_in + e*y_in)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = (a + b*x_in + c*y_in) / (1.0 + d*x_in + e*y_in)\n"
        return s


class RationalA_WO_3D(RationalA3D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class RationalA_X_LinearDecay_3D(RationalA3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class RationalA_Y_LinearDecay_3D(RationalA3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class RationalA_XY_LinearDecay_3D(RationalA3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class RationalA_X_ExponentialDecay_3D(RationalA3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class RationalA_Y_ExponentialDecay_3D(RationalA3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class RationalA_XY_ExponentialDecay_3D(RationalA3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class RationalA_X_LinearGrowth_3D(RationalA3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class RationalA_Y_LinearGrowth_3D(RationalA3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class RationalA_XY_LinearGrowth_3D(RationalA3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class RationalA_X_ExponentialGrowth_3D(RationalA3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class RationalA_Y_ExponentialGrowth_3D(RationalA3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class RationalA_XY_ExponentialGrowth_3D(RationalA3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class RationalA_X_LinearDecayAndOffset_3D(RationalA3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class RationalA_Y_LinearDecayAndOffset_3D(RationalA3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class RationalA_XY_LinearDecayAndOffset_3D(RationalA3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class RationalA_X_ExponentialDecayAndOffset_3D(RationalA3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class RationalA_Y_ExponentialDecayAndOffset_3D(RationalA3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class RationalA_XY_ExponentialDecayAndOffset_3D(RationalA3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class RationalA_X_LinearGrowthAndOffset_3D(RationalA3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class RationalA_Y_LinearGrowthAndOffset_3D(RationalA3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class RationalA_XY_LinearGrowthAndOffset_3D(RationalA3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class RationalA_X_ExponentialGrowthAndOffset_3D(RationalA3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class RationalA_Y_ExponentialGrowthAndOffset_3D(RationalA3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class RationalA_XY_ExponentialGrowthAndOffset_3D(RationalA3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()


class RationalB3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Rational B"
        self.HTML = "z = (a + b*ln(x) + c*ln(y))/(1 + dx + ey)"
        self.coefficientDesignatorTuple = ("a", "b", "c", "d", "e")
        self.RequiresPositiveX = 1
        self.RequiresPositiveY = 1

        self.function_cpp_code = 'temp = (coeff[0] + coeff[1] * indep_data[(int)cachedWeaveOffsets[3] + i] + coeff[2] * indep_data[(int)cachedWeaveOffsets[4] + i]) / (1.0 + coeff[3] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[4] * indep_data[(int)cachedWeaveOffsets[2] + i]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Y(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogX(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogY(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = (a + b*log(x_in) + c*log(y_in)) / (1.0 + d*x_in + e*y_in);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\ttemp = (a + b*Math.log(x_in) + c*Math.log(y_in)) / (1.0 + d*x_in + e*y_in);\n"
        return s

    def SpecificCodeCS(self):
        s = "\ttemp = (a + b*Math.Log(x_in) + c*Math.Log(y_in)) / (1.0 + d*x_in + e*y_in);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = (a + b*math.log(x_in) + c*math.log(y_in)) / (1.0 + d*x_in + e*y_in)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = (a + b*log(x_in) + c*log(y_in)) / (1.0 + d*x_in + e*y_in)\n"
        return s


class RationalB_WO_3D(RationalB3D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class RationalB_X_LinearDecay_3D(RationalB3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class RationalB_Y_LinearDecay_3D(RationalB3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class RationalB_XY_LinearDecay_3D(RationalB3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class RationalB_X_ExponentialDecay_3D(RationalB3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class RationalB_Y_ExponentialDecay_3D(RationalB3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class RationalB_XY_ExponentialDecay_3D(RationalB3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class RationalB_X_LinearGrowth_3D(RationalB3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class RationalB_Y_LinearGrowth_3D(RationalB3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class RationalB_XY_LinearGrowth_3D(RationalB3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class RationalB_X_ExponentialGrowth_3D(RationalB3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class RationalB_Y_ExponentialGrowth_3D(RationalB3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class RationalB_XY_ExponentialGrowth_3D(RationalB3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class RationalB_X_LinearDecayAndOffset_3D(RationalB3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class RationalB_Y_LinearDecayAndOffset_3D(RationalB3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class RationalB_XY_LinearDecayAndOffset_3D(RationalB3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class RationalB_X_ExponentialDecayAndOffset_3D(RationalB3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class RationalB_Y_ExponentialDecayAndOffset_3D(RationalB3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class RationalB_XY_ExponentialDecayAndOffset_3D(RationalB3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class RationalB_X_LinearGrowthAndOffset_3D(RationalB3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class RationalB_Y_LinearGrowthAndOffset_3D(RationalB3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class RationalB_XY_LinearGrowthAndOffset_3D(RationalB3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class RationalB_X_ExponentialGrowthAndOffset_3D(RationalB3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class RationalB_Y_ExponentialGrowthAndOffset_3D(RationalB3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class RationalB_XY_ExponentialGrowthAndOffset_3D(RationalB3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()


class RationalC3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Rational C"
        self.HTML = "z = (a + bx + cy)/(1 + d*ln(x) + e*ln(y))"
        self.coefficientDesignatorTuple = ("a", "b", "c", "d", "e")
        self.RequiresPositiveX = 1
        self.RequiresPositiveY = 1

        self.function_cpp_code = 'temp = (coeff[0] + coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[2] * indep_data[(int)cachedWeaveOffsets[2] + i]) / (1.0 + coeff[3] * indep_data[(int)cachedWeaveOffsets[3] + i] + coeff[4] * indep_data[(int)cachedWeaveOffsets[4] + i]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Y(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogX(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogY(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp  = (a + b*x_in + c*y_in) / (1.0 + d*log(x_in) + e*log(y_in));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp  = (a + b*x_in + c*y_in) / (1.0 + d*Math.log(x_in) + e*Math.log(y_in));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp  = (a + b*x_in + c*y_in) / (1.0 + d*Math.Log(x_in) + e*Math.Log(y_in));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp  = (a + b*x_in + c*y_in) / (1.0 + d*math.log(x_in) + e*math.log(y_in))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = (a + b*x_in + c*y_in) / (1.0 + d*log(x_in) + e*log(y_in))\n"
        return s


class RationalC_WO_3D(RationalC3D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class RationalC_X_LinearDecay_3D(RationalC3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class RationalC_Y_LinearDecay_3D(RationalC3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class RationalC_XY_LinearDecay_3D(RationalC3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class RationalC_X_ExponentialDecay_3D(RationalC3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class RationalC_Y_ExponentialDecay_3D(RationalC3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class RationalC_XY_ExponentialDecay_3D(RationalC3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class RationalC_X_LinearGrowth_3D(RationalC3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class RationalC_Y_LinearGrowth_3D(RationalC3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class RationalC_XY_LinearGrowth_3D(RationalC3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class RationalC_X_ExponentialGrowth_3D(RationalC3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class RationalC_Y_ExponentialGrowth_3D(RationalC3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class RationalC_XY_ExponentialGrowth_3D(RationalC3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class RationalC_X_LinearDecayAndOffset_3D(RationalC3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class RationalC_Y_LinearDecayAndOffset_3D(RationalC3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class RationalC_XY_LinearDecayAndOffset_3D(RationalC3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class RationalC_X_ExponentialDecayAndOffset_3D(RationalC3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class RationalC_Y_ExponentialDecayAndOffset_3D(RationalC3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class RationalC_XY_ExponentialDecayAndOffset_3D(RationalC3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class RationalC_X_LinearGrowthAndOffset_3D(RationalC3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class RationalC_Y_LinearGrowthAndOffset_3D(RationalC3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class RationalC_XY_LinearGrowthAndOffset_3D(RationalC3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class RationalC_X_ExponentialGrowthAndOffset_3D(RationalC3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class RationalC_Y_ExponentialGrowthAndOffset_3D(RationalC3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class RationalC_XY_ExponentialGrowthAndOffset_3D(RationalC3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()


class RationalD3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Rational D"
        self.HTML = "z = (a + b*ln(x) + c*ln(y))/(1 + d*ln(x) + e*ln(y))"
        self.coefficientDesignatorTuple = ("a", "b", "c", "d", "e")
        self.RequiresPositiveX = 1
        self.RequiresPositiveY = 1

        self.function_cpp_code = 'temp = (coeff[0] + coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[2] * indep_data[(int)cachedWeaveOffsets[2] + i]) / (1.0 + coeff[3] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[4] * indep_data[(int)cachedWeaveOffsets[2] + i]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogX(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_LogY(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp  = (a + b*log(x_in) + c*log(y_in)) / (1.0 + d*log(x_in) + e*log(y_in));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp  = (a + b*Math.log(x_in) + c*Math.log(y_in)) / (1.0 + d*Math.log(x_in) + e*Math.log(y_in));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp  = (a + b*Math.Log(x_in) + c*Math.Log(y_in)) / (1.0 + d*Math.Log(x_in) + e*Math.Log(y_in));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp  = (a + b*math.log(x_in) + c*math.log(y_in)) / (1.0 + d*math.log(x_in) + e*math.log(y_in))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = (a + b*log(x_in) + c*log(y_in)) / (1.0 + d*log(x_in) + e*log(y_in))\n"
        return s


class RationalD_WO_3D(RationalD3D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class RationalD_X_LinearDecay_3D(RationalD3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class RationalD_Y_LinearDecay_3D(RationalD3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class RationalD_XY_LinearDecay_3D(RationalD3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class RationalD_X_ExponentialDecay_3D(RationalD3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class RationalD_Y_ExponentialDecay_3D(RationalD3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class RationalD_XY_ExponentialDecay_3D(RationalD3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class RationalD_X_LinearGrowth_3D(RationalD3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class RationalD_Y_LinearGrowth_3D(RationalD3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class RationalD_XY_LinearGrowth_3D(RationalD3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class RationalD_X_ExponentialGrowth_3D(RationalD3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class RationalD_Y_ExponentialGrowth_3D(RationalD3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class RationalD_XY_ExponentialGrowth_3D(RationalD3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class RationalD_X_LinearDecayAndOffset_3D(RationalD3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class RationalD_Y_LinearDecayAndOffset_3D(RationalD3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class RationalD_XY_LinearDecayAndOffset_3D(RationalD3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class RationalD_X_ExponentialDecayAndOffset_3D(RationalD3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class RationalD_Y_ExponentialDecayAndOffset_3D(RationalD3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class RationalD_XY_ExponentialDecayAndOffset_3D(RationalD3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class RationalD_X_LinearGrowthAndOffset_3D(RationalD3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class RationalD_Y_LinearGrowthAndOffset_3D(RationalD3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class RationalD_XY_LinearGrowthAndOffset_3D(RationalD3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class RationalD_X_ExponentialGrowthAndOffset_3D(RationalD3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class RationalD_Y_ExponentialGrowthAndOffset_3D(RationalD3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class RationalD_XY_ExponentialGrowthAndOffset_3D(RationalD3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()
