#    pythonequations is a collection of equations expressed as Python classes
#    Copyright (C) 2008 James R. Phillips
#    2548 Vera Cruz Drive
#    Birmingham, AL 35235 USA
#    email: zunzun@zunzun.com
#
#    Version info: $Id: Miscellaneous.py 13 2008-07-26 16:07:14Z zunzun.com $
#
#    License: BSD-style (see LICENSE.txt in main source directory)

import pythonequations, pythonequations.EquationBaseClasses
import numpy
numpy.seterr(all = 'raise') # numpy raises warnings, convert to exceptions to trap them


class RomanSurfacePlus3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Roman Surface (plus)"
        self.HTML = "z=(k(y<sup>2</sup>-x<sup>2</sup>) + (x<sup>2</sup>-y<sup>2</sup>)sqrt(k<sup>2</sup>-x<sup>2</sup>-y<sup>2</sup>)) / (2(x<sup>2</sup>+y<sup>2</sup>))"
        self.coefficientDesignatorTuple = ("k")

        self.function_cpp_code = 'temp = ( (coeff[0] * indep_data[(int)cachedWeaveOffsets[1] + i]) + (indep_data[(int)cachedWeaveOffsets[1] + i] * pow( (coeff[0] * coeff[0]) - indep_data[(int)cachedWeaveOffsets[0] + i], 0.5)) ) / (2.0 * indep_data[(int)cachedWeaveOffsets[2] + i]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]

    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_XSQMINUSYSQ(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_YSQMINUSXSQ(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_XSQPLUSYSQ(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = (k * (y_in * y_in - x_in * x_in) + (x_in * x_in - y_in * y_in) * pow(k * k - x_in * x_in - y_in * y_in, 0.5)) / (2.0 * (x_in * x_in + y_in * y_in));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = (k * (y_in * y_in - x_in * x_in) + (x_in * x_in - y_in * y_in) * Math.pow(k * k - x_in * x_in - y_in * y_in, 0.5)) / (2.0 * (x_in * x_in + y_in * y_in));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = (k * (y_in * y_in - x_in * x_in) + (x_in * x_in - y_in * y_in) * Math.Pow(k * k - x_in * x_in - y_in * y_in, 0.5)) / (2.0 * (x_in * x_in + y_in * y_in));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\t\ttemp = (k * (y_in * y_in - x_in * x_in) + (x_in * x_in - y_in * y_in) * math.pow(k * k - x_in * x_in - y_in * y_in, 0.5)) / (2.0 * (x_in * x_in + y_in * y_in))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\t\ttemp = (k * (y_in * y_in - x_in * x_in) + (x_in * x_in - y_in * y_in) * pow(k * k - x_in * x_in - y_in * y_in, 0.5)) / (2.0 * (x_in * x_in + y_in * y_in))\n"
        return s


class RomanSurfacePlus_WO_3D(RomanSurfacePlus3D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class RomanSurfacePlus_X_LinearDecay_3D(RomanSurfacePlus3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class RomanSurfacePlus_Y_LinearDecay_3D(RomanSurfacePlus3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class RomanSurfacePlus_XY_LinearDecay_3D(RomanSurfacePlus3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class RomanSurfacePlus_X_ExponentialDecay_3D(RomanSurfacePlus3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class RomanSurfacePlus_Y_ExponentialDecay_3D(RomanSurfacePlus3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class RomanSurfacePlus_XY_ExponentialDecay_3D(RomanSurfacePlus3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class RomanSurfacePlus_X_LinearGrowth_3D(RomanSurfacePlus3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class RomanSurfacePlus_Y_LinearGrowth_3D(RomanSurfacePlus3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class RomanSurfacePlus_XY_LinearGrowth_3D(RomanSurfacePlus3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class RomanSurfacePlus_X_ExponentialGrowth_3D(RomanSurfacePlus3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class RomanSurfacePlus_Y_ExponentialGrowth_3D(RomanSurfacePlus3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class RomanSurfacePlus_XY_ExponentialGrowth_3D(RomanSurfacePlus3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class RomanSurfacePlus_X_LinearDecayAndOffset_3D(RomanSurfacePlus3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class RomanSurfacePlus_Y_LinearDecayAndOffset_3D(RomanSurfacePlus3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class RomanSurfacePlus_XY_LinearDecayAndOffset_3D(RomanSurfacePlus3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class RomanSurfacePlus_X_ExponentialDecayAndOffset_3D(RomanSurfacePlus3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class RomanSurfacePlus_Y_ExponentialDecayAndOffset_3D(RomanSurfacePlus3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class RomanSurfacePlus_XY_ExponentialDecayAndOffset_3D(RomanSurfacePlus3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class RomanSurfacePlus_X_LinearGrowthAndOffset_3D(RomanSurfacePlus3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class RomanSurfacePlus_Y_LinearGrowthAndOffset_3D(RomanSurfacePlus3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class RomanSurfacePlus_XY_LinearGrowthAndOffset_3D(RomanSurfacePlus3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class RomanSurfacePlus_X_ExponentialGrowthAndOffset_3D(RomanSurfacePlus3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class RomanSurfacePlus_Y_ExponentialGrowthAndOffset_3D(RomanSurfacePlus3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class RomanSurfacePlus_XY_ExponentialGrowthAndOffset_3D(RomanSurfacePlus3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()


class RomanSurfaceMinus3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Roman Surface (minus)"
        self.HTML = "z=(k(y<sup>2</sup>-x<sup>2</sup>) - (x<sup>2</sup>-y<sup>2</sup>)sqrt(k<sup>2</sup>-x<sup>2</sup>-y<sup>2</sup>)) / (2(x<sup>2</sup>+y<sup>2</sup>))"
        self.coefficientDesignatorTuple = ("k")

        self.function_cpp_code = 'temp = ( (coeff[0] * indep_data[(int)cachedWeaveOffsets[1] + i]) - (indep_data[(int)cachedWeaveOffsets[1] + i] * pow( (coeff[0] * coeff[0]) - indep_data[(int)cachedWeaveOffsets[0] + i], 0.5)) ) / (2.0 * indep_data[(int)cachedWeaveOffsets[2] + i]);// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]

    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_XSQMINUSYSQ(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_YSQMINUSXSQ(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_XSQPLUSYSQ(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = (k * (y_in * y_in - x_in * x_in) - (x_in * x_in - y_in * y_in) * pow(k * k - x_in * x_in - y_in * y_in, 0.5)) / (2.0 * (x_in * x_in + y_in * y_in));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\t\ttemp = (k * (y_in * y_in - x_in * x_in) - (x_in * x_in - y_in * y_in) * Math.pow(k * k - x_in * x_in - y_in * y_in, 0.5)) / (2.0 * (x_in * x_in + y_in * y_in));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = (k * (y_in * y_in - x_in * x_in) - (x_in * x_in - y_in * y_in) * Math.Pow(k * k - x_in * x_in - y_in * y_in, 0.5)) / (2.0 * (x_in * x_in + y_in * y_in));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\t\ttemp = (k * (y_in * y_in - x_in * x_in) - (x_in * x_in - y_in * y_in) * math.pow(k * k - x_in * x_in - y_in * y_in, 0.5)) / (2.0 * (x_in * x_in + y_in * y_in))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\t\ttemp = (k * (y_in * y_in - x_in * x_in) - (x_in * x_in - y_in * y_in) * pow(k * k - x_in * x_in - y_in * y_in, 0.5)) / (2.0 * (x_in * x_in + y_in * y_in))\n"
        return s


class RomanSurfaceMinus_WO_3D(RomanSurfaceMinus3D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class RomanSurfaceMinus_X_LinearDecay_3D(RomanSurfaceMinus3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class RomanSurfaceMinus_Y_LinearDecay_3D(RomanSurfaceMinus3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class RomanSurfaceMinus_XY_LinearDecay_3D(RomanSurfaceMinus3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class RomanSurfaceMinus_X_ExponentialDecay_3D(RomanSurfaceMinus3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class RomanSurfaceMinus_Y_ExponentialDecay_3D(RomanSurfaceMinus3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class RomanSurfaceMinus_XY_ExponentialDecay_3D(RomanSurfaceMinus3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class RomanSurfaceMinus_X_LinearGrowth_3D(RomanSurfaceMinus3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class RomanSurfaceMinus_Y_LinearGrowth_3D(RomanSurfaceMinus3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class RomanSurfaceMinus_XY_LinearGrowth_3D(RomanSurfaceMinus3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class RomanSurfaceMinus_X_ExponentialGrowth_3D(RomanSurfaceMinus3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class RomanSurfaceMinus_Y_ExponentialGrowth_3D(RomanSurfaceMinus3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class RomanSurfaceMinus_XY_ExponentialGrowth_3D(RomanSurfaceMinus3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class RomanSurfaceMinus_X_LinearDecayAndOffset_3D(RomanSurfaceMinus3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class RomanSurfaceMinus_Y_LinearDecayAndOffset_3D(RomanSurfaceMinus3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class RomanSurfaceMinus_XY_LinearDecayAndOffset_3D(RomanSurfaceMinus3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class RomanSurfaceMinus_X_ExponentialDecayAndOffset_3D(RomanSurfaceMinus3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class RomanSurfaceMinus_Y_ExponentialDecayAndOffset_3D(RomanSurfaceMinus3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class RomanSurfaceMinus_XY_ExponentialDecayAndOffset_3D(RomanSurfaceMinus3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class RomanSurfaceMinus_X_LinearGrowthAndOffset_3D(RomanSurfaceMinus3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class RomanSurfaceMinus_Y_LinearGrowthAndOffset_3D(RomanSurfaceMinus3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class RomanSurfaceMinus_XY_LinearGrowthAndOffset_3D(RomanSurfaceMinus3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class RomanSurfaceMinus_X_ExponentialGrowthAndOffset_3D(RomanSurfaceMinus3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class RomanSurfaceMinus_Y_ExponentialGrowthAndOffset_3D(RomanSurfaceMinus3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class RomanSurfaceMinus_XY_ExponentialGrowthAndOffset_3D(RomanSurfaceMinus3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()


# note that the "offset form" code requires specific text as noted below for multiple lines
class RomanSurfacePlus_OffsetXY_3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Roman Surface (plus) Offset XY"
        self.HTML = "z=(k((y+b)<sup>2</sup>-(x+a)<sup>2</sup>) + ((x+a)<sup>2</sup>-(y+b)<sup>2</sup>)sqrt(k<sup>2</sup>-(x+a)<sup>2</sup>-(y+b)<sup>2</sup>)) / (2((x+a)<sup>2</sup>+(y+b)<sup>2</sup>))"
        self.coefficientDesignatorTuple = ("k", "a",  "b")

        # the automated "offset form" code looks for ending "//" in the C++ code, so the first lines here are not replaced
        self.function_cpp_code = 'temp_x_sq = indep_data[(int)cachedWeaveOffsets[0] + i] + coeff[1];\n'
        self.function_cpp_code += 'temp_x_sq = temp_x_sq * temp_x_sq;\n'
        self.function_cpp_code += 'temp_y_sq = indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[2];\n'
        self.function_cpp_code += 'temp_y_sq = temp_y_sq * temp_y_sq;\n'
        self.function_cpp_code += 'temp = ( (coeff[0] * (temp_y_sq - temp_x_sq)) + ((temp_x_sq - temp_y_sq) * pow( (coeff[0] * coeff[0]) - temp_x_sq - temp_y_sq, 0.5)) ) / (2.0 * (temp_x_sq + temp_y_sq));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]

    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Y(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += '\tdouble temp_x_sq = (x_in + ' + j[1] + ') * (x_in + ' + j[1] + ') ;\n' # note the ending space, no "offset form" replacement here
        s += '\tdouble temp_y_sq = (y_in + ' + j[2] + ') * (y_in + ' + j[2] + ') ;\n' # note the ending space, no "offset form" replacement here
        s += "\ttemp = (k * (temp_y_sq - temp_x_sq) + (temp_x_sq - temp_y_sq) * pow(k * k - temp_x_sq - temp_y_sq, 0.5)) / (2.0 * (temp_x_sq + temp_y_sq));\n"
        return s

    def SpecificCodeJAVA(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += '\t\tdouble temp_x_sq = (x_in + ' + j[1] + ') * (x_in + ' + j[1] + ') ;\n' # note the ending space, no "offset form" replacement here
        s += '\t\tdouble temp_y_sq = (y_in + ' + j[2] + ') * (y_in + ' + j[2] + ') ;\n' # note the ending space, no "offset form" replacement here
        s += "\t\ttemp = (k * (temp_y_sq - temp_x_sq) + (temp_x_sq - temp_y_sq) * Math.pow(k * k - temp_x_sq - temp_y_sq, 0.5)) / (2.0 * (temp_x_sq + temp_y_sq));\n"
        return s

    def SpecificCodeCS(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += '\t\tdouble temp_x_sq = (x_in + ' + j[1] + ') * (x_in + ' + j[1] + ') ;\n' # note the ending space, no "offset form" replacement here
        s += '\t\tdouble temp_y_sq = (y_in + ' + j[2] + ') * (y_in + ' + j[2] + ') ;\n' # note the ending space, no "offset form" replacement here
        s += "\t\ttemp = (k * (temp_y_sq - temp_x_sq) + (temp_x_sq - temp_y_sq) * Math.Pow(k * k - temp_x_sq - temp_y_sq, 0.5)) / (2.0 * (temp_x_sq + temp_y_sq));\n"
        return s

    def SpecificCodePYTHON(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += '\tdouble temp_x_sq = (x_in + ' + j[1] + ') * (x_in + ' + j[1] + ') \n' # note the ending space, no "offset form" replacement here
        s += '\tdouble temp_y_sq = (y_in + ' + j[2] + ') * (y_in + ' + j[2] + ') \n' # note the ending space, no "offset form" replacement here
        s += "\ttemp = (k * (temp_y_sq - temp_x_sq) + (temp_x_sq - temp_y_sq) * math.pow(k * k - temp_x_sq - temp_y_sq, 0.5)) / (2.0 * (temp_x_sq + temp_y_sq))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += '\t\tdouble temp_x_sq = (x_in + ' + j[1] + ') * (x_in + ' + j[1] + ') \n' # note the ending space, no "offset form" replacement here
        s += '\t\tdouble temp_y_sq = (y_in + ' + j[2] + ') * (y_in + ' + j[2] + ') \n' # note the ending space, no "offset form" replacement here
        s += "\t\ttemp = (k * (temp_y_sq - temp_x_sq) + (temp_x_sq - temp_y_sq) * pow(k * k - temp_x_sq - temp_y_sq, 0.5)) / (2.0 * (temp_x_sq + temp_y_sq))\n"
        return s


#note that the replaced text here contain closing parentheses with no spaces - above multilines that should not be replaced do not exactly match this pattern, having spaces at line ends
class RomanSurfacePlus_OffsetXY_WO_3D(RomanSurfacePlus_OffsetXY_3D):
    def __init__(self):
        self.InitCodeForOffsetFormsOfEquations()
    def CreateCacheGenerationList(self):
        self.__class__.__bases__[0].CreateCacheGenerationList(self);
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
    def SpecificCodeCPP(self):
        return self.__class__.__bases__[0].SpecificCodeCPP(self).replace(');\n', ') + ' + self.additionalDesignator + ';\n')
    def SpecificCodeJAVA(self):
        return self.__class__.__bases__[0].SpecificCodeJAVA(self).replace(');\n', ') + ' + self.additionalDesignator + ';\n')
    def SpecificCodeCS(self):
        return self.__class__.__bases__[0].SpecificCodeCS(self).replace(');\n', ') + ' + self.additionalDesignator + ';\n')
    def SpecificCodePYTHON(self):
        return self.__class__.__bases__[0].SpecificCodePYTHON(self).replace(')\n', ') + ' + self.additionalDesignator + '\n')
    def SpecificCodeSCILAB(self):
        return self.__class__.__bases__[0].SpecificCodeSCILAB(self).replace(')\n', ') + ' + self.additionalDesignator + '\n')


# note that the "offset form" code requires specific text as noted below for multiple lines
class RomanSurfaceMinus_OffsetXY_3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Roman Surface (minus) Offset XY"
        self.HTML = "z=(k((y+b)<sup>2</sup>-(x+a)<sup>2</sup>) - ((x+a)<sup>2</sup>-(y+b)<sup>2</sup>)sqrt(k<sup>2</sup>-(x+a)<sup>2</sup>-(y+b)<sup>2</sup>)) / (2((x+a)<sup>2</sup>+(y+b)<sup>2</sup>))"
        self.coefficientDesignatorTuple = ("k", "a",  "b")

        # the automated "offset form" code looks for ending "//" in the C++ code, so the first lines here are not replaced
        self.function_cpp_code = 'temp_x_sq = indep_data[(int)cachedWeaveOffsets[0] + i] + coeff[1];\n'
        self.function_cpp_code += 'temp_x_sq = temp_x_sq * temp_x_sq;\n'
        self.function_cpp_code += 'temp_y_sq = indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[2];\n'
        self.function_cpp_code += 'temp_y_sq = temp_y_sq * temp_y_sq;\n'
        self.function_cpp_code += 'temp = ( (coeff[0] * (temp_y_sq - temp_x_sq)) - ((temp_x_sq - temp_y_sq) * pow( (coeff[0] * coeff[0]) - temp_x_sq - temp_y_sq, 0.5)) ) / (2.0 * (temp_x_sq + temp_y_sq));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]

    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Y(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += '\tdouble temp_x_sq = (x_in + ' + j[1] + ') * (x_in + ' + j[1] + ') ;\n' # note the ending space, no "offset form" replacement here
        s += '\tdouble temp_y_sq = (y_in + ' + j[2] + ') * (y_in + ' + j[2] + ') ;\n' # note the ending space, no "offset form" replacement here
        s += "\ttemp = (k * (temp_y_sq - temp_x_sq) - (temp_x_sq - temp_y_sq) * pow(k * k - temp_x_sq - temp_y_sq, 0.5)) / (2.0 * (temp_x_sq + temp_y_sq));\n"
        return s

    def SpecificCodeJAVA(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += '\t\tdouble temp_x_sq = (x_in + ' + j[1] + ') * (x_in + ' + j[1] + ') ;\n' # note the ending space, no "offset form" replacement here
        s += '\t\tdouble temp_y_sq = (y_in + ' + j[2] + ') * (y_in + ' + j[2] + ') ;\n' # note the ending space, no "offset form" replacement here
        s += "\t\ttemp = (k * (temp_y_sq - temp_x_sq) - (temp_x_sq - temp_y_sq) * Math.pow(k * k - temp_x_sq - temp_y_sq, 0.5)) / (2.0 * (temp_x_sq + temp_y_sq));\n"
        return s

    def SpecificCodeCS(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += '\t\tdouble temp_x_sq = (x_in + ' + j[1] + ') * (x_in + ' + j[1] + ') ;\n' # note the ending space, no "offset form" replacement here
        s += '\t\tdouble temp_y_sq = (y_in + ' + j[2] + ') * (y_in + ' + j[2] + ') ;\n' # note the ending space, no "offset form" replacement here
        s += "\t\ttemp = (k * (temp_y_sq - temp_x_sq) - (temp_x_sq - temp_y_sq) * Math.Pow(k * k - temp_x_sq - temp_y_sq, 0.5)) / (2.0 * (temp_x_sq + temp_y_sq));\n"
        return s

    def SpecificCodePYTHON(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += '\tdouble temp_x_sq = (x_in + ' + j[1] + ') * (x_in + ' + j[1] + ') \n' # note the ending space, no "offset form" replacement here
        s += '\tdouble temp_y_sq = (y_in + ' + j[2] + ') * (y_in + ' + j[2] + ') \n' # note the ending space, no "offset form" replacement here
        s += "\ttemp = (k * (temp_y_sq - temp_x_sq) - (temp_x_sq - temp_y_sq) * math.pow(k * k - temp_x_sq - temp_y_sq, 0.5)) / (2.0 * (temp_x_sq + temp_y_sq))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += '\t\tdouble temp_x_sq = (x_in + ' + j[1] + ') * (x_in + ' + j[1] + ') \n' # note the ending space, no "offset form" replacement here
        s += '\t\tdouble temp_y_sq = (y_in + ' + j[2] + ') * (y_in + ' + j[2] + ') \n' # note the ending space, no "offset form" replacement here
        s += "\t\ttemp = (k * (temp_y_sq - temp_x_sq) - (temp_x_sq - temp_y_sq) * pow(k * k - temp_x_sq - temp_y_sq, 0.5)) / (2.0 * (temp_x_sq + temp_y_sq))\n"
        return s


#note that the replaced text here contain closing parentheses with no spaces - above multilines that should not be replaced do not exactly match this pattern, having spaces at line ends
class RomanSurfaceMinus_OffsetXY_WO_3D(RomanSurfaceMinus_OffsetXY_3D):
    def __init__(self):
        self.InitCodeForOffsetFormsOfEquations()
    def CreateCacheGenerationList(self):
        self.__class__.__bases__[0].CreateCacheGenerationList(self);
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
    def SpecificCodeCPP(self):
        return self.__class__.__bases__[0].SpecificCodeCPP(self).replace(');\n', ') + ' + self.additionalDesignator + ';\n')
    def SpecificCodeJAVA(self):
        return self.__class__.__bases__[0].SpecificCodeJAVA(self).replace(');\n', ') + ' + self.additionalDesignator + ';\n')
    def SpecificCodeCS(self):
        return self.__class__.__bases__[0].SpecificCodeCS(self).replace(');\n', ') + ' + self.additionalDesignator + ';\n')
    def SpecificCodePYTHON(self):
        return self.__class__.__bases__[0].SpecificCodePYTHON(self).replace(')\n', ') + ' + self.additionalDesignator + '\n')
    def SpecificCodeSCILAB(self):
        return self.__class__.__bases__[0].SpecificCodeSCILAB(self).replace(')\n', ') + ' + self.additionalDesignator + '\n')


# note that the "offset form" code requires specific text as noted below for multiple lines
class RomanSurfacePlus_ScaledAndOffsetXY_3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Roman Surface (plus) Scaled And Offset XY"
        self.HTML = "z=(k((cy+d)<sup>2</sup>-(ax+b)<sup>2</sup>) + ((ax+b)<sup>2</sup>-(cy+d)<sup>2</sup>)sqrt(k<sup>2</sup>-(ax+b)<sup>2</sup>-(cy+d)<sup>2</sup>)) / (2((ax+b)<sup>2</sup>+(cy+d)<sup>2</sup>))"
        self.coefficientDesignatorTuple = ("k", "a",  "b",  "c",  "d")

        # the automated "offset form" code looks for ending "//" in the C++ code, so the first lines here are not replaced
        self.function_cpp_code = 'temp_x_sq = coeff[1] * indep_data[(int)cachedWeaveOffsets[0] + i] + coeff[2];\n'
        self.function_cpp_code += 'temp_x_sq = temp_x_sq * temp_x_sq;\n'
        self.function_cpp_code += 'temp_y_sq = coeff[3] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[4];\n'
        self.function_cpp_code += 'temp_y_sq = temp_y_sq * temp_y_sq;\n'
        self.function_cpp_code += 'temp = ( (coeff[0] * (temp_y_sq - temp_x_sq)) + ((temp_x_sq - temp_y_sq) * pow( (coeff[0] * coeff[0]) - temp_x_sq - temp_y_sq, 0.5)) ) / (2.0 * (temp_x_sq + temp_y_sq));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]

    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Y(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += '\tdouble temp_x_sq = (' + j[1] + ' * x_in + ' + j[2] + ') * (' + j[1] + ' * x_in + ' + j[2] + ') ;\n' # note the ending space, no "offset form" replacement here
        s += '\tdouble temp_y_sq = (' + j[3] + ' * y_in + ' + j[4] + ') * (' + j[3] + ' * y_in + ' + j[4] + ') ;\n' # note the ending space, no "offset form" replacement here
        s += "\ttemp = (k * (temp_y_sq - temp_x_sq) + (temp_x_sq - temp_y_sq) * pow(k * k - temp_x_sq - temp_y_sq, 0.5)) / (2.0 * (temp_x_sq + temp_y_sq));\n"
        return s

    def SpecificCodeJAVA(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += '\t\tdouble temp_x_sq = (' + j[1] + ' * x_in + ' + j[2] + ') * (' + j[1] + ' * x_in + ' + j[2] + ') ;\n' # note the ending space, no "offset form" replacement here
        s += '\t\tdouble temp_y_sq = (' + j[3] + ' * y_in + ' + j[4] + ') * (' + j[3] + ' * y_in + ' + j[4] + ') ;\n' # note the ending space, no "offset form" replacement here
        s += "\t\ttemp = (k * (temp_y_sq - temp_x_sq) + (temp_x_sq - temp_y_sq) * Math.pow(k * k - temp_x_sq - temp_y_sq, 0.5)) / (2.0 * (temp_x_sq + temp_y_sq));\n"
        return s

    def SpecificCodeCS(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += '\t\tdouble temp_x_sq = (' + j[1] + ' * x_in + ' + j[2] + ') * (' + j[1] + ' * x_in + ' + j[2] + ') ;\n' # note the ending space, no "offset form" replacement here
        s += '\t\tdouble temp_y_sq = (' + j[3] + ' * y_in + ' + j[4] + ') * (' + j[3] + ' * y_in + ' + j[4] + ') ;\n' # note the ending space, no "offset form" replacement here
        s += "\t\ttemp = (k * (temp_y_sq - temp_x_sq) + (temp_x_sq - temp_y_sq) * Math.Pow(k * k - temp_x_sq - temp_y_sq, 0.5)) / (2.0 * (temp_x_sq + temp_y_sq));\n"
        return s

    def SpecificCodePYTHON(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += '\tdouble temp_x_sq = (' + j[1] + ' * x_in + ' + j[2] + ') * (' + j[1] + ' * x_in + ' + j[2] + ') \n' # note the ending space, no "offset form" replacement here
        s += '\tdouble temp_y_sq = (' + j[3] + ' * y_in + ' + j[4] + ') * (' + j[3] + ' * y_in + ' + j[4] + ') \n' # note the ending space, no "offset form" replacement here
        s += "\ttemp = (k * (temp_y_sq - temp_x_sq) + (temp_x_sq - temp_y_sq) * math.pow(k * k - temp_x_sq - temp_y_sq, 0.5)) / (2.0 * (temp_x_sq + temp_y_sq))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += '\t\tdouble temp_x_sq = (' + j[1] + ' * x_in + ' + j[2] + ') * (' + j[1] + ' * x_in + ' + j[2] + ') \n' # note the ending space, no "offset form" replacement here
        s += '\t\tdouble temp_y_sq = (' + j[3] + ' * y_in + ' + j[4] + ') * (' + j[3] + ' * y_in + ' + j[4] + ') \n' # note the ending space, no "offset form" replacement here
        s += "\t\ttemp = (k * (temp_y_sq - temp_x_sq) + (temp_x_sq - temp_y_sq) * pow(k * k - temp_x_sq - temp_y_sq, 0.5)) / (2.0 * (temp_x_sq + temp_y_sq))\n"
        return s


#note that the replaced text here contain closing parentheses with no spaces - above multilines that should not be replaced do not exactly match this pattern, having spaces at line ends
class RomanSurfacePlus_ScaledAndOffsetXY_WO_3D(RomanSurfacePlus_ScaledAndOffsetXY_3D):
    def __init__(self):
        self.InitCodeForOffsetFormsOfEquations()
    def CreateCacheGenerationList(self):
        self.__class__.__bases__[0].CreateCacheGenerationList(self);
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
    def SpecificCodeCPP(self):
        return self.__class__.__bases__[0].SpecificCodeCPP(self).replace(');\n', ') + ' + self.additionalDesignator + ';\n')
    def SpecificCodeJAVA(self):
        return self.__class__.__bases__[0].SpecificCodeJAVA(self).replace(');\n', ') + ' + self.additionalDesignator + ';\n')
    def SpecificCodeCS(self):
        return self.__class__.__bases__[0].SpecificCodeCS(self).replace(');\n', ') + ' + self.additionalDesignator + ';\n')
    def SpecificCodePYTHON(self):
        return self.__class__.__bases__[0].SpecificCodePYTHON(self).replace(')\n', ') + ' + self.additionalDesignator + '\n')
    def SpecificCodeSCILAB(self):
        return self.__class__.__bases__[0].SpecificCodeSCILAB(self).replace(')\n', ') + ' + self.additionalDesignator + '\n')


# note that the "offset form" code requires specific text as noted below for multiple lines
class RomanSurfaceMinus_ScaledAndOffsetXY_3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Roman Surface (minus) Scaled And Offset XY"
        self.HTML = "z=(k((cy+d)<sup>2</sup>-(ax+b)<sup>2</sup>) - ((ax+b)<sup>2</sup>-(cy+d)<sup>2</sup>)sqrt(k<sup>2</sup>-(ax+b)<sup>2</sup>-(cy+d)<sup>2</sup>)) / (2((ax+b)<sup>2</sup>+(cy+d)<sup>2</sup>))"
        self.coefficientDesignatorTuple = ("k", "a",  "b",  "c",  "d")

        # the automated "offset form" code looks for ending "//" in the C++ code, so the first lines here are not replaced
        self.function_cpp_code = 'temp_x_sq = coeff[1] * indep_data[(int)cachedWeaveOffsets[0] + i] + coeff[2];\n'
        self.function_cpp_code += 'temp_x_sq = temp_x_sq * temp_x_sq;\n'
        self.function_cpp_code += 'temp_y_sq = coeff[3] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[4];\n'
        self.function_cpp_code += 'temp_y_sq = temp_y_sq * temp_y_sq;\n'
        self.function_cpp_code += 'temp = ( (coeff[0] * (temp_y_sq - temp_x_sq)) - ((temp_x_sq - temp_y_sq) * pow( (coeff[0] * coeff[0]) - temp_x_sq - temp_y_sq, 0.5)) ) / (2.0 * (temp_x_sq + temp_y_sq));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]

    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Y(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += '\tdouble temp_x_sq = (' + j[1] + ' * x_in + ' + j[2] + ') * (' + j[1] + ' * x_in + ' + j[2] + ') ;\n' # note the ending space, no "offset form" replacement here
        s += '\tdouble temp_y_sq = (' + j[3] + ' * y_in + ' + j[4] + ') * (' + j[3] + ' * y_in + ' + j[4] + ') ;\n' # note the ending space, no "offset form" replacement here
        s += "\ttemp = (k * (temp_y_sq - temp_x_sq) - (temp_x_sq - temp_y_sq) * pow(k * k - temp_x_sq - temp_y_sq, 0.5)) / (2.0 * (temp_x_sq + temp_y_sq));\n"
        return s

    def SpecificCodeJAVA(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += '\t\tdouble temp_x_sq = (' + j[1] + ' * x_in + ' + j[2] + ') * (' + j[1] + ' * x_in + ' + j[2] + ') ;\n' # note the ending space, no "offset form" replacement here
        s += '\t\tdouble temp_y_sq = (' + j[3] + ' * y_in + ' + j[4] + ') * (' + j[3] + ' * y_in + ' + j[4] + ') ;\n' # note the ending space, no "offset form" replacement here
        s += "\t\ttemp = (k * (temp_y_sq - temp_x_sq) - (temp_x_sq - temp_y_sq) * Math.pow(k * k - temp_x_sq - temp_y_sq, 0.5)) / (2.0 * (temp_x_sq + temp_y_sq));\n"
        return s

    def SpecificCodeCS(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += '\t\tdouble temp_x_sq = (' + j[1] + ' * x_in + ' + j[2] + ') * (' + j[1] + ' * x_in + ' + j[2] + ') ;\n' # note the ending space, no "offset form" replacement here
        s += '\t\tdouble temp_y_sq = (' + j[3] + ' * y_in + ' + j[4] + ') * (' + j[3] + ' * y_in + ' + j[4] + ') ;\n' # note the ending space, no "offset form" replacement here
        s += "\t\ttemp = (k * (temp_y_sq - temp_x_sq) - (temp_x_sq - temp_y_sq) * Math.Pow(k * k - temp_x_sq - temp_y_sq, 0.5)) / (2.0 * (temp_x_sq + temp_y_sq));\n"
        return s

    def SpecificCodePYTHON(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += '\tdouble temp_x_sq = (' + j[1] + ' * x_in + ' + j[2] + ') * (' + j[1] + ' * x_in + ' + j[2] + ') \n' # note the ending space, no "offset form" replacement here
        s += '\tdouble temp_y_sq = (' + j[3] + ' * y_in + ' + j[4] + ') * (' + j[3] + ' * y_in + ' + j[4] + ') \n' # note the ending space, no "offset form" replacement here
        s += "\ttemp = (k * (temp_y_sq - temp_x_sq) - (temp_x_sq - temp_y_sq) * math.pow(k * k - temp_x_sq - temp_y_sq, 0.5)) / (2.0 * (temp_x_sq + temp_y_sq))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = ""
        j = self.coefficientDesignatorTuple # makes coding below easier to read
        s += '\t\tdouble temp_x_sq = (' + j[1] + ' * x_in + ' + j[2] + ') * (' + j[1] + ' * x_in + ' + j[2] + ') \n' # note the ending space, no "offset form" replacement here
        s += '\t\tdouble temp_y_sq = (' + j[3] + ' * y_in + ' + j[4] + ') * (' + j[3] + ' * y_in + ' + j[4] + ') \n' # note the ending space, no "offset form" replacement here
        s += "\t\ttemp = (k * (temp_y_sq - temp_x_sq) - (temp_x_sq - temp_y_sq) * pow(k * k - temp_x_sq - temp_y_sq, 0.5)) / (2.0 * (temp_x_sq + temp_y_sq))\n"
        return s

#note that the replaced text here contain closing parentheses with no spaces - above multilines that should not be replaced do not exactly match this pattern, having spaces at line ends
class RomanSurfaceMinus_ScaledAndOffsetXY_WO_3D(RomanSurfaceMinus_ScaledAndOffsetXY_3D):
    def __init__(self):
        self.InitCodeForOffsetFormsOfEquations()
    def CreateCacheGenerationList(self):
        self.__class__.__bases__[0].CreateCacheGenerationList(self);
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
    def SpecificCodeCPP(self):
        return self.__class__.__bases__[0].SpecificCodeCPP(self).replace(');\n', ') + ' + self.additionalDesignator + ';\n')
    def SpecificCodeJAVA(self):
        return self.__class__.__bases__[0].SpecificCodeJAVA(self).replace(');\n', ') + ' + self.additionalDesignator + ';\n')
    def SpecificCodeCS(self):
        return self.__class__.__bases__[0].SpecificCodeCS(self).replace(');\n', ') + ' + self.additionalDesignator + ';\n')
    def SpecificCodePYTHON(self):
        return self.__class__.__bases__[0].SpecificCodePYTHON(self).replace(')\n', ') + ' + self.additionalDesignator + '\n')
    def SpecificCodeSCILAB(self):
        return self.__class__.__bases__[0].SpecificCodeSCILAB(self).replace(')\n', ') + ' + self.additionalDesignator + '\n')
