#    pythonequations is a collection of equations expressed as Python classes
#    Copyright (C) 2008 James R. Phillips
#    2548 Vera Cruz Drive
#    Birmingham, AL 35235 USA
#    email: zunzun@zunzun.com
#
#    Version info: $Id$
#
#    License: BSD-style (see LICENSE.txt in main source directory)

import pythonequations, pythonequations.EquationBaseClasses
import numpy
numpy.seterr(all = 'raise') # numpy raises warnings, convert to exceptions to trap them


class AndreaPrunottoSigmoidA3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Andrea Prunotto Sigmoid A"
        self.HTML = "z = a0 + (a1 / (1.0 + e<SUP>a2 * (x + a3 + a4 * y + a5 * x * y)</SUP>))"
        self.coefficientDesignatorTuple = ("a0", "a1", "a2", "a3", "a4", "a5")

        self.function_cpp_code = 'temp = coeff[0] + (coeff[1] / (1.0 + exp(coeff[2] * (indep_data[(int)cachedWeaveOffsets[0] + i] + coeff[3] + coeff[4] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[5] * indep_data[(int)cachedWeaveOffsets[2] + i]))));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Y(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_XY(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a0 + (a1 / (1.0 + exp(a2 * (x_in + a3 + a4 * y_in + a5 * x_in * y_in))));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\ttemp = a0 + (a1 / (1.0 + Math.exp(a2 * (x_in + a3 + a4 * y_in + a5 * x_in * y_in))));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a0 + (a1 / (1.0 + Math.Exp(a2 * (x_in + a3 + a4 * y_in + a5 * x_in * y_in))));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = a0 + (a1 / (1.0 + math.exp(a2 * (x_in + a3 + a4 * y_in + a5 * x_in * y_in))))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = a0 + (a1 / (1.0 + exp(a2 * (x_in + a3 + a4 * y_in + a5 * x_in * y_in))))\n"
        return s


class AndreaPrunottoSigmoidA_X_LinearDecay_3D(AndreaPrunottoSigmoidA3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class AndreaPrunottoSigmoidA_Y_LinearDecay_3D(AndreaPrunottoSigmoidA3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class AndreaPrunottoSigmoidA_XY_LinearDecay_3D(AndreaPrunottoSigmoidA3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class AndreaPrunottoSigmoidA_X_ExponentialDecay_3D(AndreaPrunottoSigmoidA3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class AndreaPrunottoSigmoidA_Y_ExponentialDecay_3D(AndreaPrunottoSigmoidA3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class AndreaPrunottoSigmoidA_XY_ExponentialDecay_3D(AndreaPrunottoSigmoidA3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class AndreaPrunottoSigmoidA_X_LinearGrowth_3D(AndreaPrunottoSigmoidA3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class AndreaPrunottoSigmoidA_Y_LinearGrowth_3D(AndreaPrunottoSigmoidA3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class AndreaPrunottoSigmoidA_XY_LinearGrowth_3D(AndreaPrunottoSigmoidA3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class AndreaPrunottoSigmoidA_X_ExponentialGrowth_3D(AndreaPrunottoSigmoidA3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class AndreaPrunottoSigmoidA_Y_ExponentialGrowth_3D(AndreaPrunottoSigmoidA3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class AndreaPrunottoSigmoidA_XY_ExponentialGrowth_3D(AndreaPrunottoSigmoidA3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class AndreaPrunottoSigmoidA_X_LinearDecayAndOffset_3D(AndreaPrunottoSigmoidA3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class AndreaPrunottoSigmoidA_Y_LinearDecayAndOffset_3D(AndreaPrunottoSigmoidA3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class AndreaPrunottoSigmoidA_XY_LinearDecayAndOffset_3D(AndreaPrunottoSigmoidA3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class AndreaPrunottoSigmoidA_X_ExponentialDecayAndOffset_3D(AndreaPrunottoSigmoidA3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class AndreaPrunottoSigmoidA_Y_ExponentialDecayAndOffset_3D(AndreaPrunottoSigmoidA3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class AndreaPrunottoSigmoidA_XY_ExponentialDecayAndOffset_3D(AndreaPrunottoSigmoidA3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class AndreaPrunottoSigmoidA_X_LinearGrowthAndOffset_3D(AndreaPrunottoSigmoidA3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class AndreaPrunottoSigmoidA_Y_LinearGrowthAndOffset_3D(AndreaPrunottoSigmoidA3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class AndreaPrunottoSigmoidA_XY_LinearGrowthAndOffset_3D(AndreaPrunottoSigmoidA3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class AndreaPrunottoSigmoidA_X_ExponentialGrowthAndOffset_3D(AndreaPrunottoSigmoidA3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class AndreaPrunottoSigmoidA_Y_ExponentialGrowthAndOffset_3D(AndreaPrunottoSigmoidA3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class AndreaPrunottoSigmoidA_XY_ExponentialGrowthAndOffset_3D(AndreaPrunottoSigmoidA3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()


class AndreaPrunottoSigmoidB3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Andrea Prunotto Sigmoid B"
        self.HTML = "z = a0 + (a1 / (1.0 + e<SUP>a2 * (x * a3 + a4 * y + a5 * x * y)</SUP>))"
        self.coefficientDesignatorTuple = ("a0", "a1", "a2", "a3", "a4", "a5")

        self.function_cpp_code = 'temp = coeff[0] + (coeff[1] / (1.0 + exp(coeff[2] * (indep_data[(int)cachedWeaveOffsets[0] + i] * coeff[3] + coeff[4] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[5] * indep_data[(int)cachedWeaveOffsets[2] + i]))));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Y(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_XY(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a0 + (a1 / (1.0 + exp(a2 * (x_in * a3 + a4 * y_in + a5 * x_in * y_in))));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\ttemp = a0 + (a1 / (1.0 + Math.exp(a2 * (x_in * a3 + a4 * y_in + a5 * x_in * y_in))));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a0 + (a1 / (1.0 + Math.Exp(a2 * (x_in * a3 + a4 * y_in + a5 * x_in * y_in))));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = a0 + (a1 / (1.0 + math.exp(a2 * (x_in * a3 + a4 * y_in + a5 * x_in * y_in))))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = a0 + (a1 / (1.0 + exp(a2 * (x_in * a3 + a4 * y_in + a5 * x_in * y_in))))\n"
        return s


class AndreaPrunottoSigmoidB_X_LinearDecay_3D(AndreaPrunottoSigmoidB3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class AndreaPrunottoSigmoidB_Y_LinearDecay_3D(AndreaPrunottoSigmoidB3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class AndreaPrunottoSigmoidB_XY_LinearDecay_3D(AndreaPrunottoSigmoidB3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class AndreaPrunottoSigmoidB_X_ExponentialDecay_3D(AndreaPrunottoSigmoidB3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class AndreaPrunottoSigmoidB_Y_ExponentialDecay_3D(AndreaPrunottoSigmoidB3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class AndreaPrunottoSigmoidB_XY_ExponentialDecay_3D(AndreaPrunottoSigmoidB3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class AndreaPrunottoSigmoidB_X_LinearGrowth_3D(AndreaPrunottoSigmoidB3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class AndreaPrunottoSigmoidB_Y_LinearGrowth_3D(AndreaPrunottoSigmoidB3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class AndreaPrunottoSigmoidB_XY_LinearGrowth_3D(AndreaPrunottoSigmoidB3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class AndreaPrunottoSigmoidB_X_ExponentialGrowth_3D(AndreaPrunottoSigmoidB3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class AndreaPrunottoSigmoidB_Y_ExponentialGrowth_3D(AndreaPrunottoSigmoidB3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class AndreaPrunottoSigmoidB_XY_ExponentialGrowth_3D(AndreaPrunottoSigmoidB3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class AndreaPrunottoSigmoidB_X_LinearDecayAndOffset_3D(AndreaPrunottoSigmoidB3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class AndreaPrunottoSigmoidB_Y_LinearDecayAndOffset_3D(AndreaPrunottoSigmoidB3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class AndreaPrunottoSigmoidB_XY_LinearDecayAndOffset_3D(AndreaPrunottoSigmoidB3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class AndreaPrunottoSigmoidB_X_ExponentialDecayAndOffset_3D(AndreaPrunottoSigmoidB3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class AndreaPrunottoSigmoidB_Y_ExponentialDecayAndOffset_3D(AndreaPrunottoSigmoidB3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class AndreaPrunottoSigmoidB_XY_ExponentialDecayAndOffset_3D(AndreaPrunottoSigmoidB3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class AndreaPrunottoSigmoidB_X_LinearGrowthAndOffset_3D(AndreaPrunottoSigmoidB3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class AndreaPrunottoSigmoidB_Y_LinearGrowthAndOffset_3D(AndreaPrunottoSigmoidB3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class AndreaPrunottoSigmoidB_XY_LinearGrowthAndOffset_3D(AndreaPrunottoSigmoidB3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class AndreaPrunottoSigmoidB_X_ExponentialGrowthAndOffset_3D(AndreaPrunottoSigmoidB3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class AndreaPrunottoSigmoidB_Y_ExponentialGrowthAndOffset_3D(AndreaPrunottoSigmoidB3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class AndreaPrunottoSigmoidB_XY_ExponentialGrowthAndOffset_3D(AndreaPrunottoSigmoidB3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()


class Sigmoid3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Sigmoid"
        self.HTML = "z = a / ((1.0 + e<SUP>(b - cx)</SUP>) * (1.0 + e<SUP>(d - ey)</SUP>))"
        self.coefficientDesignatorTuple = ("a", "b", "c", "d", "e")

        self.function_cpp_code = 'temp = coeff[0] / ((1.0 + exp(coeff[1] - coeff[2] * indep_data[(int)cachedWeaveOffsets[2] + i])) * (1.0 + exp(coeff[3] - coeff[4] * indep_data[(int)cachedWeaveOffsets[4] + i])));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Y(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a / ((1.0 + exp(b - c * x_in)) * (1.0 + exp(d - e * y_in)));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\ttemp = a / ((1.0 + Math.exp(b - c * x_in)) * (1.0 + Math.exp(d - e * y_in)));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = a / ((1.0 + Math.Exp(b - c * x_in)) * (1.0 + Math.Exp(d - e * y_in)));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = a / ((1.0 + math.exp(b - c * x_in)) * (1.0 + math.exp(d - e * y_in)))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = a / ((1.0 + exp(b - c * x_in)) * (1.0 + exp(d - e * y_in)))\n"
        return s


class Sigmoid_WO_3D(Sigmoid3D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class Sigmoid_X_LinearDecay_3D(Sigmoid3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class Sigmoid_Y_LinearDecay_3D(Sigmoid3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class Sigmoid_XY_LinearDecay_3D(Sigmoid3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class Sigmoid_X_ExponentialDecay_3D(Sigmoid3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class Sigmoid_Y_ExponentialDecay_3D(Sigmoid3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class Sigmoid_XY_ExponentialDecay_3D(Sigmoid3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class Sigmoid_X_LinearGrowth_3D(Sigmoid3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class Sigmoid_Y_LinearGrowth_3D(Sigmoid3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class Sigmoid_XY_LinearGrowth_3D(Sigmoid3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class Sigmoid_X_ExponentialGrowth_3D(Sigmoid3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class Sigmoid_Y_ExponentialGrowth_3D(Sigmoid3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class Sigmoid_XY_ExponentialGrowth_3D(Sigmoid3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class Sigmoid_X_LinearDecayAndOffset_3D(Sigmoid3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class Sigmoid_Y_LinearDecayAndOffset_3D(Sigmoid3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class Sigmoid_XY_LinearDecayAndOffset_3D(Sigmoid3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class Sigmoid_X_ExponentialDecayAndOffset_3D(Sigmoid3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class Sigmoid_Y_ExponentialDecayAndOffset_3D(Sigmoid3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class Sigmoid_XY_ExponentialDecayAndOffset_3D(Sigmoid3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class Sigmoid_X_LinearGrowthAndOffset_3D(Sigmoid3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class Sigmoid_Y_LinearGrowthAndOffset_3D(Sigmoid3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class Sigmoid_XY_LinearGrowthAndOffset_3D(Sigmoid3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class Sigmoid_X_ExponentialGrowthAndOffset_3D(Sigmoid3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class Sigmoid_Y_ExponentialGrowthAndOffset_3D(Sigmoid3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class Sigmoid_XY_ExponentialGrowthAndOffset_3D(Sigmoid3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()


class FraserSmithSigmoid3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Fraser Smith Sigmoid"
        self.HTML = "z = 1.0 / ((1.0 + e<SUP>(a - bx)</SUP>) * (1.0 + e<SUP>(c - dy)</SUP>))"
        self.coefficientDesignatorTuple = ("a", "b", "c", "d")

        self.function_cpp_code = 'temp = 1.0 / ((1.0 + exp(coeff[0] - coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i])) * (1.0 + exp(coeff[2] - coeff[3] * indep_data[(int)cachedWeaveOffsets[3] + i])));// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Y(NameOrValueFlag=1), []])

    def SpecificCodeCPP(self):
        s = "\ttemp = 1.0 / ((1.0 + exp(a - b * x_in)) * (1.0 + exp(c - d * y_in)));\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\ttemp = 1.0 / ((1.0 + Math.exp(a - b * x_in)) * (1.0 + Math.exp(c - d * y_in)));\n"
        return s

    def SpecificCodeCS(self):
        s = "\t\ttemp = 1.0 / ((1.0 + Math.Exp(a - b * x_in)) * (1.0 + Math.Exp(c - d * y_in)));\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp = 1.0 / ((1.0 + math.exp(a - b * x_in)) * (1.0 + math.exp(c - d * y_in)))\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = 1.0 / ((1.0 + exp(a - b * x_in)) * (1.0 + exp(c - d * y_in)))\n"
        return s


class FraserSmithSigmoid_WO_3D(FraserSmithSigmoid3D):
    def __init__(self): self.InitCodeForOffsetFormsOfEquations()
class FraserSmithSigmoid_X_LinearDecay_3D(FraserSmithSigmoid3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class FraserSmithSigmoid_Y_LinearDecay_3D(FraserSmithSigmoid3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class FraserSmithSigmoid_XY_LinearDecay_3D(FraserSmithSigmoid3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class FraserSmithSigmoid_X_ExponentialDecay_3D(FraserSmithSigmoid3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class FraserSmithSigmoid_Y_ExponentialDecay_3D(FraserSmithSigmoid3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class FraserSmithSigmoid_XY_ExponentialDecay_3D(FraserSmithSigmoid3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class FraserSmithSigmoid_X_LinearGrowth_3D(FraserSmithSigmoid3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class FraserSmithSigmoid_Y_LinearGrowth_3D(FraserSmithSigmoid3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class FraserSmithSigmoid_XY_LinearGrowth_3D(FraserSmithSigmoid3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class FraserSmithSigmoid_X_ExponentialGrowth_3D(FraserSmithSigmoid3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class FraserSmithSigmoid_Y_ExponentialGrowth_3D(FraserSmithSigmoid3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class FraserSmithSigmoid_XY_ExponentialGrowth_3D(FraserSmithSigmoid3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class FraserSmithSigmoid_X_LinearDecayAndOffset_3D(FraserSmithSigmoid3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class FraserSmithSigmoid_Y_LinearDecayAndOffset_3D(FraserSmithSigmoid3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class FraserSmithSigmoid_XY_LinearDecayAndOffset_3D(FraserSmithSigmoid3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class FraserSmithSigmoid_X_ExponentialDecayAndOffset_3D(FraserSmithSigmoid3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class FraserSmithSigmoid_Y_ExponentialDecayAndOffset_3D(FraserSmithSigmoid3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class FraserSmithSigmoid_XY_ExponentialDecayAndOffset_3D(FraserSmithSigmoid3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class FraserSmithSigmoid_X_LinearGrowthAndOffset_3D(FraserSmithSigmoid3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class FraserSmithSigmoid_Y_LinearGrowthAndOffset_3D(FraserSmithSigmoid3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class FraserSmithSigmoid_XY_LinearGrowthAndOffset_3D(FraserSmithSigmoid3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class FraserSmithSigmoid_X_ExponentialGrowthAndOffset_3D(FraserSmithSigmoid3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class FraserSmithSigmoid_Y_ExponentialGrowthAndOffset_3D(FraserSmithSigmoid3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class FraserSmithSigmoid_XY_ExponentialGrowthAndOffset_3D(FraserSmithSigmoid3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()
