#    pythonequations is a collection of equations expressed as Python classes
#    Copyright (C) 2008 James R. Phillips
#    2548 Vera Cruz Drive
#    Birmingham, AL 35235 USA
#    email: zunzun@zunzun.com
#
#    Version info: $Id$
#
#    License: BSD-style (see LICENSE.txt in main source directory)

import pythonequations, pythonequations.EquationBaseClasses
import numpy
numpy.seterr(all = 'raise') # numpy raises warnings, convert to exceptions to trap them

class TaylorA3D(pythonequations.EquationBaseClasses.Equation3D):


    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Taylor Series A"
        self.HTML = "z = a + bx + cy + dx<SUP>2</SUP> + ey<SUP>2</SUP> + fxy"
        self.coefficientDesignatorTuple = ("a", "b", "c", "d", "e", "f")
        self.LinearSSQSolverFlag = 1

        self.function_cpp_code = 'temp = coeff[0] + coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[2] * indep_data[(int)cachedWeaveOffsets[2] + i] + coeff[3] * indep_data[(int)cachedWeaveOffsets[3] + i] + coeff[4] * indep_data[(int)cachedWeaveOffsets[4] + i] + coeff[5] * indep_data[(int)cachedWeaveOffsets[5] + i];// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Y(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_PowX(NameOrValueFlag=1, args=[2.0]), [2.0]])
        self.CacheGenerationList.append([self.CG_PowY(NameOrValueFlag=1, args=[2.0]), [2.0]])
        self.CacheGenerationList.append([self.CG_XY(NameOrValueFlag=1), self.CG_XY, []])

    def SpecificCodeCPP(self):
        s = "\ttemp = a + b*x_in + c*y_in + d*pow(x_in, 2.0) + e*pow(y_in, 2.0) + f*x_in*y_in;\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\ttemp = a + b*x_in + c*y_in + d*Math.pow(x_in, 2.0) + e*Math.pow(y_in, 2.0) + f*x_in*y_in;\n"
        return s

    def SpecificCodeCS(self):
        s = "\ttemp = a + b*x_in + c*y_in + d*Math.Pow(x_in, 2.0) + e*Math.Pow(y_in, 2.0) + f*x_in*y_in;\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp  = a + b*x_in + c*y_in + d*math.pow(x_in, 2.0) + e*math.pow(y_in, 2.0) + f*x_in*y_in\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = a + b*x_in + c*y_in + d*(x_in ^ 2.0) + e*(y_in ^ 2.0) + f*x_in*y_in\n"
        return s


class TaylorA_X_LinearDecay_3D(TaylorA3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class TaylorA_Y_LinearDecay_3D(TaylorA3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class TaylorA_XY_LinearDecay_3D(TaylorA3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class TaylorA_X_ExponentialDecay_3D(TaylorA3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class TaylorA_Y_ExponentialDecay_3D(TaylorA3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class TaylorA_XY_ExponentialDecay_3D(TaylorA3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class TaylorA_X_LinearGrowth_3D(TaylorA3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class TaylorA_Y_LinearGrowth_3D(TaylorA3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class TaylorA_XY_LinearGrowth_3D(TaylorA3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class TaylorA_X_ExponentialGrowth_3D(TaylorA3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class TaylorA_Y_ExponentialGrowth_3D(TaylorA3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class TaylorA_XY_ExponentialGrowth_3D(TaylorA3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class TaylorA_X_LinearDecayAndOffset_3D(TaylorA3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class TaylorA_Y_LinearDecayAndOffset_3D(TaylorA3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class TaylorA_XY_LinearDecayAndOffset_3D(TaylorA3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class TaylorA_X_ExponentialDecayAndOffset_3D(TaylorA3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class TaylorA_Y_ExponentialDecayAndOffset_3D(TaylorA3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class TaylorA_XY_ExponentialDecayAndOffset_3D(TaylorA3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class TaylorA_X_LinearGrowthAndOffset_3D(TaylorA3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class TaylorA_Y_LinearGrowthAndOffset_3D(TaylorA3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class TaylorA_XY_LinearGrowthAndOffset_3D(TaylorA3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class TaylorA_X_ExponentialGrowthAndOffset_3D(TaylorA3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class TaylorA_Y_ExponentialGrowthAndOffset_3D(TaylorA3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class TaylorA_XY_ExponentialGrowthAndOffset_3D(TaylorA3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()


class TaylorB3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Taylor Series B"
        self.HTML = "z = a + b/x + cy + d/x<SUP>2</SUP> + ey<SUP>2</SUP> + fy/x"
        self.coefficientDesignatorTuple = ("a", "b", "c", "d", "e", "f")
        self.LinearSSQSolverFlag = 1
        self.RequiresNonzeroX = 1 # /x

        self.function_cpp_code = 'temp = coeff[0] + coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[2] * indep_data[(int)cachedWeaveOffsets[2] + i] + coeff[3] * indep_data[(int)cachedWeaveOffsets[3] + i] + coeff[4] * indep_data[(int)cachedWeaveOffsets[4] + i] + coeff[5] * indep_data[(int)cachedWeaveOffsets[5] + i];// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_InverseX(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_Y(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_PowX(NameOrValueFlag=1, args=[-2.0]), [-2.0]])
        self.CacheGenerationList.append([self.CG_PowY(NameOrValueFlag=1, args=[2.0]), [2.0]])
        self.CacheGenerationList.append([self.CG_PowXY(NameOrValueFlag=1, args=[-1.0, 1.0]), [-1.0, 1.0]])

    def SpecificCodeCPP(self):
        s = "\ttemp = a + b/x_in + c*y_in + d/pow(x_in, 2.0) + e*pow(y_in, 2.0) + f*y_in/x_in;\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\ttemp = a + b/x_in + c*y_in + d/Math.pow(x_in, 2.0) + e*Math.pow(y_in, 2.0) + f*y_in/x_in;\n"
        return s

    def SpecificCodeCS(self):
        s = "\ttemp = a + b/x_in + c*y_in + d/Math.Pow(x_in, 2.0) + e*Math.Pow(y_in, 2.0) + f*y_in/x_in;\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp  = a + b/x_in + c*y_in + d/math.pow(x_in, 2.0) + e*math.pow(y_in, 2.0) + f*y_in/x_in\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp  = a + b/x_in + c*y_in + d/(x_in ^ 2.0) + e*(y_in ^ 2.0) + f*y_in/x_in\n"
        return s


class TaylorB_X_LinearDecay_3D(TaylorB3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class TaylorB_Y_LinearDecay_3D(TaylorB3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class TaylorB_XY_LinearDecay_3D(TaylorB3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class TaylorB_X_ExponentialDecay_3D(TaylorB3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class TaylorB_Y_ExponentialDecay_3D(TaylorB3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class TaylorB_XY_ExponentialDecay_3D(TaylorB3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class TaylorB_X_LinearGrowth_3D(TaylorB3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class TaylorB_Y_LinearGrowth_3D(TaylorB3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class TaylorB_XY_LinearGrowth_3D(TaylorB3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class TaylorB_X_ExponentialGrowth_3D(TaylorB3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class TaylorB_Y_ExponentialGrowth_3D(TaylorB3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class TaylorB_XY_ExponentialGrowth_3D(TaylorB3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class TaylorB_X_LinearDecayAndOffset_3D(TaylorB3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class TaylorB_Y_LinearDecayAndOffset_3D(TaylorB3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class TaylorB_XY_LinearDecayAndOffset_3D(TaylorB3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class TaylorB_X_ExponentialDecayAndOffset_3D(TaylorB3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class TaylorB_Y_ExponentialDecayAndOffset_3D(TaylorB3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class TaylorB_XY_ExponentialDecayAndOffset_3D(TaylorB3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class TaylorB_X_LinearGrowthAndOffset_3D(TaylorB3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class TaylorB_Y_LinearGrowthAndOffset_3D(TaylorB3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class TaylorB_XY_LinearGrowthAndOffset_3D(TaylorB3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class TaylorB_X_ExponentialGrowthAndOffset_3D(TaylorB3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class TaylorB_Y_ExponentialGrowthAndOffset_3D(TaylorB3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class TaylorB_XY_ExponentialGrowthAndOffset_3D(TaylorB3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()


class TaylorC3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Taylor Series C"
        self.HTML = "z = a + bx + c/y + dx<SUP>2</SUP> + e/y<SUP>2</SUP> + fx/y"
        self.coefficientDesignatorTuple = ("a", "b", "c", "d", "e", "f")
        self.LinearSSQSolverFlag = 1
        self.RequiresNonzeroY = 1 # /y

        self.function_cpp_code = 'temp = coeff[0] + coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[2] * indep_data[(int)cachedWeaveOffsets[2] + i] + coeff[3] * indep_data[(int)cachedWeaveOffsets[3] + i] + coeff[4] * indep_data[(int)cachedWeaveOffsets[4] + i] + coeff[5] * indep_data[(int)cachedWeaveOffsets[5] + i];// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_X(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_InverseY(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_PowX(NameOrValueFlag=1, args=[2.0]), [2.0]])
        self.CacheGenerationList.append([self.CG_PowY(NameOrValueFlag=1, args=[-2.0]), [-2.0]])
        self.CacheGenerationList.append([self.CG_PowXY(NameOrValueFlag=1, args=[1.0, -1.0]), [1.0, -1.0]])

    def SpecificCodeCPP(self):
        s = "\ttemp = a + b*x_in + c/y_in + d*pow(x_in, 2.0) + e/pow(y_in, 2.0) + f*x_in/y_in;\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\ttemp = a + b*x_in + c/y_in + d*Math.pow(x_in, 2.0) + e/Math.pow(y_in, 2.0) + f*x_in/y_in;\n"
        return s

    def SpecificCodeCS(self):
        s = "\ttemp = a + b*x_in + c/y_in + d*Math.Pow(x_in, 2.0) + e/Math.Pow(y_in, 2.0) + f*x_in/y_in;\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp  = a + b*x_in + c/y_in + d*math.pow(x_in, 2.0) + e/math.pow(y_in, 2.0) + f*x_in/y_in\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = a + b*x_in + c/y_in + d*(x_in ^ 2.0) + e/(y_in ^ 2.0) + f*x_in/y_in\n"
        return s

class TaylorC_X_LinearDecay_3D(TaylorC3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class TaylorC_Y_LinearDecay_3D(TaylorC3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class TaylorC_XY_LinearDecay_3D(TaylorC3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class TaylorC_X_ExponentialDecay_3D(TaylorC3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class TaylorC_Y_ExponentialDecay_3D(TaylorC3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class TaylorC_XY_ExponentialDecay_3D(TaylorC3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class TaylorC_X_LinearGrowth_3D(TaylorC3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class TaylorC_Y_LinearGrowth_3D(TaylorC3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class TaylorC_XY_LinearGrowth_3D(TaylorC3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class TaylorC_X_ExponentialGrowth_3D(TaylorC3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class TaylorC_Y_ExponentialGrowth_3D(TaylorC3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class TaylorC_XY_ExponentialGrowth_3D(TaylorC3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class TaylorC_X_LinearDecayAndOffset_3D(TaylorC3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class TaylorC_Y_LinearDecayAndOffset_3D(TaylorC3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class TaylorC_XY_LinearDecayAndOffset_3D(TaylorC3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class TaylorC_X_ExponentialDecayAndOffset_3D(TaylorC3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class TaylorC_Y_ExponentialDecayAndOffset_3D(TaylorC3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class TaylorC_XY_ExponentialDecayAndOffset_3D(TaylorC3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class TaylorC_X_LinearGrowthAndOffset_3D(TaylorC3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class TaylorC_Y_LinearGrowthAndOffset_3D(TaylorC3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class TaylorC_XY_LinearGrowthAndOffset_3D(TaylorC3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class TaylorC_X_ExponentialGrowthAndOffset_3D(TaylorC3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class TaylorC_Y_ExponentialGrowthAndOffset_3D(TaylorC3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class TaylorC_XY_ExponentialGrowthAndOffset_3D(TaylorC3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()


class TaylorD3D(pythonequations.EquationBaseClasses.Equation3D):

    def __init__(self):
        pythonequations.EquationBaseClasses.Equation3D.__init__(self)
        self.name = "Taylor Series D"
        self.HTML = "z = a + b/x + c/y + d/x<SUP>2</SUP> + e/y<SUP>2</SUP> + f/(xy)"
        self.coefficientDesignatorTuple = ("a", "b", "c", "d", "e", "f")
        self.LinearSSQSolverFlag = 1
        self.RequiresNonzeroX = 1 # /x
        self.RequiresNonzeroY = 1 # /y

        self.function_cpp_code = 'temp = coeff[0] + coeff[1] * indep_data[(int)cachedWeaveOffsets[1] + i] + coeff[2] * indep_data[(int)cachedWeaveOffsets[2] + i] + coeff[3] * indep_data[(int)cachedWeaveOffsets[3] + i] + coeff[4] * indep_data[(int)cachedWeaveOffsets[4] + i] + coeff[5] * indep_data[(int)cachedWeaveOffsets[5] + i];// ' + str(self.__class__).split(".")[len(str(self.__class__).split("."))-1]


    def CreateCacheGenerationList(self):
        self.CacheGenerationList = []
        self.CacheGenerationList.append([self.CG_Ones(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_InverseX(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_InverseY(NameOrValueFlag=1), []])
        self.CacheGenerationList.append([self.CG_PowX(NameOrValueFlag=1, args=[-2.0]), [-2.0]])
        self.CacheGenerationList.append([self.CG_PowY(NameOrValueFlag=1, args=[-2.0]), [-2.0]])
        self.CacheGenerationList.append([self.CG_PowXY(NameOrValueFlag=1, args=[-1.0, -1.0]), [-1.0, -1.0]])

    def SpecificCodeCPP(self):
        s = "\ttemp = a + b/x_in + c/y_in + d/pow(x_in, 2.0) + e/pow(y_in, 2.0) + f/(x_in*y_in);\n"
        return s

    def SpecificCodeJAVA(self):
        s = "\ttemp = a + b/x_in + c/y_in + d/Math.pow(x_in, 2.0) + e/Math.pow(y_in, 2.0) + f/(x_in*y_in);\n"
        return s

    def SpecificCodeCS(self):
        s = "\ttemp = a + b/x_in + c/y_in + d/Math.Pow(x_in, 2.0) + e/Math.Pow(y_in, 2.0) + f/(x_in*y_in);\n"
        return s

    def SpecificCodePYTHON(self):
        s = "\ttemp  = a + b/x_in + c/y_in + d/math.pow(x_in, 2.0) + e/math.pow(y_in, 2.0) + f/(x_in*y_in)\n"
        return s

    def SpecificCodeSCILAB(self):
        s = "\ttemp = a + b/x_in + c/y_in + d/(x_in ^ 2.0) + e/(y_in ^ 2.0) + f/(x_in*y_in)\n"
        return s


class TaylorD_X_LinearDecay_3D(TaylorD3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayFormsOfEquations()
class TaylorD_Y_LinearDecay_3D(TaylorD3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayFormsOfEquations()
class TaylorD_XY_LinearDecay_3D(TaylorD3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayFormsOfEquations()
class TaylorD_X_ExponentialDecay_3D(TaylorD3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayFormsOfEquations()
class TaylorD_Y_ExponentialDecay_3D(TaylorD3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayFormsOfEquations()
class TaylorD_XY_ExponentialDecay_3D(TaylorD3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayFormsOfEquations()
class TaylorD_X_LinearGrowth_3D(TaylorD3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthFormsOfEquations()
class TaylorD_Y_LinearGrowth_3D(TaylorD3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthFormsOfEquations()
class TaylorD_XY_LinearGrowth_3D(TaylorD3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthFormsOfEquations()
class TaylorD_X_ExponentialGrowth_3D(TaylorD3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthFormsOfEquations()
class TaylorD_Y_ExponentialGrowth_3D(TaylorD3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthFormsOfEquations()
class TaylorD_XY_ExponentialGrowth_3D(TaylorD3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthFormsOfEquations()
class TaylorD_X_LinearDecayAndOffset_3D(TaylorD3D):
    def __init__(self): self.InitCodeFor_X_LinearDecayAndOffsetFormsOfEquations()
class TaylorD_Y_LinearDecayAndOffset_3D(TaylorD3D):
    def __init__(self): self.InitCodeFor_Y_LinearDecayAndOffsetFormsOfEquations()
class TaylorD_XY_LinearDecayAndOffset_3D(TaylorD3D):
    def __init__(self): self.InitCodeFor_XY_LinearDecayAndOffsetFormsOfEquations()
class TaylorD_X_ExponentialDecayAndOffset_3D(TaylorD3D):
    def __init__(self): self.InitCodeFor_X_ExponentialDecayAndOffsetFormsOfEquations()
class TaylorD_Y_ExponentialDecayAndOffset_3D(TaylorD3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialDecayAndOffsetFormsOfEquations()
class TaylorD_XY_ExponentialDecayAndOffset_3D(TaylorD3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialDecayAndOffsetFormsOfEquations()
class TaylorD_X_LinearGrowthAndOffset_3D(TaylorD3D):
    def __init__(self): self.InitCodeFor_X_LinearGrowthAndOffsetFormsOfEquations()
class TaylorD_Y_LinearGrowthAndOffset_3D(TaylorD3D):
    def __init__(self): self.InitCodeFor_Y_LinearGrowthAndOffsetFormsOfEquations()
class TaylorD_XY_LinearGrowthAndOffset_3D(TaylorD3D):
    def __init__(self): self.InitCodeFor_XY_LinearGrowthAndOffsetFormsOfEquations()
class TaylorD_X_ExponentialGrowthAndOffset_3D(TaylorD3D):
    def __init__(self): self.InitCodeFor_X_ExponentialGrowthAndOffsetFormsOfEquations()
class TaylorD_Y_ExponentialGrowthAndOffset_3D(TaylorD3D):
    def __init__(self): self.InitCodeFor_Y_ExponentialGrowthAndOffsetFormsOfEquations()
class TaylorD_XY_ExponentialGrowthAndOffset_3D(TaylorD3D):
    def __init__(self): self.InitCodeFor_XY_ExponentialGrowthAndOffsetFormsOfEquations()
