#    pythonequations is a collection of equations expressed as Python classes
#    Copyright (C) 2008 James R. Phillips
#    2548 Vera Cruz Drive
#    Birmingham, AL 35235 USA
#    email: zunzun@zunzun.com
#
#    Version info: $Id$
#
#    License: BSD-style (see LICENSE.txt in main source directory)

import sys
import numpy
numpy.seterr(all = 'raise') # numpy raises warnings, convert to exceptions to trap them

class eq0:

    def __init__(self, variableName, codeName):
        self.RequiresNonzero = 0
        self.RequiresPositive = 0
        self.HTML = ''
        self.JAVA = ''
        self.CPP = ''
        self.CSHARP = ''
        self.PYTHON = ''
        self.SCILAB = ''

    def value(self, x):
        return numpy.ones_like(x)


class eq1:

    def __init__(self, variableName, codeName):
        self.RequiresNonzero = 0
        self.RequiresPositive = 0
        self.HTML = 'atan(' + variableName + ')'
        self.JAVA = 'Math.atan(' + codeName + ')'
        self.CPP = 'atan(' + codeName + ')'
        self.CSHARP = 'Math.Atan(' + codeName + ')'
        self.PYTHON = 'math.atan(' + codeName + ')'
        self.SCILAB = 'atan(' + codeName + ')'

    def value(self, x):
        try:
            return numpy.arctan(x)
            returnValue = numpy.arctan(x)
            if max(returnValue) > 1.0E300:
                return 1.0E300 * numpy.ones_like(x)
            if min(returnValue) < -1.0E300:
                return 1.0E300 * numpy.ones_like(x)
            return returnValue
        except:
            return 1.0E300 * numpy.ones_like(x)


class eq2:

    def __init__(self, variableName, codeName):
        self.RequiresNonzero = 1
        self.RequiresPositive = 0
        self.HTML = variableName + "<SUP>-1</SUP>"
        self.JAVA = 'Math.pow(' + codeName + ', -1.0)'
        self.CPP = 'pow(' + codeName + ', -1.0)'
        self.CSHARP = 'Math.Pow(' + codeName + ', -1.0)'
        self.PYTHON = 'math.pow(' + codeName + ', -1.0)'
        self.SCILAB = '(' + codeName + ' ^ -1.0)'

    def value(self, x):
        try:
            returnValue = numpy.power(x, -1.0)
            if max(returnValue) > 1.0E300:
                return 1.0E300 * numpy.ones_like(x)
            if min(returnValue) < -1.0E300:
                return 1.0E300 * numpy.ones_like(x)
            return returnValue
        except:
            return 1.0E300 * numpy.ones_like(x)


class eq3:

    def __init__(self, variableName, codeName):
        self.RequiresNonzero = 0
        self.RequiresPositive = 0
        self.HTML = 'cosh(' + variableName + ')'
        self.JAVA = 'Math.cosh(' + codeName + ')'
        self.CPP = 'cosh(' + codeName + ')'
        self.CSHARP = 'Math.Cosh(' + codeName + ')'
        self.PYTHON = 'math.cosh(' + codeName + ')'
        self.SCILAB = 'cosh(' + codeName + ')'

    def value(self, x):
        try:
            returnValue = numpy.cosh(x)
            if max(returnValue) > 1.0E300:
                return 1.0E300 * numpy.ones_like(x)
            if min(returnValue) < -1.0E300:
                return 1.0E300 * numpy.ones_like(x)
            return returnValue
        except:
            return 1.0E300 * numpy.ones_like(x)


class eq4:

    def __init__(self, variableName, codeName):
        self.RequiresNonzero = 0
        self.RequiresPositive = 1
        self.HTML = variableName + "<SUP>0.5</SUP>"
        self.JAVA = 'Math.pow(' + codeName + ', 0.5)'
        self.CPP = 'pow(' + codeName + ', 0.5)'
        self.CSHARP = 'Math.Pow(' + codeName + ', 0.5)'
        self.PYTHON = 'math.pow(' + codeName + ', 0.5)'
        self.SCILAB = '(' + codeName + ' ^ 0.5)'

    def value(self, x):
        try:
            returnValue = numpy.power(x, 0.5)
            if max(returnValue) > 1.0E300:
                return 1.0E300 * numpy.ones_like(x)
            if min(returnValue) < -1.0E300:
                return 1.0E300 * numpy.ones_like(x)
            return returnValue
        except:
            return 1.0E300 * numpy.ones_like(x)


class eq5:

    def __init__(self, variableName, codeName):
        self.RequiresNonzero = 0
        self.RequiresPositive = 0
        self.HTML = variableName
        self.JAVA = codeName
        self.CPP = codeName
        self.CSHARP = codeName
        self.PYTHON = codeName
        self.SCILAB = codeName

    def value(self, x):
        return x


class eq6:

    def __init__(self, variableName, codeName):
        self.RequiresNonzero = 0
        self.RequiresPositive = 0
        self.HTML = variableName + "<SUP>2</SUP>"
        self.JAVA = 'Math.pow(' + codeName + ', 2.0)'
        self.CPP = 'pow(' + codeName + ', 2.0)'
        self.CSHARP = 'Math.Pow(' + codeName + ', 2.0)'
        self.PYTHON = 'math.pow(' + codeName + ', 2.0)'
        self.SCILAB = '(' + codeName + ' ^ 2.0)'

    def value(self, x):
        try:
            returnValue = numpy.power(x, 2.0)
            if max(returnValue) > 1.0E300:
                return 1.0E300 * numpy.ones_like(x)
            if min(returnValue) < -1.0E300:
                return 1.0E300 * numpy.ones_like(x)
            return returnValue
        except:
            return 1.0E300 * numpy.ones_like(x)


class eq7:

    def __init__(self, variableName, codeName):
        self.RequiresNonzero = 0
        self.RequiresPositive = 1
        self.HTML = 'ln(' + variableName + ')'
        self.JAVA = 'Math.log(' + codeName + ')'
        self.CPP = 'log(' + codeName + ')'
        self.CSHARP = 'Math.Log(' + codeName + ')'
        self.PYTHON = 'math.log(' + codeName + ')'
        self.SCILAB = 'log(' + codeName + ')'

    def value(self, x):
        try:
            returnValue = numpy.log(x)
            if max(returnValue) > 1.0E300:
                return 1.0E300 * numpy.ones_like(x)
            if min(returnValue) < -1.0E300:
                return 1.0E300 * numpy.ones_like(x)
            return returnValue
        except:
            return 1.0E300 * numpy.ones_like(x)


class eq8:

    def __init__(self, variableName, codeName):
        self.RequiresNonzero = 0
        self.RequiresPositive = 0
        self.HTML = 'sinh(' + variableName + ')'
        self.JAVA = 'Math.sinh(' + codeName + ')'
        self.CPP = 'sinh(' + codeName + ')'
        self.CSHARP = 'Math.Sinh(' + codeName + ')'
        self.PYTHON = 'math.sinh(' + codeName + ')'
        self.SCILAB = 'sinh(' + codeName + ')'

    def value(self, x):
        try:
            returnValue = numpy.sinh(x)
            if max(returnValue) > 1.0E300:
                return 1.0E300 * numpy.ones_like(x)
            if min(returnValue) < -1.0E300:
                return 1.0E300 * numpy.ones_like(x)
            return returnValue
        except:
            return 1.0E300 * numpy.ones_like(x)


class eq9:

    def __init__(self, variableName, codeName):
        self.RequiresNonzero = 0
        self.RequiresPositive = 0
        self.HTML = 'e<SUP>' + variableName + '</SUP>'
        self.JAVA = 'Math.exp(' + codeName + ')'
        self.CPP = 'exp(' + codeName + ')'
        self.CSHARP = 'Math.Exp(' + codeName + ')'
        self.PYTHON = 'math.exp(' + codeName + ')'
        self.SCILAB = 'exp(' + codeName + ')'

    def value(self, x):
        try:
            returnValue = numpy.exp(x)
            if max(returnValue) > 1.0E300:
                return 1.0E300 * numpy.ones_like(x)
            if min(returnValue) < -1.0E300:
                return 1.0E300 * numpy.ones_like(x)
            return returnValue
        except:
            return 1.0E300 * numpy.ones_like(x)


class eq10:

    def __init__(self, variableName, codeName):
        self.RequiresNonzero = 0
        self.RequiresPositive = 0
        self.HTML = 'e<SUP>-' + variableName + '</SUP>'
        self.JAVA = 'Math.exp(-1.0 * ' + codeName + ')'
        self.CPP = 'exp(-1.0 * ' + codeName + ')'
        self.CSHARP = 'Math.Exp(-1.0 * ' + codeName + ')'
        self.PYTHON = 'math.exp(-1.0 * ' + codeName + ')'
        self.SCILAB = 'exp(-1.0 * ' + codeName + ')'

    def value(self, x):
        try:
            returnValue = numpy.exp(-x)
            if max(returnValue) > 1.0E300:
                return 1.0E300 * numpy.ones_like(x)
            if min(returnValue) < -1.0E300:
                return 1.0E300 * numpy.ones_like(x)
            return returnValue
        except:
            return 1.0E300 * numpy.ones_like(x)


class eq11:

    def __init__(self, variableName, codeName):
        self.RequiresNonzero = 0
        self.RequiresPositive = 0
        self.HTML = 'sin(' + variableName + ')'
        self.JAVA = 'Math.sin(' + codeName + ')'
        self.CPP = 'sin(' + codeName + ')'
        self.CSHARP = 'Math.Sin(' + codeName + ')'
        self.PYTHON = 'math.sin(' + codeName + ')'
        self.SCILAB = 'sin(' + codeName + ')'

    def value(self, x):
        try:
            returnValue = numpy.sin(x)
            if max(returnValue) > 1.0E300:
                return 1.0E300 * numpy.ones_like(x)
            if min(returnValue) < -1.0E300:
                return 1.0E300 * numpy.ones_like(x)
            return returnValue
        except:
            return 1.0E300 * numpy.ones_like(x)


class eq12:

    def __init__(self, variableName, codeName):
        self.RequiresNonzero = 0
        self.RequiresPositive = 0
        self.HTML = 'cos(' + variableName + ')'
        self.JAVA = 'Math.cos(' + codeName + ')'
        self.CPP = 'cos(' + codeName + ')'
        self.CSHARP = 'Math.Cos(' + codeName + ')'
        self.PYTHON = 'math.cos(' + codeName + ')'
        self.SCILAB = 'cos(' + codeName + ')'

    def value(self, x):
        try:
            returnValue = numpy.cos(x)
            if max(returnValue) > 1.0E300:
                return 1.0E300 * numpy.ones_like(x)
            if min(returnValue) < -1.0E300:
                return 1.0E300 * numpy.ones_like(x)
            return returnValue
        except:
            return 1.0E300 * numpy.ones_like(x)


class eq13:

    def __init__(self, variableName, codeName):
        self.RequiresNonzero = 0
        self.RequiresPositive = 0
        self.HTML = 'tan(' + variableName + ')'
        self.HTML = 'tan(' + variableName + ')'
        self.JAVA = 'Math.tan(' + codeName + ')'
        self.CPP = 'tan(' + codeName + ')'
        self.CSHARP = 'Math.Tan(' + codeName + ')'
        self.PYTHON = 'math.tan(' + codeName + ')'
        self.SCILAB = 'tan(' + codeName + ')'

    def value(self, x):
        try:
            returnValue = numpy.tan(x)
            if max(returnValue) > 1.0E300:
                return 1.0E300 * numpy.ones_like(x)
            if min(returnValue) < -1.0E300:
                return 1.0E300 * numpy.ones_like(x)
            return returnValue
        except:
            return 1.0E300 * numpy.ones_like(x)


class eq14:

    def __init__(self, variableName, codeName):
        self.RequiresNonzero = 0
        self.RequiresPositive = 0
        self.HTML = 'tanh(' + variableName + ')'
        self.HTML = 'tanh(' + variableName + ')'
        self.JAVA = 'Math.tanh(' + codeName + ')'
        self.CPP = 'tanh(' + codeName + ')'
        self.CSHARP = 'Math.Tanh(' + codeName + ')'
        self.PYTHON = 'math.tanh(' + codeName + ')'
        self.SCILAB = 'tanh(' + codeName + ')'

    def value(self, x):
        try:
            returnValue = numpy.tanh(x)
            if max(returnValue) > 1.0E300:
                return 1.0E300 * numpy.ones_like(x)
            if min(returnValue) < -1.0E300:
                return 1.0E300 * numpy.ones_like(x)
            return returnValue
        except:
            return 1.0E300 * numpy.ones_like(x)


class eq15:

    def __init__(self, variableName, codeName):
        self.RequiresNonzero = 0
        self.RequiresPositive = 1
        self.HTML = variableName + "<SUP>-0.5</SUP>"
        self.JAVA = 'Math.pow(' + codeName + ', -0.5)'
        self.CPP = 'pow(' + codeName + ', -0.5)'
        self.CSHARP = 'Math.Pow(' + codeName + ', -0.5)'
        self.PYTHON = 'math.pow(' + codeName + ', -0.5)'
        self.SCILAB = '(' + codeName + ' ^ -0.5)'

    def value(self, x):
        try:
            returnValue = numpy.power(x, -0.5)
            if max(returnValue) > 1.0E300:
                return 1.0E300 * numpy.ones_like(x)
            if min(returnValue) < -1.0E300:
                return 1.0E300 * numpy.ones_like(x)
            return returnValue
        except:
            return 1.0E300 * numpy.ones_like(x)


class eq16:

    def __init__(self, variableName, codeName):
        self.RequiresNonzero = 0
        self.RequiresPositive = 1
        self.HTML = variableName + "<SUP>-2.0</SUP>"
        self.JAVA = 'Math.pow(' + codeName + ', -2.0)'
        self.CPP = 'pow(' + codeName + ', -2.0)'
        self.CSHARP = 'Math.Pow(' + codeName + ', -2.0)'
        self.PYTHON = 'math.pow(' + codeName + ', -2.0)'
        self.SCILAB = '(' + codeName + ' ^ -2.0)'

    def value(self, x):
        try:
            returnValue = numpy.power(x, -2.0)
            if max(returnValue) > 1.0E300:
                return 1.0E300 * numpy.ones_like(x)
            if min(returnValue) < -1.0E300:
                return 1.0E300 * numpy.ones_like(x)
            return returnValue
        except:
            return 1.0E300 * numpy.ones_like(x)


class eq17:

    def __init__(self, variableName, codeName):
        self.RequiresNonzero = 0
        self.RequiresPositive = 1
        self.HTML = variableName + "<SUP>1.5</SUP>"
        self.JAVA = 'Math.pow(' + codeName + ', 1.5)'
        self.CPP = 'pow(' + codeName + ', 1.5)'
        self.CSHARP = 'Math.Pow(' + codeName + ', 1.5)'
        self.PYTHON = 'math.pow(' + codeName + ', 1.5)'
        self.SCILAB = '(' + codeName + ' ^ 1.5)'

    def value(self, x):
        try:
            returnValue = numpy.power(x, 1.5)
            if max(returnValue) > 1.0E300:
                return 1.0E300 * numpy.ones_like(x)
            if min(returnValue) < -1.0E300:
                return 1.0E300 * numpy.ones_like(x)
            return returnValue
        except:
            return 1.0E300 * numpy.ones_like(x)



class eq18:

    def __init__(self, variableName, codeName):
        self.RequiresNonzero = 0
        self.RequiresPositive = 1
        self.HTML = variableName + "<SUP>-1.5</SUP>"
        self.JAVA = 'Math.pow(' + codeName + ', -1.5)'
        self.CPP = 'pow(' + codeName + ', -1.5)'
        self.CSHARP = 'Math.Pow(' + codeName + ', -1.5)'
        self.PYTHON = 'math.pow(' + codeName + ', -1.5)'
        self.SCILAB = '(' + codeName + ' ^ -1.5)'

    def value(self, x):
        try:
            returnValue = numpy.power(x, -1.5)
            if max(returnValue) > 1.0E300:
                return 1.0E300 * numpy.ones_like(x)
            if min(returnValue) < -1.0E300:
                return 1.0E300 * numpy.ones_like(x)
            return returnValue
        except:
            return 1.0E300 * numpy.ones_like(x)




# variableName here could be x or y
def GenerateList(variableName, codeName):
    EquationList = []
    EquationList.append(eq0(variableName, codeName))
    EquationList.append(eq1(variableName, codeName))
    EquationList.append(eq2(variableName, codeName))
    EquationList.append(eq3(variableName, codeName))
    EquationList.append(eq4(variableName, codeName))
    EquationList.append(eq5(variableName, codeName))
    EquationList.append(eq6(variableName, codeName))
    EquationList.append(eq7(variableName, codeName))
    EquationList.append(eq8(variableName, codeName))
    EquationList.append(eq9(variableName, codeName))
    EquationList.append(eq10(variableName, codeName))
    EquationList.append(eq11(variableName, codeName))
    EquationList.append(eq12(variableName, codeName))
    EquationList.append(eq13(variableName, codeName))
    EquationList.append(eq14(variableName, codeName))
    EquationList.append(eq15(variableName, codeName))
    EquationList.append(eq16(variableName, codeName))
    EquationList.append(eq17(variableName, codeName))
    EquationList.append(eq18(variableName, codeName))
    return EquationList

