#! /usr/bin/python
#    Version info: $Id: FitAllEquations3D.py 9 2008-06-27 00:29:42Z zunzun.com $

# the pythonequations base is located up one directory from the top-level examples
# directory, go up one directory in the path from there for the import to work properly
from __future__ import generators
import sys, os, inspect
if os.path.join(sys.path[0][:sys.path[0].rfind(os.sep)], '../..') not in sys.path:
    sys.path.append(os.path.join(sys.path[0][:sys.path[0].rfind(os.sep)], '../..'))
import pythonequations


# helper function
def SetParametersAndFit(equation, resultList):
    try:
        equation.Initialize()

        # check for number of coefficients > number of data points to be fitted
        if len(equation.coefficientDesignatorTuple) > len(equation.IndependentDataArray[0]):
            return

        # check for functions requiring nonzero data such as 1/x
        if equation.RequiresNonzeroX == 1 and equation.IndependentData1ContainsZeroFlag == 1:
            return
        if equation.RequiresNonzeroY == 1 and equation.IndependentData2ContainsZeroFlag == 1:
            return

        # check for functions requiring positive data such as log() and ln()
        if equation.RequiresPositiveX == 1 and (equation.IndependentData1ContainsZeroFlag or equation.IndependentData1ContainsNegativeFlag ):
            return
        if equation.RequiresPositiveY == 1 and (equation.IndependentData2ContainsZeroFlag or equation.IndependentData2ContainsNegativeFlag ):
            return

        equation.SetGAParametersAndGuessInitialCoefficientsIfNeeded()
        equation.FitToCacheData()

        t0 = equation.__class__.__name__
        t1 = equation.name
        t2 = equation.CalculateFittingTarget(equation.coefficientArray)
        if t2 > 1.0E290: #skip equations yielding very large errors
            return

        t3 = equation.xPolynomialOrder
        t4 = equation.yPolynomialOrder
        t5 = equation.Polyfun3DFlags
        t6 = equation.coefficientArray

        resultList += ([t0,t1,t2,t3,t4,t5,t6]),

    except:
        print "Exception in " + equation.name + '\n' + str(sys.exc_info()[0]) + '\n' + str(sys.exc_info()[1]) + '\n'


# helper function
def ResultListSortFunction(a, b):
    if a[2] < b[2]:
        return -1
    if a[2] > b[2]:
        return 1
    return 0


# helper function
def UniqueCombinations(items, n):
    if n==0:
        yield []
    else:
        for i in xrange(len(items)):
            for cc in UniqueCombinations(items[i+1:],n-1):
                yield [items[i]]+cc




# this example yields a sorted output list to inspect after completion
resultList = []

# Standard lowest sum-of-squared errors
fittingTarget = 'SSQABS'

# we are using the same data set repeatedly, so create a cache external to the equations
externalCacheDict = {}

for submodule in inspect.getmembers(pythonequations.Equations3D):
    if True == inspect.ismodule(submodule[1]):
        for equationClass in inspect.getmembers(submodule[1]):
            if True == inspect.isclass(equationClass[1]):

                    equation = equationClass[1]()
                    if equation.name[:5] != 'Roman':
                        continue

                    print 'Fitting', equation.name, `equation.dimensionality` + "D"

                    equation.cacheDict = externalCacheDict # reuse the cache
                    equation.fittingTarget = fittingTarget # see the Equation base class for a list of fitting targets

                    # we only need to convert text to data once and before the first
                    # equation is fitted, the cache is empty - use this as a flag
                    if externalCacheDict == {}:
                        equation.ConvertTextToData(equation.exampleData) # Equations have ASCII text data for testing and examples
                        DependentDataContainsZeroFlag = equation.DependentDataContainsZeroFlag
                        IndependentData1ContainsZeroFlag = equation.IndependentData1ContainsZeroFlag
                        IndependentData1ContainsPositiveFlag = equation.IndependentData1ContainsPositiveFlag
                        IndependentData1ContainsNegativeFlag = equation.IndependentData1ContainsNegativeFlag
                        IndependentData2ContainsZeroFlag = equation.IndependentData2ContainsZeroFlag
                        IndependentData2ContainsPositiveFlag = equation.IndependentData2ContainsPositiveFlag
                        IndependentData2ContainsNegativeFlag = equation.IndependentData2ContainsNegativeFlag
                        IndependentDataArray = equation.IndependentDataArray
                        DependentDataArray = equation.DependentDataArray
                    else:
                        equation.DependentDataContainsZeroFlag = DependentDataContainsZeroFlag
                        equation.IndependentData1ContainsZeroFlag = IndependentData1ContainsZeroFlag
                        equation.IndependentData1ContainsPositiveFlag = IndependentData1ContainsPositiveFlag
                        equation.IndependentData1ContainsNegativeFlag = IndependentData1ContainsNegativeFlag
                        equation.IndependentData2ContainsZeroFlag = IndependentData2ContainsZeroFlag
                        equation.IndependentData2ContainsPositiveFlag = IndependentData2ContainsPositiveFlag
                        equation.IndependentData2ContainsNegativeFlag = IndependentData2ContainsNegativeFlag
                        equation.IndependentDataArray = IndependentDataArray
                        equation.DependentDataArray = DependentDataArray

                    SetParametersAndFit(equation, resultList)
                    print equation.CalculateFittingTarget(equation.coefficientArray)
