#    pythonequations is a collection of equations expressed as Python classes
#    Copyright (C) 2008 James R. Phillips
#    2548 Vera Cruz Drive
#    Birmingham, AL 35235 USA
#    email: zunzun@zunzun.com
#
#    Version info: $Id$
#
#    License: BSD-style (see LICENSE.txt in main source directory)

import ExtraCodeForEquationBaseClasses, EquationBaseClasses, EquationsForPolyfunctionals, Equations2D, Equations3D
import os, inspect

svnRevisionNumber = '102'
speedupFileNamePrefix = 'speedup_importing'
speedupImportFileName = speedupFileNamePrefix + '_' + svnRevisionNumber + '.py'


# remove old "speedup importing" files before attempting to make new file
allFilesInDir = os.listdir(os.path.dirname(__file__))
for fileName in allFilesInDir:
    if fileName.startswith(speedupFileNamePrefix) and fileName != speedupImportFileName:
        # user may not have rights to delete file
        try:
            os.remove(os.path.join(os.path.dirname(__file__), fileName))
        except:
            pass

filePath = os.path.join(os.path.dirname(__file__), speedupImportFileName)
if (os.path.exists(filePath)):
    exec('import ' + speedupImportFileName[:-3])
    equationCount = 0
    for submodule in inspect.getmembers(Equations2D) + inspect.getmembers(Equations3D):
        if True == inspect.ismodule(submodule[1]):
            for equationClass in inspect.getmembers(submodule[1]):
                if True == inspect.isclass(equationClass[1]):
                    equationClass[1].equationIndex = equationCount # give each equation class a unique identifying index matching the below function code
                    equationCount += 1
    exec('ExtraCodeForEquationBaseClasses.cppCodeForEvaluate = ' + speedupImportFileName[:-3] + '.cppCodeForEvaluate')
    exec('ExtraCodeForEquationBaseClasses.cppCodeForGA = ' + speedupImportFileName[:-3] + '.cppCodeForGA')
else:
    # to allocate C++ function array, first count the total number of equations
    equationCount = 0
    for submodule in inspect.getmembers(Equations2D) + inspect.getmembers(Equations3D):
        if True == inspect.ismodule(submodule[1]):
            for equationClass in inspect.getmembers(submodule[1]):
                if True == inspect.isclass(equationClass[1]):
                    equationCount += 1


    # two code fragments will be generated, one for evaluating and one for Genetic Algorithm (GA) use

    ExtraCodeForEquationBaseClasses.cppCodeForEvaluate = '''
    double temp, temp_x_sq, temp_y_sq, s_sq, s_over_r, s_sq_b, s_over_r_b;
    int i, k;
    int functionArrayInitializedFlag = 0;

    void (*functionArray[''' + str(equationCount) + '''])(int, int, int*, double*, double*, double*) = {NULL};
    '''

    ExtraCodeForEquationBaseClasses.cppCodeForGA = '''
    double temp, temp_x_sq, temp_y_sq, s_sq, s_over_r, s_sq_b, s_over_r_b, summation;
    int i, k;
    int functionArrayInitializedFlag = 0;

    double (*functionArray[''' + str(equationCount) + '''])(int, int, int*, double*, double*, double*) = {NULL};
    '''

    cppCodeForFunctionPointerArrayInitialization = '''
    void initializeFunctionPointerArray()
    {
        if (0 != functionArrayInitializedFlag)
        {
            return;
        }
        functionArrayInitializedFlag = 1;
        
    '''


    # make functions and place addresses into function pointer array
    equationCount = 0
    for submodule in inspect.getmembers(Equations2D) + inspect.getmembers(Equations3D):
        if True == inspect.ismodule(submodule[1]):
            for equationClass in inspect.getmembers(submodule[1]):
                if True == inspect.isclass(equationClass[1]):
                    
                    equationClass[1].equationIndex = equationCount # give each equation class a unique identifying index matching the below function code
                    
                    equation = equationClass[1]() # need to make an instance so the extended forms can auto-generate themselves properly

                    ExtraCodeForEquationBaseClasses.cppCodeForEvaluate += '''
    void function_''' + str(equationCount) + '''(int numberOfDataPoints, int numberOfCoefficients, int* cachedWeaveOffsets, double* coeff, double* indep_data, double* resultArray)
    {
        for (i=0; i < numberOfDataPoints; i++)
        {
            try
            {
                errno = 0;
                ''' + equation.function_cpp_code + '''
                if (errno)
                {
                    temp = 1.0E300;
                }
    #ifdef __GNUC__
                if (!(__fpclassify (temp) & (FP_ZERO | FP_NORMAL))) // need a normal double
                {
                    temp = 1.0E300;
                }
    #endif
            }
            catch(...)
            {
                temp = 1.0E300;
            }
            resultArray[i] = temp;
        }
    }

    '''

                    ExtraCodeForEquationBaseClasses.cppCodeForGA += '''
    double function_''' + str(equationCount) + '''(int numberOfDataPoints, int numberOfCoefficients, int* cachedWeaveOffsets, double* coeff, double* indep_data, double* dep_data)
    {
        summation = 0.0;
        for(i=0; i<numberOfDataPoints; i++)
        {
            try
            {
               errno = 0;
               ''' + equation.function_cpp_code + '''
               if (errno)
               {
                   summation = 1.0E300;
                   break;
               }
    #ifdef __GNUC__
               if (!(__fpclassify (temp) & (FP_ZERO | FP_NORMAL))) // need a normal double
               {
                   summation = 1.0E300;
                   break;
               }
    #endif
               temp = temp - dep_data[i]; // absolute error always needed
               summation += temp * temp;
            }
            catch(...)
            {
                summation = 1.0E300;
                break;
            }
        }
        return summation;
    }

    '''

                    cppCodeForFunctionPointerArrayInitialization += '''
        functionArray[''' + str(equationCount) + '''] = &function_''' + str(equationCount) + ''';
    '''

                    equationCount += 1

    ExtraCodeForEquationBaseClasses.cppCodeForEvaluate += cppCodeForFunctionPointerArrayInitialization + '''
    }
    '''
    ExtraCodeForEquationBaseClasses.cppCodeForGA += cppCodeForFunctionPointerArrayInitialization + '''
    }
    '''
    
    # user may not have write priviliges to this directory, wrap in try/except block
    try:
        f = open(filePath, 'w')
        f.write('cppCodeForEvaluate = \'\'\'' + ExtraCodeForEquationBaseClasses.cppCodeForEvaluate + '\'\'\'\n\ncppCodeForGA = \'\'\'' + ExtraCodeForEquationBaseClasses.cppCodeForGA + '\'\'\'\n')
        f.close()
    except:
        pass
